#include "monty.h"
#include "fusion_p.h"

template<typename T> struct _checked_ptr_1
{
  T * ptr;
  size_t sz;
  _checked_ptr_1<T>(T * ptr, size_t sz) : ptr(ptr), sz(sz) {}
  T & operator[](ptrdiff_t i) { assert(i >= 0 && i < sz); return ptr[i]; }
  const T & operator[](ptrdiff_t i) const { assert(i >= 0 && i < sz); return ptr[i]; }
  void update(T * ptr_, size_t sz_) { ptr = ptr_; sz = sz_; }
};

template<typename T> struct _checked_ptr_2
{
  T * ptr;
  size_t sz0, sz1;
  _checked_ptr_2<T>(T * ptr, size_t sz0, size_t sz1) : ptr(ptr), sz0(sz0),sz1(sz1) {}
  T & operator()(ptrdiff_t i0, ptrdiff_t i1) { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; }
  const T & operator()(ptrdiff_t i0, ptrdiff_t i1) const { assert(i0 >= 0 && i0 < sz0 && i1 >= 0 && i1 < sz1); return ptr[i0 * sz1 + i1]; }
  void update(T * ptr_, size_t sz0_, size_t sz1_) { ptr = ptr_; sz0 = sz0_; sz1 = sz1_; }
};

// See http://www.cplusplus.com/articles/DE18T05o/
//                 A      && ( (       B      && B1 && B2      ) || (      C      &&   C1 &&   C2  ) )
// A a and b a have different signs
// B, B1, B2 a and b are both non-negative, r is less than both a and b
// C, C1, C2 a and b are both negative, r is greater than both a and b

struct InternalNumericOverflow {};

template<typename T>
static inline T checked_add(T a, T b, bool & overflow) {
  int r = a+b;
  overflow = ((a ^ b) >= 0) && ( (( (a & b) >= 0) && r < a && r < b) || ( ((a & b) < 0) && a < r && b < r) );
  return r;
}

template<typename T>
static inline T safe_add_(T a, T b) {
  bool overflow;
  T r = checked_add(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_add(int a, int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(int a, long long int b) { return safe_add_<long long int>(a,b); }
static inline long long int safe_add(long long int a, int b) { return safe_add_<long long int>(a,b); }

template<typename T>
static inline T checked_mul(T a, T b, bool & overflow) {
  T r = a * b;
  overflow = b != 0 && (((a ^ b) >= 0 && a > std::numeric_limits<T>::max() / b) || ((a ^ b) < 0 && a < std::numeric_limits<T>::min() / b));
  return r;
}

template<typename T>
static inline T safe_mul_(T a, T b) {
  bool overflow;
  T r = checked_mul(a,b,overflow);
  if (overflow)
    throw InternalNumericOverflow();
  else
    return r;
}

static inline           int safe_mul(int a, int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(int a, long long int b) { return safe_mul_<long long int>(a,b); }
static inline long long int safe_mul(long long int a, int b) { return safe_mul_<long long int>(a,b); }

std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::StatusKey val){switch (val){case StatusKey::Unknown: os << "StatusKey::Unknown"; break;case StatusKey::Basic: os << "StatusKey::Basic"; break;case StatusKey::SuperBasic: os << "StatusKey::SuperBasic"; break;case StatusKey::OnBound: os << "StatusKey::OnBound"; break;case StatusKey::Infinity: os << "StatusKey::Infinity"; break;default: os << "StatusKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionType val){switch (val){case SolutionType::Default: os << "SolutionType::Default"; break;case SolutionType::Basic: os << "SolutionType::Basic"; break;case SolutionType::Interior: os << "SolutionType::Interior"; break;case SolutionType::Integer: os << "SolutionType::Integer"; break;default: os << "SolutionType.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ProblemStatus val){switch (val){case ProblemStatus::Unknown: os << "ProblemStatus::Unknown"; break;case ProblemStatus::PrimalAndDualFeasible: os << "ProblemStatus::PrimalAndDualFeasible"; break;case ProblemStatus::PrimalFeasible: os << "ProblemStatus::PrimalFeasible"; break;case ProblemStatus::DualFeasible: os << "ProblemStatus::DualFeasible"; break;case ProblemStatus::PrimalInfeasible: os << "ProblemStatus::PrimalInfeasible"; break;case ProblemStatus::DualInfeasible: os << "ProblemStatus::DualInfeasible"; break;case ProblemStatus::PrimalAndDualInfeasible: os << "ProblemStatus::PrimalAndDualInfeasible"; break;case ProblemStatus::IllPosed: os << "ProblemStatus::IllPosed"; break;case ProblemStatus::PrimalInfeasibleOrUnbounded: os << "ProblemStatus::PrimalInfeasibleOrUnbounded"; break;default: os << "ProblemStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::AccSolutionStatus val){switch (val){case AccSolutionStatus::Anything: os << "AccSolutionStatus::Anything"; break;case AccSolutionStatus::Optimal: os << "AccSolutionStatus::Optimal"; break;case AccSolutionStatus::Feasible: os << "AccSolutionStatus::Feasible"; break;case AccSolutionStatus::Certificate: os << "AccSolutionStatus::Certificate"; break;default: os << "AccSolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::SolutionStatus val){switch (val){case SolutionStatus::Undefined: os << "SolutionStatus::Undefined"; break;case SolutionStatus::Unknown: os << "SolutionStatus::Unknown"; break;case SolutionStatus::Optimal: os << "SolutionStatus::Optimal"; break;case SolutionStatus::Feasible: os << "SolutionStatus::Feasible"; break;case SolutionStatus::Certificate: os << "SolutionStatus::Certificate"; break;case SolutionStatus::IllposedCert: os << "SolutionStatus::IllposedCert"; break;default: os << "SolutionStatus.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::ObjectiveSense val){switch (val){case ObjectiveSense::Undefined: os << "ObjectiveSense::Undefined"; break;case ObjectiveSense::Minimize: os << "ObjectiveSense::Minimize"; break;case ObjectiveSense::Maximize: os << "ObjectiveSense::Maximize"; break;default: os << "ObjectiveSense.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::QConeKey val){switch (val){case QConeKey::InQCone: os << "QConeKey::InQCone"; break;case QConeKey::InRotatedQCone: os << "QConeKey::InRotatedQCone"; break;case QConeKey::InPExpCone: os << "QConeKey::InPExpCone"; break;case QConeKey::InPPowCone: os << "QConeKey::InPPowCone"; break;case QConeKey::InDExpCone: os << "QConeKey::InDExpCone"; break;case QConeKey::InDPowCone: os << "QConeKey::InDPowCone"; break;default: os << "QConeKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::PSDKey val){switch (val){case PSDKey::IsSymPSD: os << "PSDKey::IsSymPSD"; break;case PSDKey::IsTrilPSD: os << "PSDKey::IsTrilPSD"; break;default: os << "PSDKey.<invalid>"; break;}return os;}std::ostream & mosek::fusion::operator<<(std::ostream & os,mosek::fusion::RelationKey val){switch (val){case RelationKey::EqualsTo: os << "RelationKey::EqualsTo"; break;case RelationKey::LessThan: os << "RelationKey::LessThan"; break;case RelationKey::GreaterThan: os << "RelationKey::GreaterThan"; break;case RelationKey::IsFree: os << "RelationKey::IsFree"; break;case RelationKey::InRange: os << "RelationKey::InRange"; break;default: os << "RelationKey.<invalid>"; break;}return os;}mosek::fusion::Sort::Sort(mosek::fusion::p_Sort *_impl) : _impl(_impl) { /*std::cout << "Sort() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Sort::~Sort() { delete _impl; _impl = nullptr; }mosek::fusion::p_Sort::p_Sort  (::mosek::fusion::Sort * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Sort::argTransposeSort  ( std::shared_ptr< monty::ndarray< long long,1 > > _157,    std::shared_ptr< monty::ndarray< long long,1 > > _158,    int _159,    int _160,    int _161,    std::shared_ptr< monty::ndarray< long long,1 > > _162) { mosek::fusion::p_Sort::argTransposeSort(_157,_158,_159,_160,_161,_162); }void mosek::fusion::p_Sort::argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _157,std::shared_ptr< monty::ndarray< long long,1 > > _158,int _159,int _160,int _161,std::shared_ptr< monty::ndarray< long long,1 > > _162){
  _checked_ptr_1<long long> _ptr__157(_157 ? _157->raw() : nullptr, _157 ? _157->size(0) : 0);
  _checked_ptr_1<long long> _ptr__158(_158 ? _158->raw() : nullptr, _158 ? _158->size(0) : 0);
  _checked_ptr_1<long long> _ptr__162(_162 ? _162->raw() : nullptr, _162 ? _162->size(0) : 0);
  int _8621 = (int)0;
  int _8622 = safe_add( safe_mul( _159,_161 ),(int)1 );
  for (int _163 = _8621; _163 < _8622; ++_163)
  {
    {
      _ptr__158[_163] = (int)0;
    }
  }
  int _8623 = (int)0;
  int _8624 = (int)((_162)->size(0));
  for (int _164 = _8623; _164 < _8624; ++_164)
  {
    {
      ++ _ptr__158[safe_add( safe_add( safe_mul( (_ptr__162[_ptr__157[_164]] / safe_mul( _160,_161 )),_161 ),(_ptr__162[_ptr__157[_164]] % _161) ),(int)1 )];
    }
  }
  int _8625 = (int)0;
  int _8626 = safe_mul( _159,_161 );
  for (int _165 = _8625; _165 < _8626; ++_165)
  {
    {
      _ptr__158[safe_add( _165,(int)1 )] = safe_add( _ptr__158[safe_add( _165,(int)1 )],_ptr__158[_165] );
    }
  }
  std::vector<long long> _8627;
  for (int _167 = (int)0, _8628 = (int)((_157)->size(0)); _167 < _8628 ; ++_167)
  {
    _8627.push_back(_ptr__157[_167]);
  }
  auto _8629 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8627.size()),_8627.begin(),_8627.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _166 = _8629;
  _checked_ptr_1<long long> _ptr__166(_166 ? _166->raw() : nullptr,_166 ? _166->size(0) : 0);
  long long _8630 = (long long)0;
  long long _8631 = (long long)((_162)->size(0));
  for (long long _168 = _8630; _168 < _8631; ++_168)
  {
    {
      long long _169 = safe_add( safe_mul( (_ptr__162[_ptr__166[_168]] / safe_mul( _160,_161 )),_161 ),(_ptr__162[_ptr__166[_168]] % _161) );
      _ptr__157[_ptr__158[_169]] = _ptr__166[_168];
      ++ _ptr__158[_169];
    }
  }
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _170,    std::shared_ptr< monty::ndarray< long long,1 > > _171) { mosek::fusion::p_Sort::argsort(_170,_171); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _170,std::shared_ptr< monty::ndarray< long long,1 > > _171){
  _checked_ptr_1<long long> _ptr__170(_170 ? _170->raw() : nullptr, _170 ? _170->size(0) : 0);
  _checked_ptr_1<long long> _ptr__171(_171 ? _171->raw() : nullptr, _171 ? _171->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_170,_171,(long long)((int)0),(long long)((int)((_170)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _172,    std::shared_ptr< monty::ndarray< int,1 > > _173) { mosek::fusion::p_Sort::argsort(_172,_173); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173){
  _checked_ptr_1<long long> _ptr__172(_172 ? _172->raw() : nullptr, _172 ? _172->size(0) : 0);
  _checked_ptr_1<int> _ptr__173(_173 ? _173->raw() : nullptr, _173 ? _173->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_172,_173,(long long)((int)0),(long long)((int)((_172)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _174,    std::shared_ptr< monty::ndarray< long long,1 > > _175,    std::shared_ptr< monty::ndarray< long long,1 > > _176) { mosek::fusion::p_Sort::argsort(_174,_175,_176); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,std::shared_ptr< monty::ndarray< long long,1 > > _176){
  _checked_ptr_1<long long> _ptr__174(_174 ? _174->raw() : nullptr, _174 ? _174->size(0) : 0);
  _checked_ptr_1<long long> _ptr__175(_175 ? _175->raw() : nullptr, _175 ? _175->size(0) : 0);
  _checked_ptr_1<long long> _ptr__176(_176 ? _176->raw() : nullptr, _176 ? _176->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_174,_175,_176,(long long)((int)0),(long long)((int)((_174)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _177,    std::shared_ptr< monty::ndarray< int,1 > > _178,    std::shared_ptr< monty::ndarray< int,1 > > _179) { mosek::fusion::p_Sort::argsort(_177,_178,_179); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _177,std::shared_ptr< monty::ndarray< int,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179){
  _checked_ptr_1<long long> _ptr__177(_177 ? _177->raw() : nullptr, _177 ? _177->size(0) : 0);
  _checked_ptr_1<int> _ptr__178(_178 ? _178->raw() : nullptr, _178 ? _178->size(0) : 0);
  _checked_ptr_1<int> _ptr__179(_179 ? _179->raw() : nullptr, _179 ? _179->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_177,_178,_179,(long long)((int)0),(long long)((int)((_177)->size(0))),false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _180,    std::shared_ptr< monty::ndarray< long long,1 > > _181,    long long _182,    long long _183) { mosek::fusion::p_Sort::argsort(_180,_181,_182,_183); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _180,std::shared_ptr< monty::ndarray< long long,1 > > _181,long long _182,long long _183){
  _checked_ptr_1<long long> _ptr__180(_180 ? _180->raw() : nullptr, _180 ? _180->size(0) : 0);
  _checked_ptr_1<long long> _ptr__181(_181 ? _181->raw() : nullptr, _181 ? _181->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_180,_181,_182,_183,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _184,    std::shared_ptr< monty::ndarray< int,1 > > _185,    long long _186,    long long _187) { mosek::fusion::p_Sort::argsort(_184,_185,_186,_187); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _184,std::shared_ptr< monty::ndarray< int,1 > > _185,long long _186,long long _187){
  _checked_ptr_1<long long> _ptr__184(_184 ? _184->raw() : nullptr, _184 ? _184->size(0) : 0);
  _checked_ptr_1<int> _ptr__185(_185 ? _185->raw() : nullptr, _185 ? _185->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_184,_185,_186,_187,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _188,    std::shared_ptr< monty::ndarray< long long,1 > > _189,    std::shared_ptr< monty::ndarray< long long,1 > > _190,    long long _191,    long long _192) { mosek::fusion::p_Sort::argsort(_188,_189,_190,_191,_192); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _188,std::shared_ptr< monty::ndarray< long long,1 > > _189,std::shared_ptr< monty::ndarray< long long,1 > > _190,long long _191,long long _192){
  _checked_ptr_1<long long> _ptr__188(_188 ? _188->raw() : nullptr, _188 ? _188->size(0) : 0);
  _checked_ptr_1<long long> _ptr__189(_189 ? _189->raw() : nullptr, _189 ? _189->size(0) : 0);
  _checked_ptr_1<long long> _ptr__190(_190 ? _190->raw() : nullptr, _190 ? _190->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_188,_189,_190,_191,_192,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _193,    std::shared_ptr< monty::ndarray< int,1 > > _194,    std::shared_ptr< monty::ndarray< int,1 > > _195,    long long _196,    long long _197) { mosek::fusion::p_Sort::argsort(_193,_194,_195,_196,_197); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _193,std::shared_ptr< monty::ndarray< int,1 > > _194,std::shared_ptr< monty::ndarray< int,1 > > _195,long long _196,long long _197){
  _checked_ptr_1<long long> _ptr__193(_193 ? _193->raw() : nullptr, _193 ? _193->size(0) : 0);
  _checked_ptr_1<int> _ptr__194(_194 ? _194->raw() : nullptr, _194 ? _194->size(0) : 0);
  _checked_ptr_1<int> _ptr__195(_195 ? _195->raw() : nullptr, _195 ? _195->size(0) : 0);
  ::mosek::fusion::p_Sort::argsort(_193,_194,_195,_196,_197,false);
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _198,    std::shared_ptr< monty::ndarray< long long,1 > > _199,    long long _200,    long long _201,    bool _202) { mosek::fusion::p_Sort::argsort(_198,_199,_200,_201,_202); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _198,std::shared_ptr< monty::ndarray< long long,1 > > _199,long long _200,long long _201,bool _202){
  _checked_ptr_1<long long> _ptr__198(_198 ? _198->raw() : nullptr, _198 ? _198->size(0) : 0);
  _checked_ptr_1<long long> _ptr__199(_199 ? _199->raw() : nullptr, _199 ? _199->size(0) : 0);
  if (((!_202) || ((_201 - _200) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_198,_199,_200,_201);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_198,_199,_200,_201,_202)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _203 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__203(_203 ? _203->raw() : nullptr,_203 ? _203->size(0) : 0);
      int _204 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_198,_199,nullptr,_200,_201,_203);
      if (((_ptr__203[(int)1] - _ptr__203[(int)0]) < safe_mul( _204,(_201 - _200) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_198,_199,_200,_201,_ptr__203[(int)0],_ptr__203[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_198,_199,_200,_201);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _205,    std::shared_ptr< monty::ndarray< int,1 > > _206,    long long _207,    long long _208,    bool _209) { mosek::fusion::p_Sort::argsort(_205,_206,_207,_208,_209); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _205,std::shared_ptr< monty::ndarray< int,1 > > _206,long long _207,long long _208,bool _209){
  _checked_ptr_1<long long> _ptr__205(_205 ? _205->raw() : nullptr, _205 ? _205->size(0) : 0);
  _checked_ptr_1<int> _ptr__206(_206 ? _206->raw() : nullptr, _206 ? _206->size(0) : 0);
  if (((!_209) || ((_208 - _207) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_205,_206,_207,_208);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_205,_206,_207,_208,_209)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _210 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__210(_210 ? _210->raw() : nullptr,_210 ? _210->size(0) : 0);
      int _211 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_205,_206,nullptr,_207,_208,_210);
      if (((_ptr__210[(int)1] - _ptr__210[(int)0]) < safe_mul( _211,(_208 - _207) )))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_205,_206,_207,_208,_ptr__210[(int)0],_ptr__210[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_205,_206,_207,_208);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _212,    std::shared_ptr< monty::ndarray< long long,1 > > _213,    std::shared_ptr< monty::ndarray< long long,1 > > _214,    long long _215,    long long _216,    bool _217) { mosek::fusion::p_Sort::argsort(_212,_213,_214,_215,_216,_217); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _212,std::shared_ptr< monty::ndarray< long long,1 > > _213,std::shared_ptr< monty::ndarray< long long,1 > > _214,long long _215,long long _216,bool _217){
  _checked_ptr_1<long long> _ptr__212(_212 ? _212->raw() : nullptr, _212 ? _212->size(0) : 0);
  _checked_ptr_1<long long> _ptr__213(_213 ? _213->raw() : nullptr, _213 ? _213->size(0) : 0);
  _checked_ptr_1<long long> _ptr__214(_214 ? _214->raw() : nullptr, _214 ? _214->size(0) : 0);
  if (((!_217) || ((_216 - _215) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_212,_213,_214,_215,_216);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_212,_213,_214,_215,_216,_217)))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _218 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)4)));
      _checked_ptr_1<long long> _ptr__218(_218 ? _218->raw() : nullptr,_218 ? _218->size(0) : 0);
      int _219 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_212,_213,_214,_215,_216,_218);
      if ((((_ptr__218[(int)1] - _ptr__218[(int)0]) < safe_mul( _219,(_216 - _215) )) && ((_ptr__218[(int)3] - _ptr__218[(int)2]) < safe_mul( _219,(_216 - _215) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_212,_214,_215,_216,_ptr__218[(int)2],_ptr__218[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_212,_213,_215,_216,_ptr__218[(int)0],_ptr__218[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_212,_213,_214,_215,_216);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _220,    std::shared_ptr< monty::ndarray< int,1 > > _221,    std::shared_ptr< monty::ndarray< int,1 > > _222,    long long _223,    long long _224,    bool _225) { mosek::fusion::p_Sort::argsort(_220,_221,_222,_223,_224,_225); }void mosek::fusion::p_Sort::argsort(std::shared_ptr< monty::ndarray< long long,1 > > _220,std::shared_ptr< monty::ndarray< int,1 > > _221,std::shared_ptr< monty::ndarray< int,1 > > _222,long long _223,long long _224,bool _225){
  _checked_ptr_1<long long> _ptr__220(_220 ? _220->raw() : nullptr, _220 ? _220->size(0) : 0);
  _checked_ptr_1<int> _ptr__221(_221 ? _221->raw() : nullptr, _221 ? _221->size(0) : 0);
  _checked_ptr_1<int> _ptr__222(_222 ? _222->raw() : nullptr, _222 ? _222->size(0) : 0);
  if (((!_225) || ((_224 - _223) < (int)16)))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_220,_221,_222,_223,_224);
    }
  }
  else if((!::mosek::fusion::p_Sort::issorted(_220,_221,_222,_223,_224,_225)))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _226 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)4)));
      _checked_ptr_1<int> _ptr__226(_226 ? _226->raw() : nullptr,_226 ? _226->size(0) : 0);
      int _227 = (int)2;
      ::mosek::fusion::p_Sort::getminmax(_220,_221,_222,_223,_224,_226);
      if ((((_ptr__226[(int)1] - _ptr__226[(int)0]) < safe_mul( _227,(_224 - _223) )) && ((_ptr__226[(int)3] - _ptr__226[(int)2]) < safe_mul( _227,(_224 - _223) ))))
      {
        {
          ::mosek::fusion::p_Sort::argbucketsort(_220,_222,_223,_224,_ptr__226[(int)2],_ptr__226[(int)3]);
          ::mosek::fusion::p_Sort::argbucketsort(_220,_221,_223,_224,_ptr__226[(int)0],_ptr__226[(int)1]);
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::argsort(_220,_221,_222,_223,_224);
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _228,    std::shared_ptr< monty::ndarray< long long,1 > > _229,    long long _230,    long long _231,    long long _232,    long long _233) { mosek::fusion::p_Sort::argbucketsort(_228,_229,_230,_231,_232,_233); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< long long,1 > > _229,long long _230,long long _231,long long _232,long long _233){
  _checked_ptr_1<long long> _ptr__228(_228 ? _228->raw() : nullptr, _228 ? _228->size(0) : 0);
  _checked_ptr_1<long long> _ptr__229(_229 ? _229->raw() : nullptr, _229 ? _229->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_228,_230,_231,_229,_232,_233);
}
void mosek::fusion::Sort::argbucketsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _234,    std::shared_ptr< monty::ndarray< int,1 > > _235,    long long _236,    long long _237,    int _238,    int _239) { mosek::fusion::p_Sort::argbucketsort(_234,_235,_236,_237,_238,_239); }void mosek::fusion::p_Sort::argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< int,1 > > _235,long long _236,long long _237,int _238,int _239){
  _checked_ptr_1<long long> _ptr__234(_234 ? _234->raw() : nullptr, _234 ? _234->size(0) : 0);
  _checked_ptr_1<int> _ptr__235(_235 ? _235->raw() : nullptr, _235 ? _235->size(0) : 0);
  ::mosek::fusion::Utils::Tools::bucketsort(_234,_236,_237,_235,_238,_239);
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _240,    std::shared_ptr< monty::ndarray< long long,1 > > _241,    std::shared_ptr< monty::ndarray< long long,1 > > _242,    long long _243,    long long _244,    std::shared_ptr< monty::ndarray< long long,1 > > _245) { mosek::fusion::p_Sort::getminmax(_240,_241,_242,_243,_244,_245); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _240,std::shared_ptr< monty::ndarray< long long,1 > > _241,std::shared_ptr< monty::ndarray< long long,1 > > _242,long long _243,long long _244,std::shared_ptr< monty::ndarray< long long,1 > > _245){
  _checked_ptr_1<long long> _ptr__240(_240 ? _240->raw() : nullptr, _240 ? _240->size(0) : 0);
  _checked_ptr_1<long long> _ptr__241(_241 ? _241->raw() : nullptr, _241 ? _241->size(0) : 0);
  _checked_ptr_1<long long> _ptr__242(_242 ? _242->raw() : nullptr, _242 ? _242->size(0) : 0);
  _checked_ptr_1<long long> _ptr__245(_245 ? _245->raw() : nullptr, _245 ? _245->size(0) : 0);
  _ptr__245[(int)0] = _ptr__241[_ptr__240[_243]];
  _ptr__245[(int)1] = _ptr__241[_ptr__240[_243]];
  long long _8632 = safe_add( _243,(int)1 );
  long long _8633 = _244;
  for (long long _246 = _8632; _246 < _8633; ++_246)
  {
    {
      if ((_ptr__245[(int)0] > _ptr__241[_ptr__240[_246]]))
      {
        {
          _ptr__245[(int)0] = _ptr__241[_ptr__240[_246]];
        }
      }
      {}
      if ((_ptr__245[(int)1] < _ptr__241[_ptr__240[_246]]))
      {
        {
          _ptr__245[(int)1] = _ptr__241[_ptr__240[_246]];
        }
      }
      {}
    }
  }
  if ((NULL != _242.get()))
  {
    {
      _ptr__245[(int)2] = _ptr__242[_ptr__240[_243]];
      _ptr__245[(int)3] = _ptr__242[_ptr__240[_243]];
      long long _8634 = safe_add( _243,(int)1 );
      long long _8635 = _244;
      for (long long _247 = _8634; _247 < _8635; ++_247)
      {
        {
          if ((_ptr__245[(int)2] > _ptr__242[_ptr__240[_247]]))
          {
            {
              _ptr__245[(int)2] = _ptr__242[_ptr__240[_247]];
            }
          }
          {}
          if ((_ptr__245[(int)3] < _ptr__242[_ptr__240[_247]]))
          {
            {
              _ptr__245[(int)3] = _ptr__242[_ptr__240[_247]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
void mosek::fusion::Sort::getminmax  ( std::shared_ptr< monty::ndarray< long long,1 > > _248,    std::shared_ptr< monty::ndarray< int,1 > > _249,    std::shared_ptr< monty::ndarray< int,1 > > _250,    long long _251,    long long _252,    std::shared_ptr< monty::ndarray< int,1 > > _253) { mosek::fusion::p_Sort::getminmax(_248,_249,_250,_251,_252,_253); }void mosek::fusion::p_Sort::getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _248,std::shared_ptr< monty::ndarray< int,1 > > _249,std::shared_ptr< monty::ndarray< int,1 > > _250,long long _251,long long _252,std::shared_ptr< monty::ndarray< int,1 > > _253){
  _checked_ptr_1<long long> _ptr__248(_248 ? _248->raw() : nullptr, _248 ? _248->size(0) : 0);
  _checked_ptr_1<int> _ptr__249(_249 ? _249->raw() : nullptr, _249 ? _249->size(0) : 0);
  _checked_ptr_1<int> _ptr__250(_250 ? _250->raw() : nullptr, _250 ? _250->size(0) : 0);
  _checked_ptr_1<int> _ptr__253(_253 ? _253->raw() : nullptr, _253 ? _253->size(0) : 0);
  _ptr__253[(int)0] = _ptr__249[_ptr__248[_251]];
  _ptr__253[(int)1] = _ptr__249[_ptr__248[_251]];
  long long _8636 = safe_add( _251,(int)1 );
  long long _8637 = _252;
  for (long long _254 = _8636; _254 < _8637; ++_254)
  {
    {
      if ((_ptr__253[(int)0] > _ptr__249[_ptr__248[_254]]))
      {
        {
          _ptr__253[(int)0] = _ptr__249[_ptr__248[_254]];
        }
      }
      {}
      if ((_ptr__253[(int)1] < _ptr__249[_ptr__248[_254]]))
      {
        {
          _ptr__253[(int)1] = _ptr__249[_ptr__248[_254]];
        }
      }
      {}
    }
  }
  if ((NULL != _250.get()))
  {
    {
      _ptr__253[(int)2] = _ptr__250[_ptr__248[_251]];
      _ptr__253[(int)3] = _ptr__250[_ptr__248[_251]];
      long long _8638 = safe_add( _251,(int)1 );
      long long _8639 = _252;
      for (long long _255 = _8638; _255 < _8639; ++_255)
      {
        {
          if ((_ptr__253[(int)2] > _ptr__250[_ptr__248[_255]]))
          {
            {
              _ptr__253[(int)2] = _ptr__250[_ptr__248[_255]];
            }
          }
          {}
          if ((_ptr__253[(int)3] < _ptr__250[_ptr__248[_255]]))
          {
            {
              _ptr__253[(int)3] = _ptr__250[_ptr__248[_255]];
            }
          }
          {}
        }
      }
    }
  }
  {}
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _256,    std::shared_ptr< monty::ndarray< long long,1 > > _257,    long long _258,    long long _259,    bool _260) { return mosek::fusion::p_Sort::issorted(_256,_257,_258,_259,_260); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< long long,1 > > _257,long long _258,long long _259,bool _260){
  _checked_ptr_1<long long> _ptr__256(_256 ? _256->raw() : nullptr, _256 ? _256->size(0) : 0);
  _checked_ptr_1<long long> _ptr__257(_257 ? _257->raw() : nullptr, _257 ? _257->size(0) : 0);
  long long _8640 = _258;
  long long _8641 = (_259 - (int)1);
  for (long long _261 = _8640; _261 < _8641; ++_261)
  {
    {
      if ((_ptr__257[_ptr__256[_261]] > _ptr__257[_ptr__256[safe_add( _261,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _262,    std::shared_ptr< monty::ndarray< int,1 > > _263,    long long _264,    long long _265,    bool _266) { return mosek::fusion::p_Sort::issorted(_262,_263,_264,_265,_266); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< int,1 > > _263,long long _264,long long _265,bool _266){
  _checked_ptr_1<long long> _ptr__262(_262 ? _262->raw() : nullptr, _262 ? _262->size(0) : 0);
  _checked_ptr_1<int> _ptr__263(_263 ? _263->raw() : nullptr, _263 ? _263->size(0) : 0);
  long long _8642 = _264;
  long long _8643 = (_265 - (int)1);
  for (long long _267 = _8642; _267 < _8643; ++_267)
  {
    {
      if ((_ptr__263[_ptr__262[_267]] > _ptr__263[_ptr__262[safe_add( _267,(int)1 )]]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _268,    std::shared_ptr< monty::ndarray< long long,1 > > _269,    std::shared_ptr< monty::ndarray< long long,1 > > _270,    long long _271,    long long _272,    bool _273) { return mosek::fusion::p_Sort::issorted(_268,_269,_270,_271,_272,_273); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _268,std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< long long,1 > > _270,long long _271,long long _272,bool _273){
  _checked_ptr_1<long long> _ptr__268(_268 ? _268->raw() : nullptr, _268 ? _268->size(0) : 0);
  _checked_ptr_1<long long> _ptr__269(_269 ? _269->raw() : nullptr, _269 ? _269->size(0) : 0);
  _checked_ptr_1<long long> _ptr__270(_270 ? _270->raw() : nullptr, _270 ? _270->size(0) : 0);
  long long _8644 = _271;
  long long _8645 = (_272 - (int)1);
  for (long long _274 = _8644; _274 < _8645; ++_274)
  {
    {
      if (((_ptr__269[_ptr__268[_274]] > _ptr__269[_ptr__268[safe_add( _274,(int)1 )]]) || ((_ptr__269[_ptr__268[safe_add( _274,(int)1 )]] == _ptr__269[_ptr__268[_274]]) && (_ptr__270[_ptr__268[_274]] > _ptr__270[_ptr__268[safe_add( _274,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
bool mosek::fusion::Sort::issorted  ( std::shared_ptr< monty::ndarray< long long,1 > > _275,    std::shared_ptr< monty::ndarray< int,1 > > _276,    std::shared_ptr< monty::ndarray< int,1 > > _277,    long long _278,    long long _279,    bool _280) { return mosek::fusion::p_Sort::issorted(_275,_276,_277,_278,_279,_280); }bool mosek::fusion::p_Sort::issorted(std::shared_ptr< monty::ndarray< long long,1 > > _275,std::shared_ptr< monty::ndarray< int,1 > > _276,std::shared_ptr< monty::ndarray< int,1 > > _277,long long _278,long long _279,bool _280){
  _checked_ptr_1<long long> _ptr__275(_275 ? _275->raw() : nullptr, _275 ? _275->size(0) : 0);
  _checked_ptr_1<int> _ptr__276(_276 ? _276->raw() : nullptr, _276 ? _276->size(0) : 0);
  _checked_ptr_1<int> _ptr__277(_277 ? _277->raw() : nullptr, _277 ? _277->size(0) : 0);
  long long _8646 = _278;
  long long _8647 = (_279 - (int)1);
  for (long long _281 = _8646; _281 < _8647; ++_281)
  {
    {
      if (((_ptr__276[_ptr__275[_281]] > _ptr__276[_ptr__275[safe_add( _281,(int)1 )]]) || ((_ptr__276[_ptr__275[_281]] == _ptr__276[_ptr__275[safe_add( _281,(int)1 )]]) && (_ptr__277[_ptr__275[_281]] > _ptr__277[_ptr__275[safe_add( _281,(int)1 )]]))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_Sort::destroy(){}void mosek::fusion::Sort::destroy() { mosek::fusion::p_Sort::_get_impl(this)->destroy(); }mosek::fusion::IndexCounter::IndexCounter(mosek::fusion::p_IndexCounter *_impl) : _impl(_impl) { /*std::cout << "IndexCounter() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::IndexCounter::~IndexCounter() { delete _impl; _impl = nullptr; }mosek::fusion::p_IndexCounter::p_IndexCounter  (::mosek::fusion::IndexCounter * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _282){ return new mosek::fusion::IndexCounter(_282); }mosek::fusion::IndexCounter::IndexCounter  (std::shared_ptr< monty::ndarray< int,1 > > _282) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_282); }void mosek::fusion::p_IndexCounter::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _282){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__282(_282 ? _282->raw() : nullptr, _282 ? _282->size(0) : 0);
    n = (int)((_282)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    start = (long long)0;
    strides = ::mosek::fusion::p_Set::strides(_282);
    std::vector<int> _8648;
    for (int _283 = (int)0, _8649 = (int)((_282)->size(0)); _283 < _8649 ; ++_283)
    {
      _8648.push_back(_ptr__282[_283]);
    }
    auto _8650 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8648.size()),_8648.begin(),_8648.end()));
    dims = _8650;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _284,    std::shared_ptr< monty::ndarray< int,1 > > _285,    std::shared_ptr< monty::ndarray< int,1 > > _286){ return new mosek::fusion::IndexCounter(_284,_285,_286); }mosek::fusion::IndexCounter::IndexCounter  (long long _284,    std::shared_ptr< monty::ndarray< int,1 > > _285,    std::shared_ptr< monty::ndarray< int,1 > > _286) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_284,_285,_286); }void mosek::fusion::p_IndexCounter::_initialize  (long long _284,    std::shared_ptr< monty::ndarray< int,1 > > _285,    std::shared_ptr< monty::ndarray< int,1 > > _286){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__285(_285 ? _285->raw() : nullptr, _285 ? _285->size(0) : 0);
    _checked_ptr_1<int> _ptr__286(_286 ? _286->raw() : nullptr, _286 ? _286->size(0) : 0);
    int _287 = (int)((_286)->size(0));
    n = (int)((_285)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _8651 = (int)0;
    int _8652 = n;
    for (int _288 = _8651; _288 < _8652; ++_288)
    {
      {
        ((*st)(_288)) = _284;
      }
    }
    strides = ::mosek::fusion::p_Set::strides(_286);
    dims = _285;
    start = _284;
  }
}mosek::fusion::IndexCounter::t mosek::fusion::p_IndexCounter::_new_IndexCounter  (long long _289,    std::shared_ptr< monty::ndarray< int,1 > > _290,    std::shared_ptr< monty::ndarray< long long,1 > > _291){ return new mosek::fusion::IndexCounter(_289,_290,_291); }mosek::fusion::IndexCounter::IndexCounter  (long long _289,    std::shared_ptr< monty::ndarray< int,1 > > _290,    std::shared_ptr< monty::ndarray< long long,1 > > _291) :    IndexCounter(new mosek::fusion::p_IndexCounter(this)){ mosek::fusion::p_IndexCounter::_get_impl(this)->_initialize(_289,_290,_291); }void mosek::fusion::p_IndexCounter::_initialize  (long long _289,    std::shared_ptr< monty::ndarray< int,1 > > _290,    std::shared_ptr< monty::ndarray< long long,1 > > _291){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__290(_290 ? _290->raw() : nullptr, _290 ? _290->size(0) : 0);
    _checked_ptr_1<long long> _ptr__291(_291 ? _291->raw() : nullptr, _291 ? _291->size(0) : 0);
    n = (int)((_290)->size(0));
    ii = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(n)));
    st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
    int _8653 = (int)0;
    int _8654 = n;
    for (int _292 = _8653; _292 < _8654; ++_292)
    {
      {
        ((*st)(_292)) = _289;
      }
    }
    strides = _291;
    dims = _290;
    start = _289;
  }
}bool mosek::fusion::IndexCounter :: atEnd() { return mosek::fusion::p_IndexCounter::_get_impl(this)->atEnd(); }bool mosek::fusion::p_IndexCounter::atEnd(){
  return (((*ii)((n - (int)1))) >= ((*dims)((n - (int)1))));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::IndexCounter :: getIndex() { return mosek::fusion::p_IndexCounter::_get_impl(this)->getIndex(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_IndexCounter::getIndex(){
  return ii;
}
long long mosek::fusion::IndexCounter :: next() { return mosek::fusion::p_IndexCounter::_get_impl(this)->next(); }long long mosek::fusion::p_IndexCounter::next(){
  long long _293 = _pubthis->get();
  _pubthis->inc();
  return _293;
}
long long mosek::fusion::IndexCounter :: get() { return mosek::fusion::p_IndexCounter::_get_impl(this)->get(); }long long mosek::fusion::p_IndexCounter::get(){
  return ((*st)((int)0));
}
void mosek::fusion::IndexCounter :: inc() { mosek::fusion::p_IndexCounter::_get_impl(this)->inc(); }void mosek::fusion::p_IndexCounter::inc(){
  ++ ((*ii)((int)0));
  ((*st)((int)0)) = safe_add( ((*st)((int)0)),((*strides)((n - (int)1))) );
  int _294;
  {
    _294 = (int)0;
    for(;((_294 < (n - (int)1)) && (((*ii)(_294)) == ((*dims)(((n - _294) - (int)1)))));++ _294)
    {
      {
        ((*ii)(_294)) = (int)0;
        ++ ((*ii)(safe_add( _294,(int)1 )));
        ((*st)(safe_add( _294,(int)1 ))) = safe_add( ((*st)(safe_add( _294,(int)1 ))),((*strides)(((n - _294) - (int)2))) );
      }
    }
  }
  int _8655 = (int)0;
  int _8656 = _294;
  for (int _295 = _8655; _295 < _8656; ++_295)
  {
    {
      ((*st)(_295)) = ((*st)(_294));
    }
  }
}
void mosek::fusion::IndexCounter :: reset() { mosek::fusion::p_IndexCounter::_get_impl(this)->reset(); }void mosek::fusion::p_IndexCounter::reset(){
  st = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(n)));
  int _8657 = (int)0;
  int _8658 = n;
  for (int _296 = _8657; _296 < _8658; ++_296)
  {
    {
      ((*st)(_296)) = start;
    }
  }
}
void mosek::fusion::p_IndexCounter::destroy(){dims.reset();strides.reset();st.reset();ii.reset();}void mosek::fusion::IndexCounter::destroy() { mosek::fusion::p_IndexCounter::_get_impl(this)->destroy(); }mosek::fusion::CommonTools::CommonTools(mosek::fusion::p_CommonTools *_impl) : _impl(_impl) { /*std::cout << "CommonTools() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::CommonTools::~CommonTools() { delete _impl; _impl = nullptr; }mosek::fusion::p_CommonTools::p_CommonTools  (::mosek::fusion::CommonTools * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< long long,1 > > _297,    int _298) { return mosek::fusion::p_CommonTools::resize(_297,_298); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< long long,1 > > _297,int _298){
  _checked_ptr_1<long long> _ptr__297(_297 ? _297->raw() : nullptr, _297 ? _297->size(0) : 0);
  if ((_298 == (int)((_297)->size(0))))
  {
    {
      return _297;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _299 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_298)));
      _checked_ptr_1<long long> _ptr__299(_299 ? _299->raw() : nullptr,_299 ? _299->size(0) : 0);
      if ((_298 > (int)((_297)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,(int)((_297)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_297,(int)0,_299,(int)0,_298);
        }
      }
      return _299;
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< int,1 > > _300,    int _301) { return mosek::fusion::p_CommonTools::resize(_300,_301); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301){
  _checked_ptr_1<int> _ptr__300(_300 ? _300->raw() : nullptr, _300 ? _300->size(0) : 0);
  if ((_301 == (int)((_300)->size(0))))
  {
    {
      return _300;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _302 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_301)));
      _checked_ptr_1<int> _ptr__302(_302 ? _302->raw() : nullptr,_302 ? _302->size(0) : 0);
      if ((_301 > (int)((_300)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_300,(int)0,_302,(int)0,(int)((_300)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_300,(int)0,_302,(int)0,_301);
        }
      }
      return _302;
    }
  }
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::CommonTools::resize  ( std::shared_ptr< monty::ndarray< double,1 > > _303,    int _304) { return mosek::fusion::p_CommonTools::resize(_303,_304); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_CommonTools::resize(std::shared_ptr< monty::ndarray< double,1 > > _303,int _304){
  _checked_ptr_1<double> _ptr__303(_303 ? _303->raw() : nullptr, _303 ? _303->size(0) : 0);
  if ((_304 == (int)((_303)->size(0))))
  {
    {
      return _303;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _305 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_304)));
      _checked_ptr_1<double> _ptr__305(_305 ? _305->raw() : nullptr,_305 ? _305->size(0) : 0);
      if ((_304 > (int)((_303)->size(0))))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_303,(int)0,_305,(int)0,(int)((_303)->size(0)));
        }
      }
      else
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(_303,(int)0,_305,(int)0,_304);
        }
      }
      return _305;
    }
  }
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< int,1 > > _306,    int _307) { return mosek::fusion::p_CommonTools::binarySearch(_306,_307); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _306,int _307){
  _checked_ptr_1<int> _ptr__306(_306 ? _306->raw() : nullptr, _306 ? _306->size(0) : 0);
  int _308 = (int)0;
  int _309 = (int)((_306)->size(0));
  if ((_ptr__306[_308] == _307))
  {
    {
      return _308;
    }
  }
  else if((_ptr__306[(_309 - (int)1)] == _307))
  {
    {
      return (_309 - (int)1);
    }
  }
  {}
  while ( (_308 < (_309 - (int)1)) )
  {
    {
      int _310 = ((_309 - _308) / (int)2);
      if ((_307 < _ptr__306[_310]))
      {
        {
          _308 = safe_add( _310,(int)1 );
        }
      }
      else if((_307 > _ptr__306[_310]))
      {
        {
          _309 = _310;
        }
      }
      else
      {
        {
          return _310;
        }
      }
    }
  }
  return (-(int)1);
}
int mosek::fusion::CommonTools::binarySearch  ( std::shared_ptr< monty::ndarray< long long,1 > > _311,    long long _312) { return mosek::fusion::p_CommonTools::binarySearch(_311,_312); }int mosek::fusion::p_CommonTools::binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _311,long long _312){
  _checked_ptr_1<long long> _ptr__311(_311 ? _311->raw() : nullptr, _311 ? _311->size(0) : 0);
  int _313 = ::mosek::fusion::p_CommonTools::binarySearchL(_311,_312);
  if (((_313 < (int)((_311)->size(0))) && (_ptr__311[_313] == _312)))
  {
    {
      return _313;
    }
  }
  else
  {
    {
      return (-(int)1);
    }
  }
}
int mosek::fusion::CommonTools::binarySearchR  ( std::shared_ptr< monty::ndarray< long long,1 > > _314,    long long _315) { return mosek::fusion::p_CommonTools::binarySearchR(_314,_315); }int mosek::fusion::p_CommonTools::binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _314,long long _315){
  _checked_ptr_1<long long> _ptr__314(_314 ? _314->raw() : nullptr, _314 ? _314->size(0) : 0);
  int _316 = (int)0;
  int _317 = (int)((_314)->size(0));
  if ((_ptr__314[_316] > _315))
  {
    {
      return _316;
    }
  }
  {}
  while ( (_316 < (_317 - (int)1)) )
  {
    {
      int _318 = (safe_add( _317,_316 ) / (int)2);
      if ((_315 >= _ptr__314[_318]))
      {
        {
          _316 = _318;
        }
      }
      else
      {
        {
          _317 = _318;
        }
      }
    }
  }
  return _317;
}
int mosek::fusion::CommonTools::binarySearchL  ( std::shared_ptr< monty::ndarray< long long,1 > > _319,    long long _320) { return mosek::fusion::p_CommonTools::binarySearchL(_319,_320); }int mosek::fusion::p_CommonTools::binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _319,long long _320){
  _checked_ptr_1<long long> _ptr__319(_319 ? _319->raw() : nullptr, _319 ? _319->size(0) : 0);
  int _321 = (int)0;
  int _322 = (int)((_319)->size(0));
  if ((_320 <= _ptr__319[_321]))
  {
    {
      return _321;
    }
  }
  {}
  while ( (_321 < (_322 - (int)1)) )
  {
    {
      int _323 = (safe_add( _322,_321 ) / (int)2);
      if ((_ptr__319[_323] < _320))
      {
        {
          _321 = _323;
        }
      }
      else
      {
        {
          _322 = _323;
        }
      }
    }
  }
  return _322;
}
void mosek::fusion::CommonTools::ndIncr  ( std::shared_ptr< monty::ndarray< int,1 > > _324,    std::shared_ptr< monty::ndarray< int,1 > > _325,    std::shared_ptr< monty::ndarray< int,1 > > _326) { mosek::fusion::p_CommonTools::ndIncr(_324,_325,_326); }void mosek::fusion::p_CommonTools::ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _324,std::shared_ptr< monty::ndarray< int,1 > > _325,std::shared_ptr< monty::ndarray< int,1 > > _326){
  _checked_ptr_1<int> _ptr__324(_324 ? _324->raw() : nullptr, _324 ? _324->size(0) : 0);
  _checked_ptr_1<int> _ptr__325(_325 ? _325->raw() : nullptr, _325 ? _325->size(0) : 0);
  _checked_ptr_1<int> _ptr__326(_326 ? _326->raw() : nullptr, _326 ? _326->size(0) : 0);
  int _327 = ((int)((_324)->size(0)) - (int)1);
  ++ _ptr__324[_327];
  while ( ((_327 > (int)0) && (_ptr__324[_327] >= _ptr__326[_327])) )
  {
    {
      _ptr__324[_327] = _ptr__325[_327];
      ++ _ptr__324[(_327 - (int)1)];
    }
  }
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _328,    std::shared_ptr< monty::ndarray< int,1 > > _329,    std::shared_ptr< monty::ndarray< double,1 > > _330,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _331,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _332,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _333,    long long _334,    int _335,    int _336) { mosek::fusion::p_CommonTools::transposeTriplets(_328,_329,_330,_331,_332,_333,_334,_335,_336); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _328,std::shared_ptr< monty::ndarray< int,1 > > _329,std::shared_ptr< monty::ndarray< double,1 > > _330,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _331,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _332,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _333,long long _334,int _335,int _336){
  _checked_ptr_1<int> _ptr__328(_328 ? _328->raw() : nullptr, _328 ? _328->size(0) : 0);
  _checked_ptr_1<int> _ptr__329(_329 ? _329->raw() : nullptr, _329 ? _329->size(0) : 0);
  _checked_ptr_1<double> _ptr__330(_330 ? _330->raw() : nullptr, _330 ? _330->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _337 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _335,(int)2 ))));
  _checked_ptr_1<long long> _ptr__337(_337 ? _337->raw() : nullptr,_337 ? _337->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _338 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _336,(int)2 ))));
  _checked_ptr_1<long long> _ptr__338(_338 ? _338->raw() : nullptr,_338 ? _338->size(0) : 0);
  {
    long long _339 = (long long)0;
    for(;(_339 < _334);++ _339)
    {
      {
        _ptr__338[safe_add( _ptr__329[_339],(int)2 )] = safe_add( _ptr__338[safe_add( _ptr__329[_339],(int)2 )],(int)1 );
        _ptr__337[safe_add( _ptr__328[_339],(int)2 )] = safe_add( _ptr__337[safe_add( _ptr__328[_339],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _340 = (int)1;
    for(;(_340 < _335);++ _340)
    {
      {
        _ptr__337[safe_add( _340,(int)1 )] = safe_add( _ptr__337[safe_add( _340,(int)1 )],_ptr__337[_340] );
      }
    }
  }
  {
    int _341 = (int)1;
    for(;(_341 < _336);++ _341)
    {
      {
        _ptr__338[safe_add( _341,(int)1 )] = safe_add( _ptr__338[safe_add( _341,(int)1 )],_ptr__338[_341] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _342 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_334)));
  _checked_ptr_1<long long> _ptr__342(_342 ? _342->raw() : nullptr,_342 ? _342->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _343 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_334)));
  _checked_ptr_1<long long> _ptr__343(_343 ? _343->raw() : nullptr,_343 ? _343->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _344 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_334)));
  _checked_ptr_1<double> _ptr__344(_344 ? _344->raw() : nullptr,_344 ? _344->size(0) : 0);
  int _8659 = (int)0;
  int _8660 = _335;
  for (int _345 = _8659; _345 < _8660; ++_345)
  {
    {
      {
        long long _346 = _ptr__337[_345];
        for(;(_346 < _ptr__337[safe_add( _345,(int)1 )]);++ _346)
        {
          {
            int _347 = _ptr__329[_346];
            long long _348 = _ptr__338[_347];
            _ptr__342[_348] = _345;
            _ptr__343[_348] = _347;
            _ptr__344[_348] = _ptr__330[_346];
            _ptr__338[_347] = safe_add( _348,(int)1 );
          }
        }
      }
    }
  }
  ((*_331)((int)0)) = _343;
  ((*_332)((int)0)) = _342;
  ((*_333)((int)0)) = _344;
}
void mosek::fusion::CommonTools::transposeTriplets  ( std::shared_ptr< monty::ndarray< int,1 > > _349,    std::shared_ptr< monty::ndarray< int,1 > > _350,    std::shared_ptr< monty::ndarray< double,1 > > _351,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _352,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _353,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _354,    long long _355,    int _356,    int _357) { mosek::fusion::p_CommonTools::transposeTriplets(_349,_350,_351,_352,_353,_354,_355,_356,_357); }void mosek::fusion::p_CommonTools::transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _349,std::shared_ptr< monty::ndarray< int,1 > > _350,std::shared_ptr< monty::ndarray< double,1 > > _351,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _352,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _353,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _354,long long _355,int _356,int _357){
  _checked_ptr_1<int> _ptr__349(_349 ? _349->raw() : nullptr, _349 ? _349->size(0) : 0);
  _checked_ptr_1<int> _ptr__350(_350 ? _350->raw() : nullptr, _350 ? _350->size(0) : 0);
  _checked_ptr_1<double> _ptr__351(_351 ? _351->raw() : nullptr, _351 ? _351->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _358 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _356,(int)2 ))));
  _checked_ptr_1<long long> _ptr__358(_358 ? _358->raw() : nullptr,_358 ? _358->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _359 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _357,(int)2 ))));
  _checked_ptr_1<long long> _ptr__359(_359 ? _359->raw() : nullptr,_359 ? _359->size(0) : 0);
  {
    long long _360 = (long long)0;
    for(;(_360 < _355);++ _360)
    {
      {
        _ptr__359[safe_add( _ptr__350[_360],(int)2 )] = safe_add( _ptr__359[safe_add( _ptr__350[_360],(int)2 )],(int)1 );
        _ptr__358[safe_add( _ptr__349[_360],(int)2 )] = safe_add( _ptr__358[safe_add( _ptr__349[_360],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _361 = (int)1;
    for(;(_361 < _356);++ _361)
    {
      {
        _ptr__358[safe_add( _361,(int)1 )] = safe_add( _ptr__358[safe_add( _361,(int)1 )],_ptr__358[_361] );
      }
    }
  }
  {
    int _362 = (int)1;
    for(;(_362 < _357);++ _362)
    {
      {
        _ptr__359[safe_add( _362,(int)1 )] = safe_add( _ptr__359[safe_add( _362,(int)1 )],_ptr__359[_362] );
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _363 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_355)));
  _checked_ptr_1<int> _ptr__363(_363 ? _363->raw() : nullptr,_363 ? _363->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _364 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_355)));
  _checked_ptr_1<int> _ptr__364(_364 ? _364->raw() : nullptr,_364 ? _364->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _365 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_355)));
  _checked_ptr_1<double> _ptr__365(_365 ? _365->raw() : nullptr,_365 ? _365->size(0) : 0);
  {
    int _366 = (int)0;
    for(;(_366 < _356);++ _366)
    {
      {
        long long _8661 = _ptr__358[_366];
        long long _8662 = _ptr__358[safe_add( _366,(int)1 )];
        for (long long _367 = _8661; _367 < _8662; ++_367)
        {
          {
            int _368 = _ptr__350[_367];
            long long _369 = _ptr__359[_368];
            _ptr__363[_369] = _366;
            _ptr__364[_369] = _368;
            _ptr__365[_369] = _ptr__351[_367];
            _ptr__359[_368] = safe_add( _369,(int)1 );
          }
        }
      }
    }
  }
  ((*_352)((int)0)) = _364;
  ((*_353)((int)0)) = _363;
  ((*_354)((int)0)) = _365;
}
void mosek::fusion::CommonTools::tripletSort  ( std::shared_ptr< monty::ndarray< int,1 > > _370,    std::shared_ptr< monty::ndarray< int,1 > > _371,    std::shared_ptr< monty::ndarray< double,1 > > _372,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _373,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _374,    std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _375,    long long _376,    int _377,    int _378) { mosek::fusion::p_CommonTools::tripletSort(_370,_371,_372,_373,_374,_375,_376,_377,_378); }void mosek::fusion::p_CommonTools::tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _370,std::shared_ptr< monty::ndarray< int,1 > > _371,std::shared_ptr< monty::ndarray< double,1 > > _372,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _373,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _374,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _375,long long _376,int _377,int _378){
  _checked_ptr_1<int> _ptr__370(_370 ? _370->raw() : nullptr, _370 ? _370->size(0) : 0);
  _checked_ptr_1<int> _ptr__371(_371 ? _371->raw() : nullptr, _371 ? _371->size(0) : 0);
  _checked_ptr_1<double> _ptr__372(_372 ? _372->raw() : nullptr, _372 ? _372->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _379 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_376)));
  _checked_ptr_1<int> _ptr__379(_379 ? _379->raw() : nullptr,_379 ? _379->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _380 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _378,(int)2 ))));
  _checked_ptr_1<long long> _ptr__380(_380 ? _380->raw() : nullptr,_380 ? _380->size(0) : 0);
  long long _8663 = (long long)0;
  long long _8664 = _376;
  for (long long _381 = _8663; _381 < _8664; ++_381)
  {
    {
      _ptr__380[safe_add( _ptr__371[_381],(int)2 )] = safe_add( _ptr__380[safe_add( _ptr__371[_381],(int)2 )],(int)1 );
    }
  }
  int _8665 = (int)1;
  int _8666 = _378;
  for (int _382 = _8665; _382 < _8666; ++_382)
  {
    {
      _ptr__380[safe_add( _382,(int)1 )] = safe_add( _ptr__380[safe_add( _382,(int)1 )],_ptr__380[_382] );
    }
  }
  int _8667 = (int)0;
  int _8668 = (int)_376;
  for (int _383 = _8667; _383 < _8668; ++_383)
  {
    {
      int _384 = _ptr__371[_383];
      _ptr__379[_ptr__380[safe_add( _384,(int)1 )]] = _383;
      _ptr__380[safe_add( _384,(int)1 )] = safe_add( _ptr__380[safe_add( _384,(int)1 )],(int)1 );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _385 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _377,(int)2 ))));
  _checked_ptr_1<long long> _ptr__385(_385 ? _385->raw() : nullptr,_385 ? _385->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _386 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_376)));
  _checked_ptr_1<int> _ptr__386(_386 ? _386->raw() : nullptr,_386 ? _386->size(0) : 0);
  {
    int _387 = (int)0;
    for(;(_387 < _376);++ _387)
    {
      {
        _ptr__385[safe_add( _ptr__370[_387],(int)2 )] = safe_add( _ptr__385[safe_add( _ptr__370[_387],(int)2 )],(int)1 );
      }
    }
  }
  {
    int _388 = (int)1;
    for(;(_388 < _377);++ _388)
    {
      {
        _ptr__385[safe_add( _388,(int)1 )] = safe_add( _ptr__385[safe_add( _388,(int)1 )],_ptr__385[_388] );
      }
    }
  }
  {
    int _389 = (int)0;
    for(;(_389 < _378);++ _389)
    {
      {
        {
          long long _390 = _ptr__380[_389];
          for(;(_390 < _ptr__380[safe_add( _389,(int)1 )]);++ _390)
          {
            {
              int _391 = _ptr__370[_ptr__379[_390]];
              _ptr__386[_ptr__385[safe_add( _391,(int)1 )]] = _ptr__379[_390];
              _ptr__385[safe_add( _391,(int)1 )] = safe_add( _ptr__385[safe_add( _391,(int)1 )],(int)1 );
            }
          }
        }
      }
    }
  }
  int _392 = (int)1;
  {
    int _393 = _ptr__370[_ptr__386[(int)0]];
    int _394 = _ptr__371[_ptr__386[(int)0]];
    {
      int _395 = (int)1;
      for(;(_395 < _376);++ _395)
      {
        {
          int _396 = _ptr__386[_395];
          if (((_393 != _ptr__370[_396]) || (_394 != _ptr__371[_396])))
          {
            {
              _393 = _ptr__370[_396];
              _394 = _ptr__371[_396];
              ++ _392;
            }
          }
          {}
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _397 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_392)));
  _checked_ptr_1<int> _ptr__397(_397 ? _397->raw() : nullptr,_397 ? _397->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _398 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_392)));
  _checked_ptr_1<int> _ptr__398(_398 ? _398->raw() : nullptr,_398 ? _398->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _399 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_392)));
  _checked_ptr_1<double> _ptr__399(_399 ? _399->raw() : nullptr,_399 ? _399->size(0) : 0);
  {
    int _400 = _ptr__386[(int)0];
    _ptr__397[(int)0] = _ptr__370[_400];
    _ptr__398[(int)0] = _ptr__371[_400];
    _ptr__399[(int)0] = _ptr__372[_400];
  }
  int _401 = (int)1;
  int _8669 = (int)1;
  long long _8670 = _376;
  for (long long _402 = _8669; _402 < _8670; ++_402)
  {
    {
      int _403 = _ptr__386[_402];
      if (((_ptr__397[(_401 - (int)1)] == _ptr__370[_403]) && (_ptr__398[(_401 - (int)1)] == _ptr__371[_403])))
      {
        {
          _ptr__399[(_401 - (int)1)] = (_ptr__399[(_401 - (int)1)] + _ptr__372[_403]);
        }
      }
      else
      {
        {
          _ptr__397[_401] = _ptr__370[_403];
          _ptr__398[_401] = _ptr__371[_403];
          _ptr__399[_401] = _ptr__372[_403];
          ++ _401;
        }
      }
    }
  }
  ((*_373)((int)0)) = _397;
  ((*_374)((int)0)) = _398;
  ((*_375)((int)0)) = _399;
}
void mosek::fusion::CommonTools::argMSort  ( std::shared_ptr< monty::ndarray< int,1 > > _404,    std::shared_ptr< monty::ndarray< int,1 > > _405) { mosek::fusion::p_CommonTools::argMSort(_404,_405); }void mosek::fusion::p_CommonTools::argMSort(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405){
  _checked_ptr_1<int> _ptr__404(_404 ? _404->raw() : nullptr, _404 ? _404->size(0) : 0);
  _checked_ptr_1<int> _ptr__405(_405 ? _405->raw() : nullptr, _405 ? _405->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _406 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_404)->size(0)))));
  _checked_ptr_1<int> _ptr__406(_406 ? _406->raw() : nullptr,_406 ? _406->size(0) : 0);
  bool _407 = false;
  {
    int _408 = (int)1;
    for(;(_408 < (int)((_404)->size(0)));_408 *= (int)2)
    {
      {
        _407 = (!_407);
        int _8671 = (int)0;
        int _8672 = (int)((_404)->size(0));
        int _8673 = safe_mul( _408,(int)2 );
        for (int _409 = _8671; _409 < _8672; _409 += _8673)
        {
          {
            if (_407)
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_404,_406,_405,_409,safe_add( _409,_408 ),safe_add( _409,safe_mul( (int)2,_408 ) ));
              }
            }
            else
            {
              {
                ::mosek::fusion::p_CommonTools::mergeInto(_406,_404,_405,_409,safe_add( _409,_408 ),safe_add( _409,safe_mul( (int)2,_408 ) ));
              }
            }
          }
        }
      }
    }
  }
  if (_407)
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_406,(int)0,_404,(int)0,(int)((_404)->size(0)));
    }
  }
  {}
}
void mosek::fusion::p_CommonTools::mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _410,std::shared_ptr< monty::ndarray< int,1 > > _411,std::shared_ptr< monty::ndarray< int,1 > > _412,int _413,int _414,int _415){
  _checked_ptr_1<int> _ptr__410(_410 ? _410->raw() : nullptr, _410 ? _410->size(0) : 0);
  _checked_ptr_1<int> _ptr__411(_411 ? _411->raw() : nullptr, _411 ? _411->size(0) : 0);
  _checked_ptr_1<int> _ptr__412(_412 ? _412->raw() : nullptr, _412 ? _412->size(0) : 0);
  int _8674;
  bool _8675 = (_415 > (int)((_410)->size(0)));
  if (_8675)
  {
    _8674 = (int)((_410)->size(0));
  }
  else
  {
    _8674 = _415;
  }
  int _416 = _8674;
  int _8676;
  bool _8677 = (_414 > _416);
  if (_8677)
  {
    _8676 = _416;
  }
  else
  {
    _8676 = _414;
  }
  int _417 = _8676;
  if ((_417 == _416))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(_410,_413,_411,_413,(_417 - _413));
    }
  }
  else
  {
    {
      int _418 = _413;
      int _419 = _417;
      int _420;
      {
        _420 = _413;
        for(;((_418 < _417) && (_419 < _416));++ _420)
        {
          {
            if ((_ptr__412[_ptr__410[_418]] < _ptr__412[_ptr__410[_419]]))
            {
              {
                _ptr__411[_420] = _ptr__410[_418];
                ++ _418;
              }
            }
            else
            {
              {
                _ptr__411[_420] = _ptr__410[_419];
                ++ _419;
              }
            }
          }
        }
      }
      while ( (_418 < _417) )
      {
        {
          _ptr__411[_420] = _ptr__410[_418];
          ++ _418;
          ++ _420;
        }
      }
      while ( (_419 < _416) )
      {
        {
          _ptr__411[_420] = _ptr__410[_419];
          ++ _419;
          ++ _420;
        }
      }
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _421,    std::shared_ptr< monty::ndarray< long long,1 > > _422,    std::shared_ptr< monty::ndarray< long long,1 > > _423,    long long _424,    long long _425) { mosek::fusion::p_CommonTools::argQsort(_421,_422,_423,_424,_425); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _421,std::shared_ptr< monty::ndarray< long long,1 > > _422,std::shared_ptr< monty::ndarray< long long,1 > > _423,long long _424,long long _425){
  _checked_ptr_1<long long> _ptr__421(_421 ? _421->raw() : nullptr, _421 ? _421->size(0) : 0);
  _checked_ptr_1<long long> _ptr__422(_422 ? _422->raw() : nullptr, _422 ? _422->size(0) : 0);
  _checked_ptr_1<long long> _ptr__423(_423 ? _423->raw() : nullptr, _423 ? _423->size(0) : 0);
  if ((NULL == _423.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_421,_422,_424,_425);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_421,_422,_423,_424,_425);
    }
  }
}
void mosek::fusion::CommonTools::argQsort  ( std::shared_ptr< monty::ndarray< long long,1 > > _426,    std::shared_ptr< monty::ndarray< int,1 > > _427,    std::shared_ptr< monty::ndarray< int,1 > > _428,    long long _429,    long long _430) { mosek::fusion::p_CommonTools::argQsort(_426,_427,_428,_429,_430); }void mosek::fusion::p_CommonTools::argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _426,std::shared_ptr< monty::ndarray< int,1 > > _427,std::shared_ptr< monty::ndarray< int,1 > > _428,long long _429,long long _430){
  _checked_ptr_1<long long> _ptr__426(_426 ? _426->raw() : nullptr, _426 ? _426->size(0) : 0);
  _checked_ptr_1<int> _ptr__427(_427 ? _427->raw() : nullptr, _427 ? _427->size(0) : 0);
  _checked_ptr_1<int> _ptr__428(_428 ? _428->raw() : nullptr, _428 ? _428->size(0) : 0);
  if ((NULL == _428.get()))
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_426,_427,_429,_430);
    }
  }
  else
  {
    {
      ::mosek::fusion::Utils::Tools::argsort(_426,_427,_428,_429,_430);
    }
  }
}
void mosek::fusion::p_CommonTools::destroy(){}void mosek::fusion::CommonTools::destroy() { mosek::fusion::p_CommonTools::_get_impl(this)->destroy(); }mosek::fusion::SolutionStruct::SolutionStruct(mosek::fusion::p_SolutionStruct *_impl) : _impl(_impl) { /*std::cout << "SolutionStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SolutionStruct::~SolutionStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_SolutionStruct::p_SolutionStruct  (::mosek::fusion::SolutionStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_yx() { return _impl->yx; }
void mosek::fusion::SolutionStruct::set_yx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->yx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_snx() { return _impl->snx; }
void mosek::fusion::SolutionStruct::set_snx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->snx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_sux() { return _impl->sux; }
void mosek::fusion::SolutionStruct::set_sux(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->sux = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slx() { return _impl->slx; }
void mosek::fusion::SolutionStruct::set_slx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_bars() { return _impl->bars; }
void mosek::fusion::SolutionStruct::set_bars(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bars = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_barx() { return _impl->barx; }
void mosek::fusion::SolutionStruct::set_barx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->barx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_y() { return _impl->y; }
void mosek::fusion::SolutionStruct::set_y(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->y = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_suc() { return _impl->suc; }
void mosek::fusion::SolutionStruct::set_suc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->suc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_slc() { return _impl->slc; }
void mosek::fusion::SolutionStruct::set_slc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->slc = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xx() { return _impl->xx; }
void mosek::fusion::SolutionStruct::set_xx(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xx = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SolutionStruct::get_xc() { return _impl->xc; }
void mosek::fusion::SolutionStruct::set_xc(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->xc = _val; }
double mosek::fusion::SolutionStruct::get_dobj() { return _impl->dobj; }
void mosek::fusion::SolutionStruct::set_dobj(double _val) { _impl->dobj = _val; }
double mosek::fusion::SolutionStruct::get_pobj() { return _impl->pobj; }
void mosek::fusion::SolutionStruct::set_pobj(double _val) { _impl->pobj = _val; }
mosek::fusion::ProblemStatus mosek::fusion::SolutionStruct::get_probstatus() { return _impl->probstatus; }
void mosek::fusion::SolutionStruct::set_probstatus(mosek::fusion::ProblemStatus _val) { _impl->probstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_dstatus() { return _impl->dstatus; }
void mosek::fusion::SolutionStruct::set_dstatus(mosek::fusion::SolutionStatus _val) { _impl->dstatus = _val; }
mosek::fusion::SolutionStatus mosek::fusion::SolutionStruct::get_pstatus() { return _impl->pstatus; }
void mosek::fusion::SolutionStruct::set_pstatus(mosek::fusion::SolutionStatus _val) { _impl->pstatus = _val; }
int mosek::fusion::SolutionStruct::get_sol_numbarvar() { return _impl->sol_numbarvar; }
void mosek::fusion::SolutionStruct::set_sol_numbarvar(int _val) { _impl->sol_numbarvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcone() { return _impl->sol_numcone; }
void mosek::fusion::SolutionStruct::set_sol_numcone(int _val) { _impl->sol_numcone = _val; }
int mosek::fusion::SolutionStruct::get_sol_numvar() { return _impl->sol_numvar; }
void mosek::fusion::SolutionStruct::set_sol_numvar(int _val) { _impl->sol_numvar = _val; }
int mosek::fusion::SolutionStruct::get_sol_numcon() { return _impl->sol_numcon; }
void mosek::fusion::SolutionStruct::set_sol_numcon(int _val) { _impl->sol_numcon = _val; }
mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (int _431,    int _432,    int _433,    int _434){ return new mosek::fusion::SolutionStruct(_431,_432,_433,_434); }mosek::fusion::SolutionStruct::SolutionStruct  (int _431,    int _432,    int _433,    int _434) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_431,_432,_433,_434); }void mosek::fusion::p_SolutionStruct::_initialize  (int _431,    int _432,    int _433,    int _434){monty::rc_reserve __reserve_this(_pubthis);   {
    pobj = 0.0;
    dobj = 0.0;
    pstatus = ::mosek::fusion::SolutionStatus::Unknown;
    dstatus = ::mosek::fusion::SolutionStatus::Unknown;
    probstatus = ::mosek::fusion::ProblemStatus::Unknown;
    sol_numvar = _431;
    sol_numcon = _432;
    sol_numcone = _433;
    sol_numbarvar = _434;
    slx = nullptr;
    sux = nullptr;
    xx = nullptr;
    yx = nullptr;
    slc = nullptr;
    suc = nullptr;
    y = nullptr;
    xc = nullptr;
    snx = nullptr;
    barx = nullptr;
    bars = nullptr;
    if ((_431 > (int)0))
    {
      {
        slx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_431)));
        sux = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_431)));
        xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_431)));
        yx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_431)));
      }
    }
    {}
    if ((_434 > (int)0))
    {
      {
        barx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_434)));
        bars = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_434)));
      }
    }
    {}
    if ((_432 > (int)0))
    {
      {
        slc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_432)));
        suc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_432)));
        y = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_432)));
        xc = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_432)));
      }
    }
    {}
    if ((_433 > (int)0))
    {
      {
        snx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_431)));
      }
    }
    {}
  }
}mosek::fusion::SolutionStruct::t mosek::fusion::p_SolutionStruct::_new_SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _435){ return new mosek::fusion::SolutionStruct(_435); }mosek::fusion::SolutionStruct::SolutionStruct  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _435) :    SolutionStruct(new mosek::fusion::p_SolutionStruct(this)){ mosek::fusion::p_SolutionStruct::_get_impl(this)->_initialize(_435); }void mosek::fusion::p_SolutionStruct::_initialize  (monty::rc_ptr< ::mosek::fusion::SolutionStruct > _435){monty::rc_reserve __reserve_this(_pubthis);   {
    sol_numcon = mosek::fusion::p_SolutionStruct::_get_impl(_435)->sol_numcon;
    sol_numvar = mosek::fusion::p_SolutionStruct::_get_impl(_435)->sol_numvar;
    sol_numcone = mosek::fusion::p_SolutionStruct::_get_impl(_435)->sol_numcone;
    sol_numbarvar = mosek::fusion::p_SolutionStruct::_get_impl(_435)->sol_numbarvar;
    pstatus = mosek::fusion::p_SolutionStruct::_get_impl(_435)->pstatus;
    dstatus = mosek::fusion::p_SolutionStruct::_get_impl(_435)->dstatus;
    probstatus = mosek::fusion::p_SolutionStruct::_get_impl(_435)->probstatus;
    pobj = mosek::fusion::p_SolutionStruct::_get_impl(_435)->pobj;
    dobj = mosek::fusion::p_SolutionStruct::_get_impl(_435)->dobj;
    std::shared_ptr< monty::ndarray< double,1 > > _8678;
    bool _8679 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->xc.get());
    if (_8679)
    {
      _8678 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->xc);
    }
    else
    {
      _8678 = nullptr;
    }
    xc = _8678;
    std::shared_ptr< monty::ndarray< double,1 > > _8680;
    bool _8681 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->xx.get());
    if (_8681)
    {
      _8680 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->xx);
    }
    else
    {
      _8680 = nullptr;
    }
    xx = _8680;
    std::shared_ptr< monty::ndarray< double,1 > > _8682;
    bool _8683 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->yx.get());
    if (_8683)
    {
      _8682 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->yx);
    }
    else
    {
      _8682 = nullptr;
    }
    yx = _8682;
    std::shared_ptr< monty::ndarray< double,1 > > _8684;
    bool _8685 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->slc.get());
    if (_8685)
    {
      _8684 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->slx);
    }
    else
    {
      _8684 = nullptr;
    }
    slc = _8684;
    std::shared_ptr< monty::ndarray< double,1 > > _8686;
    bool _8687 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->suc.get());
    if (_8687)
    {
      _8686 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->sux);
    }
    else
    {
      _8686 = nullptr;
    }
    suc = _8686;
    std::shared_ptr< monty::ndarray< double,1 > > _8688;
    bool _8689 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->y.get());
    if (_8689)
    {
      _8688 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->y);
    }
    else
    {
      _8688 = nullptr;
    }
    y = _8688;
    barx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->barx);
    bars = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->bars);
    std::shared_ptr< monty::ndarray< double,1 > > _8690;
    bool _8691 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->slx.get());
    if (_8691)
    {
      _8690 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->slx);
    }
    else
    {
      _8690 = nullptr;
    }
    slx = _8690;
    std::shared_ptr< monty::ndarray< double,1 > > _8692;
    bool _8693 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->sux.get());
    if (_8693)
    {
      _8692 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->sux);
    }
    else
    {
      _8692 = nullptr;
    }
    sux = _8692;
    std::shared_ptr< monty::ndarray< double,1 > > _8694;
    bool _8695 = (NULL != mosek::fusion::p_SolutionStruct::_get_impl(_435)->snx.get());
    if (_8695)
    {
      _8694 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_435)->snx);
    }
    else
    {
      _8694 = nullptr;
    }
    snx = _8694;
  }
}monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct :: __mosek_2fusion_2SolutionStruct__clone() { return mosek::fusion::p_SolutionStruct::_get_impl(this)->__mosek_2fusion_2SolutionStruct__clone(); }monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::SolutionStruct::clone() { return __mosek_2fusion_2SolutionStruct__clone(); }
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_SolutionStruct::__mosek_2fusion_2SolutionStruct__clone(){
  return ::mosek::fusion::p_SolutionStruct::_new_SolutionStruct(::mosek::fusion::SolutionStruct::t(_pubthis));
}
void mosek::fusion::SolutionStruct :: resize(int _436,int _437,int _438,int _439) { mosek::fusion::p_SolutionStruct::_get_impl(this)->resize(_436,_437,_438,_439); }void mosek::fusion::p_SolutionStruct::resize(int _436,int _437,int _438,int _439){
  if ((_439 < (int)0))
  {
    {
    }
  }
  else if((_439 <= sol_numbarvar))
  {
    {
      sol_numbarvar = _439;
    }
  }
  else if((_439 <= (int)((barx)->size(0))))
  {
    {
    }
  }
  else
  {
    {
      int _440;
      if ((safe_mul( sol_numbarvar,(int)2 ) > safe_add( _439,(int)100 )))
      {
        {
          _440 = safe_mul( sol_numbarvar,(int)2 );
        }
      }
      else
      {
        {
          _440 = safe_add( _439,(int)100 );
        }
      }
      barx = ::mosek::fusion::p_CommonTools::resize(barx,_440);
      bars = ::mosek::fusion::p_CommonTools::resize(bars,_440);
      sol_numbarvar = _440;
    }
  }
  if ((_436 < (int)0))
  {
    {
    }
  }
  else if((_436 <= sol_numvar))
  {
    {
      sol_numvar = _436;
    }
  }
  else if((_436 <= (int)((xx)->size(0))))
  {
    {
      int _8696 = sol_numvar;
      int _8697 = _436;
      for (int _441 = _8696; _441 < _8697; ++_441)
      {
        {
          ((*slx)(_441)) = 0.0;
          ((*sux)(_441)) = 0.0;
          ((*xx)(_441)) = 0.0;
          ((*yx)(_441)) = 0.0;
        }
      }
      sol_numvar = _436;
    }
  }
  else
  {
    {
      int _442;
      if ((safe_mul( sol_numvar,(int)2 ) > safe_add( _436,(int)100 )))
      {
        {
          _442 = safe_mul( sol_numvar,(int)2 );
        }
      }
      else
      {
        {
          _442 = safe_add( _436,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _443 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_442)));
      _checked_ptr_1<double> _ptr__443(_443 ? _443->raw() : nullptr,_443 ? _443->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slx,(int)0,_443,(int)0,(int)((slx)->size(0)));
      slx = _443;
      std::shared_ptr< monty::ndarray< double,1 > > _444 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_442)));
      _checked_ptr_1<double> _ptr__444(_444 ? _444->raw() : nullptr,_444 ? _444->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(sux,(int)0,_444,(int)0,(int)((sux)->size(0)));
      sux = _444;
      std::shared_ptr< monty::ndarray< double,1 > > _445 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_442)));
      _checked_ptr_1<double> _ptr__445(_445 ? _445->raw() : nullptr,_445 ? _445->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xx,(int)0,_445,(int)0,(int)((xx)->size(0)));
      xx = _445;
      std::shared_ptr< monty::ndarray< double,1 > > _446 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_442)));
      _checked_ptr_1<double> _ptr__446(_446 ? _446->raw() : nullptr,_446 ? _446->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(yx,(int)0,_446,(int)0,(int)((yx)->size(0)));
      yx = _446;
      {
        int _447 = sol_numvar;
        for(;(_447 < _436);++ _447)
        {
          {
            ((*slx)(_447)) = 0.0;
            ((*sux)(_447)) = 0.0;
            ((*xx)(_447)) = 0.0;
          }
        }
      }
      sol_numvar = _436;
    }
  }
  if ((_437 < (int)0))
  {
    {
    }
  }
  else if((_437 <= sol_numcon))
  {
    {
      sol_numcon = _437;
    }
  }
  else if((_437 <= (int)((xx)->size(0))))
  {
    {
      int _8698 = sol_numcon;
      int _8699 = _437;
      for (int _448 = _8698; _448 < _8699; ++_448)
      {
        {
          ((*slc)(_448)) = 0.0;
          ((*suc)(_448)) = 0.0;
          ((*xc)(_448)) = 0.0;
          ((*y)(_448)) = 0.0;
        }
      }
      sol_numcon = _437;
    }
  }
  else
  {
    {
      int _449;
      if ((safe_mul( sol_numcon,(int)2 ) > safe_add( _437,(int)100 )))
      {
        {
          _449 = safe_mul( sol_numcon,(int)2 );
        }
      }
      else
      {
        {
          _449 = safe_add( _437,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _450 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_449)));
      _checked_ptr_1<double> _ptr__450(_450 ? _450->raw() : nullptr,_450 ? _450->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(slc,(int)0,_450,(int)0,(int)((slc)->size(0)));
      slc = _450;
      std::shared_ptr< monty::ndarray< double,1 > > _451 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_449)));
      _checked_ptr_1<double> _ptr__451(_451 ? _451->raw() : nullptr,_451 ? _451->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(suc,(int)0,_451,(int)0,(int)((suc)->size(0)));
      suc = _451;
      std::shared_ptr< monty::ndarray< double,1 > > _452 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_449)));
      _checked_ptr_1<double> _ptr__452(_452 ? _452->raw() : nullptr,_452 ? _452->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(xc,(int)0,_452,(int)0,(int)((xc)->size(0)));
      xc = _452;
      std::shared_ptr< monty::ndarray< double,1 > > _453 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_449)));
      _checked_ptr_1<double> _ptr__453(_453 ? _453->raw() : nullptr,_453 ? _453->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(y,(int)0,_453,(int)0,(int)((y)->size(0)));
      y = _453;
      int _8700 = sol_numcon;
      int _8701 = _437;
      for (int _454 = _8700; _454 < _8701; ++_454)
      {
        {
          ((*slc)(_454)) = 0.0;
          ((*suc)(_454)) = 0.0;
          ((*xc)(_454)) = 0.0;
          ((*y)(_454)) = 0.0;
        }
      }
      sol_numcon = _437;
    }
  }
  if ((_438 < (int)0))
  {
    {
    }
  }
  else if((_438 <= sol_numcone))
  {
    {
      sol_numcone = _438;
    }
  }
  else if((_438 <= (int)((xx)->size(0))))
  {
    {
      int _8702 = sol_numcone;
      int _8703 = _438;
      for (int _455 = _8702; _455 < _8703; ++_455)
      {
        {
          ((*snx)(_455)) = 0.0;
        }
      }
      sol_numcone = _438;
    }
  }
  else
  {
    {
      int _456;
      if ((safe_mul( sol_numcone,(int)2 ) > safe_add( _438,(int)100 )))
      {
        {
          _456 = safe_mul( sol_numcone,(int)2 );
        }
      }
      else
      {
        {
          _456 = safe_add( _438,(int)100 );
        }
      }
      std::shared_ptr< monty::ndarray< double,1 > > _457 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_456)));
      _checked_ptr_1<double> _ptr__457(_457 ? _457->raw() : nullptr,_457 ? _457->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(snx,(int)0,_457,(int)0,(int)((snx)->size(0)));
      snx = _457;
      {
        int _458 = sol_numcone;
        for(;(_458 < _438);++ _458)
        {
          {
            ((*snx)(_458)) = 0.0;
          }
        }
      }
      sol_numcone = _438;
    }
  }
}
bool mosek::fusion::SolutionStruct :: isDualAcceptable(mosek::fusion::AccSolutionStatus _459) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isDualAcceptable(_459); }bool mosek::fusion::p_SolutionStruct::isDualAcceptable(mosek::fusion::AccSolutionStatus _459){
  return isAcceptable(dstatus,_459);
}
bool mosek::fusion::SolutionStruct :: isPrimalAcceptable(mosek::fusion::AccSolutionStatus _460) { return mosek::fusion::p_SolutionStruct::_get_impl(this)->isPrimalAcceptable(_460); }bool mosek::fusion::p_SolutionStruct::isPrimalAcceptable(mosek::fusion::AccSolutionStatus _460){
  return isAcceptable(pstatus,_460);
}
bool mosek::fusion::p_SolutionStruct::isAcceptable(mosek::fusion::SolutionStatus _461,mosek::fusion::AccSolutionStatus _462){
  if ((_462 == ::mosek::fusion::AccSolutionStatus::Anything))
  {
    {
      return true;
    }
  }
  else if((_462 == ::mosek::fusion::AccSolutionStatus::Optimal))
  {
    {
      return (_461 == ::mosek::fusion::SolutionStatus::Optimal);
    }
  }
  else if((_462 == ::mosek::fusion::AccSolutionStatus::Feasible))
  {
    {
      return ((_461 == ::mosek::fusion::SolutionStatus::Optimal) || (_461 == ::mosek::fusion::SolutionStatus::Feasible));
    }
  }
  else if((_462 == ::mosek::fusion::AccSolutionStatus::Certificate))
  {
    {
      return (_461 == ::mosek::fusion::SolutionStatus::Certificate);
    }
  }
  {}
  return false;
}
void mosek::fusion::p_SolutionStruct::destroy(){yx.reset();snx.reset();sux.reset();slx.reset();bars.reset();barx.reset();y.reset();suc.reset();slc.reset();xx.reset();xc.reset();}void mosek::fusion::SolutionStruct::destroy() { mosek::fusion::p_SolutionStruct::_get_impl(this)->destroy(); }mosek::fusion::ConNZStruct::ConNZStruct(mosek::fusion::p_ConNZStruct *_impl) : _impl(_impl) { /*std::cout << "ConNZStruct() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConNZStruct::~ConNZStruct() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConNZStruct::p_ConNZStruct  (::mosek::fusion::ConNZStruct * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barmidx() { return _impl->barmidx; }
void mosek::fusion::ConNZStruct::set_barmidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConNZStruct::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConNZStruct::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConNZStruct::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConNZStruct::get_cof() { return _impl->cof; }
void mosek::fusion::ConNZStruct::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConNZStruct::get_subj() { return _impl->subj; }
void mosek::fusion::ConNZStruct::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::ConNZStruct::get_ptrb() { return _impl->ptrb; }
void mosek::fusion::ConNZStruct::set_ptrb(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->ptrb = _val; }
mosek::fusion::ConNZStruct::t mosek::fusion::p_ConNZStruct::_new_ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _463,    std::shared_ptr< monty::ndarray< int,1 > > _464,    std::shared_ptr< monty::ndarray< double,1 > > _465,    std::shared_ptr< monty::ndarray< double,1 > > _466,    std::shared_ptr< monty::ndarray< int,1 > > _467,    std::shared_ptr< monty::ndarray< int,1 > > _468,    std::shared_ptr< monty::ndarray< int,1 > > _469){ return new mosek::fusion::ConNZStruct(_463,_464,_465,_466,_467,_468,_469); }mosek::fusion::ConNZStruct::ConNZStruct  (std::shared_ptr< monty::ndarray< long long,1 > > _463,    std::shared_ptr< monty::ndarray< int,1 > > _464,    std::shared_ptr< monty::ndarray< double,1 > > _465,    std::shared_ptr< monty::ndarray< double,1 > > _466,    std::shared_ptr< monty::ndarray< int,1 > > _467,    std::shared_ptr< monty::ndarray< int,1 > > _468,    std::shared_ptr< monty::ndarray< int,1 > > _469) :    ConNZStruct(new mosek::fusion::p_ConNZStruct(this)){ mosek::fusion::p_ConNZStruct::_get_impl(this)->_initialize(_463,_464,_465,_466,_467,_468,_469); }void mosek::fusion::p_ConNZStruct::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _463,    std::shared_ptr< monty::ndarray< int,1 > > _464,    std::shared_ptr< monty::ndarray< double,1 > > _465,    std::shared_ptr< monty::ndarray< double,1 > > _466,    std::shared_ptr< monty::ndarray< int,1 > > _467,    std::shared_ptr< monty::ndarray< int,1 > > _468,    std::shared_ptr< monty::ndarray< int,1 > > _469){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__463(_463 ? _463->raw() : nullptr, _463 ? _463->size(0) : 0);
    _checked_ptr_1<int> _ptr__464(_464 ? _464->raw() : nullptr, _464 ? _464->size(0) : 0);
    _checked_ptr_1<double> _ptr__465(_465 ? _465->raw() : nullptr, _465 ? _465->size(0) : 0);
    _checked_ptr_1<double> _ptr__466(_466 ? _466->raw() : nullptr, _466 ? _466->size(0) : 0);
    _checked_ptr_1<int> _ptr__467(_467 ? _467->raw() : nullptr, _467 ? _467->size(0) : 0);
    _checked_ptr_1<int> _ptr__468(_468 ? _468->raw() : nullptr, _468 ? _468->size(0) : 0);
    _checked_ptr_1<int> _ptr__469(_469 ? _469->raw() : nullptr, _469 ? _469->size(0) : 0);
    ptrb = _463;
    subj = _464;
    cof = _465;
    bfix = _466;
    barsubi = _467;
    barsubj = _468;
    barmidx = _469;
  }
}void mosek::fusion::p_ConNZStruct::destroy(){barmidx.reset();barsubj.reset();barsubi.reset();bfix.reset();cof.reset();subj.reset();ptrb.reset();}void mosek::fusion::ConNZStruct::destroy() { mosek::fusion::p_ConNZStruct::_get_impl(this)->destroy(); }mosek::fusion::Model::Model(mosek::fusion::p_Model *_impl) : mosek::fusion::BaseModel(_impl) { /*std::cout << "Model()" << this << std::endl; */ }mosek::fusion::Model::~Model() {  /* std::cout << "~Model()" << this << std::endl << std::flush; */ }mosek::fusion::p_Model::p_Model  (::mosek::fusion::Model * _pubthis) :     mosek::fusion::p_BaseModel(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (monty::rc_ptr< ::mosek::fusion::Model > _470){ return new mosek::fusion::Model(_470); }mosek::fusion::Model::Model  (monty::rc_ptr< ::mosek::fusion::Model > _470) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_470); }void mosek::fusion::p_Model::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _470){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_470);
    monty::rc_ptr< ::mosek::fusion::Model > _471 = ::mosek::fusion::Model::t(_pubthis);
    model_name = mosek::fusion::p_Model::_get_impl(_470)->model_name;
    acceptable_sol = mosek::fusion::p_Model::_get_impl(_470)->acceptable_sol;
    solutionptr = mosek::fusion::p_Model::_get_impl(_470)->solutionptr;
    natvarmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natvarmap_blockid);
    natvarmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natvarmap_idx);
    natvarmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natvarmap_type);
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_470)->natvarmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _8704;
    for (int _472 = (int)0, _8705 = (int)((mosek::fusion::p_Model::_get_impl(_470)->vars)->size(0)); _472 < _8705 ; ++_472)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _8706;
      bool _8707 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_470)->vars)(_472)).get());
      if (_8707)
      {
        _8706 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_470)->vars)(_472)).get())->__mosek_2fusion_2ModelVariable__clone(_471);
      }
      else
      {
        _8706 = nullptr;
      }
      _8704.push_back(_8706);
    }
    auto _8708 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_8704.size()),_8704.begin(),_8704.end()));
    vars = _8708;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_470)->natconemap);
    natconemap_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconemap_dim);
    natbarvar_numbarvarelm = mosek::fusion::p_Model::_get_impl(_470)->natbarvar_numbarvarelm;
    natbarvar_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natbarvar_ptr);
    natbarvar_i = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natbarvar_i);
    natbarvar_j = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natbarvar_j);
    natbarvar_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natbarvar_idx);
    natbarvarmap_nblock = mosek::fusion::p_Model::_get_impl(_470)->natbarvarmap_nblock;
    natbarvar_dim = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natbarvar_dim);
    natbarvarmap_num = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natbarvarmap_num);
    natbarvarmap_ptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natbarvarmap_ptr);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _8709;
    for (int _473 = (int)0, _8710 = (int)((mosek::fusion::p_Model::_get_impl(_470)->barvars)->size(0)); _473 < _8710 ; ++_473)
    {
      monty::rc_ptr< ::mosek::fusion::ModelVariable > _8711;
      bool _8712 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_470)->barvars)(_473)).get());
      if (_8712)
      {
        _8711 = mosek::fusion::p_ModelVariable::_get_impl(((*mosek::fusion::p_Model::_get_impl(_470)->barvars)(_473)).get())->__mosek_2fusion_2ModelVariable__clone(_471);
      }
      else
      {
        _8711 = nullptr;
      }
      _8709.push_back(_8711);
    }
    auto _8713 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_8709.size()),_8709.begin(),_8709.end()));
    barvars = _8713;
    var_map = mosek::fusion::p_Model::_get_impl(_470)->var_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    natconmap_blockid = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_blockid);
    natconmap_slackidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_slackidx);
    natconmap_idx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_idx);
    natconmap_type = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_type);
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks(mosek::fusion::p_Model::_get_impl(_470)->natconmap);
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _8714;
    for (int _474 = (int)0, _8715 = (int)((mosek::fusion::p_Model::_get_impl(_470)->cons)->size(0)); _474 < _8715 ; ++_474)
    {
      monty::rc_ptr< ::mosek::fusion::ModelConstraint > _8716;
      bool _8717 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_470)->cons)(_474)).get());
      if (_8717)
      {
        _8716 = mosek::fusion::p_ModelConstraint::_get_impl(((*mosek::fusion::p_Model::_get_impl(_470)->cons)(_474)).get())->__mosek_2fusion_2ModelConstraint__clone(_471);
      }
      else
      {
        _8716 = nullptr;
      }
      _8714.push_back(_8716);
    }
    auto _8718 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_8714.size()),_8714.begin(),_8714.end()));
    cons = _8718;
    con_map = mosek::fusion::p_Model::_get_impl(_470)->con_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    numparameter = mosek::fusion::p_Model::_get_impl(_470)->numparameter;
    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _8719;
    bool _8720 = (NULL == mosek::fusion::p_Model::_get_impl(_470)->parameters.get());
    if (_8720)
    {
      _8719 = nullptr;
    }
    else
    {
      std::vector<monty::rc_ptr< ::mosek::fusion::Parameter >> _8721;
      for (int _475 = (int)0, _8722 = (int)((mosek::fusion::p_Model::_get_impl(_470)->parameters)->size(0)); _475 < _8722 ; ++_475)
      {
        monty::rc_ptr< ::mosek::fusion::Parameter > _8723;
        bool _8724 = (NULL != ((*mosek::fusion::p_Model::_get_impl(_470)->parameters)(_475)).get());
        if (_8724)
        {
          _8723 = ((*mosek::fusion::p_Model::_get_impl(_470)->parameters)(_475))->__mosek_2fusion_2Parameter__clone(_471);
        }
        else
        {
          _8723 = nullptr;
        }
        _8721.push_back(_8723);
      }
      auto _8725 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >(monty::shape(_8721.size()),_8721.begin(),_8721.end()));
      _8719 = _8725;
    }
    parameters = _8719;
    par_map = mosek::fusion::p_Model::_get_impl(_470)->par_map->__mosek_2fusion_2Utils_2StringIntMap__clone();
    param_num = mosek::fusion::p_Model::_get_impl(_470)->param_num;
    param_value = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->param_value);
    natconmap_codenztop = mosek::fusion::p_Model::_get_impl(_470)->natconmap_codenztop;
    natconmap_codeatomtop = mosek::fusion::p_Model::_get_impl(_470)->natconmap_codeatomtop;
    natconmap_numparameterized = mosek::fusion::p_Model::_get_impl(_470)->natconmap_numparameterized;
    natconmap_coderowptrb = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_coderowptrb);
    natconmap_coderowptre = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_coderowptre);
    natconmap_codenidx = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_codenidx);
    natconmap_codeptr = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_codeptr);
    natconmap_code = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_code);
    natconmap_cconst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_cconst);
    std::shared_ptr< monty::ndarray< long long,1 > > _8726;
    bool _8727 = (NULL != mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcodenidx.get());
    if (_8727)
    {
      _8726 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcodenidx);
    }
    else
    {
      _8726 = nullptr;
    }
    natconmap_objcodenidx = _8726;
    std::shared_ptr< monty::ndarray< int,1 > > _8728;
    bool _8729 = (NULL != mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcodeptr.get());
    if (_8729)
    {
      _8728 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcodeptr);
    }
    else
    {
      _8728 = nullptr;
    }
    natconmap_objcodeptr = _8728;
    std::shared_ptr< monty::ndarray< int,1 > > _8730;
    bool _8731 = (NULL != mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcode.get());
    if (_8731)
    {
      _8730 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcode);
    }
    else
    {
      _8730 = nullptr;
    }
    natconmap_objcode = _8730;
    std::shared_ptr< monty::ndarray< double,1 > > _8732;
    bool _8733 = (NULL != mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcconst.get());
    if (_8733)
    {
      _8732 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Model::_get_impl(_470)->natconmap_objcconst);
    }
    else
    {
      _8732 = nullptr;
    }
    natconmap_objcconst = _8732;
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    bfixidx = mosek::fusion::p_Model::_get_impl(_470)->bfixidx;
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (const std::string &  _476){ return new mosek::fusion::Model(_476); }mosek::fusion::Model::Model  (const std::string &  _476) :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(_476); }void mosek::fusion::p_Model::_initialize  (const std::string &  _476){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseModel::_initialize(_476,std::string (""));
    model_name = _476;
    acceptable_sol = ::mosek::fusion::AccSolutionStatus::Optimal;
    solutionptr = ::mosek::fusion::SolutionType::Default;
    natvarmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natvarmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natvarmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelVariable >> _8734;
    for (int _477 = (int)0, _8735 = (int)1024; _477 < _8735 ; ++_477)
    {
      _8734.push_back(nullptr);
    }
    auto _8736 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_8734.size()),_8734.begin(),_8734.end()));
    vars = _8736;
    natconemap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconemap_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    natbarvar_ptr = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
    natbarvar_numbarvarelm = (int)0;
    natbarvar_i = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_j = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvar_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_nblock = (int)0;
    natbarvar_dim = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_num = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
    natbarvarmap_ptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
    barvars = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape((int)0)));
    var_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    initsol_xx = nullptr;
    initsol_xx_flag = nullptr;
    natconmap = ::mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks();
    natconmap_blockid = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_slackidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_idx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_type = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_coderowptrb = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_coderowptre = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    std::vector<monty::rc_ptr< ::mosek::fusion::ModelConstraint >> _8737;
    for (int _478 = (int)0, _8738 = (int)1024; _478 < _8738 ; ++_478)
    {
      _8737.push_back(nullptr);
    }
    auto _8739 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_8737.size()),_8737.begin(),_8737.end()));
    cons = _8739;
    con_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    numparameter = (int)0;
    parameters = nullptr;
    par_map = ::mosek::fusion::Utils::p_StringIntMap::_new_StringIntMap();
    param_num = (int)0;
    param_value = nullptr;
    natconmap_numparameterized = (int)0;
    natconmap_codeatomtop = (int)0;
    natconmap_codenztop = (int)0;
    natconmap_codenidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1024)));
    natconmap_codeptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_code = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)1024)));
    natconmap_cconst = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)1024)));
    natconmap_objcodenidx = nullptr;
    natconmap_objcodeptr = nullptr;
    natconmap_objcode = nullptr;
    natconmap_objcconst = nullptr;
    bfixidx = natvarmap_alloc((int)1);
    task_var_putboundlist_fx(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(bfixidx)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}));
    task_var_name(bfixidx,std::string ("1.0"));
    rs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    ws = ::mosek::fusion::p_WorkStack::_new_WorkStack();
    xs = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  }
}mosek::fusion::Model::t mosek::fusion::p_Model::_new_Model  (){ return new mosek::fusion::Model(); }mosek::fusion::Model::Model  () :    Model(new mosek::fusion::p_Model(this)){ mosek::fusion::p_Model::_get_impl(this)->_initialize(); }void mosek::fusion::p_Model::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Model::_initialize(std::string (""));
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_Model::__mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _479,std::shared_ptr< monty::ndarray< int,1 > > _480,std::shared_ptr< monty::ndarray< int,1 > > _481){
  _checked_ptr_1<int> _ptr__480(_480 ? _480->raw() : nullptr, _480 ? _480->size(0) : 0);
  _checked_ptr_1<int> _ptr__481(_481 ? _481->raw() : nullptr, _481 ? _481->size(0) : 0);
  return _479;
}
void mosek::fusion::p_Model::connames(std::shared_ptr< monty::ndarray< int,1 > > _482,const std::string & _483,std::shared_ptr< monty::ndarray< int,1 > > _484,std::shared_ptr< monty::ndarray< long long,1 > > _485){
  _checked_ptr_1<int> _ptr__482(_482 ? _482->raw() : nullptr, _482 ? _482->size(0) : 0);
  _checked_ptr_1<int> _ptr__484(_484 ? _484->raw() : nullptr, _484 ? _484->size(0) : 0);
  _checked_ptr_1<long long> _ptr__485(_485 ? _485->raw() : nullptr, _485 ? _485->size(0) : 0);
  task_format_con_names(_482,_483,_484,_485);
}
void mosek::fusion::p_Model::varnames(std::shared_ptr< monty::ndarray< int,1 > > _486,const std::string & _487,std::shared_ptr< monty::ndarray< int,1 > > _488,std::shared_ptr< monty::ndarray< long long,1 > > _489){
  _checked_ptr_1<int> _ptr__486(_486 ? _486->raw() : nullptr, _486 ? _486->size(0) : 0);
  _checked_ptr_1<int> _ptr__488(_488 ? _488->raw() : nullptr, _488 ? _488->size(0) : 0);
  _checked_ptr_1<long long> _ptr__489(_489 ? _489->raw() : nullptr, _489 ? _489->size(0) : 0);
  task_format_var_names(_486,_487,_488,_489);
}
void mosek::fusion::p_Model::varname(int _490,const std::string & _491){
  task_var_name(_490,_491);
}
void mosek::fusion::p_Model::natbarvarmap_get(int _492,std::shared_ptr< monty::ndarray< int,1 > > _493){
  _checked_ptr_1<int> _ptr__493(_493 ? _493->raw() : nullptr, _493 ? _493->size(0) : 0);
  int _494 = ((*natbarvarmap_ptr)(_492));
  int _495 = ((*natbarvarmap_num)(_492));
  int _8740 = (int)0;
  int _8741 = _495;
  for (int _496 = _8740; _496 < _8741; ++_496)
  {
    {
      _ptr__493[_496] = safe_add( _494,_496 );
    }
  }
}
void mosek::fusion::p_Model::natbarvar_get(int _497,std::shared_ptr< monty::ndarray< long long,1 > > _498){
  _checked_ptr_1<long long> _ptr__498(_498 ? _498->raw() : nullptr, _498 ? _498->size(0) : 0);
  int _499 = ((*natbarvarmap_ptr)(_497));
  int _500 = ((*natbarvarmap_num)(_497));
  int _501 = ((*natbarvar_dim)(((*natbarvarmap_ptr)(_497))));
  int _502 = (safe_mul( safe_mul( _500,_501 ),safe_add( _501,(int)1 ) ) / (int)2);
  long long _503 = ((*natbarvar_ptr)(_499));
  int _8742 = (int)0;
  int _8743 = _502;
  for (int _504 = _8742; _504 < _8743; ++_504)
  {
    {
      _ptr__498[_504] = safe_add( _503,_504 );
    }
  }
}
int mosek::fusion::p_Model::natbarvarmap_alloc(int _505,int _506){
  int _507 = (int)((natbarvar_idx)->size(0));
  int _508 = task_numbarvar();
  int _509 = (safe_mul( _506,safe_add( _506,(int)1 ) ) / (int)2);
  int _510 = safe_mul( _505,_509 );
  if ((safe_add( natbarvar_numbarvarelm,_510 ) >= _507))
  {
    {
      if ((_510 < _507))
      {
        {
          _510 = _507;
        }
      }
      {}
      natbarvar_idx = ::mosek::fusion::p_CommonTools::resize(natbarvar_idx,safe_add( _507,_510 ));
      natbarvar_i = ::mosek::fusion::p_CommonTools::resize(natbarvar_i,safe_add( _507,_510 ));
      natbarvar_j = ::mosek::fusion::p_CommonTools::resize(natbarvar_j,safe_add( _507,_510 ));
    }
  }
  {}
  if ((safe_add( natbarvarmap_nblock,(int)1 ) >= (int)((natbarvarmap_num)->size(0))))
  {
    {
      int _8744;
      bool _8745 = ((int)((natbarvarmap_num)->size(0)) > (int)0);
      if (_8745)
      {
        _8744 = safe_mul( (int)((natbarvarmap_num)->size(0)),(int)2 );
      }
      else
      {
        _8744 = (int)32;
      }
      int _511 = _8744;
      natbarvarmap_num = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_num,_511);
      natbarvarmap_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvarmap_ptr,safe_add( _511,(int)1 ));
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _512 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_511)));
      int _8746 = (int)0;
      int _8747 = (int)((barvars)->size(0));
      for (int _513 = _8746; _513 < _8747; ++_513)
      {
        {
          ((*_512)(_513)) = ((*barvars)(_513));
        }
      }
      barvars = _512;
    }
  }
  {}
  if ((safe_add( _508,_505 ) > (int)((natbarvar_dim)->size(0))))
  {
    {
      int _8748;
      bool _8749 = (safe_add( _508,_505 ) < safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 ));
      if (_8749)
      {
        _8748 = safe_mul( (int)((natbarvar_dim)->size(0)),(int)2 );
      }
      else
      {
        _8748 = safe_add( _508,_505 );
      }
      int _514 = _8748;
      natbarvar_dim = ::mosek::fusion::p_CommonTools::resize(natbarvar_dim,_514);
    }
  }
  {}
  if ((safe_add( _508,_505 ) >= (int)((natbarvar_ptr)->size(0))))
  {
    {
      int _8750;
      bool _8751 = (_505 > (int)((natbarvar_ptr)->size(0)));
      if (_8751)
      {
        _8750 = _505;
      }
      else
      {
        _8750 = (int)((natbarvar_ptr)->size(0));
      }
      int _515 = _8750;
      natbarvar_ptr = ::mosek::fusion::p_CommonTools::resize(natbarvar_ptr,safe_add( safe_add( (int)((natbarvar_ptr)->size(0)),_515 ),(int)1 ));
    }
  }
  {}
  int _8752 = (int)0;
  int _8753 = _505;
  for (int _516 = _8752; _516 < _8753; ++_516)
  {
    {
      ((*natbarvar_dim)(safe_add( _508,_516 ))) = _506;
    }
  }
  ((*natbarvarmap_num)(natbarvarmap_nblock)) = _505;
  ((*natbarvarmap_ptr)(safe_add( natbarvarmap_nblock,(int)1 ))) = safe_add( ((*natbarvarmap_ptr)(natbarvarmap_nblock)),_505 );
  int _517 = task_append_barvar(_506,_505);
  int _518 = ((*natbarvarmap_ptr)(natbarvarmap_nblock));
  {
    long long _519 = ((*natbarvar_ptr)(_508));
    int _8754 = (int)0;
    int _8755 = _506;
    for (int _520 = _8754; _520 < _8755; ++_520)
    {
      {
        int _8756 = _520;
        int _8757 = _506;
        for (int _521 = _8756; _521 < _8757; ++_521)
        {
          {
            int _8758 = (int)0;
            int _8759 = _505;
            for (int _522 = _8758; _522 < _8759; ++_522)
            {
              {
                ((*natbarvar_idx)(safe_add( _519,safe_mul( _522,_509 ) ))) = safe_add( _518,_522 );
                ((*natbarvar_i)(safe_add( _519,safe_mul( _522,_509 ) ))) = _521;
                ((*natbarvar_j)(safe_add( _519,safe_mul( _522,_509 ) ))) = _520;
              }
            }
            ++ _519;
          }
        }
      }
    }
    int _8760 = (int)0;
    int _8761 = _505;
    for (int _523 = _8760; _523 < _8761; ++_523)
    {
      {
        ((*natbarvar_ptr)(safe_add( safe_add( _518,_523 ),(int)1 ))) = safe_add( ((*natbarvar_ptr)(safe_add( _518,_523 ))),_509 );
      }
    }
  }
  natbarvarmap_nblock += (int)1;
  natbarvar_numbarvarelm += safe_mul( _505,_509 );
  return (natbarvarmap_nblock - (int)1);
}
int mosek::fusion::p_Model::natvarmap_alloc(int _524){
  int _525 = natvarmap->alloc(_524);
  int _526 = safe_add( natvarmap->maxidx(_525),(int)1 );
  int _527 = natvarmap->capacity();
  int _528 = natvarmap->numblocks();
  if (((int)((natvarmap_idx)->size(0)) < _527))
  {
    {
      int _529 = (int)((natvarmap_idx)->size(0));
      natvarmap_idx = ::mosek::fusion::p_CommonTools::resize(natvarmap_idx,_527);
      int _8762 = _529;
      int _8763 = _527;
      for (int _530 = _8762; _530 < _8763; ++_530)
      {
        {
          ((*natvarmap_idx)(_530)) = (-(int)1);
        }
      }
      natvarmap_blockid = ::mosek::fusion::p_CommonTools::resize(natvarmap_blockid,_527);
    }
  }
  {}
  if (((int)((vars)->size(0)) < _528))
  {
    {
      natvarmap_type = ::mosek::fusion::p_CommonTools::resize(natvarmap_type,_528);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > _531 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 >(monty::shape(_528)));
      int _8764 = (int)0;
      int _8765 = (int)((vars)->size(0));
      for (int _532 = _8764; _532 < _8765; ++_532)
      {
        {
          ((*_531)(_532)) = ((*vars)(_532));
        }
      }
      int _8766 = (int)((vars)->size(0));
      int _8767 = (int)((_531)->size(0));
      for (int _533 = _8766; _533 < _8767; ++_533)
      {
        {
          ((*_531)(_533)) = nullptr;
        }
      }
      vars = _531;
    }
  }
  {}
  if ((task_numvar() < _526))
  {
    {
      task_append_var((_526 - task_numvar()));
    }
  }
  {}
  return _525;
}
void mosek::fusion::p_Model::natconmap_codealloc(int _534,int _535){
  int _536 = safe_add( _534,natconmap_codenztop );
  int _537 = safe_add( _535,natconmap_codeatomtop );
  if ((_536 > (int)((natconmap_codenidx)->size(0))))
  {
    {
      if ((_536 < safe_mul( (int)2,(int)((natconmap_codenidx)->size(0)) )))
      {
        {
          _536 = safe_mul( (int)2,(int)((natconmap_codenidx)->size(0)) );
        }
      }
      {}
      std::shared_ptr< monty::ndarray< long long,1 > > _538 = natconmap_codenidx;
      _checked_ptr_1<long long> _ptr__538(_538 ? _538->raw() : nullptr,_538 ? _538->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _539 = natconmap_codeptr;
      _checked_ptr_1<int> _ptr__539(_539 ? _539->raw() : nullptr,_539 ? _539->size(0) : 0);
      natconmap_codenidx = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_536)));
      ::mosek::fusion::Utils::Tools::arraycopy(_538,(int)0,natconmap_codenidx,(int)0,(int)((_538)->size(0)));
      natconmap_codeptr = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _536,(int)1 ))));
      ::mosek::fusion::Utils::Tools::arraycopy(_539,(int)0,natconmap_codeptr,(int)0,(int)((_539)->size(0)));
    }
  }
  {}
  if ((_537 > (int)((natconmap_code)->size(0))))
  {
    {
      if ((_537 < safe_mul( (int)2,(int)((natconmap_code)->size(0)) )))
      {
        {
          _537 = safe_mul( (int)2,(int)((natconmap_code)->size(0)) );
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,1 > > _540 = natconmap_code;
      _checked_ptr_1<int> _ptr__540(_540 ? _540->raw() : nullptr,_540 ? _540->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _541 = natconmap_cconst;
      _checked_ptr_1<double> _ptr__541(_541 ? _541->raw() : nullptr,_541 ? _541->size(0) : 0);
      natconmap_code = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_537)));
      ::mosek::fusion::Utils::Tools::arraycopy(_540,(int)0,natconmap_code,(int)0,(int)((_540)->size(0)));
      natconmap_cconst = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( _537,(int)1 ))));
      ::mosek::fusion::Utils::Tools::arraycopy(_541,(int)0,natconmap_cconst,(int)0,(int)((_541)->size(0)));
    }
  }
  {}
  natconmap_codenztop += _534;
  natconmap_codeatomtop += _535;
}
int mosek::fusion::p_Model::natconmap_alloc(int _542){
  int _543 = natconmap->alloc(_542);
  int _544 = safe_add( natconmap->maxidx(_543),(int)1 );
  int _545 = natconmap->capacity();
  int _546 = natconmap->numblocks();
  if (((int)((natconmap_idx)->size(0)) < _545))
  {
    {
      int _547 = (int)((natconmap_idx)->size(0));
      natconmap_idx = ::mosek::fusion::p_CommonTools::resize(natconmap_idx,_545);
      int _8768 = _547;
      int _8769 = _545;
      for (int _548 = _8768; _548 < _8769; ++_548)
      {
        {
          ((*natconmap_idx)(_548)) = (-(int)1);
        }
      }
      natconmap_blockid = ::mosek::fusion::p_CommonTools::resize(natconmap_blockid,_545);
      natconmap_slackidx = ::mosek::fusion::p_CommonTools::resize(natconmap_slackidx,_545);
      natconmap_coderowptrb = ::mosek::fusion::p_CommonTools::resize(natconmap_coderowptrb,_545);
      natconmap_coderowptre = ::mosek::fusion::p_CommonTools::resize(natconmap_coderowptre,_545);
    }
  }
  {}
  if (((int)((cons)->size(0)) < _546))
  {
    {
      natconmap_type = ::mosek::fusion::p_CommonTools::resize(natconmap_type,_546);
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > _549 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 >(monty::shape(_546)));
      int _8770 = (int)0;
      int _8771 = (int)((cons)->size(0));
      for (int _550 = _8770; _550 < _8771; ++_550)
      {
        {
          ((*_549)(_550)) = ((*cons)(_550));
        }
      }
      int _8772 = (int)((cons)->size(0));
      int _8773 = _546;
      for (int _551 = _8772; _551 < _8773; ++_551)
      {
        {
          ((*_549)(_551)) = nullptr;
        }
      }
      cons = _549;
    }
  }
  {}
  if ((_544 > task_numcon()))
  {
    {
      task_append_con((_544 - task_numcon()));
    }
  }
  {}
  return _543;
}
int mosek::fusion::p_Model::natconemap_alloc(int _552){
  int _553 = natconemap->alloc(_552);
  int _554 = safe_add( natconemap->maxidx(_553),(int)1 );
  if ((_554 > task_numcone()))
  {
    {
      task_append_zerocones((_554 - task_numcone()));
    }
  }
  {}
  natconemap_dim = ::mosek::fusion::p_CommonTools::resize(natconemap_dim,natconemap->numblocks());
  return _553;
}
void mosek::fusion::p_Model::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _555){
  _checked_ptr_1<long long> _ptr__555(_555 ? _555->raw() : nullptr, _555 ? _555->size(0) : 0);
  int _556 = (int)0;
  int _8774 = (int)0;
  int _8775 = (int)((_555)->size(0));
  for (int _557 = _8774; _557 < _8775; ++_557)
  {
    {
      if ((_ptr__555[_557] > (int)0))
      {
        {
          ++ _556;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _558 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_556)));
  _checked_ptr_1<int> _ptr__558(_558 ? _558->raw() : nullptr,_558 ? _558->size(0) : 0);
  int _559 = (int)0;
  int _8776 = (int)0;
  int _8777 = (int)((_555)->size(0));
  for (int _560 = _8776; _560 < _8777; ++_560)
  {
    {
      if ((_ptr__555[_560] > (int)0))
      {
        {
          _ptr__558[_559] = (int)_ptr__555[_560];
          ++ _559;
        }
      }
      {}
    }
  }
  task_var_putcontlist(_558);
}
void mosek::fusion::p_Model::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _561){
  _checked_ptr_1<long long> _ptr__561(_561 ? _561->raw() : nullptr, _561 ? _561->size(0) : 0);
  int _562 = (int)0;
  int _8778 = (int)0;
  int _8779 = (int)((_561)->size(0));
  for (int _563 = _8778; _563 < _8779; ++_563)
  {
    {
      if ((_ptr__561[_563] > (int)0))
      {
        {
          ++ _562;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _564 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_562)));
  _checked_ptr_1<int> _ptr__564(_564 ? _564->raw() : nullptr,_564 ? _564->size(0) : 0);
  int _565 = (int)0;
  int _8780 = (int)0;
  int _8781 = (int)((_561)->size(0));
  for (int _566 = _8780; _566 < _8781; ++_566)
  {
    {
      if ((_ptr__561[_566] > (int)0))
      {
        {
          _ptr__564[_565] = (int)_ptr__561[_566];
          ++ _565;
        }
      }
      {}
    }
  }
  task_var_putintlist(_564);
}
void mosek::fusion::Model::putlicensewait  ( bool _567) { mosek::fusion::p_Model::putlicensewait(_567); }void mosek::fusion::p_Model::putlicensewait(bool _567){
  ::mosek::fusion::p_BaseModel::env_putlicensewait(_567);
}
void mosek::fusion::Model::putlicensepath  ( const std::string & _568) { mosek::fusion::p_Model::putlicensepath(_568); }void mosek::fusion::p_Model::putlicensepath(const std::string & _568){
  ::mosek::fusion::p_BaseModel::env_putlicensepath(_568);
}
void mosek::fusion::Model::putlicensecode  ( std::shared_ptr< monty::ndarray< int,1 > > _569) { mosek::fusion::p_Model::putlicensecode(_569); }void mosek::fusion::p_Model::putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _569){
  _checked_ptr_1<int> _ptr__569(_569 ? _569->raw() : nullptr, _569 ? _569->size(0) : 0);
  ::mosek::fusion::p_BaseModel::env_putlicensecode(_569);
}
void mosek::fusion::Model :: dispose() { mosek::fusion::p_Model::_get_impl(this)->dispose(); }void mosek::fusion::p_Model::dispose(){
  int _8782 = (int)0;
  int _8783 = (int)((vars)->size(0));
  for (int _570 = _8782; _570 < _8783; ++_570)
  {
    {
      ((*vars)(_570)) = nullptr;
    }
  }
  int _8784 = (int)0;
  int _8785 = (int)((cons)->size(0));
  for (int _571 = _8784; _571 < _8785; ++_571)
  {
    {
      ((*cons)(_571)) = nullptr;
    }
  }
  ::mosek::fusion::p_BaseModel::dispose();
}
void mosek::fusion::p_Model::nativeVarToStr(int _572,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _573){
  if (((_572 < (int)0) || ((_572 >= (int)((natvarmap_idx)->size(0))) || (((*natvarmap_idx)(_572)) < (int)0))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Native variable index is invalid"));
    }
  }
  {}
  ((*vars)(((*natvarmap_blockid)(_572))))->elementName((long long)(((*natvarmap_idx)(_572))),_573);
}
MSKtask_t mosek::fusion::Model :: __mosek_2fusion_2Model__getTask() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getTask(); }MSKtask_t mosek::fusion::Model::getTask() { return __mosek_2fusion_2Model__getTask(); }
MSKtask_t mosek::fusion::p_Model::__mosek_2fusion_2Model__getTask(){
  return __mosek_2fusion_2BaseModel__task_get();
}
void mosek::fusion::Model :: getConstraintDuals(bool _574,std::shared_ptr< monty::ndarray< int,1 > > _575,std::shared_ptr< monty::ndarray< double,1 > > _576,int _577) { mosek::fusion::p_Model::_get_impl(this)->getConstraintDuals(_574,_575,_576,_577); }void mosek::fusion::p_Model::getConstraintDuals(bool _574,std::shared_ptr< monty::ndarray< int,1 > > _575,std::shared_ptr< monty::ndarray< double,1 > > _576,int _577){
  _checked_ptr_1<int> _ptr__575(_575 ? _575->raw() : nullptr, _575 ? _575->size(0) : 0);
  _checked_ptr_1<double> _ptr__576(_576 ? _576->raw() : nullptr, _576 ? _576->size(0) : 0);
  int _578 = (int)((_575)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _579 = getSolution_slx(::mosek::fusion::SolutionType::Default);
  _checked_ptr_1<double> _ptr__579(_579 ? _579->raw() : nullptr,_579 ? _579->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _580 = getSolution_sux(::mosek::fusion::SolutionType::Default);
  _checked_ptr_1<double> _ptr__580(_580 ? _580->raw() : nullptr,_580 ? _580->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _581 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  _checked_ptr_1<double> _ptr__581(_581 ? _581->raw() : nullptr,_581 ? _581->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _582 = getSolution_slc(::mosek::fusion::SolutionType::Default);
  _checked_ptr_1<double> _ptr__582(_582 ? _582->raw() : nullptr,_582 ? _582->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _583 = getSolution_suc(::mosek::fusion::SolutionType::Default);
  _checked_ptr_1<double> _ptr__583(_583 ? _583->raw() : nullptr,_583 ? _583->size(0) : 0);
  int _8786 = (int)0;
  int _8787 = _578;
  for (int _584 = _8786; _584 < _8787; ++_584)
  {
    {
      long long _585 = ((*natconmap_slackidx)(_ptr__575[_584]));
      if ((_585 < (int)0))
      {
        {
          long long _586 = (-safe_add( _585,(int)1 ));
          if (_574)
          {
            {
              _ptr__576[safe_add( _577,_584 )] = _ptr__581[_586];
            }
          }
          else
          {
            {
              _ptr__576[safe_add( _577,_584 )] = (-_ptr__581[_586]);
            }
          }
        }
      }
      else if((_585 > (int)0))
      {
        {
          _ptr__576[safe_add( _577,_584 )] = (_ptr__579[(_585 - (int)1)] - _ptr__580[(_585 - (int)1)]);
        }
      }
      else
      {
        {
          if (_574)
          {
            {
              _ptr__576[safe_add( _577,_584 )] = _ptr__582[_ptr__575[_584]];
            }
          }
          else
          {
            {
              _ptr__576[safe_add( _577,_584 )] = (-_ptr__583[_ptr__575[_584]]);
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getConstraintValues(bool _587,std::shared_ptr< monty::ndarray< int,1 > > _588,std::shared_ptr< monty::ndarray< double,1 > > _589,int _590) { mosek::fusion::p_Model::_get_impl(this)->getConstraintValues(_587,_588,_589,_590); }void mosek::fusion::p_Model::getConstraintValues(bool _587,std::shared_ptr< monty::ndarray< int,1 > > _588,std::shared_ptr< monty::ndarray< double,1 > > _589,int _590){
  _checked_ptr_1<int> _ptr__588(_588 ? _588->raw() : nullptr, _588 ? _588->size(0) : 0);
  _checked_ptr_1<double> _ptr__589(_589 ? _589->raw() : nullptr, _589 ? _589->size(0) : 0);
  int _591 = (int)((_588)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _8788;
  bool _8789 = _587;
  if (_8789)
  {
    _8788 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _8788 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _592 = _8788;
  _checked_ptr_1<double> _ptr__592(_592 ? _592->raw() : nullptr,_592 ? _592->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _8790;
  bool _8791 = _587;
  if (_8791)
  {
    _8790 = getSolution_barx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _8790 = getSolution_bars(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _593 = _8790;
  _checked_ptr_1<double> _ptr__593(_593 ? _593->raw() : nullptr,_593 ? _593->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _8792;
  bool _8793 = _587;
  if (_8793)
  {
    _8792 = getSolution_xc(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _8792 = getSolution_y(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _594 = _8792;
  _checked_ptr_1<double> _ptr__594(_594 ? _594->raw() : nullptr,_594 ? _594->size(0) : 0);
  int _8794 = (int)0;
  int _8795 = _591;
  for (int _595 = _8794; _595 < _8795; ++_595)
  {
    {
      long long _596 = ((*natconmap_slackidx)(_ptr__588[_595]));
      if ((_596 < (int)0))
      {
        {
          long long _597 = (-safe_add( _596,(int)1 ));
          _ptr__589[safe_add( _590,_595 )] = _ptr__593[_597];
        }
      }
      else if((_596 > (int)0))
      {
        {
          _ptr__589[safe_add( _590,_595 )] = _ptr__592[(_596 - (int)1)];
        }
      }
      else
      {
        {
          _ptr__589[safe_add( _590,_595 )] = _ptr__594[_ptr__588[_595]];
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableDuals(bool _598,std::shared_ptr< monty::ndarray< long long,1 > > _599,std::shared_ptr< monty::ndarray< double,1 > > _600,int _601) { mosek::fusion::p_Model::_get_impl(this)->getVariableDuals(_598,_599,_600,_601); }void mosek::fusion::p_Model::getVariableDuals(bool _598,std::shared_ptr< monty::ndarray< long long,1 > > _599,std::shared_ptr< monty::ndarray< double,1 > > _600,int _601){
  _checked_ptr_1<long long> _ptr__599(_599 ? _599->raw() : nullptr, _599 ? _599->size(0) : 0);
  _checked_ptr_1<double> _ptr__600(_600 ? _600->raw() : nullptr, _600 ? _600->size(0) : 0);
  int _602 = (int)((_599)->size(0));
  if (_598)
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _603 = getSolution_slx(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__603(_603 ? _603->raw() : nullptr,_603 ? _603->size(0) : 0);
      int _8796 = (int)0;
      int _8797 = _602;
      for (int _604 = _8796; _604 < _8797; ++_604)
      {
        {
          if ((_ptr__599[_604] > (int)0))
          {
            {
              _ptr__600[safe_add( _601,_604 )] = _ptr__603[_ptr__599[_604]];
            }
          }
          else
          {
            {
              _ptr__600[safe_add( _601,_604 )] = (int)0;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _605 = getSolution_sux(::mosek::fusion::SolutionType::Default);
      _checked_ptr_1<double> _ptr__605(_605 ? _605->raw() : nullptr,_605 ? _605->size(0) : 0);
      int _8798 = (int)0;
      int _8799 = _602;
      for (int _606 = _8798; _606 < _8799; ++_606)
      {
        {
          if ((_ptr__599[_606] > (int)0))
          {
            {
              _ptr__600[safe_add( _601,_606 )] = (-_ptr__605[_ptr__599[_606]]);
            }
          }
          else
          {
            {
              _ptr__600[safe_add( _601,_606 )] = (int)0;
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::Model :: getVariableValues(bool _607,std::shared_ptr< monty::ndarray< long long,1 > > _608,std::shared_ptr< monty::ndarray< double,1 > > _609,int _610) { mosek::fusion::p_Model::_get_impl(this)->getVariableValues(_607,_608,_609,_610); }void mosek::fusion::p_Model::getVariableValues(bool _607,std::shared_ptr< monty::ndarray< long long,1 > > _608,std::shared_ptr< monty::ndarray< double,1 > > _609,int _610){
  _checked_ptr_1<long long> _ptr__608(_608 ? _608->raw() : nullptr, _608 ? _608->size(0) : 0);
  _checked_ptr_1<double> _ptr__609(_609 ? _609->raw() : nullptr, _609 ? _609->size(0) : 0);
  int _611 = (int)((_608)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _8800;
  bool _8801 = _607;
  if (_8801)
  {
    _8800 = getSolution_xx(::mosek::fusion::SolutionType::Default);
  }
  else
  {
    _8800 = getSolution_yx(::mosek::fusion::SolutionType::Default);
  }
  std::shared_ptr< monty::ndarray< double,1 > > _612 = _8800;
  _checked_ptr_1<double> _ptr__612(_612 ? _612->raw() : nullptr,_612 ? _612->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _8802;
  bool _8803 = (natbarvar_numbarvarelm > (int)0);
  if (_8803)
  {
    std::shared_ptr< monty::ndarray< double,1 > > _8804;
    bool _8805 = _607;
    if (_8805)
    {
      _8804 = getSolution_barx(::mosek::fusion::SolutionType::Default);
    }
    else
    {
      _8804 = getSolution_bars(::mosek::fusion::SolutionType::Default);
    }
    _8802 = _8804;
  }
  else
  {
    _8802 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _613 = _8802;
  _checked_ptr_1<double> _ptr__613(_613 ? _613->raw() : nullptr,_613 ? _613->size(0) : 0);
  int _8806 = (int)0;
  int _8807 = _611;
  for (int _614 = _8806; _614 < _8807; ++_614)
  {
    {
      if ((_ptr__608[_614] > (int)0))
      {
        {
          _ptr__609[safe_add( _610,_614 )] = _ptr__612[_ptr__608[_614]];
        }
      }
      else if((_ptr__608[_614] < (int)0))
      {
        {
          long long _615 = (-safe_add( _ptr__608[_614],(int)1 ));
          _ptr__609[safe_add( _610,_614 )] = _ptr__613[_615];
        }
      }
      else
      {
        {
          _ptr__609[safe_add( _610,_614 )] = (int)0;
        }
      }
    }
  }
}
void mosek::fusion::Model :: setVariableValues(bool _616,std::shared_ptr< monty::ndarray< long long,1 > > _617,std::shared_ptr< monty::ndarray< double,1 > > _618) { mosek::fusion::p_Model::_get_impl(this)->setVariableValues(_616,_617,_618); }void mosek::fusion::p_Model::setVariableValues(bool _616,std::shared_ptr< monty::ndarray< long long,1 > > _617,std::shared_ptr< monty::ndarray< double,1 > > _618){
  _checked_ptr_1<long long> _ptr__617(_617 ? _617->raw() : nullptr, _617 ? _617->size(0) : 0);
  _checked_ptr_1<double> _ptr__618(_618 ? _618->raw() : nullptr, _618 ? _618->size(0) : 0);
  if (_616)
  {
    {
      int _619 = (int)0;
      int _8808 = (int)0;
      int _8809 = (int)((_617)->size(0));
      for (int _620 = _8808; _620 < _8809; ++_620)
      {
        {
          if ((_ptr__617[_620] >= (int)0))
          {
            {
              ++ _619;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _621 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_619)));
      _checked_ptr_1<int> _ptr__621(_621 ? _621->raw() : nullptr,_621 ? _621->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _8810;
      bool _8811 = (_619 == (int)((_617)->size(0)));
      if (_8811)
      {
        _8810 = _618;
      }
      else
      {
        _8810 = _618;
      }
      std::shared_ptr< monty::ndarray< double,1 > > _622 = _8810;
      _checked_ptr_1<double> _ptr__622(_622 ? _622->raw() : nullptr,_622 ? _622->size(0) : 0);
      int _623 = (int)0;
      int _8812 = (int)0;
      int _8813 = (int)((_617)->size(0));
      for (int _624 = _8812; _624 < _8813; ++_624)
      {
        {
          if ((_ptr__617[_624] > (int)0))
          {
            {
              _ptr__621[_623] = (int)_ptr__617[_624];
              ++ _623;
            }
          }
          {}
        }
      }
      setSolution_xx(_621,_622);
    }
  }
  else
  {
    {
    }
  }
}
void mosek::fusion::Model :: flushNames() { mosek::fusion::p_Model::_get_impl(this)->flushNames(); }void mosek::fusion::p_Model::flushNames(){
  int _8814 = (int)0;
  int _8815 = (int)((vars)->size(0));
  for (int _625 = _8814; _625 < _8815; ++_625)
  {
    {
      if ((NULL != ((*vars)(_625)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*vars)(_625)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _8816 = (int)0;
  int _8817 = (int)((barvars)->size(0));
  for (int _626 = _8816; _626 < _8817; ++_626)
  {
    {
      if ((NULL != ((*barvars)(_626)).get()))
      {
        {
          mosek::fusion::p_ModelVariable::_get_impl(((*barvars)(_626)).get())->flushNames();
        }
      }
      {}
    }
  }
  int _8818 = (int)0;
  int _8819 = (int)((cons)->size(0));
  for (int _627 = _8818; _627 < _8819; ++_627)
  {
    {
      if ((NULL != ((*cons)(_627)).get()))
      {
        {
          mosek::fusion::p_ModelConstraint::_get_impl(((*cons)(_627)).get())->flushNames();
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: writeTaskNoFlush(const std::string & _628) { mosek::fusion::p_Model::_get_impl(this)->writeTaskNoFlush(_628); }void mosek::fusion::p_Model::writeTaskNoFlush(const std::string & _628){
  _pubthis->flushNames();
  task_write(_628);
}
void mosek::fusion::Model :: writeTask(const std::string & _629) { mosek::fusion::p_Model::_get_impl(this)->writeTask(_629); }void mosek::fusion::p_Model::writeTask(const std::string & _629){
  _pubthis->flushNames();
  flush_parameters();
  task_write(_629);
}
long long mosek::fusion::Model :: getSolverLIntInfo(const std::string & _630) { return mosek::fusion::p_Model::_get_impl(this)->getSolverLIntInfo(_630); }long long mosek::fusion::p_Model::getSolverLIntInfo(const std::string & _630){
  return task_get_liinf(_630);
}
int mosek::fusion::Model :: getSolverIntInfo(const std::string & _631) { return mosek::fusion::p_Model::_get_impl(this)->getSolverIntInfo(_631); }int mosek::fusion::p_Model::getSolverIntInfo(const std::string & _631){
  return task_get_iinf(_631);
}
double mosek::fusion::Model :: getSolverDoubleInfo(const std::string & _632) { return mosek::fusion::p_Model::_get_impl(this)->getSolverDoubleInfo(_632); }double mosek::fusion::p_Model::getSolverDoubleInfo(const std::string & _632){
  return task_get_dinf(_632);
}
void mosek::fusion::Model :: setCallbackHandler(mosek::cbhandler_t _633) { mosek::fusion::p_Model::_get_impl(this)->setCallbackHandler(_633); }void mosek::fusion::p_Model::setCallbackHandler(mosek::cbhandler_t _633){
  task_setCallbackHandler(_633);
}
void mosek::fusion::Model :: setDataCallbackHandler(mosek::datacbhandler_t _634) { mosek::fusion::p_Model::_get_impl(this)->setDataCallbackHandler(_634); }void mosek::fusion::p_Model::setDataCallbackHandler(mosek::datacbhandler_t _634){
  task_setDataCallbackHandler(_634);
}
void mosek::fusion::Model :: setLogHandler(mosek::msghandler_t _635) { mosek::fusion::p_Model::_get_impl(this)->setLogHandler(_635); }void mosek::fusion::p_Model::setLogHandler(mosek::msghandler_t _635){
  task_setLogHandler(_635);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _636,double _637) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_636,_637); }void mosek::fusion::p_Model::setSolverParam(const std::string & _636,double _637){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_636,_637);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _638,int _639) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_638,_639); }void mosek::fusion::p_Model::setSolverParam(const std::string & _638,int _639){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_638,_639);
}
void mosek::fusion::Model :: setSolverParam(const std::string & _640,const std::string & _641) { mosek::fusion::p_Model::_get_impl(this)->setSolverParam(_640,_641); }void mosek::fusion::p_Model::setSolverParam(const std::string & _640,const std::string & _641){
  ::mosek::fusion::p_Parameters::setParameter(::mosek::fusion::Model::t(_pubthis),_640,_641);
}
void mosek::fusion::Model :: breakSolver() { mosek::fusion::p_Model::_get_impl(this)->breakSolver(); }void mosek::fusion::p_Model::breakSolver(){
  task_break_solve();
}
void mosek::fusion::Model :: optserverHost(const std::string & _642) { mosek::fusion::p_Model::_get_impl(this)->optserverHost(_642); }void mosek::fusion::p_Model::optserverHost(const std::string & _642){
  task_putoptserver_host(_642);
}
void mosek::fusion::Model :: solve(const std::string & _643,const std::string & _644) { mosek::fusion::p_Model::_get_impl(this)->solve(_643,_644); }void mosek::fusion::p_Model::solve(const std::string & _643,const std::string & _644){
  _pubthis->flushSolutions();
  flush_parameters();
  task_solve(true,_643,_644);
}
void mosek::fusion::Model :: solve() { mosek::fusion::p_Model::_get_impl(this)->solve(); }void mosek::fusion::p_Model::solve(){
  _pubthis->flushSolutions();
  flush_parameters();
  task_solve(false,std::string (""),std::string (""));
}
void mosek::fusion::p_Model::flush_parameters(){
  if ((natconmap_numparameterized > (int)0))
  {
    {
      int _645 = task_numcon();
      std::shared_ptr< monty::ndarray< int,1 > > _646 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natconmap_numparameterized)));
      _checked_ptr_1<int> _ptr__646(_646 ? _646->raw() : nullptr,_646 ? _646->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _647 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natconmap_numparameterized)));
      _checked_ptr_1<int> _ptr__647(_647 ? _647->raw() : nullptr,_647 ? _647->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _648 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(natconmap_numparameterized)));
      _checked_ptr_1<double> _ptr__648(_648 ? _648->raw() : nullptr,_648 ? _648->size(0) : 0);
      int _649 = (int)0;
      int _8820 = (int)0;
      int _8821 = _645;
      for (int _650 = _8820; _650 < _8821; ++_650)
      {
        {
          int _651 = (((*natconmap_coderowptre)(_650)) - ((*natconmap_coderowptrb)(_650)));
          if ((_651 > (int)0))
          {
            {
              int _8822 = _649;
              int _8823 = safe_add( _649,_651 );
              for (int _652 = _8822; _652 < _8823; ++_652)
              {
                {
                  _ptr__646[_652] = _650;
                }
              }
              _649 += _651;
            }
          }
          {}
        }
      }
      evaluate_parameterized(xs,_645,natconmap_coderowptrb,natconmap_coderowptre,natconmap_codenidx,natconmap_codeptr,natconmap_code,natconmap_cconst,_647,_648);
      task_putaijlist(_646,_647,_648,(long long)(natconmap_numparameterized));
    }
  }
  {}
  if ((NULL != natconmap_objcodenidx.get()))
  {
    {
      int _653 = (int)((natconmap_objcodenidx)->size(0));
      std::shared_ptr< monty::ndarray< int,1 > > _654 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_653)));
      _checked_ptr_1<int> _ptr__654(_654 ? _654->raw() : nullptr,_654 ? _654->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _655 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_653)));
      _checked_ptr_1<double> _ptr__655(_655 ? _655->raw() : nullptr,_655 ? _655->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _656 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      _checked_ptr_1<int> _ptr__656(_656 ? _656->raw() : nullptr,_656 ? _656->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _657 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((natconmap_objcodenidx)->size(0)))});
      _checked_ptr_1<int> _ptr__657(_657 ? _657->raw() : nullptr,_657 ? _657->size(0) : 0);
      evaluate_parameterized(xs,(int)1,_656,_657,natconmap_objcodenidx,natconmap_objcodeptr,natconmap_objcode,natconmap_objcconst,_654,_655);
      task_putclist(_654,_655);
    }
  }
  {}
}
void mosek::fusion::Model :: flushParameters() { mosek::fusion::p_Model::_get_impl(this)->flushParameters(); }void mosek::fusion::p_Model::flushParameters(){
  flush_parameters();
}
void mosek::fusion::p_Model::evaluate_parameterized(monty::rc_ptr< ::mosek::fusion::WorkStack > _658,int _659,std::shared_ptr< monty::ndarray< int,1 > > _660,std::shared_ptr< monty::ndarray< int,1 > > _661,std::shared_ptr< monty::ndarray< long long,1 > > _662,std::shared_ptr< monty::ndarray< int,1 > > _663,std::shared_ptr< monty::ndarray< int,1 > > _664,std::shared_ptr< monty::ndarray< double,1 > > _665,std::shared_ptr< monty::ndarray< int,1 > > _666,std::shared_ptr< monty::ndarray< double,1 > > _667){
  _checked_ptr_1<int> _ptr__660(_660 ? _660->raw() : nullptr, _660 ? _660->size(0) : 0);
  _checked_ptr_1<int> _ptr__661(_661 ? _661->raw() : nullptr, _661 ? _661->size(0) : 0);
  _checked_ptr_1<long long> _ptr__662(_662 ? _662->raw() : nullptr, _662 ? _662->size(0) : 0);
  _checked_ptr_1<int> _ptr__663(_663 ? _663->raw() : nullptr, _663 ? _663->size(0) : 0);
  _checked_ptr_1<int> _ptr__664(_664 ? _664->raw() : nullptr, _664 ? _664->size(0) : 0);
  _checked_ptr_1<double> _ptr__665(_665 ? _665->raw() : nullptr, _665 ? _665->size(0) : 0);
  _checked_ptr_1<int> _ptr__666(_666 ? _666->raw() : nullptr, _666 ? _666->size(0) : 0);
  _checked_ptr_1<double> _ptr__667(_667 ? _667->raw() : nullptr, _667 ? _667->size(0) : 0);
  int _668 = _658->allocf64((int)((_664)->size(0)));
  int _669 = (int)0;
  std::shared_ptr< monty::ndarray< double,1 > > _670 = mosek::fusion::p_WorkStack::_get_impl(_658)->f64;
  _checked_ptr_1<double> _ptr__670(_670 ? _670->raw() : nullptr,_670 ? _670->size(0) : 0);
  int _671 = (int)0;
  int _8824 = (int)0;
  int _8825 = _659;
  for (int _672 = _8824; _672 < _8825; ++_672)
  {
    {
      int _8826 = _ptr__660[_672];
      int _8827 = _ptr__661[_672];
      for (int _673 = _8826; _673 < _8827; ++_673)
      {
        {
          int _8828 = _ptr__663[_673];
          int _8829 = _ptr__663[safe_add( _673,(int)1 )];
          for (int _674 = _8828; _674 < _8829; ++_674)
          {
            {
              if ((_ptr__664[_674] == 0))
              {
                {
                }
              }
              else
              {
                {
                  if ((_ptr__664[_674] == 1))
                  {
                    {
                      _ptr__670[safe_add( _668,_669 )] = ((*param_value)((int)_ptr__665[_674]));
                      ++ _669;
                    }
                  }
                  else
                  {
                    {
                      if ((_ptr__664[_674] == 2))
                      {
                        {
                          _ptr__670[safe_add( _668,_669 )] = _ptr__665[_674];
                          ++ _669;
                        }
                      }
                      else
                      {
                        {
                          if ((_ptr__664[_674] == 3))
                          {
                            {
                              _ptr__670[(safe_add( _668,_669 ) - (int)2)] += _ptr__670[(safe_add( _668,_669 ) - (int)1)];
                              -- _669;
                            }
                          }
                          else
                          {
                            {
                              if ((_ptr__664[_674] == 4))
                              {
                                {
                                  _ptr__670[(safe_add( _668,_669 ) - (int)1)] = (-_ptr__670[(safe_add( _668,_669 ) - (int)1)]);
                                }
                              }
                              else
                              {
                                {
                                  if ((_ptr__664[_674] == 5))
                                  {
                                    {
                                      _ptr__670[(safe_add( _668,_669 ) - (int)2)] *= _ptr__670[(safe_add( _668,_669 ) - (int)1)];
                                      -- _669;
                                    }
                                  }
                                  else
                                  {
                                    {
                                      if ((_ptr__664[_674] == 6))
                                      {
                                        {
                                          _ptr__670[(safe_add( _668,_669 ) - (int)1)] = (1.0 / _ptr__670[(safe_add( _668,_669 ) - (int)1)]);
                                        }
                                      }
                                      else
                                      {
                                        {
                                          if ((_ptr__664[_674] == 8))
                                          {
                                            {
                                              double _675 = 0.0;
                                              int _8830 = (int)0;
                                              int _8831 = (int)_ptr__665[_674];
                                              for (int _676 = _8830; _676 < _8831; ++_676)
                                              {
                                                {
                                                  _675 += _ptr__670[(safe_add( _668,_669 ) - (int)1)];
                                                  -- _669;
                                                }
                                              }
                                              _ptr__670[safe_add( _668,_669 )] = _675;
                                              ++ _669;
                                            }
                                          }
                                          else
                                          {
                                            {
                                            }
                                          }
                                        }
                                      }
                                    }
                                  }
                                }
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
          _ptr__666[_671] = (int)_ptr__662[_673];
          _ptr__667[_671] = _ptr__670[_668];
          _669 = (int)0;
          ++ _671;
        }
      }
    }
  }
  _658->popf64((int)((_664)->size(0)));
}
void mosek::fusion::Model :: flushSolutions() { mosek::fusion::p_Model::_get_impl(this)->flushSolutions(); }void mosek::fusion::p_Model::flushSolutions(){
  flush_initsol(::mosek::fusion::SolutionType::Interior);
  flush_initsol(::mosek::fusion::SolutionType::Integer);
  flush_initsol(::mosek::fusion::SolutionType::Basic);
}
void mosek::fusion::p_Model::flush_initsol(mosek::fusion::SolutionType _677){
  if ((NULL != initsol_xx.get()))
  {
    {
      int _678 = task_numvar();
      std::shared_ptr< monty::ndarray< double,1 > > _679 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_678)));
      _checked_ptr_1<double> _ptr__679(_679 ? _679->raw() : nullptr,_679 ? _679->size(0) : 0);
      try
      {
        {
          monty::rc_ptr< ::mosek::fusion::SolutionStruct > _681 = __mosek_2fusion_2Model__get_sol_cache(_677,true);
          if ((NULL != mosek::fusion::p_SolutionStruct::_get_impl(_681)->xx.get()))
          {
            {
              int _8832;
              bool _8833 = ((int)((mosek::fusion::p_SolutionStruct::_get_impl(_681)->xx)->size(0)) <= _678);
              if (_8833)
              {
                _8832 = (int)((mosek::fusion::p_SolutionStruct::_get_impl(_681)->xx)->size(0));
              }
              else
              {
                _8832 = _678;
              }
              ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SolutionStruct::_get_impl(_681)->xx,(int)0,_679,(int)0,_8832);
            }
          }
          {}
        }
      }
      catch (mosek::fusion::SolutionError _680)
      {
        {
        }
      }
      int _8834;
      bool _8835 = ((int)((initsol_xx)->size(0)) <= _678);
      if (_8835)
      {
        _8834 = (int)((initsol_xx)->size(0));
      }
      else
      {
        _8834 = _678;
      }
      int _682 = _8834;
      int _8836 = (int)0;
      int _8837 = _682;
      for (int _683 = _8836; _683 < _8837; ++_683)
      {
        {
          if (((*initsol_xx_flag)(_683)))
          {
            {
              _ptr__679[_683] = ((*initsol_xx)(_683));
            }
          }
          {}
        }
      }
      task_putxx_slice(_677,(int)0,_678,_679);
    }
  }
  {}
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(){
  return _pubthis->getDualSolutionStatus(solutionptr);
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus() { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(){
  return _pubthis->getProblemStatus(solutionptr);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(){
  return _pubthis->getPrimalSolutionStatus(solutionptr);
}
double mosek::fusion::Model :: dualObjValue() { return mosek::fusion::p_Model::_get_impl(this)->dualObjValue(); }double mosek::fusion::p_Model::dualObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,false))->dobj;
}
double mosek::fusion::Model :: primalObjValue() { return mosek::fusion::p_Model::_get_impl(this)->primalObjValue(); }double mosek::fusion::p_Model::primalObjValue(){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(::mosek::fusion::SolutionType::Default,true))->pobj;
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _684,bool _685,bool _686){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _687 = nullptr;
  mosek::fusion::SolutionType _688 = _684;
  if ((_688 == ::mosek::fusion::SolutionType::Default))
  {
    {
      _688 = solutionptr;
    }
  }
  {}
  if ((_688 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _687 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _687 = sol_bas;
        }
      }
      else
      {
        {
          _687 = sol_itr;
        }
      }
    }
  }
  else if((_688 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _687 = sol_itr;
    }
  }
  else if((_688 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _687 = sol_bas;
    }
  }
  else if((_688 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _687 = sol_itg;
    }
  }
  {}
  if ((NULL == _687.get()))
  {
    {
      throw ::mosek::fusion::SolutionError(std::string ("Solution not available"));
    }
  }
  else
  {
    {
      if ((_686 || ((_685 && _687->isPrimalAcceptable(acceptable_sol)) || ((!_685) && _687->isDualAcceptable(acceptable_sol)))))
      {
        {
          return _687;
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _689 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          mosek::fusion::SolutionStatus _690 = mosek::fusion::p_SolutionStruct::_get_impl(_687)->pstatus;
          mosek::fusion::ProblemStatus _691 = mosek::fusion::p_SolutionStruct::_get_impl(_687)->probstatus;
          if ((!_685))
          {
            {
              _690 = mosek::fusion::p_SolutionStruct::_get_impl(_687)->dstatus;
            }
          }
          {}
          _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Solution status is "));
          if ((_690 == ::mosek::fusion::SolutionStatus::Undefined))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Undefined"));
            }
          }
          else if((_690 == ::mosek::fusion::SolutionStatus::Unknown))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_690 == ::mosek::fusion::SolutionStatus::Optimal))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((_690 == ::mosek::fusion::SolutionStatus::Feasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Feasible"));
            }
          }
          else if((_690 == ::mosek::fusion::SolutionStatus::Certificate))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          else if((_690 == ::mosek::fusion::SolutionStatus::IllposedCert))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("IllposedCert"));
            }
          }
          {}
          _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" but "));
          if ((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Anything))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Anything"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Optimal))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Optimal"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Feasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("at least Feasible"));
            }
          }
          else if((acceptable_sol == ::mosek::fusion::AccSolutionStatus::Certificate))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Certificate"));
            }
          }
          {}
          _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" is expected. Reason: Accessing "));
          if ((_687 == sol_itr))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("interior-point solution"));
            }
          }
          else if((_687 == sol_bas))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("basic solution"));
            }
          }
          else if((_687 == sol_itg))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("integer solution"));
            }
          }
          {}
          _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" whose problem status is "));
          if ((_691 == ::mosek::fusion::ProblemStatus::Unknown))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Unknown"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::PrimalAndDualFeasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalAndDualFeasible"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::PrimalFeasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalFeasible"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::DualFeasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DualFeasible"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::PrimalInfeasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalInfeasible"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::DualInfeasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DualInfeasible"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::PrimalAndDualInfeasible))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalAndDualInfeasible"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::IllPosed))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("IllPosed"));
            }
          }
          else if((_691 == ::mosek::fusion::ProblemStatus::PrimalInfeasibleOrUnbounded))
          {
            {
              _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PrimalInfeasibleOrUnbounded"));
            }
          }
          {}
          _689->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("."));
          throw ::mosek::fusion::SolutionError(_689->toString());
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::SolutionStruct > mosek::fusion::p_Model::__mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _692,bool _693){
  return __mosek_2fusion_2Model__get_sol_cache(_692,_693,false);
}
void mosek::fusion::p_Model::setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _694,std::shared_ptr< monty::ndarray< double,1 > > _695){
  _checked_ptr_1<int> _ptr__694(_694 ? _694->raw() : nullptr, _694 ? _694->size(0) : 0);
  _checked_ptr_1<double> _ptr__695(_695 ? _695->raw() : nullptr, _695 ? _695->size(0) : 0);
  ensure_initsol_xx();
  int _8838 = (int)0;
  int _8839 = (int)((_694)->size(0));
  for (int _696 = _8838; _696 < _8839; ++_696)
  {
    {
      ((*initsol_xx)(_ptr__694[_696])) = _ptr__695[_696];
      ((*initsol_xx_flag)(_ptr__694[_696])) = true;
    }
  }
}
void mosek::fusion::p_Model::ensure_initsol_xx(){
  int _697 = (int)((natvarmap_idx)->size(0));
  if ((NULL == initsol_xx.get()))
  {
    {
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_697)));
      std::vector<bool> _8840;
      for (int _698 = (int)0, _8841 = _697; _698 < _8841 ; ++_698)
      {
        _8840.push_back(false);
      }
      auto _8842 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_8840.size()),_8840.begin(),_8840.end()));
      initsol_xx_flag = _8842;
    }
  }
  else if(((int)((initsol_xx)->size(0)) < _697))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _699 = initsol_xx;
      _checked_ptr_1<double> _ptr__699(_699 ? _699->raw() : nullptr,_699 ? _699->size(0) : 0);
      std::shared_ptr< monty::ndarray< bool,1 > > _700 = initsol_xx_flag;
      initsol_xx = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_697)));
      initsol_xx_flag = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_697)));
      ::mosek::fusion::Utils::Tools::arraycopy(_699,(int)0,initsol_xx,(int)0,_697);
      int _8843 = (int)0;
      int _8844 = _697;
      for (int _701 = _8843; _701 < _8844; ++_701)
      {
        {
          ((*initsol_xx_flag)(_701)) = ((*_700)(_701));
        }
      }
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_bars(mosek::fusion::SolutionType _702){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_702,false))->bars;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_barx(mosek::fusion::SolutionType _703){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_703,true))->barx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_y(mosek::fusion::SolutionType _704){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_704,false))->y;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xc(mosek::fusion::SolutionType _705){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_705,true))->xc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_snx(mosek::fusion::SolutionType _706){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_706,false))->snx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_suc(mosek::fusion::SolutionType _707){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_707,false))->suc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slc(mosek::fusion::SolutionType _708){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_708,false))->slc;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_sux(mosek::fusion::SolutionType _709){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_709,false))->sux;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_slx(mosek::fusion::SolutionType _710){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_710,false))->slx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_yx(mosek::fusion::SolutionType _711){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_711,false))->yx;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getSolution_xx(mosek::fusion::SolutionType _712){
  return mosek::fusion::p_SolutionStruct::_get_impl(__mosek_2fusion_2Model__get_sol_cache(_712,true))->xx;
}
void mosek::fusion::Model :: selectedSolution(mosek::fusion::SolutionType _713) { mosek::fusion::p_Model::_get_impl(this)->selectedSolution(_713); }void mosek::fusion::p_Model::selectedSolution(mosek::fusion::SolutionType _713){
  solutionptr = _713;
}
mosek::fusion::AccSolutionStatus mosek::fusion::Model :: getAcceptedSolutionStatus() { return mosek::fusion::p_Model::_get_impl(this)->getAcceptedSolutionStatus(); }mosek::fusion::AccSolutionStatus mosek::fusion::p_Model::getAcceptedSolutionStatus(){
  return acceptable_sol;
}
void mosek::fusion::Model :: acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _714) { mosek::fusion::p_Model::_get_impl(this)->acceptedSolutionStatus(_714); }void mosek::fusion::p_Model::acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _714){
  acceptable_sol = _714;
}
mosek::fusion::ProblemStatus mosek::fusion::Model :: getProblemStatus(mosek::fusion::SolutionType _715) { return mosek::fusion::p_Model::_get_impl(this)->getProblemStatus(_715); }mosek::fusion::ProblemStatus mosek::fusion::p_Model::getProblemStatus(mosek::fusion::SolutionType _715){
  monty::rc_ptr< ::mosek::fusion::SolutionStruct > _716 = nullptr;
  if ((_715 == ::mosek::fusion::SolutionType::Default))
  {
    {
      if ((NULL != sol_itg.get()))
      {
        {
          _716 = sol_itg;
        }
      }
      else if((NULL != sol_bas.get()))
      {
        {
          _716 = sol_bas;
        }
      }
      else
      {
        {
          _716 = sol_itr;
        }
      }
    }
  }
  else if((_715 == ::mosek::fusion::SolutionType::Interior))
  {
    {
      _716 = sol_itr;
    }
  }
  else if((_715 == ::mosek::fusion::SolutionType::Basic))
  {
    {
      _716 = sol_bas;
    }
  }
  else if((_715 == ::mosek::fusion::SolutionType::Integer))
  {
    {
      _716 = sol_itg;
    }
  }
  {}
  if ((NULL == _716.get()))
  {
    {
      return ::mosek::fusion::ProblemStatus::Unknown;
    }
  }
  else
  {
    {
      return mosek::fusion::p_SolutionStruct::_get_impl(_716)->probstatus;
    }
  }
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getDualSolutionStatus(mosek::fusion::SolutionType _717) { return mosek::fusion::p_Model::_get_impl(this)->getDualSolutionStatus(_717); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getDualSolutionStatus(mosek::fusion::SolutionType _717){
  return getSolutionStatus(_717,false);
}
mosek::fusion::SolutionStatus mosek::fusion::Model :: getPrimalSolutionStatus(mosek::fusion::SolutionType _718) { return mosek::fusion::p_Model::_get_impl(this)->getPrimalSolutionStatus(_718); }mosek::fusion::SolutionStatus mosek::fusion::p_Model::getPrimalSolutionStatus(mosek::fusion::SolutionType _718){
  return getSolutionStatus(_718,true);
}
mosek::fusion::SolutionStatus mosek::fusion::p_Model::getSolutionStatus(mosek::fusion::SolutionType _719,bool _720){
  try
  {
    {
      monty::rc_ptr< ::mosek::fusion::SolutionStruct > _722 = __mosek_2fusion_2Model__get_sol_cache(_719,_720,true);
      if (_720)
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_722)->pstatus;
        }
      }
      else
      {
        {
          return mosek::fusion::p_SolutionStruct::_get_impl(_722)->dstatus;
        }
      }
    }
  }
  catch (mosek::fusion::SolutionError _721)
  {
    {
      return ::mosek::fusion::SolutionStatus::Undefined;
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _723,monty::rc_ptr< ::mosek::fusion::Expression > _724){
  _checked_ptr_1<int> _ptr__723(_723 ? _723->raw() : nullptr, _723 ? _723->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_724)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  ws->pop_expr();
  int _725 = mosek::fusion::p_WorkStack::_get_impl(ws)->nd;
  int _726 = mosek::fusion::p_WorkStack::_get_impl(ws)->shape_base;
  int _727 = mosek::fusion::p_WorkStack::_get_impl(ws)->nelem;
  int _728 = mosek::fusion::p_WorkStack::_get_impl(ws)->nnz;
  bool _729 = mosek::fusion::p_WorkStack::_get_impl(ws)->hassp;
  int _730 = mosek::fusion::p_WorkStack::_get_impl(ws)->ncodeatom;
  int _731 = mosek::fusion::p_WorkStack::_get_impl(ws)->ptr_base;
  int _732 = mosek::fusion::p_WorkStack::_get_impl(ws)->sp_base;
  int _733 = mosek::fusion::p_WorkStack::_get_impl(ws)->nidxs_base;
  int _734 = mosek::fusion::p_WorkStack::_get_impl(ws)->cof_base;
  int _735 = mosek::fusion::p_WorkStack::_get_impl(ws)->code_base;
  int _736 = mosek::fusion::p_WorkStack::_get_impl(ws)->codeptr_base;
  int _737 = mosek::fusion::p_WorkStack::_get_impl(ws)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _738 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__738(_738 ? _738->raw() : nullptr,_738 ? _738->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _739 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__739(_739 ? _739->raw() : nullptr,_739 ? _739->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _740 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__740(_740 ? _740->raw() : nullptr,_740 ? _740->size(0) : 0);
  int _741 = (int)0;
  int _8845 = (int)0;
  int _8846 = _727;
  for (int _742 = _8845; _742 < _8846; ++_742)
  {
    {
      if ((((*natconmap_slackidx)(_ptr__723[_742])) > (int)0))
      {
        {
          ++ _741;
        }
      }
      {}
    }
  }
  int _743 = _727;
  int _744 = safe_add( _728,_741 );
  std::shared_ptr< monty::ndarray< long long,1 > > _745 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _727,(int)1 ))));
  _checked_ptr_1<long long> _ptr__745(_745 ? _745->raw() : nullptr,_745 ? _745->size(0) : 0);
  int _8847 = (int)0;
  int _8848 = _727;
  for (int _746 = _8847; _746 < _8848; ++_746)
  {
    {
      int _8849 = _ptr__738[safe_add( _731,_746 )];
      int _8850 = _ptr__738[safe_add( safe_add( _731,_746 ),(int)1 )];
      for (int _747 = _8849; _747 < _8850; ++_747)
      {
        {
          if ((_ptr__739[safe_add( _733,_747 )] >= (int)0))
          {
            {
              ++ _ptr__745[safe_add( _746,(int)1 )];
            }
          }
          {}
        }
      }
      if ((((*natconmap_slackidx)(_ptr__723[_746])) > (int)0))
      {
        {
          ++ _ptr__745[safe_add( _746,(int)1 )];
        }
      }
      {}
    }
  }
  int _8851 = (int)0;
  int _8852 = _727;
  for (int _748 = _8851; _748 < _8852; ++_748)
  {
    {
      _ptr__745[safe_add( _748,(int)1 )] += _ptr__745[_748];
    }
  }
  long long _749 = _ptr__745[_727];
  std::shared_ptr< monty::ndarray< int,1 > > _750 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_749)));
  _checked_ptr_1<int> _ptr__750(_750 ? _750->raw() : nullptr,_750 ? _750->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _751 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_749)));
  _checked_ptr_1<double> _ptr__751(_751 ? _751->raw() : nullptr,_751 ? _751->size(0) : 0);
  int _752 = (int)0;
  int _8853 = (int)0;
  int _8854 = _727;
  for (int _753 = _8853; _753 < _8854; ++_753)
  {
    {
      int _8855 = _ptr__738[safe_add( _731,_753 )];
      int _8856 = _ptr__738[safe_add( safe_add( _731,_753 ),(int)1 )];
      for (int _754 = _8855; _754 < _8856; ++_754)
      {
        {
          if ((_ptr__739[safe_add( _733,_754 )] >= (int)0))
          {
            {
              _ptr__750[_752] = (int)_ptr__739[safe_add( _733,_754 )];
              _ptr__751[_752] = _ptr__740[safe_add( _734,_754 )];
              ++ _752;
            }
          }
          {}
        }
      }
      if ((((*natconmap_slackidx)(_ptr__723[_753])) > (int)0))
      {
        {
          _ptr__750[_752] = (int)(((*natconmap_slackidx)(_ptr__723[_753])) - (int)1);
          _ptr__751[_752] = (-1.0);
          ++ _752;
        }
      }
      {}
    }
  }
  task_putarowlist(_723,_745,_750,_751);
  if ((_730 == (int)0))
  {
    {
      int _8857 = (int)0;
      int _8858 = _727;
      for (int _755 = _8857; _755 < _8858; ++_755)
      {
        {
          natconmap_numparameterized -= (((*natconmap_coderowptre)(_ptr__723[_755])) - ((*natconmap_coderowptrb)(_ptr__723[_755])));
          ((*natconmap_coderowptre)(_ptr__723[_755])) = ((*natconmap_coderowptrb)(_ptr__723[_755]));
        }
      }
    }
  }
  else
  {
    {
      bool _756 = true;
      int _757 = (int)0;
      int _758 = (int)0;
      int _8859 = (int)0;
      int _8860 = _727;
      for (int _759 = _8859; _759 < _8860; ++_759)
      {
        {
          int _8861 = _ptr__738[safe_add( _731,_759 )];
          int _8862 = _ptr__738[safe_add( safe_add( _731,_759 ),(int)1 )];
          for (int _760 = _8861; _760 < _8862; ++_760)
          {
            {
              if ((((_ptr__738[safe_add( safe_add( _736,_760 ),(int)1 )] - _ptr__738[safe_add( _736,_760 )]) == (int)1) && ((_ptr__738[safe_add( _735,_ptr__738[safe_add( _736,_760 )] )] == 10) || (_ptr__738[safe_add( _735,_ptr__738[safe_add( _736,_760 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  ++ _758;
                  _757 += (_ptr__738[safe_add( safe_add( _736,_760 ),(int)1 )] - _ptr__738[safe_add( _736,_760 )]);
                }
              }
            }
          }
        }
      }
      int _761 = natconmap_codenztop;
      int _762 = natconmap_codeatomtop;
      natconmap_codealloc(_758,_757);
      int _763 = _762;
      int _764 = _761;
      int _8863 = (int)0;
      int _8864 = _727;
      for (int _765 = _8863; _765 < _8864; ++_765)
      {
        {
          natconmap_numparameterized -= (((*natconmap_coderowptre)(_ptr__723[_765])) - ((*natconmap_coderowptrb)(_ptr__723[_765])));
          ((*natconmap_coderowptrb)(_ptr__723[_765])) = _764;
          int _8865 = _ptr__738[safe_add( _731,_765 )];
          int _8866 = _ptr__738[safe_add( safe_add( _731,_765 ),(int)1 )];
          for (int _766 = _8865; _766 < _8866; ++_766)
          {
            {
              if ((((_ptr__738[safe_add( safe_add( _736,_766 ),(int)1 )] - _ptr__738[safe_add( _736,_766 )]) == (int)1) && ((_ptr__738[safe_add( _735,_ptr__738[safe_add( _736,_766 )] )] == 10) || (_ptr__738[safe_add( _735,_ptr__738[safe_add( _736,_766 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  int _8867 = _ptr__738[safe_add( _736,_766 )];
                  int _8868 = _ptr__738[safe_add( safe_add( _736,_766 ),(int)1 )];
                  for (int _767 = _8867; _767 < _8868; ++_767)
                  {
                    {
                      ((*natconmap_code)(_763)) = _ptr__738[safe_add( _735,_767 )];
                      ((*natconmap_cconst)(_763)) = _ptr__740[safe_add( _737,_767 )];
                      ++ _763;
                    }
                  }
                  ((*natconmap_codeptr)(safe_add( _764,(int)1 ))) = _763;
                  ((*natconmap_codenidx)(_764)) = _ptr__739[safe_add( _733,_766 )];
                  _756 = (_ptr__739[safe_add( _733,_766 )] >= (int)0);
                  ++ _764;
                }
              }
            }
          }
          ((*natconmap_coderowptre)(_ptr__723[_765])) = _764;
        }
      }
      natconmap_numparameterized += _758;
      if ((!_756))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
        }
      }
      {}
    }
  }
}
void mosek::fusion::p_Model::update(std::shared_ptr< monty::ndarray< int,1 > > _768,monty::rc_ptr< ::mosek::fusion::Expression > _769,std::shared_ptr< monty::ndarray< int,1 > > _770){
  _checked_ptr_1<int> _ptr__768(_768 ? _768->raw() : nullptr, _768 ? _768->size(0) : 0);
  _checked_ptr_1<int> _ptr__770(_770 ? _770->raw() : nullptr, _770 ? _770->size(0) : 0);
  int _8869 = (int)0;
  int _8870 = (int)((_768)->size(0));
  for (int _771 = _8869; _771 < _8870; ++_771)
  {
    {
      if ((((*natconmap_coderowptrb)(_771)) < ((*natconmap_coderowptre)(_771))))
      {
        {
          throw ::mosek::fusion::UpdateError(std::string ("Cannot update parameterized constraint"));
        }
      }
      {}
    }
  }
  int _772 = safe_mul( (int)((_768)->size(0)),(int)((_770)->size(0)) );
  std::shared_ptr< monty::ndarray< double,1 > > _773 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_772)));
  _checked_ptr_1<double> _ptr__773(_773 ? _773->raw() : nullptr,_773 ? _773->size(0) : 0);
  std::vector<int> _8871;
  for (int _775 = (int)0, _8872 = (int)((_768)->size(0)); _775 < _8872 ; ++_775)
  {
    for (int _776 = (int)0, _8873 = (int)((_770)->size(0)); _776 < _8873 ; ++_776)
    {
      _8871.push_back(_ptr__768[_775]);
    }
  }
  auto _8874 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8871.size()),_8871.begin(),_8871.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _774 = _8874;
  _checked_ptr_1<int> _ptr__774(_774 ? _774->raw() : nullptr,_774 ? _774->size(0) : 0);
  std::vector<int> _8875;
  for (int _778 = (int)0, _8876 = (int)((_768)->size(0)); _778 < _8876 ; ++_778)
  {
    for (int _779 = (int)0, _8877 = (int)((_770)->size(0)); _779 < _8877 ; ++_779)
    {
      _8875.push_back(_ptr__770[_779]);
    }
  }
  auto _8878 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8875.size()),_8875.begin(),_8875.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _777 = _8878;
  _checked_ptr_1<int> _ptr__777(_777 ? _777->raw() : nullptr,_777 ? _777->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_769)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  ws->pop_expr();
  int _780 = mosek::fusion::p_WorkStack::_get_impl(ws)->nd;
  int _781 = mosek::fusion::p_WorkStack::_get_impl(ws)->nelem;
  int _782 = mosek::fusion::p_WorkStack::_get_impl(ws)->nnz;
  bool _783 = mosek::fusion::p_WorkStack::_get_impl(ws)->hassp;
  int _784 = mosek::fusion::p_WorkStack::_get_impl(ws)->ncodeatom;
  int _785 = mosek::fusion::p_WorkStack::_get_impl(ws)->shape_base;
  int _786 = mosek::fusion::p_WorkStack::_get_impl(ws)->ptr_base;
  int _787 = mosek::fusion::p_WorkStack::_get_impl(ws)->sp_base;
  int _788 = mosek::fusion::p_WorkStack::_get_impl(ws)->nidxs_base;
  int _789 = mosek::fusion::p_WorkStack::_get_impl(ws)->cof_base;
  int _790 = mosek::fusion::p_WorkStack::_get_impl(ws)->code_base;
  int _791 = mosek::fusion::p_WorkStack::_get_impl(ws)->codeptr_base;
  int _792 = mosek::fusion::p_WorkStack::_get_impl(ws)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _793 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__793(_793 ? _793->raw() : nullptr,_793 ? _793->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _794 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__794(_794 ? _794->raw() : nullptr,_794 ? _794->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _795 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__795(_795 ? _795->raw() : nullptr,_795 ? _795->size(0) : 0);
  int _796 = (int)0;
  int _8879 = (int)0;
  int _8880 = _781;
  for (int _797 = _8879; _797 < _8880; ++_797)
  {
    {
      int _798 = _ptr__793[safe_add( _786,_797 )];
      int _799 = _ptr__793[safe_add( safe_add( _786,_797 ),(int)1 )];
      int _800 = _798;
      int _801 = (int)0;
      while ( ((_801 < (int)((_770)->size(0))) && (_800 < _799)) )
      {
        {
          if ((_ptr__770[_801] < _ptr__794[safe_add( _788,_800 )]))
          {
            {
              ++ _801;
            }
          }
          else if((_ptr__770[_801] > _ptr__794[safe_add( _788,_800 )]))
          {
            {
              ++ _800;
            }
          }
          else
          {
            {
              _ptr__773[safe_add( _796,_801 )] = _ptr__795[safe_add( _789,_800 )];
              ++ _801;
              ++ _800;
            }
          }
        }
      }
      _796 += (int)((_770)->size(0));
    }
  }
  task_putaijlist(_774,_777,_773,(long long)(_772));
  if ((_784 == (int)0))
  {
    {
      int _8881 = (int)0;
      int _8882 = _781;
      for (int _802 = _8881; _802 < _8882; ++_802)
      {
        {
          natconmap_numparameterized -= (((*natconmap_coderowptre)(_ptr__768[_802])) - ((*natconmap_coderowptrb)(_ptr__768[_802])));
          ((*natconmap_coderowptre)(_ptr__768[_802])) = ((*natconmap_coderowptrb)(_ptr__768[_802]));
        }
      }
    }
  }
  else
  {
    {
      bool _803 = true;
      int _804 = (int)0;
      int _805 = (int)0;
      int _8883 = (int)0;
      int _8884 = _781;
      for (int _806 = _8883; _806 < _8884; ++_806)
      {
        {
          int _8885 = _ptr__793[safe_add( _786,_806 )];
          int _8886 = _ptr__793[safe_add( safe_add( _786,_806 ),(int)1 )];
          for (int _807 = _8885; _807 < _8886; ++_807)
          {
            {
              if ((((_ptr__793[safe_add( safe_add( _791,_807 ),(int)1 )] - _ptr__793[safe_add( _791,_807 )]) == (int)1) && ((_ptr__793[safe_add( _790,_ptr__793[safe_add( _791,_807 )] )] == 10) || (_ptr__793[safe_add( _790,_ptr__793[safe_add( _791,_807 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  ++ _804;
                  _805 += (_ptr__793[safe_add( safe_add( _791,_807 ),(int)1 )] - _ptr__793[safe_add( _791,_807 )]);
                }
              }
            }
          }
        }
      }
      int _808 = natconmap_codenztop;
      int _809 = natconmap_codeatomtop;
      natconmap_codealloc(_804,_805);
      int _810 = _809;
      int _811 = _808;
      int _8887 = (int)0;
      int _8888 = _781;
      for (int _812 = _8887; _812 < _8888; ++_812)
      {
        {
          natconmap_numparameterized -= (((*natconmap_coderowptre)(_ptr__768[_812])) - ((*natconmap_coderowptrb)(_ptr__768[_812])));
          ((*natconmap_coderowptrb)(_ptr__768[_812])) = _811;
          int _8889 = _ptr__793[safe_add( _786,_812 )];
          int _8890 = _ptr__793[safe_add( safe_add( _786,_812 ),(int)1 )];
          for (int _813 = _8889; _813 < _8890; ++_813)
          {
            {
              if ((((_ptr__793[safe_add( safe_add( _791,_813 ),(int)1 )] - _ptr__793[safe_add( _791,_813 )]) == (int)1) && ((_ptr__793[safe_add( _790,_ptr__793[safe_add( _791,_813 )] )] == 10) || (_ptr__793[safe_add( _790,_ptr__793[safe_add( _791,_813 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  int _8891 = _ptr__793[safe_add( _791,_813 )];
                  int _8892 = _ptr__793[safe_add( safe_add( _791,_813 ),(int)1 )];
                  for (int _814 = _8891; _814 < _8892; ++_814)
                  {
                    {
                      ((*natconmap_code)(_810)) = _ptr__793[safe_add( _790,_814 )];
                      ((*natconmap_cconst)(_810)) = _ptr__795[safe_add( _792,_814 )];
                      ++ _810;
                    }
                  }
                  ((*natconmap_codeptr)(safe_add( _811,(int)1 ))) = _810;
                  ((*natconmap_codenidx)(_811)) = _ptr__794[safe_add( _788,_813 )];
                  _803 = (_ptr__794[safe_add( _788,_813 )] >= (int)0);
                  ++ _811;
                }
              }
            }
          }
          ((*natconmap_coderowptre)(_ptr__768[_812])) = _811;
        }
      }
      natconmap_numparameterized += _804;
      if ((!_803))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::Variable > _816) { mosek::fusion::p_Model::_get_impl(this)->updateObjective(_815,_816); }void mosek::fusion::p_Model::updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::Variable > _816){
  if ((_815->getSize() != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  if ((NULL != natconmap_objcodenidx.get()))
  {
    {
      throw ::mosek::fusion::UpdateError(std::string ("Cannot update parameterized objective"));
    }
  }
  {}
  int _817 = _816->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _818 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_817)));
  _checked_ptr_1<long long> _ptr__818(_818 ? _818->raw() : nullptr,_818 ? _818->size(0) : 0);
  if ((_817 < _816->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _819 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_817)));
      _checked_ptr_1<long long> _ptr__819(_819 ? _819->raw() : nullptr,_819 ? _819->size(0) : 0);
      _816->inst((int)0,_819,(int)0,_818);
    }
  }
  else
  {
    {
      _816->inst((int)0,_818);
    }
  }
  int _8893 = (int)0;
  int _8894 = _817;
  for (int _820 = _8893; _820 < _8894; ++_820)
  {
    {
      if ((_ptr__818[_820] < (int)0))
      {
        {
          throw ::mosek::fusion::UpdateError(std::string ("Updating semidefinite terms is currently not possible"));
        }
      }
      {}
    }
  }
  bool _821 = true;
  int _8895 = (int)0;
  int _8896 = (_817 - (int)1);
  for (int _822 = _8895; _822 < _8896; ++_822)
  {
    {
      _821 = (_821 && (_ptr__818[_822] < _ptr__818[(_822 - (int)1)]));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _823 = nullptr;
  _checked_ptr_1<int> _ptr__823(_823 ? _823->raw() : nullptr,_823 ? _823->size(0) : 0);
  if (_821)
  {
    {
      std::vector<int> _8897;
      for (int _824 = (int)0, _8898 = _817; _824 < _8898 ; ++_824)
      {
        _8897.push_back((int)(_ptr__818[_824] - (int)1));
      }
      auto _8899 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8897.size()),_8897.begin(),_8897.end()));
      _823 = _8899;
      _ptr__823.update(_823 ? _823->raw() : nullptr, _823 ? _823->size(0) : 0);
    }
  }
  else
  {
    {
      std::vector<long long> _8900;
      for (int _826 = (-(int)1), _8901 = _817; _826 < _8901 ; ++_826)
      {
        _8900.push_back(_826);
      }
      auto _8902 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_8900.size()),_8900.begin(),_8900.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _825 = _8902;
      _checked_ptr_1<long long> _ptr__825(_825 ? _825->raw() : nullptr,_825 ? _825->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_825,_818,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_817));
      std::vector<int> _8903;
      for (int _827 = (int)0, _8904 = _817; _827 < _8904 ; ++_827)
      {
        _8903.push_back((int)(_ptr__818[_ptr__825[_827]] - (int)1));
      }
      auto _8905 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8903.size()),_8903.begin(),_8903.end()));
      _823 = _8905;
      _ptr__823.update(_823 ? _823->raw() : nullptr, _823 ? _823->size(0) : 0);
    }
  }
  int _828 = (int)((_823)->size(0));
  std::shared_ptr< monty::ndarray< double,1 > > _829 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_828)));
  _checked_ptr_1<double> _ptr__829(_829 ? _829->raw() : nullptr,_829 ? _829->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _830 = _823;
  _checked_ptr_1<int> _ptr__830(_830 ? _830->raw() : nullptr,_830 ? _830->size(0) : 0);
  ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_815)).as<::mosek::fusion::Expression>())->eval(ws,rs,xs);
  ws->pop_expr();
  {
  }
  int _831 = mosek::fusion::p_WorkStack::_get_impl(ws)->nd;
  int _832 = mosek::fusion::p_WorkStack::_get_impl(ws)->nelem;
  int _833 = mosek::fusion::p_WorkStack::_get_impl(ws)->nnz;
  bool _834 = mosek::fusion::p_WorkStack::_get_impl(ws)->hassp;
  int _835 = mosek::fusion::p_WorkStack::_get_impl(ws)->ncodeatom;
  int _836 = mosek::fusion::p_WorkStack::_get_impl(ws)->shape_base;
  int _837 = mosek::fusion::p_WorkStack::_get_impl(ws)->ptr_base;
  int _838 = mosek::fusion::p_WorkStack::_get_impl(ws)->sp_base;
  int _839 = mosek::fusion::p_WorkStack::_get_impl(ws)->nidxs_base;
  int _840 = mosek::fusion::p_WorkStack::_get_impl(ws)->cof_base;
  int _841 = mosek::fusion::p_WorkStack::_get_impl(ws)->code_base;
  int _842 = mosek::fusion::p_WorkStack::_get_impl(ws)->codeptr_base;
  int _843 = mosek::fusion::p_WorkStack::_get_impl(ws)->cconst_base;
  {
  }
  if ((_835 > (int)0))
  {
    {
      throw ::mosek::fusion::UpdateError(std::string ("Cannot update parameterized objective"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _844 = mosek::fusion::p_WorkStack::_get_impl(ws)->i32;
  _checked_ptr_1<int> _ptr__844(_844 ? _844->raw() : nullptr,_844 ? _844->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _845 = mosek::fusion::p_WorkStack::_get_impl(ws)->i64;
  _checked_ptr_1<long long> _ptr__845(_845 ? _845->raw() : nullptr,_845 ? _845->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _846 = mosek::fusion::p_WorkStack::_get_impl(ws)->f64;
  _checked_ptr_1<double> _ptr__846(_846 ? _846->raw() : nullptr,_846 ? _846->size(0) : 0);
  int _847 = (int)0;
  int _8906 = (int)0;
  int _8907 = _832;
  for (int _848 = _8906; _848 < _8907; ++_848)
  {
    {
      int _849 = _ptr__844[safe_add( _837,_848 )];
      int _850 = _ptr__844[safe_add( safe_add( _837,_848 ),(int)1 )];
      int _851 = _849;
      int _852 = (int)0;
      while ( ((_852 < (int)((_823)->size(0))) && (_851 < _850)) )
      {
        {
          if ((_ptr__823[_852] < (_ptr__845[safe_add( _839,_851 )] - (int)1)))
          {
            {
              ++ _852;
            }
          }
          else if((_ptr__823[_852] > (_ptr__845[safe_add( _839,_851 )] - (int)1)))
          {
            {
              ++ _851;
            }
          }
          else
          {
            {
              _ptr__829[safe_add( _847,_852 )] = _ptr__846[safe_add( _840,_851 )];
              ++ _852;
              ++ _851;
            }
          }
        }
      }
      _847 += (int)((_823)->size(0));
    }
  }
  task_putclist(_830,_829);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter_unchecked(const std::string & _853,std::shared_ptr< monty::ndarray< int,1 > > _854,std::shared_ptr< monty::ndarray< long long,1 > > _855){
  _checked_ptr_1<int> _ptr__854(_854 ? _854->raw() : nullptr, _854 ? _854->size(0) : 0);
  _checked_ptr_1<long long> _ptr__855(_855 ? _855->raw() : nullptr, _855 ? _855->size(0) : 0);
  if ((((int)((_853).size()) > (int)0) && par_map->hasItem(_853)))
  {
    {
      throw ::mosek::fusion::NameError(std::string ("Duplicate parameter name"));
    }
  }
  {}
  long long _856 = ::mosek::fusion::p_Set::size(_854);
  int _8908;
  bool _8909 = (NULL != _855.get());
  if (_8909)
  {
    _8908 = (int)((_855)->size(0));
  }
  else
  {
    _8908 = (int)_856;
  }
  int _857 = _8908;
  if ((NULL == param_value.get()))
  {
    {
      param_value = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_857)));
    }
  }
  else
  {
    {
      if ((safe_add( param_num,_857 ) > (int)((param_value)->size(0))))
      {
        {
          std::shared_ptr< monty::ndarray< double,1 > > _858 = param_value;
          _checked_ptr_1<double> _ptr__858(_858 ? _858->raw() : nullptr,_858 ? _858->size(0) : 0);
          int _8910;
          bool _8911 = (safe_mul( (int)2,(int)((_858)->size(0)) ) > safe_add( (int)((_858)->size(0)),_857 ));
          if (_8911)
          {
            _8910 = safe_mul( (int)2,(int)((_858)->size(0)) );
          }
          else
          {
            _8910 = safe_add( (int)((_858)->size(0)),_857 );
          }
          int _859 = _8910;
          param_value = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_859)));
          if ((param_num > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_858,(int)0,param_value,(int)0,param_num);
            }
          }
          {}
        }
      }
      {}
    }
  }
  std::vector<int> _8912;
  for (int _861 = (int)0, _8913 = (int)_857; _861 < _8913 ; ++_861)
  {
    _8912.push_back(safe_add( param_num,_861 ));
  }
  auto _8914 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_8912.size()),_8912.begin(),_8912.end()));
  monty::rc_ptr< ::mosek::fusion::ParameterImpl > _860 = ::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(::mosek::fusion::Model::t(_pubthis),_854,_855,_8914);
  param_num += _857;
  if (((int)((_853).size()) > (int)0))
  {
    {
      if (((NULL == parameters.get()) || (numparameter == (int)((parameters)->size(0)))))
      {
        {
          std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _862 = parameters;
          std::vector<monty::rc_ptr< ::mosek::fusion::Parameter >> _8915;
          for (int _863 = (int)0, _8916 = safe_add( safe_mul( numparameter,(int)2 ),(int)64 ); _863 < _8916 ; ++_863)
          {
            _8915.push_back(nullptr);
          }
          auto _8917 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >(monty::shape(_8915.size()),_8915.begin(),_8915.end()));
          parameters = _8917;
          int _8918 = (int)0;
          int _8919 = numparameter;
          for (int _864 = _8918; _864 < _8919; ++_864)
          {
            {
              ((*parameters)(_864)) = ((*_862)(_864));
            }
          }
        }
      }
      {}
      ((*parameters)(numparameter)) = (_860).as<::mosek::fusion::Parameter>();
      par_map->setItem(_853,numparameter);
      numparameter += (int)1;
    }
  }
  {}
  return (_860).as<::mosek::fusion::Parameter>();
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter_(const std::string & _865,std::shared_ptr< monty::ndarray< int,1 > > _866,std::shared_ptr< monty::ndarray< long long,1 > > _867){
  _checked_ptr_1<int> _ptr__866(_866 ? _866->raw() : nullptr, _866 ? _866->size(0) : 0);
  _checked_ptr_1<long long> _ptr__867(_867 ? _867->raw() : nullptr, _867 ? _867->size(0) : 0);
  bool _868 = true;
  int _869 = (int)((_866)->size(0));
  if ((NULL != _867.get()))
  {
    {
      bool _870 = (_ptr__867[((int)((_867)->size(0)) - (int)1)] < ::mosek::fusion::p_Set::size(_866));
      int _8920 = (int)1;
      int _8921 = (int)((_867)->size(0));
      for (int _871 = _8920; _871 < _8921; ++_871)
      {
        {
          _870 = (_870 && (_ptr__867[(_871 - (int)1)] < _ptr__867[_871]));
        }
      }
      if ((!_870))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Unordered sparsity pattern"));
        }
      }
      {}
    }
  }
  {}
  return __mosek_2fusion_2Model__parameter_unchecked(_865,_866,_867);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter_(const std::string & _872,std::shared_ptr< monty::ndarray< int,1 > > _873,std::shared_ptr< monty::ndarray< int,2 > > _874){
  _checked_ptr_1<int> _ptr__873(_873 ? _873->raw() : nullptr, _873 ? _873->size(0) : 0);
  int _875 = (int)((_874)->size(0));
  int _876 = (int)((_874)->size(1));
  if (((int)((_873)->size(0)) != _876))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid sparsity"));
    }
  }
  {}
  if ((NULL == _874.get()))
  {
    {
      return __mosek_2fusion_2Model__parameter_unchecked(_872,_873,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _877 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_875)));
      _checked_ptr_1<long long> _ptr__877(_877 ? _877->raw() : nullptr,_877 ? _877->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _878 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_876)));
      _checked_ptr_1<long long> _ptr__878(_878 ? _878->raw() : nullptr,_878 ? _878->size(0) : 0);
      _ptr__878[(_876 - (int)1)] = (int)1;
      int _8922 = (int)1;
      int _8923 = _876;
      for (int _879 = _8922; _879 < _8923; ++_879)
      {
        {
          _ptr__878[((_876 - (int)1) - _879)] = safe_mul( _ptr__878[(_876 - _879)],_ptr__873[(_876 - _879)] );
        }
      }
      int _8924 = (int)0;
      int _8925 = _875;
      for (int _880 = _8924; _880 < _8925; ++_880)
      {
        {
          _ptr__877[_880] = (int)0;
          int _8926 = (int)0;
          int _8927 = _876;
          for (int _881 = _8926; _881 < _8927; ++_881)
          {
            {
              _ptr__877[_880] += safe_mul( ((*_874)(_880,_881)),_ptr__878[_881] );
            }
          }
        }
      }
      return __mosek_2fusion_2Model__parameter_(_872,_873,_877);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(const std::string & _882) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_882); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(const std::string &  _882) { return __mosek_2fusion_2Model__parameter(_882); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(const std::string & _882){
  std::shared_ptr< monty::ndarray< long long,1 > > _883 = nullptr;
  _checked_ptr_1<long long> _ptr__883(_883 ? _883->raw() : nullptr,_883 ? _883->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(_882,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),_883);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(const std::string & _884,int _885,int _886,int _887) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_884,_885,_886,_887); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(const std::string &  _884,int _885,int _886,int _887) { return __mosek_2fusion_2Model__parameter(_884,_885,_886,_887); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(const std::string & _884,int _885,int _886,int _887){
  std::shared_ptr< monty::ndarray< long long,1 > > _888 = nullptr;
  _checked_ptr_1<long long> _ptr__888(_888 ? _888->raw() : nullptr,_888 ? _888->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(_884,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_885),(int)(_886),(int)(_887)}),_888);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(const std::string & _889,int _890,int _891) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_889,_890,_891); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(const std::string &  _889,int _890,int _891) { return __mosek_2fusion_2Model__parameter(_889,_890,_891); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(const std::string & _889,int _890,int _891){
  std::shared_ptr< monty::ndarray< long long,1 > > _892 = nullptr;
  _checked_ptr_1<long long> _ptr__892(_892 ? _892->raw() : nullptr,_892 ? _892->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(_889,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_890),(int)(_891)}),_892);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(const std::string & _893,int _894) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_893,_894); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(const std::string &  _893,int _894) { return __mosek_2fusion_2Model__parameter(_893,_894); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(const std::string & _893,int _894){
  std::shared_ptr< monty::ndarray< long long,1 > > _895 = nullptr;
  _checked_ptr_1<long long> _ptr__895(_895 ? _895->raw() : nullptr,_895 ? _895->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(_893,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_894)}),_895);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(const std::string & _896,std::shared_ptr< monty::ndarray< int,1 > > _897) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_896,_897); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(const std::string &  _896,std::shared_ptr< monty::ndarray< int,1 > > _897) { return __mosek_2fusion_2Model__parameter(_896,_897); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(const std::string & _896,std::shared_ptr< monty::ndarray< int,1 > > _897){
  _checked_ptr_1<int> _ptr__897(_897 ? _897->raw() : nullptr, _897 ? _897->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _898 = nullptr;
  _checked_ptr_1<long long> _ptr__898(_898 ? _898->raw() : nullptr,_898 ? _898->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(_896,_897,_898);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(const std::string & _899,std::shared_ptr< monty::ndarray< int,1 > > _900,std::shared_ptr< monty::ndarray< long long,1 > > _901) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_899,_900,_901); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(const std::string &  _899,std::shared_ptr< monty::ndarray< int,1 > > _900,std::shared_ptr< monty::ndarray< long long,1 > > _901) { return __mosek_2fusion_2Model__parameter(_899,_900,_901); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(const std::string & _899,std::shared_ptr< monty::ndarray< int,1 > > _900,std::shared_ptr< monty::ndarray< long long,1 > > _901){
  _checked_ptr_1<int> _ptr__900(_900 ? _900->raw() : nullptr, _900 ? _900->size(0) : 0);
  _checked_ptr_1<long long> _ptr__901(_901 ? _901->raw() : nullptr, _901 ? _901->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(_899,_900,_901);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(const std::string & _902,std::shared_ptr< monty::ndarray< int,1 > > _903,std::shared_ptr< monty::ndarray< int,2 > > _904) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_902,_903,_904); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(const std::string &  _902,std::shared_ptr< monty::ndarray< int,1 > > _903,std::shared_ptr< monty::ndarray< int,2 > > _904) { return __mosek_2fusion_2Model__parameter(_902,_903,_904); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(const std::string & _902,std::shared_ptr< monty::ndarray< int,1 > > _903,std::shared_ptr< monty::ndarray< int,2 > > _904){
  _checked_ptr_1<int> _ptr__903(_903 ? _903->raw() : nullptr, _903 ? _903->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(_902,_903,_904);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter() { return __mosek_2fusion_2Model__parameter(); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(){
  std::shared_ptr< monty::ndarray< long long,1 > > _905 = nullptr;
  _checked_ptr_1<long long> _ptr__905(_905 ? _905->raw() : nullptr,_905 ? _905->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),_905);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(int _906,int _907,int _908) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_906,_907,_908); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(int _906,int _907,int _908) { return __mosek_2fusion_2Model__parameter(_906,_907,_908); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(int _906,int _907,int _908){
  std::shared_ptr< monty::ndarray< long long,1 > > _909 = nullptr;
  _checked_ptr_1<long long> _ptr__909(_909 ? _909->raw() : nullptr,_909 ? _909->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_906),(int)(_907),(int)(_908)}),_909);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(int _910,int _911) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_910,_911); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(int _910,int _911) { return __mosek_2fusion_2Model__parameter(_910,_911); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(int _910,int _911){
  std::shared_ptr< monty::ndarray< long long,1 > > _912 = nullptr;
  _checked_ptr_1<long long> _ptr__912(_912 ? _912->raw() : nullptr,_912 ? _912->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_910),(int)(_911)}),_912);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(int _913) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_913); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(int _913) { return __mosek_2fusion_2Model__parameter(_913); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(int _913){
  std::shared_ptr< monty::ndarray< long long,1 > > _914 = nullptr;
  _checked_ptr_1<long long> _ptr__914(_914 ? _914->raw() : nullptr,_914 ? _914->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_913)}),_914);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _915) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_915); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(std::shared_ptr< monty::ndarray< int,1 > > _915) { return __mosek_2fusion_2Model__parameter(_915); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _915){
  _checked_ptr_1<int> _ptr__915(_915 ? _915->raw() : nullptr, _915 ? _915->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _916 = nullptr;
  _checked_ptr_1<long long> _ptr__916(_916 ? _916->raw() : nullptr,_916 ? _916->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(std::string (""),_915,_916);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _917,std::shared_ptr< monty::ndarray< long long,1 > > _918) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_917,_918); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(std::shared_ptr< monty::ndarray< int,1 > > _917,std::shared_ptr< monty::ndarray< long long,1 > > _918) { return __mosek_2fusion_2Model__parameter(_917,_918); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _917,std::shared_ptr< monty::ndarray< long long,1 > > _918){
  _checked_ptr_1<int> _ptr__917(_917 ? _917->raw() : nullptr, _917 ? _917->size(0) : 0);
  _checked_ptr_1<long long> _ptr__918(_918 ? _918->raw() : nullptr, _918 ? _918->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(std::string (""),_917,_918);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _919,std::shared_ptr< monty::ndarray< int,2 > > _920) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__parameter(_919,_920); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::parameter(std::shared_ptr< monty::ndarray< int,1 > > _919,std::shared_ptr< monty::ndarray< int,2 > > _920) { return __mosek_2fusion_2Model__parameter(_919,_920); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _919,std::shared_ptr< monty::ndarray< int,2 > > _920){
  _checked_ptr_1<int> _ptr__919(_919 ? _919->raw() : nullptr, _919 ? _919->size(0) : 0);
  return __mosek_2fusion_2Model__parameter_(std::string (""),_919,_920);
}
void mosek::fusion::p_Model::objective_(const std::string & _921,mosek::fusion::ObjectiveSense _922,monty::rc_ptr< ::mosek::fusion::Expression > _923){
  task_putobjectivename(_921);
  monty::rc_ptr< ::mosek::fusion::WorkStack > _924 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::WorkStack > _925 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
  monty::rc_ptr< ::mosek::fusion::ExprDense > _926 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_923)).as<::mosek::fusion::Expression>());
  _926->eval(_924,_925,xs);
  _924->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _927 = mosek::fusion::p_WorkStack::_get_impl(_924)->i32;
  _checked_ptr_1<int> _ptr__927(_927 ? _927->raw() : nullptr,_927 ? _927->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _928 = mosek::fusion::p_WorkStack::_get_impl(_924)->i64;
  _checked_ptr_1<long long> _ptr__928(_928 ? _928->raw() : nullptr,_928 ? _928->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _929 = mosek::fusion::p_WorkStack::_get_impl(_924)->f64;
  _checked_ptr_1<double> _ptr__929(_929 ? _929->raw() : nullptr,_929 ? _929->size(0) : 0);
  int _930 = mosek::fusion::p_WorkStack::_get_impl(_924)->nd;
  int _931 = mosek::fusion::p_WorkStack::_get_impl(_924)->nelem;
  int _932 = mosek::fusion::p_WorkStack::_get_impl(_924)->nnz;
  bool _933 = mosek::fusion::p_WorkStack::_get_impl(_924)->hassp;
  int _934 = mosek::fusion::p_WorkStack::_get_impl(_924)->ncodeatom;
  int _935 = mosek::fusion::p_WorkStack::_get_impl(_924)->ptr_base;
  int _936 = mosek::fusion::p_WorkStack::_get_impl(_924)->shape_base;
  int _937 = mosek::fusion::p_WorkStack::_get_impl(_924)->nidxs_base;
  int _938 = mosek::fusion::p_WorkStack::_get_impl(_924)->cof_base;
  int _939 = mosek::fusion::p_WorkStack::_get_impl(_924)->code_base;
  int _940 = mosek::fusion::p_WorkStack::_get_impl(_924)->codeptr_base;
  int _941 = mosek::fusion::p_WorkStack::_get_impl(_924)->cconst_base;
  long long _942 = (long long)1;
  int _8928 = (int)0;
  int _8929 = _930;
  for (int _943 = _8928; _943 < _8929; ++_943)
  {
    {
      _930 *= _ptr__927[safe_add( _936,_943 )];
    }
  }
  if ((_942 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression size for objective"));
    }
  }
  {}
  if ((_931 != (int)1))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid expression for objective"));
    }
  }
  {}
  int _944 = (int)0;
  int _945 = (int)0;
  int _8930 = (int)0;
  int _8931 = _932;
  for (int _946 = _8930; _946 < _8931; ++_946)
  {
    {
      if ((_ptr__928[safe_add( _937,_946 )] < (int)0))
      {
        {
          ++ _945;
        }
      }
      else if((_ptr__928[safe_add( _937,_946 )] >= (int)0))
      {
        {
          ++ _944;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _947 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_944)));
  _checked_ptr_1<int> _ptr__947(_947 ? _947->raw() : nullptr,_947 ? _947->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _948 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_944)));
  _checked_ptr_1<double> _ptr__948(_948 ? _948->raw() : nullptr,_948 ? _948->size(0) : 0);
  {
    int _949 = (int)0;
    int _8932 = (int)0;
    int _8933 = _932;
    for (int _950 = _8932; _950 < _8933; ++_950)
    {
      {
        if ((_ptr__928[safe_add( _937,_950 )] >= (int)0))
        {
          {
            _ptr__947[_949] = (int)_ptr__928[safe_add( _937,_950 )];
            _ptr__948[_949] = _ptr__929[safe_add( _938,_950 )];
            ++ _949;
          }
        }
        {}
      }
    }
  }
  task_putobjective((_922 == ::mosek::fusion::ObjectiveSense::Maximize),_947,_948,0.0);
  if ((_945 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _951 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_945)));
      _checked_ptr_1<int> _ptr__951(_951 ? _951->raw() : nullptr,_951 ? _951->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _952 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_945)));
      _checked_ptr_1<int> _ptr__952(_952 ? _952->raw() : nullptr,_952 ? _952->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _953 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_945)));
      _checked_ptr_1<int> _ptr__953(_953 ? _953->raw() : nullptr,_953 ? _953->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _954 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_945)));
      _checked_ptr_1<double> _ptr__954(_954 ? _954->raw() : nullptr,_954 ? _954->size(0) : 0);
      int _8934 = (int)0;
      int _8935 = _945;
      for (int _955 = _8934; _955 < _8935; ++_955)
      {
        {
          long long _956 = (-safe_add( _ptr__928[safe_add( _937,_955 )],(int)1 ));
          _ptr__951[_955] = ((*natbarvar_idx)(_956));
          _ptr__952[_955] = ((*natbarvar_i)(_956));
          _ptr__953[_955] = ((*natbarvar_j)(_956));
          double _8936;
          bool _8937 = (_ptr__952[_955] == _ptr__953[_955]);
          if (_8937)
          {
            _8936 = _ptr__929[safe_add( _938,_955 )];
          }
          else
          {
            _8936 = (0.5 * _ptr__929[safe_add( _938,_955 )]);
          }
          _ptr__954[_955] = _8936;
        }
      }
      task_putbarc(_951,_952,_953,_954);
    }
  }
  {}
  if ((_934 == (int)0))
  {
    {
      int _8938 = (int)0;
      int _8939 = _931;
      for (int _957 = _8938; _957 < _8939; ++_957)
      {
        {
          natconmap_objcodenidx = nullptr;
          natconmap_objcodeptr = nullptr;
          natconmap_objcode = nullptr;
          natconmap_objcconst = nullptr;
        }
      }
    }
  }
  else
  {
    {
      bool _958 = true;
      int _959 = (int)0;
      int _960 = (int)0;
      int _8940 = _ptr__927[_935];
      int _8941 = _ptr__927[safe_add( _935,(int)1 )];
      for (int _961 = _8940; _961 < _8941; ++_961)
      {
        {
          if ((((_ptr__927[safe_add( safe_add( _940,_961 ),(int)1 )] - _ptr__927[safe_add( _940,_961 )]) == (int)1) && ((_ptr__927[safe_add( _939,_ptr__927[safe_add( _940,_961 )] )] == 10) || (_ptr__927[safe_add( _939,_ptr__927[safe_add( _940,_961 )] )] == 2))))
          {
            {
            }
          }
          else
          {
            {
              ++ _960;
              _959 += (_ptr__927[safe_add( safe_add( _940,_961 ),(int)1 )] - _ptr__927[safe_add( _940,_961 )]);
            }
          }
        }
      }
      if ((_960 > (int)0))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _962 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_960)));
          _checked_ptr_1<long long> _ptr__962(_962 ? _962->raw() : nullptr,_962 ? _962->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _963 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _960,(int)1 ))));
          _checked_ptr_1<int> _ptr__963(_963 ? _963->raw() : nullptr,_963 ? _963->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _964 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_959)));
          _checked_ptr_1<int> _ptr__964(_964 ? _964->raw() : nullptr,_964 ? _964->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _965 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_959)));
          _checked_ptr_1<double> _ptr__965(_965 ? _965->raw() : nullptr,_965 ? _965->size(0) : 0);
          {
            int _966 = (int)0;
            int _967 = (int)0;
            int _8942 = _ptr__927[_935];
            int _8943 = _ptr__927[safe_add( _935,(int)1 )];
            for (int _968 = _8942; _968 < _8943; ++_968)
            {
              {
                if ((((_ptr__927[safe_add( safe_add( _940,_968 ),(int)1 )] - _ptr__927[safe_add( _940,_968 )]) == (int)1) && ((_ptr__927[safe_add( _939,_ptr__927[safe_add( _940,_968 )] )] == 10) || (_ptr__927[safe_add( _939,_ptr__927[safe_add( _940,_968 )] )] == 2))))
                {
                  {
                  }
                }
                else
                {
                  {
                    int _8944 = _ptr__927[safe_add( _940,_968 )];
                    int _8945 = _ptr__927[safe_add( safe_add( _940,_968 ),(int)1 )];
                    for (int _969 = _8944; _969 < _8945; ++_969)
                    {
                      {
                        _ptr__964[_966] = _ptr__927[safe_add( _939,_969 )];
                        _ptr__965[_966] = _ptr__929[safe_add( _941,_969 )];
                        ++ _966;
                      }
                    }
                    _ptr__963[safe_add( _967,(int)1 )] = _966;
                    _ptr__962[_967] = _ptr__928[safe_add( _937,_968 )];
                    _958 = (_ptr__962[_967] >= (int)0);
                    ++ _967;
                  }
                }
              }
            }
          }
          natconmap_objcodenidx = _962;
          natconmap_objcodeptr = _963;
          natconmap_objcode = _964;
          natconmap_objcconst = _965;
        }
      }
      else
      {
        {
          natconmap_objcodenidx = nullptr;
          natconmap_objcodeptr = nullptr;
          natconmap_objcode = nullptr;
          natconmap_objcconst = nullptr;
        }
      }
      if ((!_958))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
        }
      }
      {}
    }
  }
}
void mosek::fusion::Model :: objective(double _970) { mosek::fusion::p_Model::_get_impl(this)->objective(_970); }void mosek::fusion::p_Model::objective(double _970){
  objective_(std::string (""),::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_970));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _971,double _972) { mosek::fusion::p_Model::_get_impl(this)->objective(_971,_972); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _971,double _972){
  objective_(std::string (""),_971,::mosek::fusion::p_Expr::constTerm(_972));
}
void mosek::fusion::Model :: objective(mosek::fusion::ObjectiveSense _973,monty::rc_ptr< ::mosek::fusion::Expression > _974) { mosek::fusion::p_Model::_get_impl(this)->objective(_973,_974); }void mosek::fusion::p_Model::objective(mosek::fusion::ObjectiveSense _973,monty::rc_ptr< ::mosek::fusion::Expression > _974){
  objective_(std::string (""),_973,_974);
}
void mosek::fusion::Model :: objective(const std::string & _975,double _976) { mosek::fusion::p_Model::_get_impl(this)->objective(_975,_976); }void mosek::fusion::p_Model::objective(const std::string & _975,double _976){
  objective_(_975,::mosek::fusion::ObjectiveSense::Minimize,::mosek::fusion::p_Expr::constTerm(_976));
}
void mosek::fusion::Model :: objective(const std::string & _977,mosek::fusion::ObjectiveSense _978,double _979) { mosek::fusion::p_Model::_get_impl(this)->objective(_977,_978,_979); }void mosek::fusion::p_Model::objective(const std::string & _977,mosek::fusion::ObjectiveSense _978,double _979){
  objective_(_977,_978,::mosek::fusion::p_Expr::constTerm(_979));
}
void mosek::fusion::Model :: objective(const std::string & _980,mosek::fusion::ObjectiveSense _981,monty::rc_ptr< ::mosek::fusion::Expression > _982) { mosek::fusion::p_Model::_get_impl(this)->objective(_980,_981,_982); }void mosek::fusion::p_Model::objective(const std::string & _980,mosek::fusion::ObjectiveSense _981,monty::rc_ptr< ::mosek::fusion::Expression > _982){
  objective_(_980,_981,_982);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _983,monty::rc_ptr< ::mosek::fusion::ConeDomain > _984) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_983,_984); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _983,monty::rc_ptr< ::mosek::fusion::ConeDomain > _984) { return __mosek_2fusion_2Model__constraint(_983,_984); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _983,monty::rc_ptr< ::mosek::fusion::ConeDomain > _984){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_983,_984);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _985,monty::rc_ptr< ::mosek::fusion::Expression > _986,monty::rc_ptr< ::mosek::fusion::ConeDomain > _987) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_985,_986,_987); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _985,monty::rc_ptr< ::mosek::fusion::Expression > _986,monty::rc_ptr< ::mosek::fusion::ConeDomain > _987) { return __mosek_2fusion_2Model__constraint(_985,_986,_987); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _985,monty::rc_ptr< ::mosek::fusion::Expression > _986,monty::rc_ptr< ::mosek::fusion::ConeDomain > _987){
  return __mosek_2fusion_2Model__constraint_(_985,_986,_987);
}
monty::rc_ptr< ::mosek::fusion::RangedConstraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _988,monty::rc_ptr< ::mosek::fusion::RangeDomain > _989) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_988,_989); }monty::rc_ptr< ::mosek::fusion::RangedConstraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _988,monty::rc_ptr< ::mosek::fusion::RangeDomain > _989) { return __mosek_2fusion_2Model__constraint(_988,_989); }
monty::rc_ptr< ::mosek::fusion::RangedConstraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _988,monty::rc_ptr< ::mosek::fusion::RangeDomain > _989){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_988,_989);
}
monty::rc_ptr< ::mosek::fusion::RangedConstraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _990,monty::rc_ptr< ::mosek::fusion::Expression > _991,monty::rc_ptr< ::mosek::fusion::RangeDomain > _992) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_990,_991,_992); }monty::rc_ptr< ::mosek::fusion::RangedConstraint > mosek::fusion::Model::constraint(const std::string &  _990,monty::rc_ptr< ::mosek::fusion::Expression > _991,monty::rc_ptr< ::mosek::fusion::RangeDomain > _992) { return __mosek_2fusion_2Model__constraint(_990,_991,_992); }
monty::rc_ptr< ::mosek::fusion::RangedConstraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _990,monty::rc_ptr< ::mosek::fusion::Expression > _991,monty::rc_ptr< ::mosek::fusion::RangeDomain > _992){
  return __mosek_2fusion_2Model__constraint_(_990,_991,_992);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _993,monty::rc_ptr< ::mosek::fusion::LinearDomain > _994) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_993,_994); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _993,monty::rc_ptr< ::mosek::fusion::LinearDomain > _994) { return __mosek_2fusion_2Model__constraint(_993,_994); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _993,monty::rc_ptr< ::mosek::fusion::LinearDomain > _994){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_993,_994);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _995,monty::rc_ptr< ::mosek::fusion::Expression > _996,monty::rc_ptr< ::mosek::fusion::LinearDomain > _997) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_995,_996,_997); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _995,monty::rc_ptr< ::mosek::fusion::Expression > _996,monty::rc_ptr< ::mosek::fusion::LinearDomain > _997) { return __mosek_2fusion_2Model__constraint(_995,_996,_997); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _995,monty::rc_ptr< ::mosek::fusion::Expression > _996,monty::rc_ptr< ::mosek::fusion::LinearDomain > _997){
  return __mosek_2fusion_2Model__constraint_(_995,_996,_997);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _998,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _999) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_998,_999); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _998,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _999) { return __mosek_2fusion_2Model__constraint(_998,_999); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _998,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _999){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_998,_999);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _1000,monty::rc_ptr< ::mosek::fusion::Expression > _1001,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1002) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_1000,_1001,_1002); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _1000,monty::rc_ptr< ::mosek::fusion::Expression > _1001,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1002) { return __mosek_2fusion_2Model__constraint(_1000,_1001,_1002); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _1000,monty::rc_ptr< ::mosek::fusion::Expression > _1001,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1002){
  return __mosek_2fusion_2Model__constraint_(_1000,_1001,_1002);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _1003,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1004) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_1003,_1004); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(monty::rc_ptr< ::mosek::fusion::Expression > _1003,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1004) { return __mosek_2fusion_2Model__constraint(_1003,_1004); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _1003,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1004){
  return __mosek_2fusion_2Model__constraint_(std::string (""),_1003,_1004);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__constraint(const std::string & _1005,monty::rc_ptr< ::mosek::fusion::Expression > _1006,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1007) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__constraint(_1005,_1006,_1007); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::constraint(const std::string &  _1005,monty::rc_ptr< ::mosek::fusion::Expression > _1006,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1007) { return __mosek_2fusion_2Model__constraint(_1005,_1006,_1007); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint(const std::string & _1005,monty::rc_ptr< ::mosek::fusion::Expression > _1006,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1007){
  return __mosek_2fusion_2Model__constraint_(_1005,_1006,_1007);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1008) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1008); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1008) { return __mosek_2fusion_2Model__variable(_1008); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1008){
  return __mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_LinPSDDomain::_get_impl(_1008)->shape,_1008);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1009,int _1010,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1011) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1009,_1010,_1011); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _1009,int _1010,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1011) { return __mosek_2fusion_2Model__variable(_1009,_1010,_1011); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1009,int _1010,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1011){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1010),(int)((safe_mul( _1009,safe_add( _1009,(int)1 ) ) / (int)2))}),_1011);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1012,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1013) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1012,_1013); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _1012,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1013) { return __mosek_2fusion_2Model__variable(_1012,_1013); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1012,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1013){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((safe_mul( _1012,safe_add( _1012,(int)1 ) ) / (int)2))}),_1013);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1014,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1015) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1014,_1015); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1014,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1015) { return __mosek_2fusion_2Model__variable(_1014,_1015); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1014,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1015){
  return __mosek_2fusion_2Model__variable_(_1014,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1015);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1016,int _1017,int _1018,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1019) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1016,_1017,_1018,_1019); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1016,int _1017,int _1018,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1019) { return __mosek_2fusion_2Model__variable(_1016,_1017,_1018,_1019); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1016,int _1017,int _1018,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1019){
  return __mosek_2fusion_2Model__variable_(_1016,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1018),(int)((safe_mul( _1017,safe_add( _1017,(int)1 ) ) / (int)2))}),_1019);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1020,int _1021,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1022) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1020,_1021,_1022); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1020,int _1021,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1022) { return __mosek_2fusion_2Model__variable(_1020,_1021,_1022); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1020,int _1021,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1022){
  return __mosek_2fusion_2Model__variable_(_1020,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((safe_mul( _1021,safe_add( _1021,(int)1 ) ) / (int)2))}),_1022);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1023,std::shared_ptr< monty::ndarray< int,1 > > _1024,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1025) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1023,_1024,_1025); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1023,std::shared_ptr< monty::ndarray< int,1 > > _1024,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1025) { return __mosek_2fusion_2Model__variable(_1023,_1024,_1025); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1023,std::shared_ptr< monty::ndarray< int,1 > > _1024,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1025){
  _checked_ptr_1<int> _ptr__1024(_1024 ? _1024->raw() : nullptr, _1024 ? _1024->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_1023,_1024,_1025);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _1026) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1026); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _1026) { return __mosek_2fusion_2Model__variable(_1026); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _1026){
  return (__mosek_2fusion_2Model__variable_(std::string (""),mosek::fusion::p_PSDDomain::_get_impl(_1026)->shape,_1026)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1027,int _1028,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1029) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1027,_1028,_1029); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _1027,int _1028,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1029) { return __mosek_2fusion_2Model__variable(_1027,_1028,_1029); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1027,int _1028,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1029){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1028),(int)(_1027),(int)(_1027)}),_1029)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1030,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1031) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1030,_1031); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _1030,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1031) { return __mosek_2fusion_2Model__variable(_1030,_1031); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1030,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1031){
  return (__mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1030),(int)(_1030)}),_1031)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1032,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1033) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1032,_1033); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1032,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1033) { return __mosek_2fusion_2Model__variable(_1032,_1033); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1032,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1033){
  return (__mosek_2fusion_2Model__variable_(_1032,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1033)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1034,int _1035,int _1036,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1037) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1034,_1035,_1036,_1037); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1034,int _1035,int _1036,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1037) { return __mosek_2fusion_2Model__variable(_1034,_1035,_1036,_1037); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1034,int _1035,int _1036,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1037){
  return (__mosek_2fusion_2Model__variable_(_1034,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1036),(int)(_1035),(int)(_1035)}),_1037)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1038,int _1039,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1040) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1038,_1039,_1040); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1038,int _1039,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1040) { return __mosek_2fusion_2Model__variable(_1038,_1039,_1040); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1038,int _1039,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1040){
  return (__mosek_2fusion_2Model__variable_(_1038,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1039),(int)(_1039)}),_1040)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1041,std::shared_ptr< monty::ndarray< int,1 > > _1042,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1043) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1041,_1042,_1043); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1041,std::shared_ptr< monty::ndarray< int,1 > > _1042,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1043) { return __mosek_2fusion_2Model__variable(_1041,_1042,_1043); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1041,std::shared_ptr< monty::ndarray< int,1 > > _1042,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1043){
  _checked_ptr_1<int> _ptr__1042(_1042 ? _1042->raw() : nullptr, _1042 ? _1042->size(0) : 0);
  return (__mosek_2fusion_2Model__variable_(_1041,_1042,_1043)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _1044) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1044); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _1044) { return __mosek_2fusion_2Model__variable(_1044); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _1044){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1044);
}
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _1045) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1045); }monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _1045) { return __mosek_2fusion_2Model__variable(_1045); }
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _1045){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1045);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _1046) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1046); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _1046) { return __mosek_2fusion_2Model__variable(_1046); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _1046){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1046);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1047,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1048) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1047,_1048); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _1047,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1048) { return __mosek_2fusion_2Model__variable(_1047,_1048); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1047,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1048){
  _checked_ptr_1<int> _ptr__1047(_1047 ? _1047->raw() : nullptr, _1047 ? _1047->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_1047,_1048);
}
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1049,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1050) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1049,_1050); }monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _1049,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1050) { return __mosek_2fusion_2Model__variable(_1049,_1050); }
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1049,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1050){
  _checked_ptr_1<int> _ptr__1049(_1049 ? _1049->raw() : nullptr, _1049 ? _1049->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),_1049,_1050);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1051,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1052) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1051,_1052); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _1051,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1052) { return __mosek_2fusion_2Model__variable(_1051,_1052); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1051,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1052){
  _checked_ptr_1<int> _ptr__1051(_1051 ? _1051->raw() : nullptr, _1051 ? _1051->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_1051,_1052);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1053) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1053); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(std::shared_ptr< monty::ndarray< int,1 > > _1053) { return __mosek_2fusion_2Model__variable(_1053); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1053){
  _checked_ptr_1<int> _ptr__1053(_1053 ? _1053->raw() : nullptr, _1053 ? _1053->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(std::string (""),_1053,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1054,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1055) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1054,_1055); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _1054,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1055) { return __mosek_2fusion_2Model__variable(_1054,_1055); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1054,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1055){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1054)}),_1055);
}
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1056,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1057) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1056,_1057); }monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model::variable(int _1056,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1057) { return __mosek_2fusion_2Model__variable(_1056,_1057); }
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1056,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1057){
  return __mosek_2fusion_2Model__ranged_variable(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1056)}),_1057);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1058,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1059) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1058,_1059); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _1058,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1059) { return __mosek_2fusion_2Model__variable(_1058,_1059); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1058,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1059){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1058)}),_1059);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(int _1060) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1060); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(int _1060) { return __mosek_2fusion_2Model__variable(_1060); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(int _1060){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1060)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable() { return __mosek_2fusion_2Model__variable(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(){
  return __mosek_2fusion_2Model__variable_(std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1061,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1062) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1061,_1062); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1061,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1062) { return __mosek_2fusion_2Model__variable(_1061,_1062); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1061,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1062){
  return __mosek_2fusion_2Model__variable_(_1061,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1062);
}
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1063,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1064) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1063,_1064); }monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model::variable(const std::string &  _1063,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1064) { return __mosek_2fusion_2Model__variable(_1063,_1064); }
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1063,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1064){
  return __mosek_2fusion_2Model__ranged_variable(_1063,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1064);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1065,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1066) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1065,_1066); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1065,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1066) { return __mosek_2fusion_2Model__variable(_1065,_1066); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1065,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1066){
  return __mosek_2fusion_2Model__variable_(_1065,std::shared_ptr< monty::ndarray< int,1 > >(nullptr),_1066);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1067,std::shared_ptr< monty::ndarray< int,1 > > _1068,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1069) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1067,_1068,_1069); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1067,std::shared_ptr< monty::ndarray< int,1 > > _1068,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1069) { return __mosek_2fusion_2Model__variable(_1067,_1068,_1069); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1067,std::shared_ptr< monty::ndarray< int,1 > > _1068,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1069){
  _checked_ptr_1<int> _ptr__1068(_1068 ? _1068->raw() : nullptr, _1068 ? _1068->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_1067,_1068,_1069);
}
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1070,std::shared_ptr< monty::ndarray< int,1 > > _1071,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1072) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1070,_1071,_1072); }monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model::variable(const std::string &  _1070,std::shared_ptr< monty::ndarray< int,1 > > _1071,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1072) { return __mosek_2fusion_2Model__variable(_1070,_1071,_1072); }
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1070,std::shared_ptr< monty::ndarray< int,1 > > _1071,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1072){
  _checked_ptr_1<int> _ptr__1071(_1071 ? _1071->raw() : nullptr, _1071 ? _1071->size(0) : 0);
  return __mosek_2fusion_2Model__ranged_variable(_1070,_1071,_1072);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1073,std::shared_ptr< monty::ndarray< int,1 > > _1074,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1075) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1073,_1074,_1075); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1073,std::shared_ptr< monty::ndarray< int,1 > > _1074,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1075) { return __mosek_2fusion_2Model__variable(_1073,_1074,_1075); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1073,std::shared_ptr< monty::ndarray< int,1 > > _1074,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1075){
  _checked_ptr_1<int> _ptr__1074(_1074 ? _1074->raw() : nullptr, _1074 ? _1074->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_1073,_1074,_1075);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1076,std::shared_ptr< monty::ndarray< int,1 > > _1077) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1076,_1077); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1076,std::shared_ptr< monty::ndarray< int,1 > > _1077) { return __mosek_2fusion_2Model__variable(_1076,_1077); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1076,std::shared_ptr< monty::ndarray< int,1 > > _1077){
  _checked_ptr_1<int> _ptr__1077(_1077 ? _1077->raw() : nullptr, _1077 ? _1077->size(0) : 0);
  return __mosek_2fusion_2Model__variable_(_1076,_1077,::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1078,int _1079,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1080) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1078,_1079,_1080); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1078,int _1079,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1080) { return __mosek_2fusion_2Model__variable(_1078,_1079,_1080); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1078,int _1079,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1080){
  return __mosek_2fusion_2Model__variable_(_1078,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1079)}),_1080);
}
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1081,int _1082,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1083) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1081,_1082,_1083); }monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::Model::variable(const std::string &  _1081,int _1082,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1083) { return __mosek_2fusion_2Model__variable(_1081,_1082,_1083); }
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1081,int _1082,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1083){
  return __mosek_2fusion_2Model__ranged_variable(_1081,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1082)}),_1083);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1084,int _1085,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1086) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1084,_1085,_1086); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1084,int _1085,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1086) { return __mosek_2fusion_2Model__variable(_1084,_1085,_1086); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1084,int _1085,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1086){
  return __mosek_2fusion_2Model__variable_(_1084,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1085)}),_1086);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1087,int _1088) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1087,_1088); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1087,int _1088) { return __mosek_2fusion_2Model__variable(_1087,_1088); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1087,int _1088){
  return __mosek_2fusion_2Model__variable_(_1087,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1088)}),::mosek::fusion::p_Domain::unbounded());
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__variable(const std::string & _1089) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__variable(_1089); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::variable(const std::string &  _1089) { return __mosek_2fusion_2Model__variable(_1089); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable(const std::string & _1089){
  return __mosek_2fusion_2Model__variable_(_1089,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),::mosek::fusion::p_Domain::unbounded());
}
void mosek::fusion::p_Model::removeConstraintBlock(int _1090){
  int _1091 = natconmap->blocksize(_1090);
  std::shared_ptr< monty::ndarray< int,1 > > _1092 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1091)));
  _checked_ptr_1<int> _ptr__1092(_1092 ? _1092->raw() : nullptr,_1092 ? _1092->size(0) : 0);
  if ((((*natconmap_slackidx)(_ptr__1092[(int)0])) != (int)0))
  {
    {
      int _1093 = ((*natvarmap_idx)(((*natconmap_slackidx)(_ptr__1092[(int)0]))));
      removeVariableBlock((long long)(_1093));
    }
  }
  {}
  natconmap->get(_1090,_1092,(int)0);
  natconmap->free(_1090);
  int _8946 = (int)0;
  int _8947 = _1091;
  for (int _1094 = _8946; _1094 < _8947; ++_1094)
  {
    {
      ((*natconmap_blockid)(_ptr__1092[_1094])) = (-(int)1);
      ((*natconmap_slackidx)(_ptr__1092[_1094])) = (int)0;
      ((*natconmap_idx)(_ptr__1092[_1094])) = (-(int)1);
      if ((((*natconmap_coderowptrb)(_ptr__1092[_1094])) < ((*natconmap_coderowptre)(_ptr__1092[_1094]))))
      {
        {
          natconmap_numparameterized -= (((*natconmap_coderowptre)(_ptr__1092[_1094])) - ((*natconmap_coderowptrb)(_ptr__1092[_1094])));
          ((*natconmap_coderowptrb)(_ptr__1092[_1094])) = ((*natconmap_coderowptre)(_ptr__1092[_1094]));
        }
      }
      {}
    }
  }
  task_con_putboundlist_fr(_1092);
  task_cleararowlist(_1092);
}
void mosek::fusion::p_Model::removeVariableBlock(long long _1095){
  if ((natconmap_numparameterized > (int)0))
  {
    {
      throw ::mosek::fusion::DeletionError(std::string ("Cannot remove variables in parameterized model"));
    }
  }
  {}
  if ((_1095 < (int)0))
  {
    {
      throw ::mosek::fusion::DeletionError(std::string ("PSD variables cannot be removed"));
    }
  }
  else
  {
    {
      int _1096 = (int)_1095;
      int _1097 = natvarmap->blocksize(_1096);
      std::shared_ptr< monty::ndarray< int,1 > > _1098 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1097)));
      _checked_ptr_1<int> _ptr__1098(_1098 ? _1098->raw() : nullptr,_1098 ? _1098->size(0) : 0);
      natvarmap->get(_1096,_1098,(int)0);
      natvarmap->free(_1096);
      if ((((*natvarmap_type)(_1096)) > (int)5))
      {
        {
          int _1099 = (((*natvarmap_type)(_1096)) - (int)6);
          int _1100 = natconemap->blocksize(_1099);
          std::shared_ptr< monty::ndarray< int,1 > > _1101 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1100)));
          _checked_ptr_1<int> _ptr__1101(_1101 ? _1101->raw() : nullptr,_1101 ? _1101->size(0) : 0);
          natconemap->get(_1099,_1101,(int)0);
          natconemap->free(_1099);
          ((*natconemap_dim)(_1099)) = (int)0;
          task_clear_cones(_1101);
        }
      }
      {}
      ((*natvarmap_type)(_1096)) = (int)0;
      int _8948 = (int)0;
      int _8949 = _1097;
      for (int _1102 = _8948; _1102 < _8949; ++_1102)
      {
        {
          ((*natvarmap_blockid)(_1102)) = (-(int)1);
          ((*natvarmap_idx)(_1102)) = (-(int)1);
        }
      }
      task_var_putboundlist_fr(_1098);
      task_clearacollist(_1098);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::RangedVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__ranged_variable(const std::string & _1103,std::shared_ptr< monty::ndarray< int,1 > > _1104,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1105){
  _checked_ptr_1<int> _ptr__1104(_1104 ? _1104->raw() : nullptr, _1104 ? _1104->size(0) : 0);
  if ((((int)((_1103).size()) > (int)0) && hasVariable(_1103)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1103)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _8950;
  bool _8951 = (NULL != _1104.get());
  if (_8951)
  {
    _8950 = _1104;
  }
  else
  {
    _8950 = mosek::fusion::p_RangeDomain::_get_impl(_1105)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1106 = _8950;
  _checked_ptr_1<int> _ptr__1106(_1106 ? _1106->raw() : nullptr,_1106 ? _1106->size(0) : 0);
  if (((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1105)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_RangeDomain::_get_impl(_1105)->shape,_1106))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _1106.get()))
  {
    {
      _1106 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__1106.update(_1106 ? _1106->raw() : nullptr, _1106 ? _1106->size(0) : 0);
    }
  }
  {}
  int _1107 = (int)((_1106)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _1108 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1107)));
  _checked_ptr_1<int> _ptr__1108(_1108 ? _1108->raw() : nullptr,_1108 ? _1108->size(0) : 0);
  if ((_1107 > (int)0))
  {
    {
      _ptr__1108[(_1107 - (int)1)] = (int)1;
      int _8952 = (int)1;
      int _8953 = _1107;
      for (int _1109 = _8952; _1109 < _8953; ++_1109)
      {
        {
          _ptr__1108[((_1107 - _1109) - (int)1)] = safe_mul( _ptr__1108[(_1107 - _1109)],_ptr__1106[(_1107 - _1109)] );
        }
      }
    }
  }
  {}
  int _1110 = (int)1;
  int _8954 = (int)0;
  int _8955 = (int)((_1106)->size(0));
  for (int _1111 = _8954; _1111 < _8955; ++_1111)
  {
    {
      _1110 *= _ptr__1106[_1111];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1112 = nullptr;
  _checked_ptr_1<long long> _ptr__1112(_1112 ? _1112->raw() : nullptr,_1112 ? _1112->size(0) : 0);
  if ((NULL != _1112.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)->size(1)) != _1107))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      _1112 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)->size(0)))));
      _ptr__1112.update(_1112 ? _1112->raw() : nullptr, _1112 ? _1112->size(0) : 0);
      int _8956 = (int)0;
      int _8957 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)->size(0));
      for (int _1113 = _8956; _1113 < _8957; ++_1113)
      {
        {
          int _8958 = (int)0;
          int _8959 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)->size(1));
          for (int _1114 = _8958; _1114 < _8959; ++_1114)
          {
            {
              if (((((*mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)(_1113,_1114)) < (int)0) || (((*mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)(_1113,_1114)) >= _ptr__1106[_1114])))
              {
                {
                  throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
                }
              }
              {}
            }
          }
          long long _1115 = (int)0;
          int _8960 = (int)0;
          int _8961 = (int)((mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)->size(1));
          for (int _1116 = _8960; _1116 < _8961; ++_1116)
          {
            {
              _1115 += safe_mul( _ptr__1108[_1116],((*mosek::fusion::p_RangeDomain::_get_impl(_1105)->sparsity)(_1113,_1116)) );
            }
          }
          _ptr__1112[_1113] = _1115;
        }
      }
    }
  }
  {}
  int _8962;
  bool _8963 = (NULL != _1112.get());
  if (_8963)
  {
    _8962 = (int)((_1112)->size(0));
  }
  else
  {
    _8962 = _1110;
  }
  int _1117 = _8962;
  std::shared_ptr< monty::ndarray< double,1 > > _1118;
  _checked_ptr_1<double> _ptr__1118(_1118 ? _1118->raw() : nullptr,_1118 ? _1118->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1119;
  _checked_ptr_1<double> _ptr__1119(_1119 ? _1119->raw() : nullptr,_1119 ? _1119->size(0) : 0);
  if (mosek::fusion::p_RangeDomain::_get_impl(_1105)->scalable)
  {
    {
      std::vector<double> _8964;
      for (int _1120 = (int)0, _8965 = _1117; _1120 < _8965 ; ++_1120)
      {
        _8964.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_1105)->lb)((int)0)));
      }
      auto _8966 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8964.size()),_8964.begin(),_8964.end()));
      _1118 = _8966;
      _ptr__1118.update(_1118 ? _1118->raw() : nullptr, _1118 ? _1118->size(0) : 0);
      std::vector<double> _8967;
      for (int _1121 = (int)0, _8968 = _1117; _1121 < _8968 ; ++_1121)
      {
        _8967.push_back(((*mosek::fusion::p_RangeDomain::_get_impl(_1105)->ub)((int)0)));
      }
      auto _8969 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8967.size()),_8967.begin(),_8967.end()));
      _1119 = _8969;
      _ptr__1119.update(_1119 ? _1119->raw() : nullptr, _1119 ? _1119->size(0) : 0);
    }
  }
  else
  {
    {
      _1118 = mosek::fusion::p_RangeDomain::_get_impl(_1105)->lb;
      _ptr__1118.update(_1118 ? _1118->raw() : nullptr, _1118 ? _1118->size(0) : 0);
      _1119 = mosek::fusion::p_RangeDomain::_get_impl(_1105)->ub;
      _ptr__1119.update(_1119 ? _1119->raw() : nullptr, _1119 ? _1119->size(0) : 0);
    }
  }
  int _1122 = natvarmap_alloc(_1117);
  std::shared_ptr< monty::ndarray< int,1 > > _1123 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_1122))));
  _checked_ptr_1<int> _ptr__1123(_1123 ? _1123->raw() : nullptr,_1123 ? _1123->size(0) : 0);
  natvarmap->get(_1122,_1123,(int)0);
  int _8970 = (int)0;
  int _8971 = _1117;
  for (int _1124 = _8970; _1124 < _8971; ++_1124)
  {
    {
      ((*natvarmap_idx)(_ptr__1123[_1124])) = _1122;
    }
  }
  task_var_putboundlist_ra(_1123,_1118,_1119);
  monty::rc_ptr< ::mosek::fusion::RangedVariable > _1125 = ::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::Model::t(_pubthis),_1103,(long long)(_1122),_1106,_1112,_1123);
  if (mosek::fusion::p_RangeDomain::_get_impl(_1105)->cardinal_flag)
  {
    {
      task_var_putintlist(_1123);
    }
  }
  {}
  ((*vars)(_1122)) = (_1125).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1103).size()) > (int)0))
  {
    {
      var_map->setItem(_1103,_1122);
    }
  }
  {}
  return _1125;
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1126,std::shared_ptr< monty::ndarray< int,1 > > _1127,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1128){
  _checked_ptr_1<int> _ptr__1127(_1127 ? _1127->raw() : nullptr, _1127 ? _1127->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _8972;
  bool _8973 = (NULL != _1127.get());
  if (_8973)
  {
    _8972 = _1127;
  }
  else
  {
    _8972 = mosek::fusion::p_ConeDomain::_get_impl(_1128)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1129 = _8972;
  _checked_ptr_1<int> _ptr__1129(_1129 ? _1129->raw() : nullptr,_1129 ? _1129->size(0) : 0);
  if ((((int)((_1126).size()) > (int)0) && hasVariable(_1126)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1126)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((NULL == _1129.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape"));
    }
  }
  else if(((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1128)->shape.get()) && (!::mosek::fusion::p_Set::match(_1129,mosek::fusion::p_ConeDomain::_get_impl(_1128)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  else if((_1128->getAxis() >= (int)((_1129)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone dimension"));
    }
  }
  {}
  int _8974;
  bool _8975 = (NULL != mosek::fusion::p_ConeDomain::_get_impl(_1128)->shape.get());
  if (_8975)
  {
    _8974 = _1128->getAxis();
  }
  else
  {
    _8974 = ((int)((_1129)->size(0)) - (int)1);
  }
  int _1130 = _8974;
  int _1131 = _ptr__1129[_1130];
  int _1132 = (int)((_1129)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _1133 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1132)));
  _checked_ptr_1<int> _ptr__1133(_1133 ? _1133->raw() : nullptr,_1133 ? _1133->size(0) : 0);
  _ptr__1133[(_1132 - (int)1)] = (int)1;
  int _8976 = (int)1;
  int _8977 = _1132;
  for (int _1134 = _8976; _1134 < _8977; ++_1134)
  {
    {
      _ptr__1133[((_1132 - _1134) - (int)1)] = safe_mul( _ptr__1133[(_1132 - _1134)],_ptr__1129[(_1132 - _1134)] );
    }
  }
  int _1135 = _ptr__1129[(int)0];
  int _8978 = (int)1;
  int _8979 = (int)((_1129)->size(0));
  for (int _1136 = _8978; _1136 < _8979; ++_1136)
  {
    {
      _1135 *= _ptr__1129[_1136];
    }
  }
  int _1137 = (int)1;
  int _8980 = (int)0;
  int _8981 = _1130;
  for (int _1138 = _8980; _1138 < _8981; ++_1138)
  {
    {
      _1137 *= _ptr__1129[_1138];
    }
  }
  int _1139 = (int)1;
  int _8982 = safe_add( _1130,(int)1 );
  int _8983 = _1132;
  for (int _1140 = _8982; _1140 < _8983; ++_1140)
  {
    {
      _1139 *= _ptr__1129[_1140];
    }
  }
  int _1141 = safe_mul( _1137,_1139 );
  if ((((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InQCone) && (_1131 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1131 < (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1131 != (int)3)) || (((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1131 < (int)2)) || (((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1131 != (int)3)) || ((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1131 < (int)2))))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for cone"));
    }
  }
  {}
  int _1142 = natvarmap_alloc(_1135);
  int _1143 = natconemap_alloc(_1141);
  ((*natvarmap_type)(_1142)) = safe_add( _1143,(int)6 );
  std::shared_ptr< monty::ndarray< int,1 > > _1144 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_1142))));
  _checked_ptr_1<int> _ptr__1144(_1144 ? _1144->raw() : nullptr,_1144 ? _1144->size(0) : 0);
  natvarmap->get(_1142,_1144,(int)0);
  int _8984 = (int)0;
  int _8985 = _1135;
  for (int _1145 = _8984; _1145 < _8985; ++_1145)
  {
    {
      ((*natvarmap_idx)(_ptr__1144[_1145])) = _1142;
    }
  }
  task_var_putboundlist_fr(_1144);
  if (mosek::fusion::p_ConeDomain::_get_impl(_1128)->int_flag)
  {
    {
      task_var_putintlist(_1144);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1146 = _1144;
  _checked_ptr_1<int> _ptr__1146(_1146 ? _1146->raw() : nullptr,_1146 ? _1146->size(0) : 0);
  if ((_1130 < ((int)((_1129)->size(0)) - (int)1)))
  {
    {
      _1146 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1144)->size(0)))));
      _ptr__1146.update(_1146 ? _1146->raw() : nullptr, _1146 ? _1146->size(0) : 0);
      int _1147 = (int)0;
      int _8986 = (int)0;
      int _8987 = _1137;
      for (int _1148 = _8986; _1148 < _8987; ++_1148)
      {
        {
          int _8988 = (int)0;
          int _8989 = _1139;
          for (int _1149 = _8988; _1149 < _8989; ++_1149)
          {
            {
              int _8990 = (int)0;
              int _8991 = _1131;
              for (int _1150 = _8990; _1150 < _8991; ++_1150)
              {
                {
                  _ptr__1146[_1147] = _ptr__1144[safe_add( safe_mul( safe_add( safe_mul( _1148,_1131 ),_1150 ),_1139 ),_1149 )];
                  ++ _1147;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1151 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1141)));
  _checked_ptr_1<int> _ptr__1151(_1151 ? _1151->raw() : nullptr,_1151 ? _1151->size(0) : 0);
  natconemap->get(_1143,_1151,(int)0);
  ((*natconemap_dim)(_1143)) = _1131;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1151,_1131,_1141,_1146);
    }
  }
  else
  {
    {
      if ((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
      {
        {
          task_put_rquadcones(_1151,_1131,_1141,_1146);
        }
      }
      else
      {
        {
          if ((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InPExpCone))
          {
            {
              task_put_pexpcones(_1151,_1131,_1141,_1146);
            }
          }
          else
          {
            {
              if ((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InPPowCone))
              {
                {
                  std::vector<double> _8992;
                  for (int _1152 = (int)0, _8993 = _1141; _1152 < _8993 ; ++_1152)
                  {
                    _8992.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1128)->alpha);
                  }
                  auto _8994 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8992.size()),_8992.begin(),_8992.end()));
                  task_put_ppowcones(_1151,_1131,_1141,_1146,_8994);
                }
              }
              else
              {
                {
                  if ((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InDExpCone))
                  {
                    {
                      task_put_dexpcones(_1151,_1131,_1141,_1146);
                    }
                  }
                  else
                  {
                    {
                      if ((mosek::fusion::p_ConeDomain::_get_impl(_1128)->key == ::mosek::fusion::QConeKey::InDPowCone))
                      {
                        {
                          std::vector<double> _8995;
                          for (int _1153 = (int)0, _8996 = _1141; _1153 < _8996 ; ++_1153)
                          {
                            _8995.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1128)->alpha);
                          }
                          auto _8997 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_8995.size()),_8995.begin(),_8995.end()));
                          task_put_dpowcones(_1151,_1131,_1141,_1146,_8997);
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _8998 = (int)0;
  int _8999 = (int)((_1151)->size(0));
  for (int _1154 = _8998; _1154 < _8999; ++_1154)
  {
    {
      task_cone_name(_ptr__1151[_1154],::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__1151[_1154])->toString());
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicVariable > _1155 = ::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::Model::t(_pubthis),_1126,_1142,_1129,_1144);
  ((*vars)(_1142)) = (_1155).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1126).size()) > (int)0))
  {
    {
      var_map->setItem(_1126,_1142);
    }
  }
  {}
  return (_1155).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1156,std::shared_ptr< monty::ndarray< int,1 > > _1157,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1158){
  _checked_ptr_1<int> _ptr__1157(_1157 ? _1157->raw() : nullptr, _1157 ? _1157->size(0) : 0);
  if ((((int)((_1156).size()) > (int)0) && hasVariable(_1156)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1156)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _9000;
  bool _9001 = (NULL != _1157.get());
  if (_9001)
  {
    _9000 = _1157;
  }
  else
  {
    _9000 = mosek::fusion::p_LinearDomain::_get_impl(_1158)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1159 = _9000;
  _checked_ptr_1<int> _ptr__1159(_1159 ? _1159->raw() : nullptr,_1159 ? _1159->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1158)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinearDomain::_get_impl(_1158)->shape,_1159))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  if ((NULL == _1159.get()))
  {
    {
      _1159 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
      _ptr__1159.update(_1159 ? _1159->raw() : nullptr, _1159 ? _1159->size(0) : 0);
    }
  }
  {}
  int _1160 = (int)((_1159)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _1161 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1160)));
  _checked_ptr_1<int> _ptr__1161(_1161 ? _1161->raw() : nullptr,_1161 ? _1161->size(0) : 0);
  if ((_1160 > (int)0))
  {
    {
      _ptr__1161[(_1160 - (int)1)] = (int)1;
      int _9002 = (int)1;
      int _9003 = _1160;
      for (int _1162 = _9002; _1162 < _9003; ++_1162)
      {
        {
          _ptr__1161[((_1160 - _1162) - (int)1)] = safe_mul( _ptr__1161[(_1160 - _1162)],_ptr__1159[(_1160 - _1162)] );
        }
      }
    }
  }
  {}
  int _1163 = (int)1;
  int _9004 = (int)0;
  int _9005 = (int)((_1159)->size(0));
  for (int _1164 = _9004; _1164 < _9005; ++_1164)
  {
    {
      _1163 *= _ptr__1159[_1164];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1165 = nullptr;
  _checked_ptr_1<long long> _ptr__1165(_1165 ? _1165->raw() : nullptr,_1165 ? _1165->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1166 = nullptr;
  _checked_ptr_1<int> _ptr__1166(_1166 ? _1166->raw() : nullptr,_1166 ? _1166->size(0) : 0);
  if (mosek::fusion::p_LinearDomain::_get_impl(_1158)->empty)
  {
    {
      _1165 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0)));
      _ptr__1165.update(_1165 ? _1165->raw() : nullptr, _1165 ? _1165->size(0) : 0);
    }
  }
  else if((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1158)->sparsity.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_1158)->sparsity)->size(1)) != _1160))
      {
        {
          throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is not correct"));
        }
      }
      {}
      int _1167 = (int)((mosek::fusion::p_LinearDomain::_get_impl(_1158)->sparsity)->size(0));
      _1165 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1167)));
      _ptr__1165.update(_1165 ? _1165->raw() : nullptr, _1165 ? _1165->size(0) : 0);
      {
        bool _1168 = false;
        std::shared_ptr< monty::ndarray< int,2 > > _1169 = mosek::fusion::p_LinearDomain::_get_impl(_1158)->sparsity;
        int _9006 = (int)0;
        int _9007 = _1167;
        for (int _1170 = _9006; _1170 < _9007; ++_1170)
        {
          {
            int _9008 = (int)0;
            int _9009 = (int)((_1169)->size(1));
            for (int _1171 = _9008; _1171 < _9009; ++_1171)
            {
              {
                _1168 = (_1168 || ((((*_1169)(_1170,_1171)) < (int)0) || (((*_1169)(_1170,_1171)) >= _ptr__1159[_1171])));
              }
            }
            if ((!_1168))
            {
              {
                long long _1172 = (int)0;
                int _9010 = (int)0;
                int _9011 = (int)((_1169)->size(1));
                for (int _1173 = _9010; _1173 < _9011; ++_1173)
                {
                  {
                    _1172 += safe_mul( _ptr__1161[_1173],((*_1169)(_1170,_1173)) );
                  }
                }
                _ptr__1165[_1170] = _1172;
              }
            }
            {}
          }
        }
        if (_1168)
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Sparsity pattern is out of bounds"));
          }
        }
        {}
      }
      std::shared_ptr< monty::ndarray< int,2 > > _1174 = mosek::fusion::p_LinearDomain::_get_impl(_1158)->sparsity;
      int _1175 = (int)0;
      int _9012 = (int)0;
      int _9013 = _1160;
      for (int _1176 = _9012; _1176 < _9013; ++_1176)
      {
        {
          if ((_1175 < _ptr__1159[_1176]))
          {
            {
              _1175 = _ptr__1159[_1176];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _1177 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1167)));
      _checked_ptr_1<int> _ptr__1177(_1177 ? _1177->raw() : nullptr,_1177 ? _1177->size(0) : 0);
      int _9014 = (int)0;
      int _9015 = _1167;
      for (int _1178 = _9014; _1178 < _9015; ++_1178)
      {
        {
          _ptr__1177[_1178] = _1178;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _1179 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1167)));
      _checked_ptr_1<int> _ptr__1179(_1179 ? _1179->raw() : nullptr,_1179 ? _1179->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1180 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _1175,(int)1 ))));
      _checked_ptr_1<int> _ptr__1180(_1180 ? _1180->raw() : nullptr,_1180 ? _1180->size(0) : 0);
      int _9016 = (int)0;
      int _9017 = _1160;
      for (int _1181 = _9016; _1181 < _9017; ++_1181)
      {
        {
          {
            int _1182 = ((_1160 - _1181) - (int)1);
            int _9018 = (int)0;
            int _9019 = safe_add( _ptr__1159[_1182],(int)1 );
            for (int _1183 = _9018; _1183 < _9019; ++_1183)
            {
              {
                _ptr__1180[_1183] = (int)0;
              }
            }
            int _9020 = (int)0;
            int _9021 = _1167;
            for (int _1184 = _9020; _1184 < _9021; ++_1184)
            {
              {
                ++ _ptr__1180[safe_add( ((*_1174)(_1184,_1182)),(int)1 )];
              }
            }
            int _9022 = (int)0;
            int _9023 = _ptr__1159[_1182];
            for (int _1185 = _9022; _1185 < _9023; ++_1185)
            {
              {
                _ptr__1180[safe_add( _1185,(int)1 )] += _ptr__1180[_1185];
              }
            }
            int _9024 = (int)0;
            int _9025 = _1167;
            for (int _1186 = _9024; _1186 < _9025; ++_1186)
            {
              {
                int _1187 = _ptr__1177[_1186];
                _ptr__1179[_ptr__1180[((*_1174)(_1187,_1182))]] = _1187;
                ++ _ptr__1180[((*_1174)(_1187,_1182))];
              }
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _1188 = _1177;
          _checked_ptr_1<int> _ptr__1188(_1188 ? _1188->raw() : nullptr,_1188 ? _1188->size(0) : 0);
          _1177 = _1179;
          _ptr__1177.update(_1177 ? _1177->raw() : nullptr, _1177 ? _1177->size(0) : 0);
          _1179 = _1188;
          _ptr__1179.update(_1179 ? _1179->raw() : nullptr, _1179 ? _1179->size(0) : 0);
        }
      }
      int _9026 = (int)0;
      int _9027 = _1167;
      for (int _1189 = _9026; _1189 < _9027; ++_1189)
      {
        {
          int _1190 = _ptr__1177[_1189];
          long long _1191 = (int)0;
          int _9028 = (int)0;
          int _9029 = _1160;
          for (int _1192 = _9028; _1192 < _9029; ++_1192)
          {
            {
              _1191 += safe_mul( _ptr__1161[_1192],((*_1174)(_1190,_1192)) );
            }
          }
          _ptr__1165[_1189] = _1191;
        }
      }
    }
  }
  {}
  int _9030;
  bool _9031 = (NULL != _1165.get());
  if (_9031)
  {
    _9030 = (int)((_1165)->size(0));
  }
  else
  {
    _9030 = _1163;
  }
  int _1193 = _9030;
  std::shared_ptr< monty::ndarray< double,1 > > _1194 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1193)));
  _checked_ptr_1<double> _ptr__1194(_1194 ? _1194->raw() : nullptr,_1194 ? _1194->size(0) : 0);
  if ((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1158)->bnd.get()))
  {
    {
      if (((int)((mosek::fusion::p_LinearDomain::_get_impl(_1158)->bnd)->size(0)) == (int)1))
      {
        {
          int _9032 = (int)0;
          int _9033 = _1193;
          for (int _1195 = _9032; _1195 < _9033; ++_1195)
          {
            {
              _ptr__1194[_1195] = ((*mosek::fusion::p_LinearDomain::_get_impl(_1158)->bnd)((int)0));
            }
          }
        }
      }
      else if(((int)((mosek::fusion::p_LinearDomain::_get_impl(_1158)->bnd)->size(0)) == _1193))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinearDomain::_get_impl(_1158)->bnd,(int)0,_1194,(int)0,_1193);
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid right hand side shape in domain"));
        }
      }
    }
  }
  {}
  int _1196 = natvarmap_alloc(_1193);
  std::shared_ptr< monty::ndarray< int,1 > > _1197 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(natvarmap->blocksize(_1196))));
  _checked_ptr_1<int> _ptr__1197(_1197 ? _1197->raw() : nullptr,_1197 ? _1197->size(0) : 0);
  natvarmap->get(_1196,_1197,(int)0);
  int _9034 = (int)0;
  int _9035 = _1193;
  for (int _1198 = _9034; _1198 < _9035; ++_1198)
  {
    {
      ((*natvarmap_idx)(_ptr__1197[_1198])) = _1196;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1158)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      task_var_putboundlist_fr(_1197);
      ((*natvarmap_type)(_1196)) = (int)1;
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1158)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      task_var_putboundlist_up(_1197,_1194);
      ((*natvarmap_type)(_1196)) = (int)3;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1158)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      task_var_putboundlist_lo(_1197,_1194);
      ((*natvarmap_type)(_1196)) = (int)2;
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1158)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      task_var_putboundlist_fx(_1197,_1194);
      ((*natvarmap_type)(_1196)) = (int)5;
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::LinearVariable > _1199 = ::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::Model::t(_pubthis),_1156,(long long)(_1196),_1159,_1165,_1197);
  if (mosek::fusion::p_LinearDomain::_get_impl(_1158)->cardinal_flag)
  {
    {
      task_var_putintlist(_1197);
    }
  }
  {}
  ((*vars)(_1196)) = (_1199).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1156).size()) > (int)0))
  {
    {
      var_map->setItem(_1156,_1196);
    }
  }
  {}
  return (_1199).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1200,std::shared_ptr< monty::ndarray< int,1 > > _1201,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1202){
  _checked_ptr_1<int> _ptr__1201(_1201 ? _1201->raw() : nullptr, _1201 ? _1201->size(0) : 0);
  if ((((int)((_1200).size()) > (int)0) && hasVariable(_1200)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1200)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _9036;
  bool _9037 = (NULL != _1201.get());
  if (_9037)
  {
    _9036 = _1201;
  }
  else
  {
    _9036 = mosek::fusion::p_LinPSDDomain::_get_impl(_1202)->shape;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1203 = _9036;
  _checked_ptr_1<int> _ptr__1203(_1203 ? _1203->raw() : nullptr,_1203 ? _1203->size(0) : 0);
  if ((NULL == _1203.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  else if(((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1202)->shape.get()) && (!::mosek::fusion::p_Set::match(mosek::fusion::p_LinPSDDomain::_get_impl(_1202)->shape,_1203))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and domain"));
    }
  }
  {}
  int _1204 = (int)((_1203)->size(0));
  int _9038;
  bool _9039 = (NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1202)->shape.get());
  if (_9039)
  {
    _9038 = mosek::fusion::p_LinPSDDomain::_get_impl(_1202)->conedim;
  }
  else
  {
    _9038 = (_1204 - (int)1);
  }
  int _1205 = _9038;
  if (((_1205 < (int)0) || (_1205 >= _1204)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone direction dimension"));
    }
  }
  {}
  int _1206 = _ptr__1203[_1205];
  int _1207 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1206 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1207,safe_add( _1207,(int)1 ) ) / (int)2) != _1206))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1208 = (int)1;
  int _1209 = _ptr__1203[_1205];
  int _1210 = (int)1;
  int _9040 = (int)0;
  int _9041 = _1205;
  for (int _1211 = _9040; _1211 < _9041; ++_1211)
  {
    {
      _1210 *= _ptr__1203[_1211];
    }
  }
  int _9042 = safe_add( _1205,(int)1 );
  int _9043 = _1204;
  for (int _1212 = _9042; _1212 < _9043; ++_1212)
  {
    {
      _1208 *= _ptr__1203[_1212];
    }
  }
  int _1213 = safe_mul( _1210,_1208 );
  int _1214 = safe_mul( _1213,_1206 );
  int _1215 = natbarvarmap_alloc(_1213,_1207);
  std::shared_ptr< monty::ndarray< int,1 > > _1216 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1213)));
  _checked_ptr_1<int> _ptr__1216(_1216 ? _1216->raw() : nullptr,_1216 ? _1216->size(0) : 0);
  natbarvarmap_get(_1215,_1216);
  std::shared_ptr< monty::ndarray< long long,1 > > _1217 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1213,_1209 ))));
  _checked_ptr_1<long long> _ptr__1217(_1217 ? _1217->raw() : nullptr,_1217 ? _1217->size(0) : 0);
  {
    int _1218 = (int)0;
    int _9044 = (int)0;
    int _9045 = _1210;
    for (int _1219 = _9044; _1219 < _9045; ++_1219)
    {
      {
        int _9046 = (int)0;
        int _9047 = _1206;
        for (int _1220 = _9046; _1220 < _9047; ++_1220)
        {
          {
            int _9048 = (int)0;
            int _9049 = _1208;
            for (int _1221 = _9048; _1221 < _9049; ++_1221)
            {
              {
                _ptr__1217[_1218] = safe_add( ((*natbarvar_ptr)(_ptr__1216[safe_add( safe_mul( _1219,_1208 ),_1221 )])),_1220 );
                ++ _1218;
              }
            }
          }
        }
      }
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1222 = ::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::Model::t(_pubthis),_1200,_1215,_1203,_1205,_1217);
  ((*barvars)(_1215)) = (_1222).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1200).size()) > (int)0))
  {
    {
      var_map->setItem(_1200,(-safe_add( _1215,(int)1 )));
    }
  }
  {}
  return (_1222).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::SymmetricVariable > mosek::fusion::p_Model::__mosek_2fusion_2Model__variable_(const std::string & _1223,std::shared_ptr< monty::ndarray< int,1 > > _1224,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1225){
  _checked_ptr_1<int> _ptr__1224(_1224 ? _1224->raw() : nullptr, _1224 ? _1224->size(0) : 0);
  if ((((int)((_1223).size()) > (int)0) && hasVariable(_1223)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate variable name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1223)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1226 = _1224;
  _checked_ptr_1<int> _ptr__1226(_1226 ? _1226->raw() : nullptr,_1226 ? _1226->size(0) : 0);
  if ((NULL == _1226.get()))
  {
    {
      _1226 = mosek::fusion::p_PSDDomain::_get_impl(_1225)->shape;
      _ptr__1226.update(_1226 ? _1226->raw() : nullptr, _1226 ? _1226->size(0) : 0);
    }
  }
  {}
  if ((NULL == _1226.get()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Missing shape for variable"));
    }
  }
  {}
  int _1227 = mosek::fusion::p_PSDDomain::_get_impl(_1225)->conedim1;
  int _1228 = mosek::fusion::p_PSDDomain::_get_impl(_1225)->conedim2;
  int _1229 = (int)((_1226)->size(0));
  int _1230 = _ptr__1226[_1227];
  if ((_1227 > _1228))
  {
    {
      int _1231 = _1227;
      _1227 = _1228;
      _1228 = _1231;
    }
  }
  {}
  if (((_1227 == _1228) || ((_1227 < (int)0) || (_1228 >= _1229))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid cone order dimensions for semidefinite variables"));
    }
  }
  {}
  if ((_ptr__1226[_1227] != _ptr__1226[_1228]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape in cone order dimensions"));
    }
  }
  {}
  int _1232 = (int)1;
  int _9050 = (int)0;
  int _9051 = _1227;
  for (int _1233 = _9050; _1233 < _9051; ++_1233)
  {
    {
      _1232 *= _ptr__1226[_1233];
    }
  }
  int _9052 = safe_add( _1227,(int)1 );
  int _9053 = _1228;
  for (int _1234 = _9052; _1234 < _9053; ++_1234)
  {
    {
      _1232 *= _ptr__1226[_1234];
    }
  }
  int _9054 = safe_add( _1228,(int)1 );
  int _9055 = _1229;
  for (int _1235 = _9054; _1235 < _9055; ++_1235)
  {
    {
      _1232 *= _ptr__1226[_1235];
    }
  }
  int _1236 = (safe_mul( safe_mul( _1232,_1230 ),safe_add( _1230,(int)1 ) ) / (int)2);
  int _1237 = natbarvarmap_alloc(_1232,_1230);
  std::shared_ptr< monty::ndarray< long long,1 > > _1238 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1236)));
  _checked_ptr_1<long long> _ptr__1238(_1238 ? _1238->raw() : nullptr,_1238 ? _1238->size(0) : 0);
  natbarvar_get(_1237,_1238);
  monty::rc_ptr< ::mosek::fusion::PSDVariable > _1239 = ::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::Model::t(_pubthis),_1223,_1237,_1226,mosek::fusion::p_PSDDomain::_get_impl(_1225)->conedim1,mosek::fusion::p_PSDDomain::_get_impl(_1225)->conedim2,_1238);
  ((*barvars)(_1237)) = (_1239).as<::mosek::fusion::ModelVariable>();
  if (((int)((_1223).size()) > (int)0))
  {
    {
      var_map->setItem(_1223,(-safe_add( _1237,(int)1 )));
    }
  }
  {}
  return (_1239).as<::mosek::fusion::SymmetricVariable>();
}
void mosek::fusion::p_Model::replace_row_code(monty::rc_ptr< ::mosek::fusion::WorkStack > _1240,std::shared_ptr< monty::ndarray< int,1 > > _1241,int _1242,int _1243,int _1244,int _1245,int _1246){
  _checked_ptr_1<int> _ptr__1241(_1241 ? _1241->raw() : nullptr, _1241 ? _1241->size(0) : 0);
  int _1247 = (int)((_1241)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _1248 = mosek::fusion::p_WorkStack::_get_impl(_1240)->i32;
  _checked_ptr_1<int> _ptr__1248(_1248 ? _1248->raw() : nullptr,_1248 ? _1248->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1249 = mosek::fusion::p_WorkStack::_get_impl(_1240)->i64;
  _checked_ptr_1<long long> _ptr__1249(_1249 ? _1249->raw() : nullptr,_1249 ? _1249->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1250 = mosek::fusion::p_WorkStack::_get_impl(_1240)->f64;
  _checked_ptr_1<double> _ptr__1250(_1250 ? _1250->raw() : nullptr,_1250 ? _1250->size(0) : 0);
  bool _1251 = true;
  int _1252 = (int)0;
  int _1253 = (int)0;
  int _9056 = (int)0;
  int _9057 = _1247;
  for (int _1254 = _9056; _1254 < _9057; ++_1254)
  {
    {
      int _9058 = _ptr__1248[safe_add( _1242,_1254 )];
      int _9059 = _ptr__1248[safe_add( safe_add( _1242,_1254 ),(int)1 )];
      for (int _1255 = _9058; _1255 < _9059; ++_1255)
      {
        {
          if ((((_ptr__1248[safe_add( safe_add( _1244,_1255 ),(int)1 )] - _ptr__1248[safe_add( _1244,_1255 )]) == (int)1) && ((_ptr__1248[safe_add( _1245,_ptr__1248[safe_add( _1244,_1255 )] )] == 10) || (_ptr__1248[safe_add( _1245,_ptr__1248[safe_add( _1244,_1255 )] )] == 2))))
          {
            {
            }
          }
          else
          {
            {
              ++ _1252;
              _1253 += (_ptr__1248[safe_add( safe_add( _1244,_1255 ),(int)1 )] - _ptr__1248[safe_add( _1244,_1255 )]);
            }
          }
        }
      }
    }
  }
  int _1256 = natconmap_codenztop;
  int _1257 = natconmap_codeatomtop;
  natconmap_codealloc(_1252,_1253);
  int _9060 = (int)0;
  int _9061 = _1247;
  for (int _1258 = _9060; _1258 < _9061; ++_1258)
  {
    {
      ((*natconmap_coderowptrb)(_ptr__1241[_1258])) = _1256;
      int _9062 = _ptr__1248[safe_add( _1242,_1258 )];
      int _9063 = _ptr__1248[safe_add( safe_add( _1242,_1258 ),(int)1 )];
      for (int _1259 = _9062; _1259 < _9063; ++_1259)
      {
        {
          if ((((_ptr__1248[safe_add( safe_add( _1244,_1259 ),(int)1 )] - _ptr__1248[safe_add( _1244,_1259 )]) == (int)1) && ((_ptr__1248[safe_add( _1245,_ptr__1248[safe_add( _1244,_1259 )] )] == 10) || (_ptr__1248[safe_add( _1245,_ptr__1248[safe_add( _1244,_1259 )] )] == 2))))
          {
            {
            }
          }
          else
          {
            {
              int _9064 = _ptr__1248[safe_add( _1244,_1259 )];
              int _9065 = _ptr__1248[safe_add( safe_add( _1244,_1259 ),(int)1 )];
              for (int _1260 = _9064; _1260 < _9065; ++_1260)
              {
                {
                  ((*natconmap_code)(_1257)) = _ptr__1248[safe_add( _1245,_1260 )];
                  ((*natconmap_cconst)(_1257)) = _ptr__1250[safe_add( _1246,_1260 )];
                  ++ _1257;
                }
              }
              ((*natconmap_codeptr)(safe_add( _1256,(int)1 ))) = _1257;
              ((*natconmap_codenidx)(_1256)) = _ptr__1249[safe_add( _1243,_1259 )];
              _1251 = (_ptr__1249[safe_add( _1243,_1259 )] >= (int)0);
              ++ _1256;
            }
          }
        }
      }
      ((*natconmap_coderowptre)(_ptr__1241[_1258])) = _1256;
    }
  }
  natconmap_numparameterized += _1252;
  if ((!_1251))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::RangedConstraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1261,monty::rc_ptr< ::mosek::fusion::Expression > _1262,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1263){
  if ((((int)((_1261).size()) > (int)0) && hasConstraint(_1261)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1261)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_RangeDomain::_get_impl(_1263)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1264 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1262)).as<::mosek::fusion::Expression>());
  _1264->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1265 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1265(_1265 ? _1265->raw() : nullptr,_1265 ? _1265->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1266 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1266(_1266 ? _1266->raw() : nullptr,_1266 ? _1266->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1267 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1267(_1267 ? _1267->raw() : nullptr,_1267 ? _1267->size(0) : 0);
  int _1268 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1269 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1270 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1271 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  int _1272 = mosek::fusion::p_WorkStack::_get_impl(rs)->ncodeatom;
  bool _1273 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1274 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1275 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1276 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  int _1277 = mosek::fusion::p_WorkStack::_get_impl(rs)->codeptr_base;
  int _1278 = mosek::fusion::p_WorkStack::_get_impl(rs)->code_base;
  int _1279 = mosek::fusion::p_WorkStack::_get_impl(rs)->cconst_base;
  if ((NULL != mosek::fusion::p_RangeDomain::_get_impl(_1263)->shape.get()))
  {
    {
      if (((int)((mosek::fusion::p_RangeDomain::_get_impl(_1263)->shape)->size(0)) != _1268))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
        }
      }
      else
      {
        {
          int _9066 = (int)0;
          int _9067 = _1268;
          for (int _1280 = _9066; _1280 < _9067; ++_1280)
          {
            {
              if ((((*mosek::fusion::p_RangeDomain::_get_impl(_1263)->shape)(_1280)) != _ptr__1265[safe_add( _1269,_1280 )]))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  {}
  int _1281 = (int)1;
  int _9068 = (int)0;
  int _9069 = _1268;
  for (int _1282 = _9068; _1282 < _9069; ++_1282)
  {
    {
      _1281 *= _ptr__1265[safe_add( _1269,_1282 )];
    }
  }
  int _1283 = natconmap_alloc(_1281);
  std::shared_ptr< monty::ndarray< int,1 > > _1284 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1281)));
  _checked_ptr_1<int> _ptr__1284(_1284 ? _1284->raw() : nullptr,_1284 ? _1284->size(0) : 0);
  natconmap->get(_1283,_1284,(int)0);
  int _9070 = (int)0;
  int _9071 = _1281;
  for (int _1285 = _9070; _1285 < _9071; ++_1285)
  {
    {
      ((*natconmap_idx)(_ptr__1284[_1285])) = _1283;
      ((*natconmap_slackidx)(_ptr__1284[_1285])) = (int)0;
    }
  }
  ((*natconmap_type)(_1283)) = (int)4;
  putarows(_1284,rs,_1270,_1271,_1274,_1275,_1276,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  xs->clear();
  std::shared_ptr< monty::ndarray< double,1 > > _1286 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1281)));
  _checked_ptr_1<double> _ptr__1286(_1286 ? _1286->raw() : nullptr,_1286 ? _1286->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1287 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1281)));
  _checked_ptr_1<double> _ptr__1287(_1287 ? _1287->raw() : nullptr,_1287 ? _1287->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1288 = mosek::fusion::p_RangeDomain::_get_impl(_1263)->lb;
  _checked_ptr_1<double> _ptr__1288(_1288 ? _1288->raw() : nullptr,_1288 ? _1288->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1289 = mosek::fusion::p_RangeDomain::_get_impl(_1263)->ub;
  _checked_ptr_1<double> _ptr__1289(_1289 ? _1289->raw() : nullptr,_1289 ? _1289->size(0) : 0);
  bool _1290 = mosek::fusion::p_RangeDomain::_get_impl(_1263)->empty;
  bool _1291 = mosek::fusion::p_RangeDomain::_get_impl(_1263)->scalable;
  std::shared_ptr< monty::ndarray< int,2 > > _1292 = mosek::fusion::p_RangeDomain::_get_impl(_1263)->sparsity;
  {
    if (_1291)
    {
      {
        int _9072 = (int)0;
        int _9073 = _1281;
        for (int _1293 = _9072; _1293 < _9073; ++_1293)
        {
          {
            _ptr__1286[_1293] = _ptr__1288[(int)0];
            _ptr__1287[_1293] = _ptr__1289[(int)0];
          }
        }
      }
    }
    else if(_1290)
    {
      {
      }
    }
    else if((NULL != _1292.get()))
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _1294 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1268)));
        _checked_ptr_1<int> _ptr__1294(_1294 ? _1294->raw() : nullptr,_1294 ? _1294->size(0) : 0);
        _ptr__1294[(_1268 - (int)1)] = (int)1;
        int _9074 = (int)1;
        int _9075 = _1268;
        for (int _1295 = _9074; _1295 < _9075; ++_1295)
        {
          {
            _ptr__1294[((_1268 - _1295) - (int)1)] = safe_mul( _ptr__1294[(_1268 - _1295)],_ptr__1265[(safe_add( _1269,_1268 ) - _1295)] );
          }
        }
        int _9076 = (int)0;
        int _9077 = (int)((_1288)->size(0));
        for (int _1296 = _9076; _1296 < _9077; ++_1296)
        {
          {
            int _1297 = (int)0;
            int _9078 = (int)0;
            int _9079 = _1268;
            for (int _1298 = _9078; _1298 < _9079; ++_1298)
            {
              {
                _1297 += safe_mul( _ptr__1294[_1298],((*_1292)(_1296,_1298)) );
              }
            }
            _ptr__1286[_1297] = _ptr__1288[_1296];
            _ptr__1287[_1297] = _ptr__1289[_1296];
          }
        }
      }
    }
    else
    {
      {
        int _9080 = (int)0;
        int _9081 = _1281;
        for (int _1299 = _9080; _1299 < _9081; ++_1299)
        {
          {
            _ptr__1286[_1299] = _ptr__1288[_1299];
            _ptr__1287[_1299] = _ptr__1289[_1299];
          }
        }
      }
    }
  }
  task_con_putboundlist_ra(_1284,_1286,_1287);
  if ((_1272 == (int)0))
  {
    {
      int _9082 = (int)0;
      int _9083 = _1270;
      for (int _1300 = _9082; _1300 < _9083; ++_1300)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1284[_1300])) = natconmap_codeatomtop;
          ((*natconmap_coderowptre)(_ptr__1284[_1300])) = natconmap_codeatomtop;
        }
      }
    }
  }
  else
  {
    {
      bool _1301 = true;
      int _1302 = (int)0;
      int _1303 = (int)0;
      int _9084 = (int)0;
      int _9085 = _1270;
      for (int _1304 = _9084; _1304 < _9085; ++_1304)
      {
        {
          int _9086 = _ptr__1265[safe_add( _1274,_1304 )];
          int _9087 = _ptr__1265[safe_add( safe_add( _1274,_1304 ),(int)1 )];
          for (int _1305 = _9086; _1305 < _9087; ++_1305)
          {
            {
              if ((((_ptr__1265[safe_add( safe_add( _1277,_1305 ),(int)1 )] - _ptr__1265[safe_add( _1277,_1305 )]) == (int)1) && ((_ptr__1265[safe_add( _1278,_ptr__1265[safe_add( _1277,_1305 )] )] == 10) || (_ptr__1265[safe_add( _1278,_ptr__1265[safe_add( _1277,_1305 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  ++ _1302;
                  _1303 += (_ptr__1265[safe_add( safe_add( _1277,_1305 ),(int)1 )] - _ptr__1265[safe_add( _1277,_1305 )]);
                }
              }
            }
          }
        }
      }
      int _1306 = natconmap_codenztop;
      int _1307 = natconmap_codeatomtop;
      natconmap_codealloc(_1302,_1303);
      int _1308 = _1307;
      int _1309 = _1306;
      int _9088 = (int)0;
      int _9089 = _1270;
      for (int _1310 = _9088; _1310 < _9089; ++_1310)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1284[_1310])) = _1309;
          if ((_1302 > (int)0))
          {
            {
              int _9090 = _ptr__1265[safe_add( _1274,_1310 )];
              int _9091 = _ptr__1265[safe_add( safe_add( _1274,_1310 ),(int)1 )];
              for (int _1311 = _9090; _1311 < _9091; ++_1311)
              {
                {
                  if ((((_ptr__1265[safe_add( safe_add( _1277,_1311 ),(int)1 )] - _ptr__1265[safe_add( _1277,_1311 )]) == (int)1) && ((_ptr__1265[safe_add( _1278,_ptr__1265[safe_add( _1277,_1311 )] )] == 10) || (_ptr__1265[safe_add( _1278,_ptr__1265[safe_add( _1277,_1311 )] )] == 2))))
                  {
                    {
                    }
                  }
                  else
                  {
                    {
                      int _9092 = _ptr__1265[safe_add( _1277,_1311 )];
                      int _9093 = _ptr__1265[safe_add( safe_add( _1277,_1311 ),(int)1 )];
                      for (int _1312 = _9092; _1312 < _9093; ++_1312)
                      {
                        {
                          ((*natconmap_code)(_1308)) = _ptr__1265[safe_add( _1278,_1312 )];
                          ((*natconmap_cconst)(_1308)) = _ptr__1267[safe_add( _1279,_1312 )];
                          ++ _1308;
                        }
                      }
                      ((*natconmap_codeptr)(safe_add( _1309,(int)1 ))) = _1308;
                      ((*natconmap_codenidx)(_1309)) = _ptr__1266[safe_add( _1275,_1311 )];
                      _1301 = (_ptr__1266[safe_add( _1275,_1311 )] >= (int)0);
                      ++ _1309;
                    }
                  }
                }
              }
              natconmap_numparameterized += _1302;
            }
          }
          {}
          ((*natconmap_coderowptre)(_ptr__1284[_1310])) = _1309;
        }
      }
      if ((!_1301))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
        }
      }
      {}
    }
  }
  std::vector<int> _9094;
  for (int _1314 = (int)0, _9095 = _1268; _1314 < _9095 ; ++_1314)
  {
    _9094.push_back(_ptr__1265[safe_add( _1269,_1314 )]);
  }
  auto _9096 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9094.size()),_9094.begin(),_9094.end()));
  monty::rc_ptr< ::mosek::fusion::RangedConstraint > _1313 = ::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::Model::t(_pubthis),_1261,_9096,_1284,_1283);
  ((*cons)(_1283)) = (_1313).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1261).size()) > (int)0))
  {
    {
      con_map->setItem(_1261,_1283);
    }
  }
  {}
  return _1313;
}
void mosek::fusion::p_Model::putarows(std::shared_ptr< monty::ndarray< int,1 > > _1315,monty::rc_ptr< ::mosek::fusion::WorkStack > _1316,int _1317,int _1318,int _1319,int _1320,int _1321,std::shared_ptr< monty::ndarray< int,1 > > _1322){
  _checked_ptr_1<int> _ptr__1315(_1315 ? _1315->raw() : nullptr, _1315 ? _1315->size(0) : 0);
  _checked_ptr_1<int> _ptr__1322(_1322 ? _1322->raw() : nullptr, _1322 ? _1322->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1323 = mosek::fusion::p_WorkStack::_get_impl(_1316)->i32;
  _checked_ptr_1<int> _ptr__1323(_1323 ? _1323->raw() : nullptr,_1323 ? _1323->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1324 = mosek::fusion::p_WorkStack::_get_impl(_1316)->i64;
  _checked_ptr_1<long long> _ptr__1324(_1324 ? _1324->raw() : nullptr,_1324 ? _1324->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1325 = mosek::fusion::p_WorkStack::_get_impl(_1316)->f64;
  _checked_ptr_1<double> _ptr__1325(_1325 ? _1325->raw() : nullptr,_1325 ? _1325->size(0) : 0);
  int _1326 = (int)0;
  int _1327 = (int)0;
  int _1328 = (int)0;
  int _9097 = (int)0;
  int _9098 = _1317;
  for (int _1329 = _9097; _1329 < _9098; ++_1329)
  {
    {
      int _1330 = _ptr__1323[safe_add( _1319,_1329 )];
      int _1331 = _ptr__1323[safe_add( safe_add( _1319,_1329 ),(int)1 )];
      int _1332 = _1330;
      while ( ((_1332 < _1331) && (_ptr__1324[safe_add( _1320,_1332 )] < (int)0)) )
      {
        {
          int _1333 = ((*natbarvar_idx)((-safe_add( _ptr__1324[safe_add( _1320,_1332 )],(int)1 ))));
          int _1334 = _1332;
          ++ _1332;
          while ( ((_1332 < _1331) && ((_ptr__1324[safe_add( _1320,_1332 )] < (int)0) && (_1333 == ((*natbarvar_idx)((-safe_add( _ptr__1324[safe_add( _1320,_1332 )],(int)1 ))))))) )
          {
            {
              ++ _1332;
            }
          }
          ++ _1327;
        }
      }
      _1328 += (_1332 - _1330);
      _1326 += (_1331 - _1332);
    }
  }
  _1326 += _1317;
  if ((NULL != _1322.get()))
  {
    {
      _1326 += _1317;
    }
  }
  {}
  int _1335 = (int)((_1315)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _1336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1335,(int)1 ))));
  _checked_ptr_1<long long> _ptr__1336(_1336 ? _1336->raw() : nullptr,_1336 ? _1336->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1337 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1326)));
  _checked_ptr_1<int> _ptr__1337(_1337 ? _1337->raw() : nullptr,_1337 ? _1337->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1338 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1326)));
  _checked_ptr_1<double> _ptr__1338(_1338 ? _1338->raw() : nullptr,_1338 ? _1338->size(0) : 0);
  if ((NULL != _1322.get()))
  {
    {
      int _1339 = (int)0;
      int _9099 = (int)0;
      int _9100 = _1317;
      for (int _1340 = _9099; _1340 < _9100; ++_1340)
      {
        {
          int _1341 = (int)0;
          int _9101 = _ptr__1323[safe_add( _1319,_1340 )];
          int _9102 = _ptr__1323[safe_add( safe_add( _1319,_1340 ),(int)1 )];
          for (int _1342 = _9101; _1342 < _9102; ++_1342)
          {
            {
              if ((_ptr__1324[safe_add( _1320,_1342 )] >= (int)0))
              {
                {
                  _ptr__1337[safe_add( _1339,_1341 )] = (int)_ptr__1324[safe_add( _1320,_1342 )];
                  _ptr__1338[safe_add( _1339,_1341 )] = _ptr__1325[safe_add( _1321,_1342 )];
                  ++ _1341;
                }
              }
              {}
            }
          }
          _ptr__1337[safe_add( _1339,_1341 )] = _ptr__1322[_1340];
          _ptr__1338[safe_add( _1339,_1341 )] = (-1.0);
          ++ _1341;
          _ptr__1336[safe_add( _1340,(int)1 )] = safe_add( _ptr__1336[_1340],_1341 );
          _1339 += _1341;
        }
      }
    }
  }
  else
  {
    {
      int _1343 = (int)0;
      int _9103 = (int)0;
      int _9104 = _1317;
      for (int _1344 = _9103; _1344 < _9104; ++_1344)
      {
        {
          int _1345 = (int)0;
          int _9105 = _ptr__1323[safe_add( _1319,_1344 )];
          int _9106 = _ptr__1323[safe_add( safe_add( _1319,_1344 ),(int)1 )];
          for (int _1346 = _9105; _1346 < _9106; ++_1346)
          {
            {
              if ((_ptr__1324[safe_add( _1320,_1346 )] >= (int)0))
              {
                {
                  _ptr__1337[safe_add( _1343,_1345 )] = (int)_ptr__1324[safe_add( _1320,_1346 )];
                  _ptr__1338[safe_add( _1343,_1345 )] = _ptr__1325[safe_add( _1321,_1346 )];
                  ++ _1345;
                }
              }
              {}
            }
          }
          _ptr__1336[safe_add( _1344,(int)1 )] = safe_add( _ptr__1336[_1344],_1345 );
          _1343 += _1345;
        }
      }
    }
  }
  task_putarowlist(_1315,_1336,_1337,_1338);
  if ((_1327 > (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _1347 = _1315;
      _checked_ptr_1<int> _ptr__1347(_1347 ? _1347->raw() : nullptr,_1347 ? _1347->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1348 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _1335,(int)1 ))));
      _checked_ptr_1<long long> _ptr__1348(_1348 ? _1348->raw() : nullptr,_1348 ? _1348->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1349 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1327)));
      _checked_ptr_1<int> _ptr__1349(_1349 ? _1349->raw() : nullptr,_1349 ? _1349->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1350 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1327)));
      _checked_ptr_1<int> _ptr__1350(_1350 ? _1350->raw() : nullptr,_1350 ? _1350->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1351 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1327)));
      _checked_ptr_1<long long> _ptr__1351(_1351 ? _1351->raw() : nullptr,_1351 ? _1351->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1352 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1328)));
      _checked_ptr_1<int> _ptr__1352(_1352 ? _1352->raw() : nullptr,_1352 ? _1352->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _1353 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1328)));
      _checked_ptr_1<int> _ptr__1353(_1353 ? _1353->raw() : nullptr,_1353 ? _1353->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _1354 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1328)));
      _checked_ptr_1<double> _ptr__1354(_1354 ? _1354->raw() : nullptr,_1354 ? _1354->size(0) : 0);
      int _1355 = (int)0;
      int _1356 = (int)0;
      int _9107 = (int)0;
      int _9108 = _1335;
      for (int _1357 = _9107; _1357 < _9108; ++_1357)
      {
        {
          int _1358 = _ptr__1323[safe_add( _1319,_1357 )];
          int _1359 = _ptr__1323[safe_add( safe_add( _1319,_1357 ),(int)1 )];
          while ( ((_1358 < _1359) && (_ptr__1324[safe_add( _1320,_1358 )] < (int)0)) )
          {
            {
              int _1360 = _1358;
              int _1361 = ((*natbarvar_idx)((-safe_add( _ptr__1324[safe_add( _1320,_1358 )],(int)1 ))));
              while ( ((_1358 < _1359) && ((_ptr__1324[safe_add( _1320,_1358 )] < (int)0) && (((*natbarvar_idx)((-safe_add( _ptr__1324[safe_add( _1320,_1358 )],(int)1 )))) == _1361))) )
              {
                {
                  _ptr__1352[_1356] = ((*natbarvar_i)((-safe_add( _ptr__1324[safe_add( _1320,_1358 )],(int)1 ))));
                  _ptr__1353[_1356] = ((*natbarvar_j)((-safe_add( _ptr__1324[safe_add( _1320,_1358 )],(int)1 ))));
                  if ((_ptr__1352[_1356] == _ptr__1353[_1356]))
                  {
                    {
                      _ptr__1354[_1356] = _ptr__1325[safe_add( _1321,_1358 )];
                    }
                  }
                  else
                  {
                    {
                      _ptr__1354[_1356] = (0.5 * _ptr__1325[safe_add( _1321,_1358 )]);
                    }
                  }
                  ++ _1356;
                  ++ _1358;
                }
              }
              _ptr__1349[_1355] = _1361;
              _ptr__1350[_1355] = ((*natbarvar_dim)(_1361));
              _ptr__1351[_1355] = (_1358 - _1360);
              ++ _1355;
            }
          }
          _1358 = _1359;
          _ptr__1348[safe_add( _1357,(int)1 )] = _1355;
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1362 = task_appendsymmatlist(_1350,_1351,_1352,_1353,_1354);
      _checked_ptr_1<long long> _ptr__1362(_1362 ? _1362->raw() : nullptr,_1362 ? _1362->size(0) : 0);
      task_putbararowlist(_1347,_1348,_1349,_1362);
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1363,monty::rc_ptr< ::mosek::fusion::Expression > _1364,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1365){
  std::shared_ptr< monty::ndarray< int,1 > > _1366 = _1364->getShape();
  _checked_ptr_1<int> _ptr__1366(_1366 ? _1366->raw() : nullptr,_1366 ? _1366->size(0) : 0);
  if (((NULL != mosek::fusion::p_PSDDomain::_get_impl(_1365)->shape.get()) && (!::mosek::fusion::p_Set::match(_1366,mosek::fusion::p_PSDDomain::_get_impl(_1365)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  bool _1367;
  int _1368;
  int _1369;
  if (mosek::fusion::p_PSDDomain::_get_impl(_1365)->axisIsSet)
  {
    {
      _1367 = (mosek::fusion::p_PSDDomain::_get_impl(_1365)->conedim1 < mosek::fusion::p_PSDDomain::_get_impl(_1365)->conedim2);
      int _9109;
      bool _9110 = _1367;
      if (_9110)
      {
        _9109 = mosek::fusion::p_PSDDomain::_get_impl(_1365)->conedim1;
      }
      else
      {
        _9109 = mosek::fusion::p_PSDDomain::_get_impl(_1365)->conedim2;
      }
      _1369 = _9109;
      int _9111;
      bool _9112 = _1367;
      if (_9112)
      {
        _9111 = mosek::fusion::p_PSDDomain::_get_impl(_1365)->conedim2;
      }
      else
      {
        _9111 = mosek::fusion::p_PSDDomain::_get_impl(_1365)->conedim1;
      }
      _1368 = _9111;
    }
  }
  else
  {
    {
      _1367 = true;
      _1369 = ((int)((_1366)->size(0)) - (int)2);
      _1368 = ((int)((_1366)->size(0)) - (int)1);
    }
  }
  if (((_1368 >= (int)((_1366)->size(0))) || (_ptr__1366[_1369] != _ptr__1366[_1368])))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Expression > _9113;
  bool _9114 = (mosek::fusion::p_PSDDomain::_get_impl(_1365)->key == ::mosek::fusion::PSDKey::IsSymPSD);
  if (_9114)
  {
    _9113 = ::mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize(_1369,_1368,_1364).as<::mosek::fusion::Expression>();
  }
  else
  {
    _9113 = _1364;
  }
  monty::rc_ptr< ::mosek::fusion::ExprOptimizeCode > _1370 = ::mosek::fusion::p_ExprOptimizeCode::_new_ExprOptimizeCode((::mosek::fusion::p_ExprCompress::_new_ExprCompress((::mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril(_1369,_1368,_9113)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>());
  _1370->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1371 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1371(_1371 ? _1371->raw() : nullptr,_1371 ? _1371->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1372 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1372(_1372 ? _1372->raw() : nullptr,_1372 ? _1372->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1373 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1373(_1373 ? _1373->raw() : nullptr,_1373 ? _1373->size(0) : 0);
  int _1374 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1375 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1376 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1377 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1378 = mosek::fusion::p_WorkStack::_get_impl(rs)->ncodeatom;
  int _1379 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1380 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1381 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1382 = mosek::fusion::p_WorkStack::_get_impl(rs)->sp_base;
  int _1383 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  int _1384 = mosek::fusion::p_WorkStack::_get_impl(rs)->codeptr_base;
  int _1385 = mosek::fusion::p_WorkStack::_get_impl(rs)->code_base;
  int _1386 = mosek::fusion::p_WorkStack::_get_impl(rs)->cconst_base;
  int _1387 = _ptr__1366[_1368];
  int _1388 = (safe_mul( _1387,safe_add( _1387,(int)1 ) ) / (int)2);
  int _9115 = (int)0;
  int _9116 = _1374;
  for (int _1389 = _9115; _1389 < _9116; ++_1389)
  {
    {
      if (((_1389 != _1369) && (_1389 != _1368)))
      {
        {
          _1388 *= _ptr__1366[_1389];
        }
      }
      {}
    }
  }
  int _1390 = natconmap_alloc(_1388);
  std::shared_ptr< monty::ndarray< int,1 > > _1391 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1388)));
  _checked_ptr_1<int> _ptr__1391(_1391 ? _1391->raw() : nullptr,_1391 ? _1391->size(0) : 0);
  natconmap->get(_1390,_1391,(int)0);
  putarows(_1391,rs,_1375,_1376,_1380,_1381,_1383,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  xs->clear();
  std::shared_ptr< monty::ndarray< int,1 > > _1392 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__1392(_1392 ? _1392->raw() : nullptr,_1392 ? _1392->size(0) : 0);
  int _9117 = (int)0;
  int _9118 = _1369;
  for (int _1393 = _9117; _1393 < _9118; ++_1393)
  {
    {
      _ptr__1392[(int)0] *= _ptr__1366[_1393];
    }
  }
  _ptr__1392[(int)1] = _ptr__1366[_1369];
  int _9119 = safe_add( _1369,(int)1 );
  int _9120 = _1368;
  for (int _1394 = _9119; _1394 < _9120; ++_1394)
  {
    {
      _ptr__1392[(int)2] *= _ptr__1366[_1394];
    }
  }
  _ptr__1392[(int)3] = _ptr__1366[_1368];
  int _9121 = safe_add( _1368,(int)1 );
  int _9122 = _1374;
  for (int _1395 = _9121; _1395 < _9122; ++_1395)
  {
    {
      _ptr__1392[(int)4] *= _ptr__1366[_1395];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1396 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__1396(_1396 ? _1396->raw() : nullptr,_1396 ? _1396->size(0) : 0);
  _ptr__1396[(int)4] = (int)1;
  int _9123 = (int)1;
  int _9124 = (int)5;
  for (int _1397 = _9123; _1397 < _9124; ++_1397)
  {
    {
      _ptr__1396[(((int)5 - _1397) - (int)1)] = safe_mul( _ptr__1396[((int)5 - _1397)],_ptr__1392[((int)5 - _1397)] );
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1398 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1388)));
  _checked_ptr_1<double> _ptr__1398(_1398 ? _1398->raw() : nullptr,_1398 ? _1398->size(0) : 0);
  if ((!_1377))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Unexpected case!"));
    }
  }
  else
  {
    {
      int _9125 = (int)0;
      int _9126 = _1375;
      for (int _1399 = _9125; _1399 < _9126; ++_1399)
      {
        {
          _ptr__1398[_1399] = 0.0;
        }
      }
    }
  }
  task_con_putboundlist_fx(_1391,_1398);
  int _1400 = safe_mul( safe_mul( _ptr__1392[(int)0],_ptr__1392[(int)2] ),_ptr__1392[(int)4] );
  int _1401 = _ptr__1392[(int)1];
  int _1402 = natbarvarmap_alloc(_1400,_1401);
  std::shared_ptr< monty::ndarray< int,1 > > _1403 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1400)));
  _checked_ptr_1<int> _ptr__1403(_1403 ? _1403->raw() : nullptr,_1403 ? _1403->size(0) : 0);
  natbarvarmap_get(_1402,_1403);
  std::vector<int> _9127;
  for (int _1405 = (int)0, _9128 = (safe_mul( _1401,safe_add( _1401,(int)1 ) ) / (int)2); _1405 < _9128 ; ++_1405)
  {
    _9127.push_back(_1401);
  }
  auto _9129 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9127.size()),_9127.begin(),_9127.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1404 = _9129;
  _checked_ptr_1<int> _ptr__1404(_1404 ? _1404->raw() : nullptr,_1404 ? _1404->size(0) : 0);
  std::vector<long long> _9130;
  for (int _1407 = (int)0, _9131 = (safe_mul( _1401,safe_add( _1401,(int)1 ) ) / (int)2); _1407 < _9131 ; ++_1407)
  {
    _9130.push_back((int)1);
  }
  auto _9132 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9130.size()),_9130.begin(),_9130.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1406 = _9132;
  _checked_ptr_1<long long> _ptr__1406(_1406 ? _1406->raw() : nullptr,_1406 ? _1406->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1408 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1401,safe_add( _1401,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1408(_1408 ? _1408->raw() : nullptr,_1408 ? _1408->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1409 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((safe_mul( _1401,safe_add( _1401,(int)1 ) ) / (int)2))));
  _checked_ptr_1<int> _ptr__1409(_1409 ? _1409->raw() : nullptr,_1409 ? _1409->size(0) : 0);
  std::vector<double> _9133;
  for (int _1411 = (int)0, _9134 = (safe_mul( _1401,safe_add( _1401,(int)1 ) ) / (int)2); _1411 < _9134 ; ++_1411)
  {
    _9133.push_back((-0.5));
  }
  auto _9135 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9133.size()),_9133.begin(),_9133.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _1410 = _9135;
  _checked_ptr_1<double> _ptr__1410(_1410 ? _1410->raw() : nullptr,_1410 ? _1410->size(0) : 0);
  int _9136 = (int)1;
  int _9137 = safe_add( _1401,(int)1 );
  for (int _1412 = _9136; _1412 < _9137; ++_1412)
  {
    {
      _ptr__1410[((safe_mul( _1412,safe_add( _1412,(int)1 ) ) / (int)2) - (int)1)] = (-1.0);
    }
  }
  {
    int _1413 = (int)0;
    int _9138 = (int)0;
    int _9139 = _1401;
    for (int _1414 = _9138; _1414 < _9139; ++_1414)
    {
      {
        int _9140 = (int)0;
        int _9141 = safe_add( _1414,(int)1 );
        for (int _1415 = _9140; _1415 < _9141; ++_1415)
        {
          {
            _ptr__1408[_1413] = _1414;
            _ptr__1409[_1413] = _1415;
            ++ _1413;
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1416 = task_appendsymmatlist(_1404,_1406,_1408,_1409,_1410);
  _checked_ptr_1<long long> _ptr__1416(_1416 ? _1416->raw() : nullptr,_1416 ? _1416->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1417 = _1391;
  _checked_ptr_1<int> _ptr__1417(_1417 ? _1417->raw() : nullptr,_1417 ? _1417->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1418 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1388)));
  _checked_ptr_1<int> _ptr__1418(_1418 ? _1418->raw() : nullptr,_1418 ? _1418->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1419 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1388)));
  _checked_ptr_1<long long> _ptr__1419(_1419 ? _1419->raw() : nullptr,_1419 ? _1419->size(0) : 0);
  {
    int _1420 = (int)0;
    if (_1367)
    {
      {
        int _9142 = (int)0;
        int _9143 = _ptr__1392[(int)0];
        for (int _1421 = _9142; _1421 < _9143; ++_1421)
        {
          {
            int _9144 = (int)0;
            int _9145 = _ptr__1392[(int)1];
            for (int _1422 = _9144; _1422 < _9145; ++_1422)
            {
              {
                int _9146 = (int)0;
                int _9147 = _ptr__1392[(int)2];
                for (int _1423 = _9146; _1423 < _9147; ++_1423)
                {
                  {
                    int _9148 = (int)0;
                    int _9149 = safe_add( _1422,(int)1 );
                    for (int _1424 = _9148; _1424 < _9149; ++_1424)
                    {
                      {
                        int _9150 = (int)0;
                        int _9151 = _ptr__1392[(int)4];
                        for (int _1425 = _9150; _1425 < _9151; ++_1425)
                        {
                          {
                            _ptr__1419[_1420] = _ptr__1416[safe_add( (safe_mul( _1422,safe_add( _1422,(int)1 ) ) / (int)2),_1424 )];
                            _ptr__1418[_1420] = _ptr__1403[safe_add( safe_mul( safe_add( safe_mul( _1421,_ptr__1392[(int)2] ),_1423 ),_ptr__1392[(int)4] ),_1425 )];
                            ((*natconmap_slackidx)(_ptr__1391[_1420])) = ((-safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1418[_1420])),(safe_mul( _1422,safe_add( _1422,(int)1 ) ) / (int)2) ),_1424 )) - (int)1);
                            ++ _1420;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _9152 = (int)0;
        int _9153 = _ptr__1392[(int)0];
        for (int _1426 = _9152; _1426 < _9153; ++_1426)
        {
          {
            int _9154 = (int)0;
            int _9155 = _ptr__1392[(int)1];
            for (int _1427 = _9154; _1427 < _9155; ++_1427)
            {
              {
                int _9156 = (int)0;
                int _9157 = _ptr__1392[(int)2];
                for (int _1428 = _9156; _1428 < _9157; ++_1428)
                {
                  {
                    int _9158 = _1427;
                    int _9159 = _ptr__1392[(int)1];
                    for (int _1429 = _9158; _1429 < _9159; ++_1429)
                    {
                      {
                        int _9160 = (int)0;
                        int _9161 = _ptr__1392[(int)4];
                        for (int _1430 = _9160; _1430 < _9161; ++_1430)
                        {
                          {
                            _ptr__1419[_1420] = _ptr__1416[safe_add( (safe_mul( _1429,safe_add( _1429,(int)1 ) ) / (int)2),_1427 )];
                            _ptr__1418[_1420] = _ptr__1403[safe_add( safe_mul( safe_add( safe_mul( _1426,_ptr__1392[(int)2] ),_1428 ),_ptr__1392[(int)4] ),_1430 )];
                            ((*natconmap_slackidx)(_ptr__1391[_1420])) = ((-safe_add( safe_add( ((*natbarvar_ptr)(_ptr__1418[_1420])),(safe_mul( _1429,safe_add( _1429,(int)1 ) ) / (int)2) ),_1427 )) - (int)1);
                            ++ _1420;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  task_putbaraijlist(_1417,_1418,_1419);
  ((*natconmap_type)(_1390)) = (-safe_add( _1402,(int)1 ));
  if ((_1378 == (int)0))
  {
    {
      int _9162 = (int)0;
      int _9163 = _1375;
      for (int _1431 = _9162; _1431 < _9163; ++_1431)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1391[_1431])) = natconmap_codeatomtop;
          ((*natconmap_coderowptre)(_ptr__1391[_1431])) = natconmap_codeatomtop;
        }
      }
    }
  }
  else
  {
    {
      bool _1432 = true;
      int _1433 = (int)0;
      int _1434 = (int)0;
      int _9164 = (int)0;
      int _9165 = _1375;
      for (int _1435 = _9164; _1435 < _9165; ++_1435)
      {
        {
          int _9166 = _ptr__1371[safe_add( _1380,_1435 )];
          int _9167 = _ptr__1371[safe_add( safe_add( _1380,_1435 ),(int)1 )];
          for (int _1436 = _9166; _1436 < _9167; ++_1436)
          {
            {
              if ((((_ptr__1371[safe_add( safe_add( _1384,_1436 ),(int)1 )] - _ptr__1371[safe_add( _1384,_1436 )]) == (int)1) && ((_ptr__1371[safe_add( _1385,_ptr__1371[safe_add( _1384,_1436 )] )] == 10) || (_ptr__1371[safe_add( _1385,_ptr__1371[safe_add( _1384,_1436 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  ++ _1433;
                  _1434 += (_ptr__1371[safe_add( safe_add( _1384,_1436 ),(int)1 )] - _ptr__1371[safe_add( _1384,_1436 )]);
                }
              }
            }
          }
        }
      }
      int _1437 = natconmap_codenztop;
      int _1438 = natconmap_codeatomtop;
      natconmap_codealloc(_1433,_1434);
      int _1439 = _1438;
      int _1440 = _1437;
      int _9168 = (int)0;
      int _9169 = _1375;
      for (int _1441 = _9168; _1441 < _9169; ++_1441)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1391[_1441])) = _1440;
          int _9170 = _ptr__1371[safe_add( _1380,_1441 )];
          int _9171 = _ptr__1371[safe_add( safe_add( _1380,_1441 ),(int)1 )];
          for (int _1442 = _9170; _1442 < _9171; ++_1442)
          {
            {
              if ((((_ptr__1371[safe_add( safe_add( _1384,_1442 ),(int)1 )] - _ptr__1371[safe_add( _1384,_1442 )]) == (int)1) && ((_ptr__1371[safe_add( _1385,_ptr__1371[safe_add( _1384,_1442 )] )] == 10) || (_ptr__1371[safe_add( _1385,_ptr__1371[safe_add( _1384,_1442 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  int _9172 = _ptr__1371[safe_add( _1384,_1442 )];
                  int _9173 = _ptr__1371[safe_add( safe_add( _1384,_1442 ),(int)1 )];
                  for (int _1443 = _9172; _1443 < _9173; ++_1443)
                  {
                    {
                      ((*natconmap_code)(_1439)) = _ptr__1371[safe_add( _1385,_1443 )];
                      ((*natconmap_cconst)(_1439)) = _ptr__1373[safe_add( _1386,_1443 )];
                      ++ _1439;
                    }
                  }
                  ((*natconmap_codeptr)(safe_add( _1440,(int)1 ))) = _1439;
                  ((*natconmap_codenidx)(_1440)) = _ptr__1372[safe_add( _1381,_1442 )];
                  _1432 = (_ptr__1372[safe_add( _1381,_1442 )] >= (int)0);
                  ++ _1440;
                }
              }
            }
          }
          ((*natconmap_coderowptre)(_ptr__1391[_1441])) = _1440;
        }
      }
      natconmap_numparameterized += _1433;
      if ((!_1432))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
        }
      }
      {}
    }
  }
  std::vector<long long> _9174;
  for (int _1445 = (int)0, _9175 = _1388; _1445 < _9175 ; ++_1445)
  {
    _9174.push_back(((*natconmap_slackidx)(_ptr__1391[_1445])));
  }
  auto _9176 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9174.size()),_9174.begin(),_9174.end()));
  monty::rc_ptr< ::mosek::fusion::PSDConstraint > _1444 = ::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::Model::t(_pubthis),_1363,_1390,_1366,_1369,_1368,_9176,_1391);
  ((*cons)(_1390)) = (_1444).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1363).size()) > (int)0))
  {
    {
      con_map->setItem(_1363,_1390);
    }
  }
  {}
  return (_1444).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1446,monty::rc_ptr< ::mosek::fusion::Expression > _1447,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1448){
  if ((((int)((_1446).size()) > (int)0) && hasConstraint(_1446)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1446)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1446).size()) > (int)0) && hasConstraint(_1446)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1446)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1449 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprOptimizeCode::_new_ExprOptimizeCode((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1447)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>());
  _1449->eval(rs,ws,xs);
  std::shared_ptr< monty::ndarray< int,1 > > _1450 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1450(_1450 ? _1450->raw() : nullptr,_1450 ? _1450->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1451 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1451(_1451 ? _1451->raw() : nullptr,_1451 ? _1451->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1452 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1452(_1452 ? _1452->raw() : nullptr,_1452 ? _1452->size(0) : 0);
  int _1453 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1454 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1455 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1456 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1457 = mosek::fusion::p_WorkStack::_get_impl(rs)->ncodeatom;
  int _1458 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1459 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1460 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1461 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  int _1462 = mosek::fusion::p_WorkStack::_get_impl(rs)->codeptr_base;
  int _1463 = mosek::fusion::p_WorkStack::_get_impl(rs)->code_base;
  int _1464 = mosek::fusion::p_WorkStack::_get_impl(rs)->cconst_base;
  std::vector<int> _9177;
  for (int _1466 = (int)0, _9178 = _1453; _1466 < _9178 ; ++_1466)
  {
    _9177.push_back(_ptr__1450[safe_add( _1458,_1466 )]);
  }
  auto _9179 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9177.size()),_9177.begin(),_9177.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1465 = _9179;
  _checked_ptr_1<int> _ptr__1465(_1465 ? _1465->raw() : nullptr,_1465 ? _1465->size(0) : 0);
  if (((NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1448)->shape.get()) && (!::mosek::fusion::p_Set::match(_1465,mosek::fusion::p_LinPSDDomain::_get_impl(_1448)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _1467 = (int)1;
  int _9180 = (int)0;
  int _9181 = _1453;
  for (int _1468 = _9180; _1468 < _9181; ++_1468)
  {
    {
      _1467 *= _ptr__1465[_1468];
    }
  }
  int _9182;
  bool _9183 = (NULL != mosek::fusion::p_LinPSDDomain::_get_impl(_1448)->shape.get());
  if (_9183)
  {
    _9182 = mosek::fusion::p_LinPSDDomain::_get_impl(_1448)->conedim;
  }
  else
  {
    _9182 = ((int)((_1465)->size(0)) - (int)1);
  }
  int _1469 = _9182;
  int _1470 = _ptr__1465[_1469];
  int _1471 = (int)((::mosek::fusion::Utils::Tools::sqrt((double)(safe_add( (int)1,safe_mul( (int)8,_1470 ) ))) - (int)1) / (int)2);
  if (((safe_mul( _1471,safe_add( _1471,(int)1 ) ) / (int)2) != _1470))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid size for semidefinite variable"));
    }
  }
  {}
  int _1472 = (int)1;
  int _9184 = (int)0;
  int _9185 = _1469;
  for (int _1473 = _9184; _1473 < _9185; ++_1473)
  {
    {
      _1472 *= _ptr__1465[_1473];
    }
  }
  int _1474 = (int)1;
  int _9186 = safe_add( _1469,(int)1 );
  int _9187 = _1453;
  for (int _1475 = _9186; _1475 < _9187; ++_1475)
  {
    {
      _1474 *= _ptr__1465[_1475];
    }
  }
  int _1476 = safe_mul( _1472,_1474 );
  int _1477 = natconmap_alloc(_1467);
  std::shared_ptr< monty::ndarray< int,1 > > _1478 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1467)));
  _checked_ptr_1<int> _ptr__1478(_1478 ? _1478->raw() : nullptr,_1478 ? _1478->size(0) : 0);
  natconmap->get(_1477,_1478,(int)0);
  putarows(_1478,rs,_1454,_1455,_1459,_1460,_1461,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  int _1479 = natbarvarmap_alloc(_1476,_1471);
  std::shared_ptr< monty::ndarray< int,1 > > _1480 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1476)));
  _checked_ptr_1<int> _ptr__1480(_1480 ? _1480->raw() : nullptr,_1480 ? _1480->size(0) : 0);
  natbarvarmap_get(_1479,_1480);
  ((*barvars)(_1479)) = nullptr;
  int _1481 = safe_mul( safe_mul( _1470,_1472 ),_1474 );
  std::vector<int> _9188;
  for (int _1483 = (int)0, _9189 = _1481; _1483 < _9189 ; ++_1483)
  {
    _9188.push_back(_1471);
  }
  auto _9190 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9188.size()),_9188.begin(),_9188.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1482 = _9190;
  _checked_ptr_1<int> _ptr__1482(_1482 ? _1482->raw() : nullptr,_1482 ? _1482->size(0) : 0);
  std::vector<long long> _9191;
  for (int _1485 = (int)0, _9192 = _1481; _1485 < _9192 ; ++_1485)
  {
    _9191.push_back((int)1);
  }
  auto _9193 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9191.size()),_9191.begin(),_9191.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _1484 = _9193;
  _checked_ptr_1<long long> _ptr__1484(_1484 ? _1484->raw() : nullptr,_1484 ? _1484->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1486 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1481)));
  _checked_ptr_1<double> _ptr__1486(_1486 ? _1486->raw() : nullptr,_1486 ? _1486->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1487 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1481)));
  _checked_ptr_1<int> _ptr__1487(_1487 ? _1487->raw() : nullptr,_1487 ? _1487->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1488 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1481)));
  _checked_ptr_1<int> _ptr__1488(_1488 ? _1488->raw() : nullptr,_1488 ? _1488->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _1489 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1481)));
  _checked_ptr_1<int> _ptr__1489(_1489 ? _1489->raw() : nullptr,_1489 ? _1489->size(0) : 0);
  {
    int _1490 = (int)0;
    int _9194 = (int)0;
    int _9195 = _1472;
    for (int _1491 = _9194; _1491 < _9195; ++_1491)
    {
      {
        int _1492 = (int)0;
        int _9196 = (int)0;
        int _9197 = _1471;
        for (int _1493 = _9196; _1493 < _9197; ++_1493)
        {
          {
            int _9198 = _1493;
            int _9199 = _1471;
            for (int _1494 = _9198; _1494 < _9199; ++_1494)
            {
              {
                int _9200 = (int)0;
                int _9201 = _1474;
                for (int _1495 = _9200; _1495 < _9201; ++_1495)
                {
                  {
                    _ptr__1489[_1490] = _ptr__1480[safe_add( safe_mul( _1491,_1474 ),_1495 )];
                    _ptr__1487[_1490] = _1494;
                    _ptr__1488[_1490] = _1493;
                    double _9202;
                    bool _9203 = (_1494 == _1493);
                    if (_9203)
                    {
                      _9202 = (-1.0);
                    }
                    else
                    {
                      _9202 = (-0.5);
                    }
                    _ptr__1486[_1490] = _9202;
                    ((*natconmap_slackidx)(_ptr__1478[_1490])) = ((-safe_add( ((*natbarvar_ptr)(_ptr__1480[safe_add( safe_mul( _1491,_1474 ),_1495 )])),_1492 )) - (int)1);
                    ++ _1490;
                  }
                }
                ++ _1492;
              }
            }
          }
        }
      }
    }
    ((*natconmap_type)(_1477)) = (-safe_add( _1479,(int)1 ));
    int _9204 = (int)0;
    int _9205 = _1467;
    for (int _1496 = _9204; _1496 < _9205; ++_1496)
    {
      {
        ((*natconmap_blockid)(_ptr__1478[_1496])) = _1477;
        ((*natconmap_idx)(_ptr__1478[_1496])) = _1496;
      }
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _1497 = task_appendsymmatlist(_1482,_1484,_1487,_1488,_1486);
  _checked_ptr_1<long long> _ptr__1497(_1497 ? _1497->raw() : nullptr,_1497 ? _1497->size(0) : 0);
  task_putbaraijlist(_1478,_1489,_1497);
  task_con_putboundlist_fx(_1478,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1467))));
  if ((_1457 == (int)0))
  {
    {
      int _9206 = (int)0;
      int _9207 = _1454;
      for (int _1498 = _9206; _1498 < _9207; ++_1498)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1478[_1498])) = natconmap_codeatomtop;
          ((*natconmap_coderowptre)(_ptr__1478[_1498])) = natconmap_codeatomtop;
        }
      }
    }
  }
  else
  {
    {
      bool _1499 = true;
      int _1500 = (int)0;
      int _1501 = (int)0;
      int _9208 = (int)0;
      int _9209 = _1454;
      for (int _1502 = _9208; _1502 < _9209; ++_1502)
      {
        {
          int _9210 = _ptr__1450[safe_add( _1459,_1502 )];
          int _9211 = _ptr__1450[safe_add( safe_add( _1459,_1502 ),(int)1 )];
          for (int _1503 = _9210; _1503 < _9211; ++_1503)
          {
            {
              if ((((_ptr__1450[safe_add( safe_add( _1462,_1503 ),(int)1 )] - _ptr__1450[safe_add( _1462,_1503 )]) == (int)1) && ((_ptr__1450[safe_add( _1463,_ptr__1450[safe_add( _1462,_1503 )] )] == 10) || (_ptr__1450[safe_add( _1463,_ptr__1450[safe_add( _1462,_1503 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  ++ _1500;
                  _1501 += (_ptr__1450[safe_add( safe_add( _1462,_1503 ),(int)1 )] - _ptr__1450[safe_add( _1462,_1503 )]);
                }
              }
            }
          }
        }
      }
      int _1504 = natconmap_codenztop;
      int _1505 = natconmap_codeatomtop;
      natconmap_codealloc(_1500,_1501);
      int _1506 = _1505;
      int _1507 = _1504;
      int _9212 = (int)0;
      int _9213 = _1454;
      for (int _1508 = _9212; _1508 < _9213; ++_1508)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1478[_1508])) = _1507;
          int _9214 = _ptr__1450[safe_add( _1459,_1508 )];
          int _9215 = _ptr__1450[safe_add( safe_add( _1459,_1508 ),(int)1 )];
          for (int _1509 = _9214; _1509 < _9215; ++_1509)
          {
            {
              if ((((_ptr__1450[safe_add( safe_add( _1462,_1509 ),(int)1 )] - _ptr__1450[safe_add( _1462,_1509 )]) == (int)1) && ((_ptr__1450[safe_add( _1463,_ptr__1450[safe_add( _1462,_1509 )] )] == 10) || (_ptr__1450[safe_add( _1463,_ptr__1450[safe_add( _1462,_1509 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  int _9216 = _ptr__1450[safe_add( _1462,_1509 )];
                  int _9217 = _ptr__1450[safe_add( safe_add( _1462,_1509 ),(int)1 )];
                  for (int _1510 = _9216; _1510 < _9217; ++_1510)
                  {
                    {
                      ((*natconmap_code)(_1506)) = _ptr__1450[safe_add( _1463,_1510 )];
                      ((*natconmap_cconst)(_1506)) = _ptr__1452[safe_add( _1464,_1510 )];
                      ++ _1506;
                    }
                  }
                  ((*natconmap_codeptr)(safe_add( _1507,(int)1 ))) = _1506;
                  ((*natconmap_codenidx)(_1507)) = _ptr__1451[safe_add( _1460,_1509 )];
                  _1499 = (_ptr__1451[safe_add( _1460,_1509 )] >= (int)0);
                  ++ _1507;
                }
              }
            }
          }
          ((*natconmap_coderowptre)(_ptr__1478[_1508])) = _1507;
        }
      }
      natconmap_numparameterized += _1500;
      if ((!_1499))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
        }
      }
      {}
    }
  }
  std::vector<long long> _9218;
  for (int _1512 = (int)0, _9219 = _1467; _1512 < _9219 ; ++_1512)
  {
    _9218.push_back(((*natconmap_slackidx)(_ptr__1478[_1512])));
  }
  auto _9220 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9218.size()),_9218.begin(),_9218.end()));
  monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _1511 = ::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::Model::t(_pubthis),_1446,_1477,_1465,_1469,_1478,_9220);
  ((*cons)(_1477)) = (_1511).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1446).size()) > (int)0))
  {
    {
      con_map->setItem(_1446,_1477);
    }
  }
  {}
  return (_1511).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1513,monty::rc_ptr< ::mosek::fusion::Expression > _1514,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1515){
  if ((((int)((_1513).size()) > (int)0) && hasConstraint(_1513)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1513)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if ((((int)((_1513).size()) > (int)0) && hasConstraint(_1513)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1513)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_ConeDomain::_get_impl(_1515)->int_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1516 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprOptimizeCode::_new_ExprOptimizeCode((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1514)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>());
  _1516->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1517 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1517(_1517 ? _1517->raw() : nullptr,_1517 ? _1517->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1518 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1518(_1518 ? _1518->raw() : nullptr,_1518 ? _1518->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1519 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1519(_1519 ? _1519->raw() : nullptr,_1519 ? _1519->size(0) : 0);
  int _1520 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1521 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1522 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1523 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  int _1524 = mosek::fusion::p_WorkStack::_get_impl(rs)->ncodeatom;
  bool _1525 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1526 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1527 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1528 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  int _1529 = mosek::fusion::p_WorkStack::_get_impl(rs)->code_base;
  int _1530 = mosek::fusion::p_WorkStack::_get_impl(rs)->codeptr_base;
  int _1531 = mosek::fusion::p_WorkStack::_get_impl(rs)->cconst_base;
  std::vector<int> _9221;
  for (int _1533 = (int)0, _9222 = _1520; _1533 < _9222 ; ++_1533)
  {
    _9221.push_back(_ptr__1517[safe_add( _1521,_1533 )]);
  }
  auto _9223 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9221.size()),_9221.begin(),_9221.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1532 = _9223;
  _checked_ptr_1<int> _ptr__1532(_1532 ? _1532->raw() : nullptr,_1532 ? _1532->size(0) : 0);
  if (((NULL != mosek::fusion::p_ConeDomain::_get_impl(_1515)->shape.get()) && (!::mosek::fusion::p_Set::match(_1532,mosek::fusion::p_ConeDomain::_get_impl(_1515)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  int _9224;
  bool _9225 = _1515->axisIsSet();
  if (_9225)
  {
    _9224 = _1515->getAxis();
  }
  else
  {
    _9224 = (_1520 - (int)1);
  }
  int _1534 = _9224;
  int _1535 = _ptr__1532[_1534];
  int _1536 = (int)1;
  int _1537 = (int)1;
  int _1538 = (int)1;
  {
    int _9226 = (int)0;
    int _9227 = _1520;
    for (int _1539 = _9226; _1539 < _9227; ++_1539)
    {
      {
        _1538 *= _ptr__1532[_1539];
      }
    }
    int _9228 = (int)0;
    int _9229 = _1534;
    for (int _1540 = _9228; _1540 < _9229; ++_1540)
    {
      {
        _1537 *= _ptr__1532[_1540];
      }
    }
    int _9230 = safe_add( _1534,(int)1 );
    int _9231 = _1520;
    for (int _1541 = _9230; _1541 < _9231; ++_1541)
    {
      {
        _1536 *= _ptr__1532[_1541];
      }
    }
  }
  int _1542 = safe_mul( _1537,_1536 );
  if (((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InQCone) && (_1535 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1535)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InRotatedQCone) && (_1535 < (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1535)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for rotated quadratic cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InPExpCone) && (_1535 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1535)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InPPowCone) && (_1535 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1535)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for power cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InDExpCone) && (_1535 != (int)3)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1535)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual exponential cone"))->toString());
    }
  }
  else if(((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InDPowCone) && (_1535 < (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Invalid size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_1535)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") for dual power cone"))->toString());
    }
  }
  {}
  int _1543 = natvarmap_alloc(_1538);
  std::shared_ptr< monty::ndarray< int,1 > > _1544 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1538)));
  _checked_ptr_1<int> _ptr__1544(_1544 ? _1544->raw() : nullptr,_1544 ? _1544->size(0) : 0);
  natvarmap->get(_1543,_1544,(int)0);
  int _1545 = natconemap_alloc(_1542);
  int _9232 = (int)0;
  int _9233 = _1538;
  for (int _1546 = _9232; _1546 < _9233; ++_1546)
  {
    {
      ((*natvarmap_idx)(_ptr__1544[_1546])) = _1543;
    }
  }
  task_var_putboundlist_fr(_1544);
  std::shared_ptr< monty::ndarray< int,1 > > _9234;
  bool _9235 = (_1534 < ((int)((_1532)->size(0)) - (int)1));
  if (_9235)
  {
    _9234 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_1544)->size(0)))));
  }
  else
  {
    _9234 = _1544;
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1547 = _9234;
  _checked_ptr_1<int> _ptr__1547(_1547 ? _1547->raw() : nullptr,_1547 ? _1547->size(0) : 0);
  if ((_1534 < ((int)((_1532)->size(0)) - (int)1)))
  {
    {
      int _1548 = (int)0;
      int _9236 = (int)0;
      int _9237 = _1537;
      for (int _1549 = _9236; _1549 < _9237; ++_1549)
      {
        {
          int _9238 = (int)0;
          int _9239 = _1536;
          for (int _1550 = _9238; _1550 < _9239; ++_1550)
          {
            {
              int _9240 = (int)0;
              int _9241 = _1535;
              for (int _1551 = _9240; _1551 < _9241; ++_1551)
              {
                {
                  _ptr__1547[_1548] = _ptr__1544[safe_add( safe_mul( safe_add( safe_mul( _1549,_1535 ),_1551 ),_1536 ),_1550 )];
                  ++ _1548;
                }
              }
            }
          }
        }
      }
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _1552 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1542)));
  _checked_ptr_1<int> _ptr__1552(_1552 ? _1552->raw() : nullptr,_1552 ? _1552->size(0) : 0);
  natconemap->get(_1545,_1552,(int)0);
  ((*natconemap_dim)(_1545)) = _1535;
  if ((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InQCone))
  {
    {
      task_put_quadcones(_1552,_1535,_1542,_1547);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InRotatedQCone))
  {
    {
      task_put_rquadcones(_1552,_1535,_1542,_1547);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InPExpCone))
  {
    {
      task_put_pexpcones(_1552,_1535,_1542,_1547);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InPPowCone))
  {
    {
      std::vector<double> _9242;
      for (int _1553 = (int)0, _9243 = _1542; _1553 < _9243 ; ++_1553)
      {
        _9242.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1515)->alpha);
      }
      auto _9244 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9242.size()),_9242.begin(),_9242.end()));
      task_put_ppowcones(_1552,_1535,_1542,_1547,_9244);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InDExpCone))
  {
    {
      task_put_dexpcones(_1552,_1535,_1542,_1547);
    }
  }
  else if((mosek::fusion::p_ConeDomain::_get_impl(_1515)->key == ::mosek::fusion::QConeKey::InDPowCone))
  {
    {
      std::vector<double> _9245;
      for (int _1554 = (int)0, _9246 = _1542; _1554 < _9246 ; ++_1554)
      {
        _9245.push_back(mosek::fusion::p_ConeDomain::_get_impl(_1515)->alpha);
      }
      auto _9247 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9245.size()),_9245.begin(),_9245.end()));
      task_put_dpowcones(_1552,_1535,_1542,_1547,_9247);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid cone type"));
    }
  }
  ((*vars)(_1543)) = nullptr;
  int _1555 = natconmap_alloc(_1538);
  std::shared_ptr< monty::ndarray< int,1 > > _1556 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1538)));
  _checked_ptr_1<int> _ptr__1556(_1556 ? _1556->raw() : nullptr,_1556 ? _1556->size(0) : 0);
  natconmap->get(_1555,_1556,(int)0);
  ((*natconmap_type)(_1555)) = safe_add( _1543,(int)6 );
  {
    int _9248 = (int)0;
    int _9249 = _1538;
    for (int _1557 = _9248; _1557 < _9249; ++_1557)
    {
      {
        ((*natconmap_slackidx)(_ptr__1556[_1557])) = safe_add( _ptr__1544[_1557],(int)1 );
      }
    }
    int _9250 = (int)0;
    int _9251 = _1538;
    for (int _1558 = _9250; _1558 < _9251; ++_1558)
    {
      {
        ((*natconmap_blockid)(_ptr__1556[_1558])) = _1555;
      }
    }
    int _9252 = (int)0;
    int _9253 = _1538;
    for (int _1559 = _9252; _1559 < _9253; ++_1559)
    {
      {
        ((*natconmap_idx)(_ptr__1556[_1559])) = _1559;
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _1560 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_1538)));
  _checked_ptr_1<double> _ptr__1560(_1560 ? _1560->raw() : nullptr,_1560 ? _1560->size(0) : 0);
  task_con_putboundlist_fx(_1556,_1560);
  putarows(_1556,rs,_1522,_1523,_1526,_1527,_1528,_1544);
  if ((_1524 == (int)0))
  {
    {
      int _9254 = (int)0;
      int _9255 = _1522;
      for (int _1561 = _9254; _1561 < _9255; ++_1561)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1556[_1561])) = natconmap_codeatomtop;
          ((*natconmap_coderowptre)(_ptr__1556[_1561])) = natconmap_codeatomtop;
        }
      }
    }
  }
  else
  {
    {
      bool _1562 = true;
      int _1563 = (int)0;
      int _1564 = (int)0;
      int _9256 = (int)0;
      int _9257 = _1522;
      for (int _1565 = _9256; _1565 < _9257; ++_1565)
      {
        {
          int _9258 = _ptr__1517[safe_add( _1526,_1565 )];
          int _9259 = _ptr__1517[safe_add( safe_add( _1526,_1565 ),(int)1 )];
          for (int _1566 = _9258; _1566 < _9259; ++_1566)
          {
            {
              if ((((_ptr__1517[safe_add( safe_add( _1530,_1566 ),(int)1 )] - _ptr__1517[safe_add( _1530,_1566 )]) == (int)1) && ((_ptr__1517[safe_add( _1529,_ptr__1517[safe_add( _1530,_1566 )] )] == 10) || (_ptr__1517[safe_add( _1529,_ptr__1517[safe_add( _1530,_1566 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  ++ _1563;
                  _1564 += (_ptr__1517[safe_add( safe_add( _1530,_1566 ),(int)1 )] - _ptr__1517[safe_add( _1530,_1566 )]);
                }
              }
            }
          }
        }
      }
      int _1567 = natconmap_codenztop;
      int _1568 = natconmap_codeatomtop;
      natconmap_codealloc(_1563,_1564);
      int _1569 = _1568;
      int _1570 = _1567;
      int _9260 = (int)0;
      int _9261 = _1522;
      for (int _1571 = _9260; _1571 < _9261; ++_1571)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1556[_1571])) = _1570;
          int _9262 = _ptr__1517[safe_add( _1526,_1571 )];
          int _9263 = _ptr__1517[safe_add( safe_add( _1526,_1571 ),(int)1 )];
          for (int _1572 = _9262; _1572 < _9263; ++_1572)
          {
            {
              if ((((_ptr__1517[safe_add( safe_add( _1530,_1572 ),(int)1 )] - _ptr__1517[safe_add( _1530,_1572 )]) == (int)1) && ((_ptr__1517[safe_add( _1529,_ptr__1517[safe_add( _1530,_1572 )] )] == 10) || (_ptr__1517[safe_add( _1529,_ptr__1517[safe_add( _1530,_1572 )] )] == 2))))
              {
                {
                }
              }
              else
              {
                {
                  int _9264 = _ptr__1517[safe_add( _1530,_1572 )];
                  int _9265 = _ptr__1517[safe_add( safe_add( _1530,_1572 ),(int)1 )];
                  for (int _1573 = _9264; _1573 < _9265; ++_1573)
                  {
                    {
                      ((*natconmap_code)(_1569)) = _ptr__1517[safe_add( _1529,_1573 )];
                      ((*natconmap_cconst)(_1569)) = _ptr__1519[safe_add( _1531,_1573 )];
                      ++ _1569;
                    }
                  }
                  ((*natconmap_codeptr)(safe_add( _1570,(int)1 ))) = _1569;
                  ((*natconmap_codenidx)(_1570)) = _ptr__1518[safe_add( _1527,_1572 )];
                  _1562 = (_ptr__1518[safe_add( _1527,_1572 )] >= (int)0);
                  ++ _1570;
                }
              }
            }
          }
          ((*natconmap_coderowptre)(_ptr__1556[_1571])) = _1570;
        }
      }
      natconmap_numparameterized += _1563;
      if ((!_1562))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Expression contains parameterized SDP non-zero"));
        }
      }
      {}
    }
  }
  monty::rc_ptr< ::mosek::fusion::ConicConstraint > _1574 = ::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::Model::t(_pubthis),_1513,_1515,_1532,_1555,_1556,_1544);
  ((*cons)(_1555)) = (_1574).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1513).size()) > (int)0))
  {
    {
      con_map->setItem(_1513,_1555);
    }
  }
  {}
  return (_1574).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__constraint_(const std::string & _1575,monty::rc_ptr< ::mosek::fusion::Expression > _1576,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1577){
  if ((((int)((_1575).size()) > (int)0) && hasConstraint(_1575)))
  {
    {
      throw ::mosek::fusion::NameError(::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Duplicate constraint name '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1575)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->toString());
    }
  }
  {}
  if (mosek::fusion::p_LinearDomain::_get_impl(_1577)->cardinal_flag)
  {
    {
      throw ::mosek::fusion::DomainError(std::string ("Integer domain not allowed in a constraint"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::ExprDense > _1578 = ::mosek::fusion::p_ExprDense::_new_ExprDense((::mosek::fusion::p_ExprOptimizeCode::_new_ExprOptimizeCode((::mosek::fusion::p_ExprCompress::_new_ExprCompress(_1576)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>());
  _1578->eval(rs,ws,xs);
  rs->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _1579 = mosek::fusion::p_WorkStack::_get_impl(rs)->i32;
  _checked_ptr_1<int> _ptr__1579(_1579 ? _1579->raw() : nullptr,_1579 ? _1579->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1580 = mosek::fusion::p_WorkStack::_get_impl(rs)->i64;
  _checked_ptr_1<long long> _ptr__1580(_1580 ? _1580->raw() : nullptr,_1580 ? _1580->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1581 = mosek::fusion::p_WorkStack::_get_impl(rs)->f64;
  _checked_ptr_1<double> _ptr__1581(_1581 ? _1581->raw() : nullptr,_1581 ? _1581->size(0) : 0);
  int _1582 = mosek::fusion::p_WorkStack::_get_impl(rs)->nd;
  int _1583 = mosek::fusion::p_WorkStack::_get_impl(rs)->nelem;
  int _1584 = mosek::fusion::p_WorkStack::_get_impl(rs)->nnz;
  bool _1585 = mosek::fusion::p_WorkStack::_get_impl(rs)->hassp;
  int _1586 = mosek::fusion::p_WorkStack::_get_impl(rs)->ncodeatom;
  int _1587 = mosek::fusion::p_WorkStack::_get_impl(rs)->shape_base;
  int _1588 = mosek::fusion::p_WorkStack::_get_impl(rs)->ptr_base;
  int _1589 = mosek::fusion::p_WorkStack::_get_impl(rs)->nidxs_base;
  int _1590 = mosek::fusion::p_WorkStack::_get_impl(rs)->cof_base;
  int _1591 = mosek::fusion::p_WorkStack::_get_impl(rs)->codeptr_base;
  int _1592 = mosek::fusion::p_WorkStack::_get_impl(rs)->code_base;
  int _1593 = mosek::fusion::p_WorkStack::_get_impl(rs)->cconst_base;
  std::vector<int> _9266;
  for (int _1595 = (int)0, _9267 = _1582; _1595 < _9267 ; ++_1595)
  {
    _9266.push_back(_ptr__1579[safe_add( _1587,_1595 )]);
  }
  auto _9268 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9266.size()),_9266.begin(),_9266.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _1594 = _9268;
  _checked_ptr_1<int> _ptr__1594(_1594 ? _1594->raw() : nullptr,_1594 ? _1594->size(0) : 0);
  int _1596 = (int)1;
  int _9269 = (int)0;
  int _9270 = _1582;
  for (int _1597 = _9269; _1597 < _9270; ++_1597)
  {
    {
      _1596 *= _ptr__1594[_1597];
    }
  }
  if (((NULL != mosek::fusion::p_LinearDomain::_get_impl(_1577)->shape.get()) && (!::mosek::fusion::p_Set::match(_1594,mosek::fusion::p_LinearDomain::_get_impl(_1577)->shape))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression and domain"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< double,1 > > _1598;
  _checked_ptr_1<double> _ptr__1598(_1598 ? _1598->raw() : nullptr,_1598 ? _1598->size(0) : 0);
  int _1599 = natconmap_alloc(_1596);
  std::shared_ptr< monty::ndarray< int,1 > > _1600 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1596)));
  _checked_ptr_1<int> _ptr__1600(_1600 ? _1600->raw() : nullptr,_1600 ? _1600->size(0) : 0);
  natconmap->get(_1599,_1600,(int)0);
  putarows(_1600,rs,_1583,_1584,_1588,_1589,_1590,std::shared_ptr< monty::ndarray< int,1 > >(nullptr));
  {
    std::shared_ptr< monty::ndarray< int,2 > > _1601 = mosek::fusion::p_LinearDomain::_get_impl(_1577)->sparsity;
    bool _1602 = mosek::fusion::p_LinearDomain::_get_impl(_1577)->empty;
    std::shared_ptr< monty::ndarray< double,1 > > _1603 = mosek::fusion::p_LinearDomain::_get_impl(_1577)->bnd;
    _checked_ptr_1<double> _ptr__1603(_1603 ? _1603->raw() : nullptr,_1603 ? _1603->size(0) : 0);
    bool _1604 = mosek::fusion::p_LinearDomain::_get_impl(_1577)->scalable;
    {
      if ((NULL == _1603.get()))
      {
        {
          std::vector<double> _9271;
          for (int _1605 = (int)0, _9272 = (int)((_1600)->size(0)); _1605 < _9272 ; ++_1605)
          {
            _9271.push_back(0.0);
          }
          auto _9273 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9271.size()),_9271.begin(),_9271.end()));
          _1598 = _9273;
          _ptr__1598.update(_1598 ? _1598->raw() : nullptr, _1598 ? _1598->size(0) : 0);
        }
      }
      else if(_1604)
      {
        {
          std::vector<double> _9274;
          for (int _1606 = (int)0, _9275 = (int)((_1600)->size(0)); _1606 < _9275 ; ++_1606)
          {
            _9274.push_back(_ptr__1603[(int)0]);
          }
          auto _9276 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9274.size()),_9274.begin(),_9274.end()));
          _1598 = _9276;
          _ptr__1598.update(_1598 ? _1598->raw() : nullptr, _1598 ? _1598->size(0) : 0);
        }
      }
      else if((NULL != _1601.get()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1607 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1582)));
          _checked_ptr_1<int> _ptr__1607(_1607 ? _1607->raw() : nullptr,_1607 ? _1607->size(0) : 0);
          _ptr__1607[(_1582 - (int)1)] = (int)1;
          int _9277 = (int)1;
          int _9278 = _1582;
          for (int _1608 = _9277; _1608 < _9278; ++_1608)
          {
            {
              _ptr__1607[((_1582 - _1608) - (int)1)] = safe_mul( _ptr__1607[(_1582 - _1608)],_ptr__1594[(_1582 - _1608)] );
            }
          }
          _1598 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((_1600)->size(0)))));
          _ptr__1598.update(_1598 ? _1598->raw() : nullptr, _1598 ? _1598->size(0) : 0);
          int _9279 = (int)0;
          int _9280 = (int)((_1601)->size(0));
          for (int _1609 = _9279; _1609 < _9280; ++_1609)
          {
            {
              int _1610 = (int)0;
              int _9281 = (int)0;
              int _9282 = _1582;
              for (int _1611 = _9281; _1611 < _9282; ++_1611)
              {
                {
                  _1610 += safe_mul( _ptr__1607[_1611],((*_1601)(_1609,_1611)) );
                }
              }
              _ptr__1598[_1610] = _ptr__1603[_1609];
            }
          }
        }
      }
      else if(_1602)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _1612 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_1582)));
          _checked_ptr_1<int> _ptr__1612(_1612 ? _1612->raw() : nullptr,_1612 ? _1612->size(0) : 0);
          _ptr__1612[(_1582 - (int)1)] = (int)1;
          int _9283 = (int)1;
          int _9284 = _1582;
          for (int _1613 = _9283; _1613 < _9284; ++_1613)
          {
            {
              _ptr__1612[((_1582 - _1613) - (int)1)] = safe_mul( _ptr__1612[(_1582 - _1613)],_ptr__1594[(_1582 - _1613)] );
            }
          }
          _1598 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((_1600)->size(0)))));
          _ptr__1598.update(_1598 ? _1598->raw() : nullptr, _1598 ? _1598->size(0) : 0);
        }
      }
      else
      {
        {
          std::vector<double> _9285;
          for (int _1614 = (int)0, _9286 = (int)((_1600)->size(0)); _1614 < _9286 ; ++_1614)
          {
            _9285.push_back(_ptr__1603[_1614]);
          }
          auto _9287 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9285.size()),_9285.begin(),_9285.end()));
          _1598 = _9287;
          _ptr__1598.update(_1598 ? _1598->raw() : nullptr, _1598 ? _1598->size(0) : 0);
        }
      }
    }
  }
  int _9288 = (int)0;
  int _9289 = _1596;
  for (int _1615 = _9288; _1615 < _9289; ++_1615)
  {
    {
      ((*natconmap_idx)(_ptr__1600[_1615])) = _1599;
      ((*natconmap_slackidx)(_ptr__1600[_1615])) = (int)0;
    }
  }
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1577)->key == ::mosek::fusion::RelationKey::IsFree))
  {
    {
      ((*natconmap_type)(_1599)) = (int)1;
      task_con_putboundlist_fr(_1600);
    }
  }
  {}
  if ((mosek::fusion::p_LinearDomain::_get_impl(_1577)->key == ::mosek::fusion::RelationKey::LessThan))
  {
    {
      ((*natconmap_type)(_1599)) = (int)3;
      task_con_putboundlist_up(_1600,_1598);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1577)->key == ::mosek::fusion::RelationKey::GreaterThan))
  {
    {
      ((*natconmap_type)(_1599)) = (int)2;
      task_con_putboundlist_lo(_1600,_1598);
    }
  }
  else if((mosek::fusion::p_LinearDomain::_get_impl(_1577)->key == ::mosek::fusion::RelationKey::EqualsTo))
  {
    {
      ((*natconmap_type)(_1599)) = (int)5;
      task_con_putboundlist_fx(_1600,_1598);
    }
  }
  {}
  if ((_1586 == (int)0))
  {
    {
      int _9290 = (int)0;
      int _9291 = _1583;
      for (int _1616 = _9290; _1616 < _9291; ++_1616)
      {
        {
          ((*natconmap_coderowptrb)(_ptr__1600[_1616])) = natconmap_codeatomtop;
          ((*natconmap_coderowptre)(_ptr__1600[_1616])) = natconmap_codeatomtop;
        }
      }
    }
  }
  else
  {
    {
      replace_row_code(rs,_1600,_1588,_1589,_1591,_1592,_1593);
    }
  }
  monty::rc_ptr< ::mosek::fusion::LinearConstraint > _1617 = ::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::Model::t(_pubthis),_1575,_1599,_1594,_1600);
  ((*cons)(_1599)) = (_1617).as<::mosek::fusion::ModelConstraint>();
  if (((int)((_1575).size()) > (int)0))
  {
    {
      con_map->setItem(_1575,_1599);
    }
  }
  {}
  return (_1617).as<::mosek::fusion::Constraint>();
}
std::string mosek::fusion::Model::getVersion  ( ) { return mosek::fusion::p_Model::getVersion(); }std::string mosek::fusion::p_Model::getVersion(){
  return ::mosek::fusion::p_BaseModel::env_getversion();
}
bool mosek::fusion::Model :: hasParameter(const std::string & _1618) { return mosek::fusion::p_Model::_get_impl(this)->hasParameter(_1618); }bool mosek::fusion::p_Model::hasParameter(const std::string & _1618){
  return par_map->hasItem(_1618);
}
bool mosek::fusion::Model :: hasConstraint(const std::string & _1619) { return mosek::fusion::p_Model::_get_impl(this)->hasConstraint(_1619); }bool mosek::fusion::p_Model::hasConstraint(const std::string & _1619){
  return con_map->hasItem(_1619);
}
bool mosek::fusion::Model :: hasVariable(const std::string & _1620) { return mosek::fusion::p_Model::_get_impl(this)->hasVariable(_1620); }bool mosek::fusion::p_Model::hasVariable(const std::string & _1620){
  return var_map->hasItem(_1620);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model :: __mosek_2fusion_2Model__getParameter(const std::string & _1621) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getParameter(_1621); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Model::getParameter(const std::string &  _1621) { return __mosek_2fusion_2Model__getParameter(_1621); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Model::__mosek_2fusion_2Model__getParameter(const std::string & _1621){
  return ((*parameters)(par_map->getItem(_1621)));
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(int _1622) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1622); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(int _1622) { return __mosek_2fusion_2Model__getConstraint(_1622); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(int _1622){
  return (((*cons)(_1622))).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model :: __mosek_2fusion_2Model__getConstraint(const std::string & _1623) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getConstraint(_1623); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Model::getConstraint(const std::string &  _1623) { return __mosek_2fusion_2Model__getConstraint(_1623); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Model::__mosek_2fusion_2Model__getConstraint(const std::string & _1623){
  monty::rc_ptr< ::mosek::fusion::ModelConstraint > _9292;
  bool _9293 = con_map->hasItem(_1623);
  if (_9293)
  {
    _9292 = ((*cons)(con_map->getItem(_1623)));
  }
  else
  {
    _9292 = nullptr;
  }
  return (_9292).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(int _1624) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1624); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(int _1624) { return __mosek_2fusion_2Model__getVariable(_1624); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(int _1624){
  return (((*vars)(_1624))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model :: __mosek_2fusion_2Model__getVariable(const std::string & _1625) { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__getVariable(_1625); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Model::getVariable(const std::string &  _1625) { return __mosek_2fusion_2Model__getVariable(_1625); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Model::__mosek_2fusion_2Model__getVariable(const std::string & _1625){
  if (var_map->hasItem(_1625))
  {
    {
      int _1626 = var_map->getItem(_1625);
      if ((_1626 < (int)0))
      {
        {
          return (((*barvars)((-safe_add( _1626,(int)1 ))))).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          return (((*vars)(_1626))).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
  else
  {
    {
      return nullptr;
    }
  }
}
std::string mosek::fusion::Model :: getName() { return mosek::fusion::p_Model::_get_impl(this)->getName(); }std::string mosek::fusion::p_Model::getName(){
  return model_name;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Model::getParameterValue(std::shared_ptr< monty::ndarray< int,1 > > _1627){
  _checked_ptr_1<int> _ptr__1627(_1627 ? _1627->raw() : nullptr, _1627 ? _1627->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1628 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((_1627)->size(0)))));
  _checked_ptr_1<double> _ptr__1628(_1628 ? _1628->raw() : nullptr,_1628 ? _1628->size(0) : 0);
  int _9294 = (int)0;
  int _9295 = (int)((_1627)->size(0));
  for (int _1629 = _9294; _1629 < _9295; ++_1629)
  {
    {
      _ptr__1628[_1629] = ((*param_value)(_ptr__1627[_1629]));
    }
  }
  return _1628;
}
void mosek::fusion::p_Model::setParameterValue(std::shared_ptr< monty::ndarray< int,1 > > _1630,std::shared_ptr< monty::ndarray< double,1 > > _1631){
  _checked_ptr_1<int> _ptr__1630(_1630 ? _1630->raw() : nullptr, _1630 ? _1630->size(0) : 0);
  _checked_ptr_1<double> _ptr__1631(_1631 ? _1631->raw() : nullptr, _1631 ? _1631->size(0) : 0);
  int _9296 = (int)0;
  int _9297 = (int)((_1630)->size(0));
  for (int _1632 = _9296; _1632 < _9297; ++_1632)
  {
    {
      ((*param_value)(_ptr__1630[_1632])) = _ptr__1631[_1632];
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model :: __mosek_2fusion_2Model__clone() { return mosek::fusion::p_Model::_get_impl(this)->__mosek_2fusion_2Model__clone(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Model::clone() { return __mosek_2fusion_2Model__clone(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Model::__mosek_2fusion_2Model__clone(){
  return ::mosek::fusion::p_Model::_new_Model(::mosek::fusion::Model::t(_pubthis));
}
void mosek::fusion::p_Model::destroy(){xs.reset();ws.reset();rs.reset();con_map.reset();cons.reset();natconmap_objcconst.reset();natconmap_objcode.reset();natconmap_objcodeptr.reset();natconmap_objcodenidx.reset();natconmap_cconst.reset();natconmap_code.reset();natconmap_codeptr.reset();natconmap_codenidx.reset();natconmap_coderowptre.reset();natconmap_coderowptrb.reset();param_value.reset();par_map.reset();parameters.reset();natconmap_type.reset();natconmap_idx.reset();natconmap_slackidx.reset();natconmap_blockid.reset();natconmap.reset();initsol_xx_flag.reset();initsol_xx.reset();var_map.reset();barvars.reset();natbarvarmap_ptr.reset();natbarvarmap_num.reset();natbarvar_dim.reset();natbarvar_ptr.reset();natbarvar_j.reset();natbarvar_i.reset();natbarvar_idx.reset();natvarmap_type.reset();natconemap_dim.reset();natconemap.reset();vars.reset();natvarmap_idx.reset();natvarmap_blockid.reset();natvarmap.reset();}void mosek::fusion::Model::destroy() { mosek::fusion::p_Model::_get_impl(this)->destroy(); }mosek::fusion::SliceVariable::SliceVariable(mosek::fusion::p_SliceVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "SliceVariable()" << this << std::endl; */ }mosek::fusion::SliceVariable::~SliceVariable() {  /* std::cout << "~SliceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceVariable::p_SliceVariable  (::mosek::fusion::SliceVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1633,    std::shared_ptr< monty::ndarray< int,1 > > _1634,    std::shared_ptr< monty::ndarray< long long,1 > > _1635,    std::shared_ptr< monty::ndarray< long long,1 > > _1636){ return new mosek::fusion::SliceVariable(_1633,_1634,_1635,_1636); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1633,    std::shared_ptr< monty::ndarray< int,1 > > _1634,    std::shared_ptr< monty::ndarray< long long,1 > > _1635,    std::shared_ptr< monty::ndarray< long long,1 > > _1636) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1633,_1634,_1635,_1636); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1633,    std::shared_ptr< monty::ndarray< int,1 > > _1634,    std::shared_ptr< monty::ndarray< long long,1 > > _1635,    std::shared_ptr< monty::ndarray< long long,1 > > _1636){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1634(_1634 ? _1634->raw() : nullptr, _1634 ? _1634->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1635(_1635 ? _1635->raw() : nullptr, _1635 ? _1635->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1636(_1636 ? _1636->raw() : nullptr, _1636 ? _1636->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1633,_1634,_1635,_1636);
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = _1636;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = _1635;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = _1634;
  }
}mosek::fusion::SliceVariable::t mosek::fusion::p_SliceVariable::_new_SliceVariable  (monty::rc_ptr< ::mosek::fusion::SliceVariable > _1637){ return new mosek::fusion::SliceVariable(_1637); }mosek::fusion::SliceVariable::SliceVariable  (monty::rc_ptr< ::mosek::fusion::SliceVariable > _1637) :    SliceVariable(new mosek::fusion::p_SliceVariable(this)){ mosek::fusion::p_SliceVariable::_get_impl(this)->_initialize(_1637); }void mosek::fusion::p_SliceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SliceVariable > _1637){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1637,_1637->__mosek_2fusion_2BaseVariable__getModel());
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_SliceVariable::_get_impl(_1637)->nativeidxs;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->sparsity = mosek::fusion::p_SliceVariable::_get_impl(_1637)->sparsity;
    mosek::fusion::p_SliceVariable::_get_impl(::mosek::fusion::SliceVariable::t(_pubthis))->shape = mosek::fusion::p_SliceVariable::_get_impl(_1637)->shape;
  }
}void mosek::fusion::p_SliceVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::SliceVariable::destroy() { mosek::fusion::p_SliceVariable::_get_impl(this)->destroy(); }mosek::fusion::SymRangedVariable::SymRangedVariable(mosek::fusion::p_SymRangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymRangedVariable()" << this << std::endl; */ }mosek::fusion::SymRangedVariable::~SymRangedVariable() {  /* std::cout << "~SymRangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymRangedVariable::p_SymRangedVariable  (::mosek::fusion::SymRangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1638,    monty::rc_ptr< ::mosek::fusion::Model > _1639){ return new mosek::fusion::SymRangedVariable(_1638,_1639); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1638,    monty::rc_ptr< ::mosek::fusion::Model > _1639) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1638,_1639); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1638,    monty::rc_ptr< ::mosek::fusion::Model > _1639){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1638,_1639);
    names_flushed = mosek::fusion::p_SymRangedVariable::_get_impl(_1638)->names_flushed;
    name = mosek::fusion::p_SymRangedVariable::_get_impl(_1638)->name;
    sparsity = mosek::fusion::p_SymRangedVariable::_get_impl(_1638)->sparsity;
    nativeidxs = mosek::fusion::p_SymRangedVariable::_get_impl(_1638)->nativeidxs;
    dim = mosek::fusion::p_SymRangedVariable::_get_impl(_1638)->dim;
  }
}mosek::fusion::SymRangedVariable::t mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1640,    const std::string &  _1641,    long long _1642,    int _1643,    std::shared_ptr< monty::ndarray< long long,1 > > _1644,    std::shared_ptr< monty::ndarray< int,1 > > _1645){ return new mosek::fusion::SymRangedVariable(_1640,_1641,_1642,_1643,_1644,_1645); }mosek::fusion::SymRangedVariable::SymRangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1640,    const std::string &  _1641,    long long _1642,    int _1643,    std::shared_ptr< monty::ndarray< long long,1 > > _1644,    std::shared_ptr< monty::ndarray< int,1 > > _1645) :    SymRangedVariable(new mosek::fusion::p_SymRangedVariable(this)){ mosek::fusion::p_SymRangedVariable::_get_impl(this)->_initialize(_1640,_1641,_1642,_1643,_1644,_1645); }void mosek::fusion::p_SymRangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1640,    const std::string &  _1641,    long long _1642,    int _1643,    std::shared_ptr< monty::ndarray< long long,1 > > _1644,    std::shared_ptr< monty::ndarray< int,1 > > _1645){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1644(_1644 ? _1644->raw() : nullptr, _1644 ? _1644->size(0) : 0);
    _checked_ptr_1<int> _ptr__1645(_1645 ? _1645->raw() : nullptr, _1645 ? _1645->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1640,_1641,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1643),(int)(_1643)}),_1642,::mosek::fusion::p_SymRangedVariable::mirror_sp(_1643,_1644),::mosek::fusion::p_SymRangedVariable::mirror_idxs(_1643,_1644,_1645));
    names_flushed = false;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->name = _1641;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->nativeidxs = _1645;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->sparsity = _1644;
    mosek::fusion::p_SymRangedVariable::_get_impl(::mosek::fusion::SymRangedVariable::t(_pubthis))->dim = _1643;
  }
}void mosek::fusion::p_SymRangedVariable::dual_u(int _1646,std::shared_ptr< monty::ndarray< double,1 > > _1647){
  _checked_ptr_1<double> _ptr__1647(_1647 ? _1647->raw() : nullptr, _1647 ? _1647->size(0) : 0);
  dual_lu(_1646,_1647,false);
}
void mosek::fusion::p_SymRangedVariable::dual_l(int _1648,std::shared_ptr< monty::ndarray< double,1 > > _1649){
  _checked_ptr_1<double> _ptr__1649(_1649 ? _1649->raw() : nullptr, _1649 ? _1649->size(0) : 0);
  dual_lu(_1648,_1649,true);
}
void mosek::fusion::p_SymRangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1650 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _9298 = (int)0;
          int _9299 = (int)((nativeidxs)->size(0));
          for (int _1651 = _9298; _1651 < _9299; ++_1651)
          {
            {
              std::string _9300;
              bool _9301 = ((int)((name).size()) == (int)0);
              if (_9301)
              {
                _9300 = std::string ("");
              }
              else
              {
                _9300 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1651 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1651 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1650.get())->varname(((*nativeidxs)(_1651)),_9300);
            }
          }
        }
      }
      else
      {
        {
          int _9302 = (int)0;
          int _9303 = (int)((sparsity)->size(0));
          for (int _1652 = _9302; _1652 < _9303; ++_1652)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1650.get())->varname(((*nativeidxs)(_1652)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1652)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1652)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymRangedVariable::__mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1653){
  return (::mosek::fusion::p_SymRangedVariable::_new_SymRangedVariable(::mosek::fusion::SymRangedVariable::t(_pubthis),_1653)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_idxs(int _1654,std::shared_ptr< monty::ndarray< long long,1 > > _1655,std::shared_ptr< monty::ndarray< int,1 > > _1656){
  _checked_ptr_1<long long> _ptr__1655(_1655 ? _1655->raw() : nullptr, _1655 ? _1655->size(0) : 0);
  _checked_ptr_1<int> _ptr__1656(_1656 ? _1656->raw() : nullptr, _1656 ? _1656->size(0) : 0);
  if ((NULL == _1655.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1657 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1654,_1654 ))));
      _checked_ptr_1<long long> _ptr__1657(_1657 ? _1657->raw() : nullptr,_1657 ? _1657->size(0) : 0);
      int _1658 = (int)0;
      {
        int _9304 = (int)0;
        int _9305 = _1654;
        for (int _1659 = _9304; _1659 < _9305; ++_1659)
        {
          {
            _ptr__1657[safe_add( safe_mul( _1659,_1654 ),_1659 )] = safe_add( _ptr__1656[_1658],(int)1 );
            ++ _1658;
            int _9306 = safe_add( _1659,(int)1 );
            int _9307 = _1654;
            for (int _1660 = _9306; _1660 < _9307; ++_1660)
            {
              {
                _ptr__1657[safe_add( safe_mul( _1659,_1654 ),_1660 )] = safe_add( _ptr__1656[_1658],(int)1 );
                _ptr__1657[safe_add( safe_mul( _1660,_1654 ),_1659 )] = safe_add( _ptr__1656[_1658],(int)1 );
                ++ _1658;
              }
            }
          }
        }
      }
      return _1657;
    }
  }
  else
  {
    {
      int _1661 = (int)0;
      {
        int _9308 = (int)0;
        int _9309 = (int)((_1655)->size(0));
        for (int _1662 = _9308; _1662 < _9309; ++_1662)
        {
          {
            int _9310;
            bool _9311 = ((_ptr__1655[_1662] % safe_add( _1654,(int)1 )) == (int)0);
            if (_9311)
            {
              _9310 = (int)1;
            }
            else
            {
              _9310 = (int)2;
            }
            _1661 += _9310;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1663 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1661)));
      _checked_ptr_1<long long> _ptr__1663(_1663 ? _1663->raw() : nullptr,_1663 ? _1663->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1664 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1661)));
      _checked_ptr_1<long long> _ptr__1664(_1664 ? _1664->raw() : nullptr,_1664 ? _1664->size(0) : 0);
      {
        int _1665 = (int)0;
        int _9312 = (int)0;
        int _9313 = (int)((_1655)->size(0));
        for (int _1666 = _9312; _1666 < _9313; ++_1666)
        {
          {
            long long _1667 = (_ptr__1655[_1666] / _1654);
            long long _1668 = (_ptr__1655[_1666] % _1654);
            _ptr__1663[_1665] = _ptr__1655[_1666];
            _ptr__1664[_1665] = safe_add( _ptr__1656[_1666],(int)1 );
            ++ _1665;
            if ((_1667 != _1668))
            {
              {
                _ptr__1663[_1665] = safe_add( safe_mul( _1668,_1654 ),_1667 );
                _ptr__1664[_1665] = safe_add( _ptr__1656[_1666],(int)1 );
                ++ _1665;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _9314;
      for (int _1670 = (int)0, _9315 = _1661; _1670 < _9315 ; ++_1670)
      {
        _9314.push_back(_1670);
      }
      auto _9316 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9314.size()),_9314.begin(),_9314.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1669 = _9316;
      _checked_ptr_1<long long> _ptr__1669(_1669 ? _1669->raw() : nullptr,_1669 ? _1669->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1669,_1663,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1661));
      std::vector<long long> _9317;
      for (int _1671 = (int)0, _9318 = _1661; _1671 < _9318 ; ++_1671)
      {
        _9317.push_back(_ptr__1664[_ptr__1669[_1671]]);
      }
      auto _9319 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9317.size()),_9317.begin(),_9317.end()));
      return _9319;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymRangedVariable::mirror_sp(int _1672,std::shared_ptr< monty::ndarray< long long,1 > > _1673){
  _checked_ptr_1<long long> _ptr__1673(_1673 ? _1673->raw() : nullptr, _1673 ? _1673->size(0) : 0);
  if ((NULL == _1673.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1674 = (int)0;
      {
        int _9320 = (int)0;
        int _9321 = (int)((_1673)->size(0));
        for (int _1675 = _9320; _1675 < _9321; ++_1675)
        {
          {
            int _9322;
            bool _9323 = ((_ptr__1673[_1675] % safe_add( _1672,(int)1 )) == (int)0);
            if (_9323)
            {
              _9322 = (int)1;
            }
            else
            {
              _9322 = (int)2;
            }
            _1674 += _9322;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1676 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1674)));
      _checked_ptr_1<long long> _ptr__1676(_1676 ? _1676->raw() : nullptr,_1676 ? _1676->size(0) : 0);
      {
        int _1677 = (int)0;
        int _9324 = (int)0;
        int _9325 = (int)((_1673)->size(0));
        for (int _1678 = _9324; _1678 < _9325; ++_1678)
        {
          {
            long long _1679 = (_ptr__1673[_1678] / _1672);
            long long _1680 = (_ptr__1673[_1678] % _1672);
            _ptr__1676[_1677] = _ptr__1673[_1678];
            ++ _1677;
            if ((_1679 != _1680))
            {
              {
                _ptr__1676[_1677] = safe_add( safe_mul( _1680,_1672 ),_1679 );
                ++ _1677;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _9326;
      for (int _1682 = (int)0, _9327 = _1674; _1682 < _9327 ; ++_1682)
      {
        _9326.push_back(_1682);
      }
      auto _9328 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9326.size()),_9326.begin(),_9326.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1681 = _9328;
      _checked_ptr_1<long long> _ptr__1681(_1681 ? _1681->raw() : nullptr,_1681 ? _1681->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1681,_1676,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1674));
      std::vector<long long> _9329;
      for (int _1683 = (int)0, _9330 = _1674; _1683 < _9330 ; ++_1683)
      {
        _9329.push_back(_ptr__1676[_ptr__1681[_1683]]);
      }
      auto _9331 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9329.size()),_9329.begin(),_9329.end()));
      return _9331;
    }
  }
}
void mosek::fusion::p_SymRangedVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymRangedVariable::destroy() { mosek::fusion::p_SymRangedVariable::_get_impl(this)->destroy(); }mosek::fusion::BoundInterfaceVariable::BoundInterfaceVariable(mosek::fusion::p_BoundInterfaceVariable *_impl) : mosek::fusion::SliceVariable(_impl) { /*std::cout << "BoundInterfaceVariable()" << this << std::endl; */ }mosek::fusion::BoundInterfaceVariable::~BoundInterfaceVariable() {  /* std::cout << "~BoundInterfaceVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_BoundInterfaceVariable::p_BoundInterfaceVariable  (::mosek::fusion::BoundInterfaceVariable * _pubthis) :     mosek::fusion::p_SliceVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::BoundInterfaceVariable::t mosek::fusion::p_BoundInterfaceVariable::_new_BoundInterfaceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1684,    std::shared_ptr< monty::ndarray< int,1 > > _1685,    std::shared_ptr< monty::ndarray< long long,1 > > _1686,    std::shared_ptr< monty::ndarray< long long,1 > > _1687,    bool _1688){ return new mosek::fusion::BoundInterfaceVariable(_1684,_1685,_1686,_1687,_1688); }mosek::fusion::BoundInterfaceVariable::BoundInterfaceVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1684,    std::shared_ptr< monty::ndarray< int,1 > > _1685,    std::shared_ptr< monty::ndarray< long long,1 > > _1686,    std::shared_ptr< monty::ndarray< long long,1 > > _1687,    bool _1688) :    BoundInterfaceVariable(new mosek::fusion::p_BoundInterfaceVariable(this)){ mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->_initialize(_1684,_1685,_1686,_1687,_1688); }void mosek::fusion::p_BoundInterfaceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1684,    std::shared_ptr< monty::ndarray< int,1 > > _1685,    std::shared_ptr< monty::ndarray< long long,1 > > _1686,    std::shared_ptr< monty::ndarray< long long,1 > > _1687,    bool _1688){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1685(_1685 ? _1685->raw() : nullptr, _1685 ? _1685->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1686(_1686 ? _1686->raw() : nullptr, _1686 ? _1686->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1687(_1687 ? _1687->raw() : nullptr, _1687 ? _1687->size(0) : 0);
    mosek::fusion::p_SliceVariable::_initialize(_1684,_1685,_1686,_1687);
    mosek::fusion::p_BoundInterfaceVariable::_get_impl(::mosek::fusion::BoundInterfaceVariable::t(_pubthis))->islower = _1688;
  }
}mosek::fusion::BoundInterfaceVariable::t mosek::fusion::p_BoundInterfaceVariable::_new_BoundInterfaceVariable  (monty::rc_ptr< ::mosek::fusion::SliceVariable > _1689,    bool _1690){ return new mosek::fusion::BoundInterfaceVariable(_1689,_1690); }mosek::fusion::BoundInterfaceVariable::BoundInterfaceVariable  (monty::rc_ptr< ::mosek::fusion::SliceVariable > _1689,    bool _1690) :    BoundInterfaceVariable(new mosek::fusion::p_BoundInterfaceVariable(this)){ mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->_initialize(_1689,_1690); }void mosek::fusion::p_BoundInterfaceVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SliceVariable > _1689,    bool _1690){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SliceVariable::_initialize(_1689);
    mosek::fusion::p_BoundInterfaceVariable::_get_impl(::mosek::fusion::BoundInterfaceVariable::t(_pubthis))->islower = _1690;
  }
}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BoundInterfaceVariable :: dual() { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BoundInterfaceVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _1691 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
  _checked_ptr_1<double> _ptr__1691(_1691 ? _1691->raw() : nullptr,_1691 ? _1691->size(0) : 0);
  dual_lu((int)0,_1691,islower);
  return _1691;
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__transpose() { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::transpose() { return __mosek_2fusion_2BoundInterfaceVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__transpose() { return __mosek_2fusion_2BoundInterfaceVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__transpose(){
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose())).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1692,std::shared_ptr< monty::ndarray< int,1 > > _1693,std::shared_ptr< monty::ndarray< int,1 > > _1694) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__pick(_1692,_1693,_1694); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1692,std::shared_ptr< monty::ndarray< int,1 > > _1693,std::shared_ptr< monty::ndarray< int,1 > > _1694) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1692,_1693,_1694); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1692,std::shared_ptr< monty::ndarray< int,1 > > _1693,std::shared_ptr< monty::ndarray< int,1 > > _1694) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1692,_1693,_1694); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1692,std::shared_ptr< monty::ndarray< int,1 > > _1693,std::shared_ptr< monty::ndarray< int,1 > > _1694){
  _checked_ptr_1<int> _ptr__1692(_1692 ? _1692->raw() : nullptr, _1692 ? _1692->size(0) : 0);
  _checked_ptr_1<int> _ptr__1693(_1693 ? _1693->raw() : nullptr, _1693 ? _1693->size(0) : 0);
  _checked_ptr_1<int> _ptr__1694(_1694 ? _1694->raw() : nullptr, _1694 ? _1694->size(0) : 0);
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(_1692,_1693,_1694))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1695,std::shared_ptr< monty::ndarray< int,1 > > _1696) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__pick(_1695,_1696); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1695,std::shared_ptr< monty::ndarray< int,1 > > _1696) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1695,_1696); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1695,std::shared_ptr< monty::ndarray< int,1 > > _1696) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1695,_1696); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1695,std::shared_ptr< monty::ndarray< int,1 > > _1696){
  _checked_ptr_1<int> _ptr__1695(_1695 ? _1695->raw() : nullptr, _1695 ? _1695->size(0) : 0);
  _checked_ptr_1<int> _ptr__1696(_1696 ? _1696->raw() : nullptr, _1696 ? _1696->size(0) : 0);
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(_1695,_1696))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1697) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__pick(_1697); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _1697) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1697); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1697) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1697); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1697){
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(_1697))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__pick(_1698); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1698); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1698); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698){
  _checked_ptr_1<int> _ptr__1698(_1698 ? _1698->raw() : nullptr, _1698 ? _1698->size(0) : 0);
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(_1698))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__antidiag(int _1699) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__antidiag(_1699); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::antidiag(int _1699) { return __mosek_2fusion_2BoundInterfaceVariable__antidiag(_1699); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__antidiag(int _1699) { return __mosek_2fusion_2BoundInterfaceVariable__antidiag(_1699); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__antidiag(int _1699){
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(_1699))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__antidiag() { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::antidiag() { return __mosek_2fusion_2BoundInterfaceVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__antidiag() { return __mosek_2fusion_2BoundInterfaceVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__antidiag(){
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag())).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__diag(int _1700) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__diag(_1700); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::diag(int _1700) { return __mosek_2fusion_2BoundInterfaceVariable__diag(_1700); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__diag(int _1700) { return __mosek_2fusion_2BoundInterfaceVariable__diag(_1700); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__diag(int _1700){
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(_1700))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__diag() { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::diag() { return __mosek_2fusion_2BoundInterfaceVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__diag() { return __mosek_2fusion_2BoundInterfaceVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__diag(){
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag())).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1701,std::shared_ptr< monty::ndarray< int,1 > > _1702) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__slice(_1701,_1702); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1701,std::shared_ptr< monty::ndarray< int,1 > > _1702) { return __mosek_2fusion_2BoundInterfaceVariable__slice(_1701,_1702); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1701,std::shared_ptr< monty::ndarray< int,1 > > _1702) { return __mosek_2fusion_2BoundInterfaceVariable__slice(_1701,_1702); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1701,std::shared_ptr< monty::ndarray< int,1 > > _1702){
  _checked_ptr_1<int> _ptr__1701(_1701 ? _1701->raw() : nullptr, _1701 ? _1701->size(0) : 0);
  _checked_ptr_1<int> _ptr__1702(_1702 ? _1702->raw() : nullptr, _1702 ? _1702->size(0) : 0);
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(_1701,_1702))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable :: __mosek_2fusion_2BoundInterfaceVariable__slice(int _1703,int _1704) { return mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->__mosek_2fusion_2BoundInterfaceVariable__slice(_1703,_1704); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::slice(int _1703,int _1704) { return __mosek_2fusion_2BoundInterfaceVariable__slice(_1703,_1704); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BoundInterfaceVariable::__mosek_2fusion_2BaseVariable__slice(int _1703,int _1704) { return __mosek_2fusion_2BoundInterfaceVariable__slice(_1703,_1704); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__slice(int _1703,int _1704){
  return (__mosek_2fusion_2BoundInterfaceVariable__from_(::mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(_1703,_1704))).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > mosek::fusion::p_BoundInterfaceVariable::__mosek_2fusion_2BoundInterfaceVariable__from_(monty::rc_ptr< ::mosek::fusion::Variable > _1705){
  std::shared_ptr< monty::ndarray< int,1 > > _1706 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__1706(_1706 ? _1706->raw() : nullptr,_1706 ? _1706->size(0) : 0);
  int _1707 = _1705->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _1708 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1707)));
  _checked_ptr_1<long long> _ptr__1708(_1708 ? _1708->raw() : nullptr,_1708 ? _1708->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1709 = nullptr;
  _checked_ptr_1<long long> _ptr__1709(_1709 ? _1709->raw() : nullptr,_1709 ? _1709->size(0) : 0);
  if ((_1705->getSize() == _1707))
  {
    {
      _1705->inst((int)0,_1708);
    }
  }
  else
  {
    {
      _1709 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1707)));
      _ptr__1709.update(_1709 ? _1709->raw() : nullptr, _1709 ? _1709->size(0) : 0);
      _1705->inst((int)0,_1709,(int)0,_1708);
    }
  }
  return ::mosek::fusion::p_BoundInterfaceVariable::_new_BoundInterfaceVariable(_1705->__mosek_2fusion_2Variable__getModel(),_1706,_1709,_1708,islower);
}
void mosek::fusion::p_BoundInterfaceVariable::destroy(){}void mosek::fusion::BoundInterfaceVariable::destroy() { mosek::fusion::p_BoundInterfaceVariable::_get_impl(this)->destroy(); }mosek::fusion::RangedVariable::RangedVariable(mosek::fusion::p_RangedVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "RangedVariable()" << this << std::endl; */ }mosek::fusion::RangedVariable::~RangedVariable() {  /* std::cout << "~RangedVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedVariable::p_RangedVariable  (::mosek::fusion::RangedVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1710,    monty::rc_ptr< ::mosek::fusion::Model > _1711){ return new mosek::fusion::RangedVariable(_1710,_1711); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1710,    monty::rc_ptr< ::mosek::fusion::Model > _1711) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1710,_1711); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedVariable > _1710,    monty::rc_ptr< ::mosek::fusion::Model > _1711){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1710,_1711);
    name = mosek::fusion::p_RangedVariable::_get_impl(_1710)->name;
    nativeidxs = mosek::fusion::p_RangedVariable::_get_impl(_1710)->nativeidxs;
    sparsity = mosek::fusion::p_RangedVariable::_get_impl(_1710)->sparsity;
    names_flushed = mosek::fusion::p_RangedVariable::_get_impl(_1710)->names_flushed;
    shape = mosek::fusion::p_RangedVariable::_get_impl(_1710)->shape;
  }
}mosek::fusion::RangedVariable::t mosek::fusion::p_RangedVariable::_new_RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1712,    const std::string &  _1713,    long long _1714,    std::shared_ptr< monty::ndarray< int,1 > > _1715,    std::shared_ptr< monty::ndarray< long long,1 > > _1716,    std::shared_ptr< monty::ndarray< int,1 > > _1717){ return new mosek::fusion::RangedVariable(_1712,_1713,_1714,_1715,_1716,_1717); }mosek::fusion::RangedVariable::RangedVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1712,    const std::string &  _1713,    long long _1714,    std::shared_ptr< monty::ndarray< int,1 > > _1715,    std::shared_ptr< monty::ndarray< long long,1 > > _1716,    std::shared_ptr< monty::ndarray< int,1 > > _1717) :    RangedVariable(new mosek::fusion::p_RangedVariable(this)){ mosek::fusion::p_RangedVariable::_get_impl(this)->_initialize(_1712,_1713,_1714,_1715,_1716,_1717); }void mosek::fusion::p_RangedVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1712,    const std::string &  _1713,    long long _1714,    std::shared_ptr< monty::ndarray< int,1 > > _1715,    std::shared_ptr< monty::ndarray< long long,1 > > _1716,    std::shared_ptr< monty::ndarray< int,1 > > _1717){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1715(_1715 ? _1715->raw() : nullptr, _1715 ? _1715->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1716(_1716 ? _1716->raw() : nullptr, _1716 ? _1716->size(0) : 0);
    _checked_ptr_1<int> _ptr__1717(_1717 ? _1717->raw() : nullptr, _1717 ? _1717->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1712,_1713,_1715,_1714,_1716,::mosek::fusion::p_RangedVariable::globalNativeIndexes(_1717));
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->nativeidxs = _1717;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->sparsity = _1716;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->name = _1713;
    mosek::fusion::p_RangedVariable::_get_impl(::mosek::fusion::RangedVariable::t(_pubthis))->shape = _1715;
    names_flushed = false;
  }
}monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__elementDesc(long long _1718,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1719) { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__elementDesc(_1718,_1719); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::RangedVariable::elementDesc(long long _1718,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1719) { return __mosek_2fusion_2RangedVariable__elementDesc(_1718,_1719); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__elementDesc(long long _1718,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1719){
  _pubthis->elementName(_1718,_1719);
  _1719->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : in range"));
  return _1719;
}
void mosek::fusion::p_RangedVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1720 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1721 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1721->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1721->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _9332 = (int)1;
          int _9333 = _pubthis->getND();
          for (int _1722 = _9332; _1722 < _9333; ++_1722)
          {
            {
              _1721->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1722);
            }
          }
        }
      }
      {}
      _1721->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      mosek::fusion::p_Model::_get_impl(_1720.get())->varnames(nativeidxs,_1721->toString(),_pubthis->getShape(),sparsity);
      names_flushed = true;
    }
  }
  {}
}
void mosek::fusion::p_RangedVariable::dual_u(int _1723,std::shared_ptr< monty::ndarray< double,1 > > _1724){
  _checked_ptr_1<double> _ptr__1724(_1724 ? _1724->raw() : nullptr, _1724 ? _1724->size(0) : 0);
  dual_lu(_1723,_1724,false);
}
void mosek::fusion::p_RangedVariable::dual_l(int _1725,std::shared_ptr< monty::ndarray< double,1 > > _1726){
  _checked_ptr_1<double> _ptr__1726(_1726 ? _1726->raw() : nullptr, _1726 ? _1726->size(0) : 0);
  dual_lu(_1725,_1726,true);
}
monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__upperBoundVar() { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__upperBoundVar(); }monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > mosek::fusion::RangedVariable::upperBoundVar() { return __mosek_2fusion_2RangedVariable__upperBoundVar(); }
monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__upperBoundVar(){
  std::vector<long long> _9334;
  for (int _1727 = (int)0, _9335 = (int)((nativeidxs)->size(0)); _1727 < _9335 ; ++_1727)
  {
    _9334.push_back(((*nativeidxs)(_1727)));
  }
  auto _9336 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9334.size()),_9334.begin(),_9334.end()));
  return ::mosek::fusion::p_BoundInterfaceVariable::_new_BoundInterfaceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),shape,sparsity,_9336,false);
}
monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > mosek::fusion::RangedVariable :: __mosek_2fusion_2RangedVariable__lowerBoundVar() { return mosek::fusion::p_RangedVariable::_get_impl(this)->__mosek_2fusion_2RangedVariable__lowerBoundVar(); }monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > mosek::fusion::RangedVariable::lowerBoundVar() { return __mosek_2fusion_2RangedVariable__lowerBoundVar(); }
monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__lowerBoundVar(){
  std::vector<long long> _9337;
  for (int _1728 = (int)0, _9338 = (int)((nativeidxs)->size(0)); _1728 < _9338 ; ++_1728)
  {
    _9337.push_back(((*nativeidxs)(_1728)));
  }
  auto _9339 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9337.size()),_9337.begin(),_9337.end()));
  return ::mosek::fusion::p_BoundInterfaceVariable::_new_BoundInterfaceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),shape,sparsity,_9339,true);
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_RangedVariable::__mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1729){
  return (::mosek::fusion::p_RangedVariable::_new_RangedVariable(::mosek::fusion::RangedVariable::t(_pubthis),_1729)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_RangedVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1730){
  _checked_ptr_1<int> _ptr__1730(_1730 ? _1730->raw() : nullptr, _1730 ? _1730->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1731 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1730)->size(0)))));
  _checked_ptr_1<long long> _ptr__1731(_1731 ? _1731->raw() : nullptr,_1731 ? _1731->size(0) : 0);
  int _9340 = (int)0;
  int _9341 = (int)((_1730)->size(0));
  for (int _1732 = _9340; _1732 < _9341; ++_1732)
  {
    {
      _ptr__1731[_1732] = _ptr__1730[_1732];
    }
  }
  return _1731;
}
void mosek::fusion::p_RangedVariable::destroy(){shape.reset();nativeidxs.reset();sparsity.reset();}void mosek::fusion::RangedVariable::destroy() { mosek::fusion::p_RangedVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDVariable::LinearPSDVariable(mosek::fusion::p_LinearPSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearPSDVariable()" << this << std::endl; */ }mosek::fusion::LinearPSDVariable::~LinearPSDVariable() {  /* std::cout << "~LinearPSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDVariable::p_LinearPSDVariable  (::mosek::fusion::LinearPSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1733,    monty::rc_ptr< ::mosek::fusion::Model > _1734){ return new mosek::fusion::LinearPSDVariable(_1733,_1734); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1733,    monty::rc_ptr< ::mosek::fusion::Model > _1734) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1733,_1734); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1733,    monty::rc_ptr< ::mosek::fusion::Model > _1734){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1733,_1734);
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = mosek::fusion::p_LinearPSDVariable::_get_impl(_1733)->conedim;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = mosek::fusion::p_LinearPSDVariable::_get_impl(_1733)->varid;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = mosek::fusion::p_LinearPSDVariable::_get_impl(_1733)->name;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = mosek::fusion::p_LinearPSDVariable::_get_impl(_1733)->shape;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = mosek::fusion::p_LinearPSDVariable::_get_impl(_1733)->nativeidxs;
  }
}mosek::fusion::LinearPSDVariable::t mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1735,    const std::string &  _1736,    int _1737,    std::shared_ptr< monty::ndarray< int,1 > > _1738,    int _1739,    std::shared_ptr< monty::ndarray< long long,1 > > _1740){ return new mosek::fusion::LinearPSDVariable(_1735,_1736,_1737,_1738,_1739,_1740); }mosek::fusion::LinearPSDVariable::LinearPSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1735,    const std::string &  _1736,    int _1737,    std::shared_ptr< monty::ndarray< int,1 > > _1738,    int _1739,    std::shared_ptr< monty::ndarray< long long,1 > > _1740) :    LinearPSDVariable(new mosek::fusion::p_LinearPSDVariable(this)){ mosek::fusion::p_LinearPSDVariable::_get_impl(this)->_initialize(_1735,_1736,_1737,_1738,_1739,_1740); }void mosek::fusion::p_LinearPSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1735,    const std::string &  _1736,    int _1737,    std::shared_ptr< monty::ndarray< int,1 > > _1738,    int _1739,    std::shared_ptr< monty::ndarray< long long,1 > > _1740){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1738(_1738 ? _1738->raw() : nullptr, _1738 ? _1738->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1740(_1740 ? _1740->raw() : nullptr, _1740 ? _1740->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1735,_1736,_1738,_1737,nullptr,::mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(_1740));
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->name = _1736;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->conedim = _1739;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->varid = _1737;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->shape = _1738;
    mosek::fusion::p_LinearPSDVariable::_get_impl(::mosek::fusion::LinearPSDVariable::t(_pubthis))->nativeidxs = _1740;
  }
}void mosek::fusion::p_LinearPSDVariable::flushNames(){
}
std::string mosek::fusion::LinearPSDVariable :: toString() { return mosek::fusion::p_LinearPSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearPSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1741 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1741->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1741->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1741->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _9342 = (int)1;
  int _9343 = (int)((shape)->size(0));
  for (int _1742 = _9342; _1742 < _9343; ++_1742)
  {
    {
      _1741->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1742)));
    }
  }
  _1741->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1741->toString();
}
void mosek::fusion::LinearPSDVariable :: make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1743) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_continuous(_1743); }void mosek::fusion::p_LinearPSDVariable::make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1743){
  _checked_ptr_1<long long> _ptr__1743(_1743 ? _1743->raw() : nullptr, _1743 ? _1743->size(0) : 0);
}
void mosek::fusion::LinearPSDVariable :: make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1744) { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->make_integer(_1744); }void mosek::fusion::p_LinearPSDVariable::make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1744){
  _checked_ptr_1<long long> _ptr__1744(_1744 ? _1744->raw() : nullptr, _1744 ? _1744->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Cannot make PSDVariable elements integer"));
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearPSDVariable::__mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1745){
  return (::mosek::fusion::p_LinearPSDVariable::_new_LinearPSDVariable(::mosek::fusion::LinearPSDVariable::t(_pubthis),_1745)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearPSDVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1746){
  _checked_ptr_1<long long> _ptr__1746(_1746 ? _1746->raw() : nullptr, _1746 ? _1746->size(0) : 0);
  std::vector<long long> _9344;
  for (int _1747 = (int)0, _9345 = (int)((_1746)->size(0)); _1747 < _9345 ; ++_1747)
  {
    _9344.push_back((-safe_add( _ptr__1746[_1747],(int)1 )));
  }
  auto _9346 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9344.size()),_9344.begin(),_9344.end()));
  return _9346;
}
void mosek::fusion::p_LinearPSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDVariable::destroy() { mosek::fusion::p_LinearPSDVariable::_get_impl(this)->destroy(); }mosek::fusion::PSDVariable::PSDVariable(mosek::fusion::p_PSDVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "PSDVariable()" << this << std::endl; */ }mosek::fusion::PSDVariable::~PSDVariable() {  /* std::cout << "~PSDVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDVariable::p_PSDVariable  (::mosek::fusion::PSDVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1748,    monty::rc_ptr< ::mosek::fusion::Model > _1749){ return new mosek::fusion::PSDVariable(_1748,_1749); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1748,    monty::rc_ptr< ::mosek::fusion::Model > _1749) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1748,_1749); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDVariable > _1748,    monty::rc_ptr< ::mosek::fusion::Model > _1749){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1748,_1749);
    varid = mosek::fusion::p_PSDVariable::_get_impl(_1748)->varid;
    nativeidxs = mosek::fusion::p_PSDVariable::_get_impl(_1748)->nativeidxs;
    name = mosek::fusion::p_PSDVariable::_get_impl(_1748)->name;
    shape = mosek::fusion::p_PSDVariable::_get_impl(_1748)->shape;
    conedim1 = mosek::fusion::p_PSDVariable::_get_impl(_1748)->conedim1;
    conedim2 = mosek::fusion::p_PSDVariable::_get_impl(_1748)->conedim2;
  }
}mosek::fusion::PSDVariable::t mosek::fusion::p_PSDVariable::_new_PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1750,    const std::string &  _1751,    int _1752,    std::shared_ptr< monty::ndarray< int,1 > > _1753,    int _1754,    int _1755,    std::shared_ptr< monty::ndarray< long long,1 > > _1756){ return new mosek::fusion::PSDVariable(_1750,_1751,_1752,_1753,_1754,_1755,_1756); }mosek::fusion::PSDVariable::PSDVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1750,    const std::string &  _1751,    int _1752,    std::shared_ptr< monty::ndarray< int,1 > > _1753,    int _1754,    int _1755,    std::shared_ptr< monty::ndarray< long long,1 > > _1756) :    PSDVariable(new mosek::fusion::p_PSDVariable(this)){ mosek::fusion::p_PSDVariable::_get_impl(this)->_initialize(_1750,_1751,_1752,_1753,_1754,_1755,_1756); }void mosek::fusion::p_PSDVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1750,    const std::string &  _1751,    int _1752,    std::shared_ptr< monty::ndarray< int,1 > > _1753,    int _1754,    int _1755,    std::shared_ptr< monty::ndarray< long long,1 > > _1756){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1753(_1753 ? _1753->raw() : nullptr, _1753 ? _1753->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1756(_1756 ? _1756->raw() : nullptr, _1756 ? _1756->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1750,_1751,_1753,_1752,nullptr,::mosek::fusion::p_PSDVariable::fullnativeidxs(_1753,_1754,_1755,_1756));
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->varid = _1752;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->nativeidxs = _1756;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->name = _1751;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->shape = _1753;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim1 = _1754;
    mosek::fusion::p_PSDVariable::_get_impl(::mosek::fusion::PSDVariable::t(_pubthis))->conedim2 = _1755;
  }
}void mosek::fusion::p_PSDVariable::flushNames(){
}
std::string mosek::fusion::PSDVariable :: toString() { return mosek::fusion::p_PSDVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1757 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1757->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("PSDVariable("));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1757->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1757->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _9347 = (int)1;
  int _9348 = (int)((shape)->size(0));
  for (int _1758 = _9347; _1758 < _9348; ++_1758)
  {
    {
      _1757->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1758)));
    }
  }
  _1757->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1757->toString();
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable :: __mosek_2fusion_2PSDVariable__elementDesc(long long _1759,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1760) { return mosek::fusion::p_PSDVariable::_get_impl(this)->__mosek_2fusion_2PSDVariable__elementDesc(_1759,_1760); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::PSDVariable::elementDesc(long long _1759,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1760) { return __mosek_2fusion_2PSDVariable__elementDesc(_1759,_1760); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__elementDesc(long long _1759,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1760){
  _pubthis->elementName(_1759,_1760);
  _1760->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element in positive semidefinite cone"));
  return _1760;
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_PSDVariable::__mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1761){
  return (::mosek::fusion::p_PSDVariable::_new_PSDVariable(::mosek::fusion::PSDVariable::t(_pubthis),_1761)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_PSDVariable::fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1762,int _1763,int _1764,std::shared_ptr< monty::ndarray< long long,1 > > _1765){
  _checked_ptr_1<int> _ptr__1762(_1762 ? _1762->raw() : nullptr, _1762 ? _1762->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1765(_1765 ? _1765->raw() : nullptr, _1765 ? _1765->size(0) : 0);
  int _1766 = (int)((_1762)->size(0));
  bool _1767 = (_1763 < _1764);
  int _9349;
  bool _9350 = _1767;
  if (_9350)
  {
    _9349 = _1763;
  }
  else
  {
    _9349 = _1764;
  }
  int _1768 = _9349;
  int _9351;
  bool _9352 = (!_1767);
  if (_9352)
  {
    _9351 = _1763;
  }
  else
  {
    _9351 = _1764;
  }
  int _1769 = _9351;
  int _1770 = (int)1;
  int _9353 = (int)0;
  int _9354 = _1768;
  for (int _1771 = _9353; _1771 < _9354; ++_1771)
  {
    {
      _1770 *= _ptr__1762[_1771];
    }
  }
  int _1772 = _ptr__1762[_1768];
  int _1773 = (int)1;
  int _9355 = safe_add( _1768,(int)1 );
  int _9356 = _1769;
  for (int _1774 = _9355; _1774 < _9356; ++_1774)
  {
    {
      _1773 *= _ptr__1762[_1774];
    }
  }
  int _1775 = _ptr__1762[_1769];
  int _1776 = (int)1;
  int _9357 = safe_add( _1769,(int)1 );
  int _9358 = _1766;
  for (int _1777 = _9357; _1777 < _9358; ++_1777)
  {
    {
      _1776 *= _ptr__1762[_1777];
    }
  }
  int _1778 = safe_mul( safe_mul( safe_mul( safe_mul( _1770,_1772 ),_1773 ),_1775 ),_1776 );
  std::shared_ptr< monty::ndarray< long long,1 > > _1779 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1778)));
  _checked_ptr_1<long long> _ptr__1779(_1779 ? _1779->raw() : nullptr,_1779 ? _1779->size(0) : 0);
  int _1780 = _1776;
  int _1781 = safe_mul( _1780,_1775 );
  int _1782 = safe_mul( _1781,_1773 );
  int _1783 = safe_mul( _1782,_1782 );
  {
    int _1784 = (int)0;
    int _9359 = (int)0;
    int _9360 = _1770;
    for (int _1785 = _9359; _1785 < _9360; ++_1785)
    {
      {
        int _9361 = (int)0;
        int _9362 = _1775;
        for (int _1786 = _9361; _1786 < _9362; ++_1786)
        {
          {
            int _9363 = (int)0;
            int _9364 = _1773;
            for (int _1787 = _9363; _1787 < _9364; ++_1787)
            {
              {
                int _9365 = _1786;
                int _9366 = _1772;
                for (int _1788 = _9365; _1788 < _9366; ++_1788)
                {
                  {
                    int _9367 = (int)0;
                    int _9368 = _1776;
                    for (int _1789 = _9367; _1789 < _9368; ++_1789)
                    {
                      {
                        _ptr__1779[safe_add( safe_add( safe_add( safe_add( safe_mul( _1785,_1783 ),safe_mul( _1788,_1782 ) ),safe_mul( _1787,_1781 ) ),safe_mul( _1786,_1780 ) ),_1789 )] = (-safe_add( _ptr__1765[_1784],(int)1 ));
                        _ptr__1779[safe_add( safe_add( safe_add( safe_add( safe_mul( _1785,_1783 ),safe_mul( _1786,_1782 ) ),safe_mul( _1787,_1781 ) ),safe_mul( _1788,_1780 ) ),_1789 )] = (-safe_add( _ptr__1765[_1784],(int)1 ));
                        ++ _1784;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _1779;
}
void mosek::fusion::p_PSDVariable::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::PSDVariable::destroy() { mosek::fusion::p_PSDVariable::_get_impl(this)->destroy(); }mosek::fusion::SymLinearVariable::SymLinearVariable(mosek::fusion::p_SymLinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "SymLinearVariable()" << this << std::endl; */ }mosek::fusion::SymLinearVariable::~SymLinearVariable() {  /* std::cout << "~SymLinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymLinearVariable::p_SymLinearVariable  (::mosek::fusion::SymLinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1790,    monty::rc_ptr< ::mosek::fusion::Model > _1791){ return new mosek::fusion::SymLinearVariable(_1790,_1791); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1790,    monty::rc_ptr< ::mosek::fusion::Model > _1791) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1790,_1791); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1790,    monty::rc_ptr< ::mosek::fusion::Model > _1791){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1790,_1791);
    names_flushed = mosek::fusion::p_SymLinearVariable::_get_impl(_1790)->names_flushed;
    name = mosek::fusion::p_SymLinearVariable::_get_impl(_1790)->name;
    sparsity = mosek::fusion::p_SymLinearVariable::_get_impl(_1790)->sparsity;
    nativeidxs = mosek::fusion::p_SymLinearVariable::_get_impl(_1790)->nativeidxs;
    dim = mosek::fusion::p_SymLinearVariable::_get_impl(_1790)->dim;
  }
}mosek::fusion::SymLinearVariable::t mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1792,    const std::string &  _1793,    long long _1794,    int _1795,    std::shared_ptr< monty::ndarray< long long,1 > > _1796,    std::shared_ptr< monty::ndarray< int,1 > > _1797){ return new mosek::fusion::SymLinearVariable(_1792,_1793,_1794,_1795,_1796,_1797); }mosek::fusion::SymLinearVariable::SymLinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1792,    const std::string &  _1793,    long long _1794,    int _1795,    std::shared_ptr< monty::ndarray< long long,1 > > _1796,    std::shared_ptr< monty::ndarray< int,1 > > _1797) :    SymLinearVariable(new mosek::fusion::p_SymLinearVariable(this)){ mosek::fusion::p_SymLinearVariable::_get_impl(this)->_initialize(_1792,_1793,_1794,_1795,_1796,_1797); }void mosek::fusion::p_SymLinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1792,    const std::string &  _1793,    long long _1794,    int _1795,    std::shared_ptr< monty::ndarray< long long,1 > > _1796,    std::shared_ptr< monty::ndarray< int,1 > > _1797){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__1796(_1796 ? _1796->raw() : nullptr, _1796 ? _1796->size(0) : 0);
    _checked_ptr_1<int> _ptr__1797(_1797 ? _1797->raw() : nullptr, _1797 ? _1797->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1792,_1793,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_1795),(int)(_1795)}),_1794,::mosek::fusion::p_SymLinearVariable::mirror_sp(_1795,_1796),::mosek::fusion::p_SymLinearVariable::mirror_idxs(_1795,_1796,_1797));
    names_flushed = false;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->name = _1793;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->nativeidxs = _1797;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->sparsity = _1796;
    mosek::fusion::p_SymLinearVariable::_get_impl(::mosek::fusion::SymLinearVariable::t(_pubthis))->dim = _1795;
  }
}void mosek::fusion::p_SymLinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1798 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if ((NULL == sparsity.get()))
      {
        {
          int _9369 = (int)0;
          int _9370 = (int)((nativeidxs)->size(0));
          for (int _1799 = _9369; _1799 < _9370; ++_1799)
          {
            {
              std::string _9371;
              bool _9372 = ((int)((name).size()) == (int)0);
              if (_9372)
              {
                _9371 = std::string ("");
              }
              else
              {
                _9371 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((_1799 / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((_1799 % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString();
              }
              mosek::fusion::p_Model::_get_impl(_1798.get())->varname(((*nativeidxs)(_1799)),_9371);
            }
          }
        }
      }
      else
      {
        {
          int _9373 = (int)0;
          int _9374 = (int)((sparsity)->size(0));
          for (int _1800 = _9373; _1800 < _9374; ++_1800)
          {
            {
              mosek::fusion::p_Model::_get_impl(_1798.get())->varname(((*nativeidxs)(_1800)),::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1800)) / dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a((((*sparsity)(_1800)) % dim))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_SymLinearVariable::__mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1801){
  return (::mosek::fusion::p_SymLinearVariable::_new_SymLinearVariable(::mosek::fusion::SymLinearVariable::t(_pubthis),_1801)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_idxs(int _1802,std::shared_ptr< monty::ndarray< long long,1 > > _1803,std::shared_ptr< monty::ndarray< int,1 > > _1804){
  _checked_ptr_1<long long> _ptr__1803(_1803 ? _1803->raw() : nullptr, _1803 ? _1803->size(0) : 0);
  _checked_ptr_1<int> _ptr__1804(_1804 ? _1804->raw() : nullptr, _1804 ? _1804->size(0) : 0);
  if ((NULL == _1803.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1805 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _1802,_1802 ))));
      _checked_ptr_1<long long> _ptr__1805(_1805 ? _1805->raw() : nullptr,_1805 ? _1805->size(0) : 0);
      int _1806 = (int)0;
      {
        int _9375 = (int)0;
        int _9376 = _1802;
        for (int _1807 = _9375; _1807 < _9376; ++_1807)
        {
          {
            _ptr__1805[safe_add( safe_mul( _1807,_1802 ),_1807 )] = safe_add( _ptr__1804[_1806],(int)1 );
            ++ _1806;
            int _9377 = safe_add( _1807,(int)1 );
            int _9378 = _1802;
            for (int _1808 = _9377; _1808 < _9378; ++_1808)
            {
              {
                _ptr__1805[safe_add( safe_mul( _1807,_1802 ),_1808 )] = safe_add( _ptr__1804[_1806],(int)1 );
                _ptr__1805[safe_add( safe_mul( _1808,_1802 ),_1807 )] = safe_add( _ptr__1804[_1806],(int)1 );
                ++ _1806;
              }
            }
          }
        }
      }
      return _1805;
    }
  }
  else
  {
    {
      int _1809 = (int)0;
      {
        int _9379 = (int)0;
        int _9380 = (int)((_1803)->size(0));
        for (int _1810 = _9379; _1810 < _9380; ++_1810)
        {
          {
            int _9381;
            bool _9382 = ((_ptr__1803[_1810] % safe_add( _1802,(int)1 )) == (int)0);
            if (_9382)
            {
              _9381 = (int)1;
            }
            else
            {
              _9381 = (int)2;
            }
            _1809 += _9381;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1811 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1809)));
      _checked_ptr_1<long long> _ptr__1811(_1811 ? _1811->raw() : nullptr,_1811 ? _1811->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1812 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1809)));
      _checked_ptr_1<long long> _ptr__1812(_1812 ? _1812->raw() : nullptr,_1812 ? _1812->size(0) : 0);
      {
        int _1813 = (int)0;
        int _9383 = (int)0;
        int _9384 = (int)((_1803)->size(0));
        for (int _1814 = _9383; _1814 < _9384; ++_1814)
        {
          {
            long long _1815 = (_ptr__1803[_1814] / _1802);
            long long _1816 = (_ptr__1803[_1814] % _1802);
            _ptr__1811[_1813] = _ptr__1803[_1814];
            _ptr__1812[_1813] = safe_add( _ptr__1804[_1814],(int)1 );
            ++ _1813;
            if ((_1815 != _1816))
            {
              {
                _ptr__1811[_1813] = safe_add( safe_mul( _1816,_1802 ),_1815 );
                _ptr__1812[_1813] = safe_add( _ptr__1804[_1814],(int)1 );
                ++ _1813;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _9385;
      for (int _1818 = (int)0, _9386 = _1809; _1818 < _9386 ; ++_1818)
      {
        _9385.push_back(_1818);
      }
      auto _9387 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9385.size()),_9385.begin(),_9385.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1817 = _9387;
      _checked_ptr_1<long long> _ptr__1817(_1817 ? _1817->raw() : nullptr,_1817 ? _1817->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1817,_1811,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1809));
      std::vector<long long> _9388;
      for (int _1819 = (int)0, _9389 = _1809; _1819 < _9389 ; ++_1819)
      {
        _9388.push_back(_ptr__1812[_ptr__1817[_1819]]);
      }
      auto _9390 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9388.size()),_9388.begin(),_9388.end()));
      return _9390;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SymLinearVariable::mirror_sp(int _1820,std::shared_ptr< monty::ndarray< long long,1 > > _1821){
  _checked_ptr_1<long long> _ptr__1821(_1821 ? _1821->raw() : nullptr, _1821 ? _1821->size(0) : 0);
  if ((NULL == _1821.get()))
  {
    {
      return nullptr;
    }
  }
  else
  {
    {
      int _1822 = (int)0;
      {
        int _9391 = (int)0;
        int _9392 = (int)((_1821)->size(0));
        for (int _1823 = _9391; _1823 < _9392; ++_1823)
        {
          {
            int _9393;
            bool _9394 = ((_ptr__1821[_1823] % safe_add( _1820,(int)1 )) == (int)0);
            if (_9394)
            {
              _9393 = (int)1;
            }
            else
            {
              _9393 = (int)2;
            }
            _1822 += _9393;
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1824 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1822)));
      _checked_ptr_1<long long> _ptr__1824(_1824 ? _1824->raw() : nullptr,_1824 ? _1824->size(0) : 0);
      {
        int _1825 = (int)0;
        int _9395 = (int)0;
        int _9396 = (int)((_1821)->size(0));
        for (int _1826 = _9395; _1826 < _9396; ++_1826)
        {
          {
            long long _1827 = (_ptr__1821[_1826] / _1820);
            long long _1828 = (_ptr__1821[_1826] % _1820);
            _ptr__1824[_1825] = _ptr__1821[_1826];
            ++ _1825;
            if ((_1827 != _1828))
            {
              {
                _ptr__1824[_1825] = safe_add( safe_mul( _1828,_1820 ),_1827 );
                ++ _1825;
              }
            }
            {}
          }
        }
      }
      std::vector<long long> _9397;
      for (int _1830 = (int)0, _9398 = _1822; _1830 < _9398 ; ++_1830)
      {
        _9397.push_back(_1830);
      }
      auto _9399 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9397.size()),_9397.begin(),_9397.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _1829 = _9399;
      _checked_ptr_1<long long> _ptr__1829(_1829 ? _1829->raw() : nullptr,_1829 ? _1829->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_1829,_1824,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1822));
      std::vector<long long> _9400;
      for (int _1831 = (int)0, _9401 = _1822; _1831 < _9401 ; ++_1831)
      {
        _9400.push_back(_ptr__1824[_ptr__1829[_1831]]);
      }
      auto _9402 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9400.size()),_9400.begin(),_9400.end()));
      return _9402;
    }
  }
}
void mosek::fusion::p_SymLinearVariable::destroy(){sparsity.reset();nativeidxs.reset();}void mosek::fusion::SymLinearVariable::destroy() { mosek::fusion::p_SymLinearVariable::_get_impl(this)->destroy(); }mosek::fusion::LinearVariable::LinearVariable(mosek::fusion::p_LinearVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "LinearVariable()" << this << std::endl; */ }mosek::fusion::LinearVariable::~LinearVariable() {  /* std::cout << "~LinearVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearVariable::p_LinearVariable  (::mosek::fusion::LinearVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1832,    monty::rc_ptr< ::mosek::fusion::Model > _1833){ return new mosek::fusion::LinearVariable(_1832,_1833); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1832,    monty::rc_ptr< ::mosek::fusion::Model > _1833) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1832,_1833); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearVariable > _1832,    monty::rc_ptr< ::mosek::fusion::Model > _1833){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1832,_1833);
    names_flushed = mosek::fusion::p_LinearVariable::_get_impl(_1832)->names_flushed;
    nativeidxs = mosek::fusion::p_LinearVariable::_get_impl(_1832)->nativeidxs;
    sparsity = mosek::fusion::p_LinearVariable::_get_impl(_1832)->sparsity;
    shape = mosek::fusion::p_LinearVariable::_get_impl(_1832)->shape;
    name = mosek::fusion::p_LinearVariable::_get_impl(_1832)->name;
  }
}mosek::fusion::LinearVariable::t mosek::fusion::p_LinearVariable::_new_LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1834,    const std::string &  _1835,    long long _1836,    std::shared_ptr< monty::ndarray< int,1 > > _1837,    std::shared_ptr< monty::ndarray< long long,1 > > _1838,    std::shared_ptr< monty::ndarray< int,1 > > _1839){ return new mosek::fusion::LinearVariable(_1834,_1835,_1836,_1837,_1838,_1839); }mosek::fusion::LinearVariable::LinearVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1834,    const std::string &  _1835,    long long _1836,    std::shared_ptr< monty::ndarray< int,1 > > _1837,    std::shared_ptr< monty::ndarray< long long,1 > > _1838,    std::shared_ptr< monty::ndarray< int,1 > > _1839) :    LinearVariable(new mosek::fusion::p_LinearVariable(this)){ mosek::fusion::p_LinearVariable::_get_impl(this)->_initialize(_1834,_1835,_1836,_1837,_1838,_1839); }void mosek::fusion::p_LinearVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1834,    const std::string &  _1835,    long long _1836,    std::shared_ptr< monty::ndarray< int,1 > > _1837,    std::shared_ptr< monty::ndarray< long long,1 > > _1838,    std::shared_ptr< monty::ndarray< int,1 > > _1839){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1837(_1837 ? _1837->raw() : nullptr, _1837 ? _1837->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1838(_1838 ? _1838->raw() : nullptr, _1838 ? _1838->size(0) : 0);
    _checked_ptr_1<int> _ptr__1839(_1839 ? _1839->raw() : nullptr, _1839 ? _1839->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1834,_1835,_1837,_1836,_1838,::mosek::fusion::p_LinearVariable::globalNativeIndexes(_1839));
    names_flushed = false;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->name = _1835;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->nativeidxs = _1839;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->sparsity = _1838;
    mosek::fusion::p_LinearVariable::_get_impl(::mosek::fusion::LinearVariable::t(_pubthis))->shape = _1837;
  }
}std::string mosek::fusion::LinearVariable :: toString() { return mosek::fusion::p_LinearVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1840 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1840->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearVariable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1840->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _9403 = (int)1;
      int _9404 = (int)((shape)->size(0));
      for (int _1841 = _9403; _1841 < _9404; ++_1841)
      {
        {
          _1840->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1841)));
        }
      }
    }
  }
  {}
  _1840->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  if ((NULL != sparsity.get()))
  {
    {
      _1840->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",sparse"));
    }
  }
  {}
  _1840->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _1840->toString();
}
void mosek::fusion::p_LinearVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1842 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if ((_pubthis->getSize() == (int)0))
  {
    {
      names_flushed = true;
    }
  }
  else
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          names_flushed = true;
        }
      }
      {}
    }
  }
  if ((!names_flushed))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1843 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1843->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      if ((_pubthis->getND() > (int)0))
      {
        {
          _1843->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
          int _9405 = (int)1;
          int _9406 = _pubthis->getND();
          for (int _1844 = _9405; _1844 < _9406; ++_1844)
          {
            {
              _1843->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1844);
            }
          }
        }
      }
      {}
      _1843->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _9407;
      bool _9408 = (_pubthis->getND() > (int)0);
      if (_9408)
      {
        _9407 = _pubthis->getShape();
      }
      else
      {
        _9407 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
      }
      mosek::fusion::p_Model::_get_impl(_1842.get())->varnames(nativeidxs,_1843->toString(),_9407,sparsity);
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_LinearVariable::__mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1845){
  return (::mosek::fusion::p_LinearVariable::_new_LinearVariable(::mosek::fusion::LinearVariable::t(_pubthis),_1845)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_LinearVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1846){
  _checked_ptr_1<int> _ptr__1846(_1846 ? _1846->raw() : nullptr, _1846 ? _1846->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1847 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1846)->size(0)))));
  _checked_ptr_1<long long> _ptr__1847(_1847 ? _1847->raw() : nullptr,_1847 ? _1847->size(0) : 0);
  int _9409 = (int)0;
  int _9410 = (int)((_1846)->size(0));
  for (int _1848 = _9409; _1848 < _9410; ++_1848)
  {
    {
      _ptr__1847[_1848] = _ptr__1846[_1848];
    }
  }
  return _1847;
}
void mosek::fusion::p_LinearVariable::destroy(){shape.reset();sparsity.reset();nativeidxs.reset();}void mosek::fusion::LinearVariable::destroy() { mosek::fusion::p_LinearVariable::_get_impl(this)->destroy(); }mosek::fusion::ConicVariable::ConicVariable(mosek::fusion::p_ConicVariable *_impl) : mosek::fusion::ModelVariable(_impl) { /*std::cout << "ConicVariable()" << this << std::endl; */ }mosek::fusion::ConicVariable::~ConicVariable() {  /* std::cout << "~ConicVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicVariable::p_ConicVariable  (::mosek::fusion::ConicVariable * _pubthis) :     mosek::fusion::p_ModelVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1849,    monty::rc_ptr< ::mosek::fusion::Model > _1850){ return new mosek::fusion::ConicVariable(_1849,_1850); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1849,    monty::rc_ptr< ::mosek::fusion::Model > _1850) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1849,_1850); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicVariable > _1849,    monty::rc_ptr< ::mosek::fusion::Model > _1850){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelVariable::_initialize(_1849,_1850);
    names_flushed = mosek::fusion::p_ConicVariable::_get_impl(_1849)->names_flushed;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1849)->shape;
    nativeidxs = mosek::fusion::p_ConicVariable::_get_impl(_1849)->nativeidxs;
    shape = mosek::fusion::p_ConicVariable::_get_impl(_1849)->shape;
    varid = mosek::fusion::p_ConicVariable::_get_impl(_1849)->varid;
    name = mosek::fusion::p_ConicVariable::_get_impl(_1849)->name;
  }
}mosek::fusion::ConicVariable::t mosek::fusion::p_ConicVariable::_new_ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1851,    const std::string &  _1852,    int _1853,    std::shared_ptr< monty::ndarray< int,1 > > _1854,    std::shared_ptr< monty::ndarray< int,1 > > _1855){ return new mosek::fusion::ConicVariable(_1851,_1852,_1853,_1854,_1855); }mosek::fusion::ConicVariable::ConicVariable  (monty::rc_ptr< ::mosek::fusion::Model > _1851,    const std::string &  _1852,    int _1853,    std::shared_ptr< monty::ndarray< int,1 > > _1854,    std::shared_ptr< monty::ndarray< int,1 > > _1855) :    ConicVariable(new mosek::fusion::p_ConicVariable(this)){ mosek::fusion::p_ConicVariable::_get_impl(this)->_initialize(_1851,_1852,_1853,_1854,_1855); }void mosek::fusion::p_ConicVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1851,    const std::string &  _1852,    int _1853,    std::shared_ptr< monty::ndarray< int,1 > > _1854,    std::shared_ptr< monty::ndarray< int,1 > > _1855){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1854(_1854 ? _1854->raw() : nullptr, _1854 ? _1854->size(0) : 0);
    _checked_ptr_1<int> _ptr__1855(_1855 ? _1855->raw() : nullptr, _1855 ? _1855->size(0) : 0);
    mosek::fusion::p_ModelVariable::_initialize(_1851,_1852,_1854,_1853,nullptr,::mosek::fusion::p_ConicVariable::globalNativeIndexes(_1855));
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->name = _1852;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->varid = _1853;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->shape = _1854;
    mosek::fusion::p_ConicVariable::_get_impl(::mosek::fusion::ConicVariable::t(_pubthis))->nativeidxs = _1855;
  }
}std::string mosek::fusion::ConicVariable :: toString() { return mosek::fusion::p_ConicVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1856 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1856->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicVariable( "));
  if (((int)((name).size()) > (int)0))
  {
    {
      _1856->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("',"));
    }
  }
  {}
  _1856->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("));
  _1856->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _9411 = (int)1;
  int _9412 = (int)((shape)->size(0));
  for (int _1857 = _9411; _1857 < _9412; ++_1857)
  {
    {
      _1856->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1857)));
    }
  }
  _1856->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _1856->toString();
}
void mosek::fusion::p_ConicVariable::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _1858 = _pubthis->__mosek_2fusion_2BaseVariable__getModel();
  if ((_pubthis->getSize() == (int)0))
  {
    {
      names_flushed = true;
    }
  }
  else
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          names_flushed = true;
        }
      }
      {}
    }
  }
  if ((!names_flushed))
  {
    {
      monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1859 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
      _1859->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
      _1859->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
      int _9413 = (int)1;
      int _9414 = _pubthis->getND();
      for (int _1860 = _9413; _1860 < _9414; ++_1860)
      {
        {
          _1859->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_1860);
        }
      }
      _1859->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
      std::shared_ptr< monty::ndarray< int,1 > > _9415;
      bool _9416 = (_pubthis->getND() > (int)0);
      if (_9416)
      {
        _9415 = _pubthis->getShape();
      }
      else
      {
        _9415 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)});
      }
      mosek::fusion::p_Model::_get_impl(_1858.get())->varnames(nativeidxs,_1859->toString(),_9415,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
      names_flushed = true;
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::ModelVariable > mosek::fusion::p_ConicVariable::__mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1861){
  return (::mosek::fusion::p_ConicVariable::_new_ConicVariable(::mosek::fusion::ConicVariable::t(_pubthis),_1861)).as<::mosek::fusion::ModelVariable>();
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ConicVariable::globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1862){
  _checked_ptr_1<int> _ptr__1862(_1862 ? _1862->raw() : nullptr, _1862 ? _1862->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1863 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_1862)->size(0)))));
  _checked_ptr_1<long long> _ptr__1863(_1863 ? _1863->raw() : nullptr,_1863 ? _1863->size(0) : 0);
  int _9417 = (int)0;
  int _9418 = (int)((_1862)->size(0));
  for (int _1864 = _9417; _1864 < _9418; ++_1864)
  {
    {
      _ptr__1863[_1864] = _ptr__1862[_1864];
    }
  }
  return _1863;
}
void mosek::fusion::p_ConicVariable::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::ConicVariable::destroy() { mosek::fusion::p_ConicVariable::_get_impl(this)->destroy(); }mosek::fusion::ModelVariable::ModelVariable(mosek::fusion::p_ModelVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "ModelVariable()" << this << std::endl; */ }mosek::fusion::ModelVariable::~ModelVariable() {  /* std::cout << "~ModelVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelVariable::p_ModelVariable  (::mosek::fusion::ModelVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelVariable > _1865,    monty::rc_ptr< ::mosek::fusion::Model > _1866){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseVariable::_initialize(_1865,_1866);
    name = mosek::fusion::p_ModelVariable::_get_impl(_1865)->name;
    varid = mosek::fusion::p_ModelVariable::_get_impl(_1865)->varid;
    nativeidxs = mosek::fusion::p_ModelVariable::_get_impl(_1865)->nativeidxs;
    shape = mosek::fusion::p_ModelVariable::_get_impl(_1865)->shape;
    sparsity = mosek::fusion::p_ModelVariable::_get_impl(_1865)->sparsity;
  }
}void mosek::fusion::p_ModelVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1867,    const std::string &  _1868,    std::shared_ptr< monty::ndarray< int,1 > > _1869,    long long _1870,    std::shared_ptr< monty::ndarray< long long,1 > > _1871,    std::shared_ptr< monty::ndarray< long long,1 > > _1872){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1869(_1869 ? _1869->raw() : nullptr, _1869 ? _1869->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1871(_1871 ? _1871->raw() : nullptr, _1871 ? _1871->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1872(_1872 ? _1872->raw() : nullptr, _1872 ? _1872->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(_1867,_1869,_1871,_1872);
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->name = _1868;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->varid = _1870;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->shape = _1869;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->sparsity = _1871;
    mosek::fusion::p_ModelVariable::_get_impl(::mosek::fusion::ModelVariable::t(_pubthis))->nativeidxs = _1872;
  }
}void mosek::fusion::ModelVariable :: elementName(long long _1873,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1874) { mosek::fusion::p_ModelVariable::_get_impl(this)->elementName(_1873,_1874); }void mosek::fusion::p_ModelVariable::elementName(long long _1873,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1874){
  std::string _9419;
  bool _9420 = ((int)((name).size()) == (int)0);
  if (_9420)
  {
    _9419 = std::string ("_");
  }
  else
  {
    _9419 = name;
  }
  _1874->__mosek_2fusion_2Utils_2StringBuffer__a(_9419)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,_1873))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
}
void mosek::fusion::ModelVariable :: remove() { mosek::fusion::p_ModelVariable::_get_impl(this)->remove(); }void mosek::fusion::p_ModelVariable::remove(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->removeVariableBlock(varid);
}
void mosek::fusion::p_ModelVariable::destroy(){sparsity.reset();shape.reset();nativeidxs.reset();}void mosek::fusion::ModelVariable::destroy() { mosek::fusion::p_ModelVariable::_get_impl(this)->destroy(); }mosek::fusion::NilVariable::NilVariable(mosek::fusion::p_NilVariable *_impl) : mosek::fusion::BaseVariable(_impl) { /*std::cout << "NilVariable()" << this << std::endl; */ }mosek::fusion::NilVariable::~NilVariable() {  /* std::cout << "~NilVariable()" << this << std::endl << std::flush; */ }mosek::fusion::p_NilVariable::p_NilVariable  (::mosek::fusion::NilVariable * _pubthis) :     mosek::fusion::p_BaseVariable(_pubthis),    _pubthis(_pubthis){}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1876){ return new mosek::fusion::NilVariable(_1876); }mosek::fusion::NilVariable::NilVariable  (std::shared_ptr< monty::ndarray< int,1 > > _1876) :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(_1876); }void mosek::fusion::p_NilVariable::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _1876){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1876(_1876 ? _1876->raw() : nullptr, _1876 ? _1876->size(0) : 0);
    mosek::fusion::p_BaseVariable::_initialize(nullptr,::mosek::fusion::Utils::Tools::arraycopy(_1876),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))));
    std::vector<int> _9421;
    for (int _1877 = (int)0, _9422 = (int)((_1876)->size(0)); _1877 < _9422 ; ++_1877)
    {
      _9421.push_back(_ptr__1876[_1877]);
    }
    auto _9423 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9421.size()),_9421.begin(),_9421.end()));
    mosek::fusion::p_NilVariable::_get_impl(::mosek::fusion::NilVariable::t(_pubthis))->shape = _9423;
  }
}mosek::fusion::NilVariable::t mosek::fusion::p_NilVariable::_new_NilVariable  (){ return new mosek::fusion::NilVariable(); }mosek::fusion::NilVariable::NilVariable  () :    NilVariable(new mosek::fusion::p_NilVariable(this)){ mosek::fusion::p_NilVariable::_get_impl(this)->_initialize(); }void mosek::fusion::p_NilVariable::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_NilVariable::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
  }
}void mosek::fusion::p_NilVariable::flushNames(){
}
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__elementDesc(long long _1878,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1879) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__elementDesc(_1878,_1879); }monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::NilVariable::elementDesc(long long _1878,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1879) { return __mosek_2fusion_2NilVariable__elementDesc(_1878,_1879); }
monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__elementDesc(long long _1878,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1879){
  return _1879;
}
void mosek::fusion::NilVariable :: elementName(long long _1880,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1881) { mosek::fusion::p_NilVariable::_get_impl(this)->elementName(_1880,_1881); }void mosek::fusion::p_NilVariable::elementName(long long _1880,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1881){
}
int mosek::fusion::NilVariable :: numInst() { return mosek::fusion::p_NilVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_NilVariable::numInst(){
  return (int)0;
}
int mosek::fusion::NilVariable :: inst(int _1882,std::shared_ptr< monty::ndarray< long long,1 > > _1883,std::shared_ptr< monty::ndarray< long long,1 > > _1884) { return mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1882,_1883,_1884); }int mosek::fusion::p_NilVariable::inst(int _1882,std::shared_ptr< monty::ndarray< long long,1 > > _1883,std::shared_ptr< monty::ndarray< long long,1 > > _1884){
  _checked_ptr_1<long long> _ptr__1883(_1883 ? _1883->raw() : nullptr, _1883 ? _1883->size(0) : 0);
  _checked_ptr_1<long long> _ptr__1884(_1884 ? _1884->raw() : nullptr, _1884 ? _1884->size(0) : 0);
  return (int)0;
}
void mosek::fusion::NilVariable :: inst(int _1885,std::shared_ptr< monty::ndarray< long long,1 > > _1886) { mosek::fusion::p_NilVariable::_get_impl(this)->inst(_1885,_1886); }void mosek::fusion::p_NilVariable::inst(int _1885,std::shared_ptr< monty::ndarray< long long,1 > > _1886){
  _checked_ptr_1<long long> _ptr__1886(_1886 ? _1886->raw() : nullptr, _1886 ? _1886->size(0) : 0);
}
void mosek::fusion::NilVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _1887,bool _1888) { mosek::fusion::p_NilVariable::_get_impl(this)->set_values(_1887,_1888); }void mosek::fusion::p_NilVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _1887,bool _1888){
  _checked_ptr_1<double> _ptr__1887(_1887 ? _1887->raw() : nullptr, _1887 ? _1887->size(0) : 0);
}
void mosek::fusion::NilVariable :: values(int _1889,std::shared_ptr< monty::ndarray< double,1 > > _1890,bool _1891) { mosek::fusion::p_NilVariable::_get_impl(this)->values(_1889,_1890,_1891); }void mosek::fusion::p_NilVariable::values(int _1889,std::shared_ptr< monty::ndarray< double,1 > > _1890,bool _1891){
  _checked_ptr_1<double> _ptr__1890(_1890 ? _1890->raw() : nullptr, _1890 ? _1890->size(0) : 0);
}
void mosek::fusion::NilVariable :: make_continuous() { mosek::fusion::p_NilVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_NilVariable::make_continuous(){
}
void mosek::fusion::NilVariable :: make_integer() { mosek::fusion::p_NilVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_NilVariable::make_integer(){
}
std::string mosek::fusion::NilVariable :: toString() { return mosek::fusion::p_NilVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_NilVariable::toString(){
  return std::string ("NilVariable");
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1892) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1892); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _1892) { return __mosek_2fusion_2NilVariable__index(_1892); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1892) { return __mosek_2fusion_2NilVariable__index(_1892); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1892) { return __mosek_2fusion_2NilVariable__index(_1892); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1892){
  _checked_ptr_1<int> _ptr__1892(_1892 ? _1892->raw() : nullptr, _1892 ? _1892->size(0) : 0);
  std::vector<int> _9424;
  for (int _1893 = (int)0, _9425 = (int)((shape)->size(0)); _1893 < _9425 ; ++_1893)
  {
    _9424.push_back((int)1);
  }
  auto _9426 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9424.size()),_9424.begin(),_9424.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_9426)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__index(int _1894) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__index(_1894); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::index(int _1894) { return __mosek_2fusion_2NilVariable__index(_1894); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__index(int _1894) { return __mosek_2fusion_2NilVariable__index(_1894); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__index(int _1894) { return __mosek_2fusion_2NilVariable__index(_1894); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__index(int _1894){
  std::vector<int> _9427;
  for (int _1895 = (int)0, _9428 = (int)((shape)->size(0)); _1895 < _9428 ; ++_1895)
  {
    _9427.push_back((int)1);
  }
  auto _9429 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9427.size()),_9427.begin(),_9427.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_9429)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1896,_1897); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897) { return __mosek_2fusion_2NilVariable__slice(_1896,_1897); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897) { return __mosek_2fusion_2NilVariable__slice(_1896,_1897); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897) { return __mosek_2fusion_2NilVariable__slice(_1896,_1897); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897){
  _checked_ptr_1<int> _ptr__1896(_1896 ? _1896->raw() : nullptr, _1896 ? _1896->size(0) : 0);
  _checked_ptr_1<int> _ptr__1897(_1897 ? _1897->raw() : nullptr, _1897 ? _1897->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)((_1896)->size(0))) || ((int)((shape)->size(0)) != (int)((_1897)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  {}
  int _9430 = (int)0;
  int _9431 = (int)((_1896)->size(0));
  for (int _1898 = _9430; _1898 < _9431; ++_1898)
  {
    {
      if (((_ptr__1897[_1898] > _ptr__1896[_1898]) || ((_ptr__1896[_1898] < (int)0) || (_ptr__1897[_1898] >= ((*shape)(_1898))))))
      {
        {
          throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _9432;
  for (int _1899 = (int)0, _9433 = (int)((shape)->size(0)); _1899 < _9433 ; ++_1899)
  {
    _9432.push_back((_ptr__1897[_1899] - _ptr__1896[_1899]));
  }
  auto _9434 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9432.size()),_9432.begin(),_9432.end()));
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_9434)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable :: __mosek_2fusion_2NilVariable__slice(int _1900,int _1901) { return mosek::fusion::p_NilVariable::_get_impl(this)->__mosek_2fusion_2NilVariable__slice(_1900,_1901); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::slice(int _1900,int _1901) { return __mosek_2fusion_2NilVariable__slice(_1900,_1901); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2BaseVariable__slice(int _1900,int _1901) { return __mosek_2fusion_2NilVariable__slice(_1900,_1901); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::NilVariable::__mosek_2fusion_2Variable__slice(int _1900,int _1901) { return __mosek_2fusion_2NilVariable__slice(_1900,_1901); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_NilVariable::__mosek_2fusion_2NilVariable__slice(int _1900,int _1901){
  if (((_1901 > _1900) || ((_1900 < (int)0) || (_1901 > ((*shape)((int)0))))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Slice is out of bounds"));
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching slice shape"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_1901 - _1900))}))).as<::mosek::fusion::Variable>();
    }
  }
}
void mosek::fusion::p_NilVariable::destroy(){shape.reset();}void mosek::fusion::NilVariable::destroy() { mosek::fusion::p_NilVariable::_get_impl(this)->destroy(); }mosek::fusion::BaseVariable::BaseVariable(mosek::fusion::p_BaseVariable *_impl) : _impl(_impl) { /*std::cout << "BaseVariable() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseVariable::~BaseVariable() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseVariable::p_BaseVariable  (::mosek::fusion::BaseVariable * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::BaseVariable > _1902,    monty::rc_ptr< ::mosek::fusion::Model > _1903){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _1903;
    shape = mosek::fusion::p_BaseVariable::_get_impl(_1902)->shape;
    sparsity = mosek::fusion::p_BaseVariable::_get_impl(_1902)->sparsity;
    nativeidxs = mosek::fusion::p_BaseVariable::_get_impl(_1902)->nativeidxs;
  }
}void mosek::fusion::p_BaseVariable::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _1904,    std::shared_ptr< monty::ndarray< int,1 > > _1905,    std::shared_ptr< monty::ndarray< long long,1 > > _1906,    std::shared_ptr< monty::ndarray< long long,1 > > _1907){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__1905(_1905 ? _1905->raw() : nullptr, _1905 ? _1905->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1906(_1906 ? _1906->raw() : nullptr, _1906 ? _1906->size(0) : 0);
    _checked_ptr_1<long long> _ptr__1907(_1907 ? _1907->raw() : nullptr, _1907 ? _1907->size(0) : 0);
    model = _1904;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->shape = _1905;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity = _1906;
    mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs = _1907;
  }
}std::string mosek::fusion::BaseVariable :: toString() { return mosek::fusion::p_BaseVariable::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseVariable::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1908 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _1908->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variable(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _1908->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _9435 = (int)1;
      int _9436 = (int)((shape)->size(0));
      for (int _1909 = _9435; _1909 < _9436; ++_1909)
      {
        {
          _1908->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_1909)));
        }
      }
    }
  }
  {}
  _1908->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("))"));
  return _1908->toString();
}
void mosek::fusion::BaseVariable :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1910,monty::rc_ptr< ::mosek::fusion::WorkStack > _1911,monty::rc_ptr< ::mosek::fusion::WorkStack > _1912) { mosek::fusion::p_BaseVariable::_get_impl(this)->eval(_1910,_1911,_1912); }void mosek::fusion::p_BaseVariable::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1910,monty::rc_ptr< ::mosek::fusion::WorkStack > _1911,monty::rc_ptr< ::mosek::fusion::WorkStack > _1912){
  int _1913 = (int)((nativeidxs)->size(0));
  int _1914 = _1913;
  int _1915 = (int)((shape)->size(0));
  bool _1916 = (NULL != sparsity.get());
  _1910->alloc_expr(_1915,_1914,_1913,_1916);
  int _1917 = mosek::fusion::p_WorkStack::_get_impl(_1910)->ptr_base;
  int _1918 = mosek::fusion::p_WorkStack::_get_impl(_1910)->nidxs_base;
  int _1919 = mosek::fusion::p_WorkStack::_get_impl(_1910)->sp_base;
  int _1920 = mosek::fusion::p_WorkStack::_get_impl(_1910)->cof_base;
  int _1921 = mosek::fusion::p_WorkStack::_get_impl(_1910)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _1922 = mosek::fusion::p_WorkStack::_get_impl(_1910)->i32;
  _checked_ptr_1<int> _ptr__1922(_1922 ? _1922->raw() : nullptr,_1922 ? _1922->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _1923 = mosek::fusion::p_WorkStack::_get_impl(_1910)->i64;
  _checked_ptr_1<long long> _ptr__1923(_1923 ? _1923->raw() : nullptr,_1923 ? _1923->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _1924 = mosek::fusion::p_WorkStack::_get_impl(_1910)->f64;
  _checked_ptr_1<double> _ptr__1924(_1924 ? _1924->raw() : nullptr,_1924 ? _1924->size(0) : 0);
  int _9437 = (int)0;
  int _9438 = _1915;
  for (int _1925 = _9437; _1925 < _9438; ++_1925)
  {
    {
      _ptr__1922[safe_add( _1921,_1925 )] = ((*shape)(_1925));
    }
  }
  {
    int _9439 = (int)0;
    int _9440 = safe_add( _1913,(int)1 );
    for (int _1926 = _9439; _1926 < _9440; ++_1926)
    {
      {
        _ptr__1922[safe_add( _1917,_1926 )] = _1926;
      }
    }
    int _9441 = (int)0;
    int _9442 = _1913;
    for (int _1927 = _9441; _1927 < _9442; ++_1927)
    {
      {
        _ptr__1923[safe_add( _1918,_1927 )] = ((*nativeidxs)(_1927));
      }
    }
    if (_1916)
    {
      {
        int _9443 = (int)0;
        int _9444 = _1913;
        for (int _1928 = _9443; _1928 < _9444; ++_1928)
        {
          {
            _ptr__1923[safe_add( _1919,_1928 )] = ((*sparsity)(_1928));
          }
        }
      }
    }
    {}
    int _9445 = (int)0;
    int _9446 = _1913;
    for (int _1929 = _9445; _1929 < _9446; ++_1929)
    {
      {
        _ptr__1924[safe_add( _1920,_1929 )] = 1.0;
      }
    }
  }
}
void mosek::fusion::BaseVariable :: remove() { mosek::fusion::p_BaseVariable::_get_impl(this)->remove(); }void mosek::fusion::p_BaseVariable::remove(){
  throw ::mosek::fusion::DeletionError(std::string ("Only original variables can be removed"));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__fromTril(int _1930,int _1931) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__fromTril(_1930,_1931); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::fromTril(int _1930,int _1931) { return __mosek_2fusion_2BaseVariable__fromTril(_1930,_1931); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__fromTril(int _1930,int _1931){
  if (((_1930 < (int)0) || (_1930 >= (int)((shape)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension"));
    }
  }
  else if((((*shape)(_1930)) != (safe_mul( _1931,safe_add( _1931,(int)1 ) ) / (int)2)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  {}
  int _1932 = (int)1;
  int _9447 = (int)0;
  int _9448 = _1930;
  for (int _1933 = _9447; _1933 < _9448; ++_1933)
  {
    {
      _1932 *= ((*shape)(_1933));
    }
  }
  int _1934 = ((*shape)(_1930));
  int _1935 = (int)1;
  int _9449 = safe_add( _1930,(int)1 );
  int _9450 = (int)((shape)->size(0));
  for (int _1936 = _9449; _1936 < _9450; ++_1936)
  {
    {
      _1935 *= ((*shape)(_1936));
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1937 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((shape)->size(0)),(int)1 ))));
  _checked_ptr_1<int> _ptr__1937(_1937 ? _1937->raw() : nullptr,_1937 ? _1937->size(0) : 0);
  int _9451 = (int)0;
  int _9452 = _1930;
  for (int _1938 = _9451; _1938 < _9452; ++_1938)
  {
    {
      _ptr__1937[_1938] = ((*shape)(_1938));
    }
  }
  _ptr__1937[_1930] = _1931;
  _ptr__1937[safe_add( _1930,(int)1 )] = _1931;
  int _9453 = safe_add( _1930,(int)1 );
  int _9454 = (int)((shape)->size(0));
  for (int _1939 = _9453; _1939 < _9454; ++_1939)
  {
    {
      _ptr__1937[safe_add( _1939,(int)1 )] = ((*shape)(_1939));
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _1940 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( safe_mul( safe_mul( _1932,_1931 ),_1931 ),_1935 ))));
      _checked_ptr_1<long long> _ptr__1940(_1940 ? _1940->raw() : nullptr,_1940 ? _1940->size(0) : 0);
      int _1941 = (int)0;
      int _9455 = (int)0;
      int _9456 = _1932;
      for (int _1942 = _9455; _1942 < _9456; ++_1942)
      {
        {
          int _9457 = (int)0;
          int _9458 = _1931;
          for (int _1943 = _9457; _1943 < _9458; ++_1943)
          {
            {
              int _9459 = (int)0;
              int _9460 = _1931;
              for (int _1944 = _9459; _1944 < _9460; ++_1944)
              {
                {
                  int _9461 = (int)0;
                  int _9462 = _1935;
                  for (int _1945 = _9461; _1945 < _9462; ++_1945)
                  {
                    {
                      if ((_1943 >= _1944))
                      {
                        {
                          _ptr__1940[_1941] = ((*nativeidxs)(safe_add( safe_add( safe_mul( safe_mul( _1942,_1934 ),_1935 ),safe_mul( safe_add( (safe_mul( _1943,safe_add( _1943,(int)1 ) ) / (int)2),_1944 ),_1935 ) ),_1945 )));
                        }
                      }
                      else
                      {
                        {
                          _ptr__1940[_1941] = ((*nativeidxs)(safe_add( safe_add( safe_mul( safe_mul( _1942,_1934 ),_1935 ),safe_mul( safe_add( (safe_mul( _1944,safe_add( _1944,(int)1 ) ) / (int)2),_1943 ),_1935 ) ),_1945 )));
                        }
                      }
                      ++ _1941;
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1937,nullptr,_1940)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1946 = (int)0;
      int _9463 = (int)0;
      int _9464 = (int)((sparsity)->size(0));
      for (int _1947 = _9463; _1947 < _9464; ++_1947)
      {
        {
          long long _1948 = ((((*sparsity)(_1947)) / _1935) % _1934);
          int _1949 = (int)(((-(int)1) + ::mosek::fusion::Utils::Tools::sqrt((double)(safe_mul( safe_add( (int)1,safe_mul( (int)2,_1948 ) ),safe_add( (int)1,safe_mul( (int)2,_1948 ) ) )))) / (int)4);
          long long _1950 = (((*sparsity)(_1947)) - (safe_mul( _1949,safe_add( _1949,(int)1 ) ) / (int)2));
          if ((_1949 == _1950))
          {
            {
              _1946 += (int)1;
            }
          }
          else
          {
            {
              _1946 += (int)2;
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1951 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1946)));
      _checked_ptr_1<long long> _ptr__1951(_1951 ? _1951->raw() : nullptr,_1951 ? _1951->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1952 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1946)));
      _checked_ptr_1<long long> _ptr__1952(_1952 ? _1952->raw() : nullptr,_1952 ? _1952->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _1953 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1946)));
      _checked_ptr_1<long long> _ptr__1953(_1953 ? _1953->raw() : nullptr,_1953 ? _1953->size(0) : 0);
      int _9465 = (int)0;
      int _9466 = _1946;
      for (int _1954 = _9465; _1954 < _9466; ++_1954)
      {
        {
          _ptr__1953[_1954] = _1954;
        }
      }
      int _1955 = (int)0;
      int _9467 = (int)0;
      int _9468 = (int)((sparsity)->size(0));
      for (int _1956 = _9467; _1956 < _9468; ++_1956)
      {
        {
          long long _1957 = (((*sparsity)(_1956)) / safe_mul( _1934,_1935 ));
          long long _1958 = ((((*sparsity)(_1956)) / _1935) % _1934);
          long long _1959 = (((*sparsity)(_1956)) % _1935);
          int _1960 = (int)(((-(int)1) + ::mosek::fusion::Utils::Tools::sqrt((double)(safe_mul( safe_add( (int)1,safe_mul( (int)2,_1958 ) ),safe_add( (int)1,safe_mul( (int)2,_1958 ) ) )))) / (int)4);
          long long _1961 = (((*sparsity)(_1956)) - (safe_mul( _1960,safe_add( _1960,(int)1 ) ) / (int)2));
          if ((_1960 == _1961))
          {
            {
              _ptr__1951[_1955] = ((*nativeidxs)(_1956));
              _ptr__1952[_1955] = safe_add( safe_add( safe_mul( safe_mul( safe_mul( _1957,_1931 ),_1931 ),_1935 ),safe_mul( safe_add( safe_mul( _1960,_1931 ),_1961 ),_1935 ) ),_1959 );
              _1955 += (int)1;
            }
          }
          else
          {
            {
              _ptr__1951[_1955] = ((*nativeidxs)(_1956));
              _ptr__1951[safe_add( _1955,(int)1 )] = ((*nativeidxs)(_1956));
              _ptr__1952[_1955] = safe_add( safe_add( safe_mul( safe_mul( safe_mul( _1957,_1931 ),_1931 ),_1935 ),safe_mul( safe_add( safe_mul( _1960,_1931 ),_1961 ),_1935 ) ),_1959 );
              _ptr__1952[safe_add( _1955,(int)1 )] = safe_add( safe_add( safe_mul( safe_mul( safe_mul( _1957,_1931 ),_1931 ),_1935 ),safe_mul( safe_add( safe_mul( _1961,_1931 ),_1960 ),_1935 ) ),_1959 );
              _1955 += (int)2;
            }
          }
        }
      }
      ::mosek::fusion::p_CommonTools::argQsort(_1953,_1951,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1946));
      std::vector<long long> _9469;
      for (int _1962 = (int)0, _9470 = _1946; _1962 < _9470 ; ++_1962)
      {
        _9469.push_back(_ptr__1952[_ptr__1953[_1962]]);
      }
      auto _9471 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9469.size()),_9469.begin(),_9469.end()));
      std::vector<long long> _9472;
      for (int _1963 = (int)0, _9473 = _1946; _1963 < _9473 ; ++_1963)
      {
        _9472.push_back(_ptr__1951[_ptr__1953[_1963]]);
      }
      auto _9474 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9472.size()),_9472.begin(),_9472.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1937,_9471,_9474)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__fromTril(int _1964) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__fromTril(_1964); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::fromTril(int _1964) { return __mosek_2fusion_2BaseVariable__fromTril(_1964); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__fromTril(int _1964) { return __mosek_2fusion_2BaseVariable__fromTril(_1964); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__fromTril(int _1964){
  return _pubthis->__mosek_2fusion_2BaseVariable__fromTril((int)0,_1964);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__tril(int _1965,int _1966) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__tril(_1965,_1966); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::tril(int _1965,int _1966) { return __mosek_2fusion_2BaseVariable__tril(_1965,_1966); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__tril(int _1965,int _1966){
  if (((_1965 < (int)0) || ((_1965 >= _1966) || (_1966 >= (int)((shape)->size(0))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension specification"));
    }
  }
  else
  {
    {
      if ((((*shape)(_1965)) != ((*shape)(_1966))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Operation only valid for square variables"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _1967 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((shape)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__1967(_1967 ? _1967->raw() : nullptr,_1967 ? _1967->size(0) : 0);
  int _9475 = (int)0;
  int _9476 = _1965;
  for (int _1968 = _9475; _1968 < _9476; ++_1968)
  {
    {
      _ptr__1967[_1968] = ((*shape)(_1968));
    }
  }
  _ptr__1967[_1965] = (safe_mul( ((*shape)(_1965)),safe_add( ((*shape)(_1965)),(int)1 ) ) / (int)2);
  int _9477 = safe_add( _1965,(int)1 );
  int _9478 = _1966;
  for (int _1969 = _9477; _1969 < _9478; ++_1969)
  {
    {
      _ptr__1967[_1969] = ((*shape)(_1969));
    }
  }
  int _9479 = safe_add( _1966,(int)1 );
  int _9480 = (int)((shape)->size(0));
  for (int _1970 = _9479; _1970 < _9480; ++_1970)
  {
    {
      _ptr__1967[(_1970 - (int)1)] = ((*shape)(_1970));
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      int _1971 = (int)1;
      int _9481 = (int)0;
      int _9482 = _1965;
      for (int _1972 = _9481; _1972 < _9482; ++_1972)
      {
        {
          _1971 *= ((*shape)(_1972));
        }
      }
      int _1973 = ((*shape)(_1965));
      int _1974 = (int)1;
      int _9483 = safe_add( _1965,(int)1 );
      int _9484 = _1966;
      for (int _1975 = _9483; _1975 < _9484; ++_1975)
      {
        {
          _1974 *= ((*shape)(_1975));
        }
      }
      int _1976 = ((*shape)(_1966));
      int _1977 = (int)1;
      int _9485 = safe_add( _1966,(int)1 );
      int _9486 = (int)((shape)->size(0));
      for (int _1978 = _9485; _1978 < _9486; ++_1978)
      {
        {
          _1977 *= ((*shape)(_1978));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _1979 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((safe_mul( safe_mul( safe_mul( safe_mul( _1971,_1974 ),_1977 ),_1973 ),safe_add( _1973,(int)1 ) ) / (int)2))));
      _checked_ptr_1<long long> _ptr__1979(_1979 ? _1979->raw() : nullptr,_1979 ? _1979->size(0) : 0);
      int _1980 = (int)0;
      int _9487 = (int)0;
      int _9488 = _1971;
      for (int _1981 = _9487; _1981 < _9488; ++_1981)
      {
        {
          int _9489 = (int)0;
          int _9490 = _1973;
          for (int _1982 = _9489; _1982 < _9490; ++_1982)
          {
            {
              int _9491 = (int)0;
              int _9492 = safe_add( _1982,(int)1 );
              for (int _1983 = _9491; _1983 < _9492; ++_1983)
              {
                {
                  int _9493 = (int)0;
                  int _9494 = _1974;
                  for (int _1984 = _9493; _1984 < _9494; ++_1984)
                  {
                    {
                      int _9495 = (int)0;
                      int _9496 = _1977;
                      for (int _1985 = _9495; _1985 < _9496; ++_1985)
                      {
                        {
                          _ptr__1979[_1980] = ((*nativeidxs)(safe_add( _1985,safe_mul( _1977,safe_add( _1983,safe_mul( _1976,safe_add( _1984,safe_mul( _1974,safe_add( _1982,safe_mul( _1973,_1981 ) ) ) ) ) ) ) )));
                          _1980 += (int)1;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1967,nullptr,_1979)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _1986 = (int)1;
      int _9497 = (int)0;
      int _9498 = _1965;
      for (int _1987 = _9497; _1987 < _9498; ++_1987)
      {
        {
          _1986 *= ((*shape)(_1987));
        }
      }
      int _1988 = ((*shape)(_1965));
      int _1989 = (int)1;
      int _9499 = safe_add( _1965,(int)1 );
      int _9500 = _1966;
      for (int _1990 = _9499; _1990 < _9500; ++_1990)
      {
        {
          _1989 *= ((*shape)(_1990));
        }
      }
      int _1991 = ((*shape)(_1966));
      int _1992 = (int)1;
      int _9501 = safe_add( _1966,(int)1 );
      int _9502 = (int)((shape)->size(0));
      for (int _1993 = _9501; _1993 < _9502; ++_1993)
      {
        {
          _1992 *= ((*shape)(_1993));
        }
      }
      int _1994 = (int)1;
      int _1995 = _1992;
      int _1996 = safe_mul( _1995,_1991 );
      int _1997 = safe_mul( _1996,_1989 );
      int _1998 = safe_mul( _1997,_1988 );
      int _1999 = (int)0;
      int _9503 = (int)0;
      int _9504 = (int)((sparsity)->size(0));
      for (int _2000 = _9503; _2000 < _9504; ++_2000)
      {
        {
          if ((((((*sparsity)(_2000)) / _1997) % _1988) >= ((((*sparsity)(_2000)) / _1995) % _1991)))
          {
            {
              ++ _1999;
            }
          }
          {}
        }
      }
      int _2001 = (int)1;
      int _2002 = _1992;
      int _2003 = safe_mul( _2002,_1989 );
      int _2004 = (safe_mul( safe_mul( _2003,_1988 ),safe_add( _1988,(int)1 ) ) / (int)2);
      std::shared_ptr< monty::ndarray< long long,1 > > _2005 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1999)));
      _checked_ptr_1<long long> _ptr__2005(_2005 ? _2005->raw() : nullptr,_2005 ? _2005->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2006 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1999)));
      _checked_ptr_1<long long> _ptr__2006(_2006 ? _2006->raw() : nullptr,_2006 ? _2006->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2007 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1999)));
      _checked_ptr_1<long long> _ptr__2007(_2007 ? _2007->raw() : nullptr,_2007 ? _2007->size(0) : 0);
      int _2008 = (int)0;
      {
        int _9505 = (int)0;
        int _9506 = (int)((sparsity)->size(0));
        for (int _2009 = _9505; _2009 < _9506; ++_2009)
        {
          {
            if ((((((*sparsity)(_2009)) / _1997) % _1988) >= ((((*sparsity)(_2009)) / _1995) % _1991)))
            {
              {
                long long _2010 = (((*sparsity)(_2009)) / _1998);
                long long _2011 = ((((*sparsity)(_2009)) / _1997) % _1988);
                long long _2012 = ((((*sparsity)(_2009)) / _1996) % _1989);
                long long _2013 = ((((*sparsity)(_2009)) / _1995) % _1991);
                long long _2014 = ((((*sparsity)(_2009)) / _1994) % _1992);
                _ptr__2006[_2008] = ((*nativeidxs)(_2009));
                _ptr__2007[_2008] = safe_add( safe_add( safe_add( safe_mul( _2004,_2010 ),safe_mul( _2003,safe_add( (safe_mul( _2011,safe_add( _2011,(int)1 ) ) / (int)2),_2013 ) ) ),safe_mul( _2002,_2012 ) ),safe_mul( _2001,_2014 ) );
                ++ _2008;
              }
            }
            {}
          }
        }
        int _9507 = (int)0;
        int _9508 = _1999;
        for (int _2015 = _9507; _2015 < _9508; ++_2015)
        {
          {
            _ptr__2005[_2015] = _2015;
          }
        }
      }
      ::mosek::fusion::p_CommonTools::argQsort(_2005,_2006,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_1999));
      std::shared_ptr< monty::ndarray< long long,1 > > _2016 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1999)));
      _checked_ptr_1<long long> _ptr__2016(_2016 ? _2016->raw() : nullptr,_2016 ? _2016->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2017 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_1999)));
      _checked_ptr_1<long long> _ptr__2017(_2017 ? _2017->raw() : nullptr,_2017 ? _2017->size(0) : 0);
      int _9509 = (int)0;
      int _9510 = _1999;
      for (int _2018 = _9509; _2018 < _9510; ++_2018)
      {
        {
          _ptr__2016[_2018] = _ptr__2006[_ptr__2005[_2018]];
        }
      }
      int _9511 = (int)0;
      int _9512 = _1999;
      for (int _2019 = _9511; _2019 < _9512; ++_2019)
      {
        {
          _ptr__2017[_2019] = _ptr__2007[_ptr__2005[_2019]];
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_1967,_2017,_2016)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__tril() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__tril(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::tril() { return __mosek_2fusion_2BaseVariable__tril(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__tril() { return __mosek_2fusion_2BaseVariable__tril(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__tril(){
  return _pubthis->__mosek_2fusion_2BaseVariable__tril((int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _2020,int _2021,int _2022) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_2020,_2021,_2022); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _2020,int _2021,int _2022) { return __mosek_2fusion_2BaseVariable__reshape(_2020,_2021,_2022); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _2020,int _2021,int _2022) { return __mosek_2fusion_2BaseVariable__reshape(_2020,_2021,_2022); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _2020,int _2021,int _2022){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2020),(int)(_2021),(int)(_2022)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _2023,int _2024) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_2023,_2024); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _2023,int _2024) { return __mosek_2fusion_2BaseVariable__reshape(_2023,_2024); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _2023,int _2024) { return __mosek_2fusion_2BaseVariable__reshape(_2023,_2024); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _2023,int _2024){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2023),(int)(_2024)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(int _2025) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_2025); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(int _2025) { return __mosek_2fusion_2BaseVariable__reshape(_2025); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(int _2025) { return __mosek_2fusion_2BaseVariable__reshape(_2025); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(int _2025){
  return _pubthis->__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2025)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _2026) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__reshape(_2026); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _2026) { return __mosek_2fusion_2BaseVariable__reshape(_2026); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _2026) { return __mosek_2fusion_2BaseVariable__reshape(_2026); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _2026){
  _checked_ptr_1<int> _ptr__2026(_2026 ? _2026->raw() : nullptr, _2026 ? _2026->size(0) : 0);
  long long _2027 = (int)1;
  int _9513 = (int)0;
  int _9514 = (int)((_2026)->size(0));
  for (int _2028 = _9513; _2028 < _9514; ++_2028)
  {
    {
      if ((_ptr__2026[_2028] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
      _2027 *= _ptr__2026[_2028];
    }
  }
  if ((_2027 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Shape size does not match variable size"));
    }
  }
  {}
  std::vector<int> _9515;
  for (int _2029 = (int)0, _9516 = (int)((_2026)->size(0)); _2029 < _9516 ; ++_2029)
  {
    _9515.push_back(_ptr__2026[_2029]);
  }
  auto _9517 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9515.size()),_9515.begin(),_9515.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_9517,sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
}
void mosek::fusion::BaseVariable :: setLevel(std::shared_ptr< monty::ndarray< double,1 > > _2030) { mosek::fusion::p_BaseVariable::_get_impl(this)->setLevel(_2030); }void mosek::fusion::p_BaseVariable::setLevel(std::shared_ptr< monty::ndarray< double,1 > > _2030){
  _checked_ptr_1<double> _ptr__2030(_2030 ? _2030->raw() : nullptr, _2030 ? _2030->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      if (((int)((_2030)->size(0)) != (int)((nativeidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      model->setVariableValues(true,nativeidxs,_2030);
    }
  }
  else
  {
    {
      if (((int)((_2030)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid length of solution values vector"));
        }
      }
      {}
      std::vector<double> _9518;
      for (int _2032 = (int)0, _9519 = (int)((nativeidxs)->size(0)); _2032 < _9519 ; ++_2032)
      {
        _9518.push_back(_ptr__2030[((*sparsity)(_2032))]);
      }
      auto _9520 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_9518.size()),_9518.begin(),_9518.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _2031 = _9520;
      _checked_ptr_1<double> _ptr__2031(_2031 ? _2031->raw() : nullptr,_2031 ? _2031->size(0) : 0);
      model->setVariableValues(true,nativeidxs,_2031);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__getModel() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__getModel(){
  return model;
}
int mosek::fusion::BaseVariable :: getND() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getND(); }int mosek::fusion::p_BaseVariable::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseVariable :: getDim(int _2033) { return mosek::fusion::p_BaseVariable::_get_impl(this)->getDim(_2033); }int mosek::fusion::p_BaseVariable::getDim(int _2033){
  return ((*shape)(_2033));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseVariable :: getShape() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseVariable::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
long long mosek::fusion::BaseVariable :: getSize() { return mosek::fusion::p_BaseVariable::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseVariable::getSize(){
  long long _2034 = (long long)1;
  int _9521 = (int)0;
  int _9522 = (int)((shape)->size(0));
  for (int _2035 = _9521; _2035 < _9522; ++_2035)
  {
    {
      _2034 *= ((*shape)(_2035));
    }
  }
  return _2034;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: dual() { return mosek::fusion::p_BaseVariable::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2036 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2036(_2036 ? _2036->raw() : nullptr,_2036 ? _2036->size(0) : 0);
  model->getVariableValues(false,nativeidxs,_2036,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _2037 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__2037(_2037 ? _2037->raw() : nullptr,_2037 ? _2037->size(0) : 0);
      int _9523 = (int)0;
      int _9524 = (int)((nativeidxs)->size(0));
      for (int _2038 = _9523; _2038 < _9524; ++_2038)
      {
        {
          _ptr__2037[((*sparsity)(_2038))] = _ptr__2036[_2038];
        }
      }
      _2036 = _2037;
      _ptr__2036.update(_2036 ? _2036->raw() : nullptr, _2036 ? _2036->size(0) : 0);
    }
  }
  {}
  return _2036;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BaseVariable :: level() { return mosek::fusion::p_BaseVariable::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BaseVariable::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2039 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2039(_2039 ? _2039->raw() : nullptr,_2039 ? _2039->size(0) : 0);
  model->getVariableValues(true,nativeidxs,_2039,(int)0);
  if ((NULL != sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _2040 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<double> _ptr__2040(_2040 ? _2040->raw() : nullptr,_2040 ? _2040->size(0) : 0);
      int _9525 = (int)0;
      int _9526 = (int)((nativeidxs)->size(0));
      for (int _2041 = _9525; _2041 < _9526; ++_2041)
      {
        {
          _ptr__2040[((*sparsity)(_2041))] = _ptr__2039[_2041];
        }
      }
      _2039 = _2040;
      _ptr__2039.update(_2039 ? _2039->raw() : nullptr, _2039 ? _2039->size(0) : 0);
    }
  }
  {}
  return _2039;
}
void mosek::fusion::BaseVariable :: makeContinuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeContinuous(); }void mosek::fusion::p_BaseVariable::makeContinuous(){
  _pubthis->make_continuous();
}
void mosek::fusion::BaseVariable :: makeInteger() { mosek::fusion::p_BaseVariable::_get_impl(this)->makeInteger(); }void mosek::fusion::p_BaseVariable::makeInteger(){
  _pubthis->make_integer();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__transpose() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__transpose(){
  if (((int)((shape)->size(0)) == (int)1))
  {
    {
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(((*shape)((int)0)))}),sparsity,nativeidxs)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((shape)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid shape for operation"));
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2042 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      _checked_ptr_1<long long> _ptr__2042(_2042 ? _2042->raw() : nullptr,_2042 ? _2042->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _9527;
      bool _9528 = (NULL == sparsity.get());
      if (_9528)
      {
        _9527 = nullptr;
      }
      else
      {
        _9527 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((nativeidxs)->size(0)))));
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2043 = _9527;
      _checked_ptr_1<long long> _ptr__2043(_2043 ? _2043->raw() : nullptr,_2043 ? _2043->size(0) : 0);
      if ((NULL == sparsity.get()))
      {
        {
          int _2044 = (int)0;
          int _9529 = (int)0;
          int _9530 = ((*shape)((int)1));
          for (int _2045 = _9529; _2045 < _9530; ++_2045)
          {
            {
              int _9531 = (int)0;
              int _9532 = ((*shape)((int)0));
              for (int _2046 = _9531; _2046 < _9532; ++_2046)
              {
                {
                  _ptr__2042[_2044] = ((*nativeidxs)(safe_add( safe_mul( _2046,((*shape)((int)1)) ),_2045 )));
                  ++ _2044;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2047 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( ((*shape)((int)1)),(int)1 ))));
          _checked_ptr_1<int> _ptr__2047(_2047 ? _2047->raw() : nullptr,_2047 ? _2047->size(0) : 0);
          int _2048 = ((*shape)((int)0));
          int _2049 = ((*shape)((int)1));
          int _9533 = (int)0;
          int _9534 = (int)((sparsity)->size(0));
          for (int _2050 = _9533; _2050 < _9534; ++_2050)
          {
            {
              ++ _ptr__2047[safe_add( (((*sparsity)(_2050)) % _2049),(int)1 )];
            }
          }
          int _9535 = (int)0;
          int _9536 = _2049;
          for (int _2051 = _9535; _2051 < _9536; ++_2051)
          {
            {
              _ptr__2047[safe_add( _2051,(int)1 )] += _ptr__2047[_2051];
            }
          }
          int _9537 = (int)0;
          int _9538 = (int)((sparsity)->size(0));
          for (int _2052 = _9537; _2052 < _9538; ++_2052)
          {
            {
              long long _2053 = (((*sparsity)(_2052)) % _2049);
              _ptr__2042[_ptr__2047[_2053]] = ((*nativeidxs)(_2052));
              _ptr__2043[_ptr__2047[_2053]] = safe_add( (((*sparsity)(_2052)) / _2049),safe_mul( (((*sparsity)(_2052)) % _2049),_2048 ) );
              ++ _ptr__2047[_2053];
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*shape)((int)1))),(int)(((*shape)((int)0)))}),_2043,_2042)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _2054,int _2055,int _2056) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_2054,_2055,_2056); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _2054,int _2055,int _2056) { return __mosek_2fusion_2BaseVariable__index(_2054,_2055,_2056); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _2054,int _2055,int _2056) { return __mosek_2fusion_2BaseVariable__index(_2054,_2055,_2056); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _2054,int _2055,int _2056){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2054),(int)(_2055),(int)(_2056)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _2057,int _2058) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_2057,_2058); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _2057,int _2058) { return __mosek_2fusion_2BaseVariable__index(_2057,_2058); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _2057,int _2058) { return __mosek_2fusion_2BaseVariable__index(_2057,_2058); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _2057,int _2058){
  return _pubthis->__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2057),(int)(_2058)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _2059) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_2059); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(std::shared_ptr< monty::ndarray< int,1 > > _2059) { return __mosek_2fusion_2BaseVariable__index(_2059); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _2059) { return __mosek_2fusion_2BaseVariable__index(_2059); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _2059){
  _checked_ptr_1<int> _ptr__2059(_2059 ? _2059->raw() : nullptr, _2059 ? _2059->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _2060 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_2059)->size(0)))));
  int _9539 = (int)0;
  int _9540 = (int)((_2059)->size(0));
  for (int _2061 = _9539; _2061 < _9540; ++_2061)
  {
    {
      ((*_2060)((int)0,_2061)) = _ptr__2059[_2061];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_2060)->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__index(int _2062) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__index(_2062); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::index(int _2062) { return __mosek_2fusion_2BaseVariable__index(_2062); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__index(int _2062) { return __mosek_2fusion_2BaseVariable__index(_2062); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__index(int _2062){
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2062)}))->__mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2063,std::shared_ptr< monty::ndarray< int,1 > > _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_2063,_2064,_2065); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _2063,std::shared_ptr< monty::ndarray< int,1 > > _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065) { return __mosek_2fusion_2BaseVariable__pick(_2063,_2064,_2065); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2063,std::shared_ptr< monty::ndarray< int,1 > > _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065) { return __mosek_2fusion_2BaseVariable__pick(_2063,_2064,_2065); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2063,std::shared_ptr< monty::ndarray< int,1 > > _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065){
  _checked_ptr_1<int> _ptr__2063(_2063 ? _2063->raw() : nullptr, _2063 ? _2063->size(0) : 0);
  _checked_ptr_1<int> _ptr__2064(_2064 ? _2064->raw() : nullptr, _2064 ? _2064->size(0) : 0);
  _checked_ptr_1<int> _ptr__2065(_2065 ? _2065->raw() : nullptr, _2065 ? _2065->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)3))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((((int)((_2063)->size(0)) != (int)((_2064)->size(0))) || ((int)((_2063)->size(0)) != (int)((_2065)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching argument lengths"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _2066 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2063)->size(0)),(int)3)));
  int _9541 = (int)0;
  int _9542 = (int)((_2063)->size(0));
  for (int _2067 = _9541; _2067 < _9542; ++_2067)
  {
    {
      ((*_2066)(_2067,(int)0)) = _ptr__2063[_2067];
      ((*_2066)(_2067,(int)1)) = _ptr__2064[_2067];
      ((*_2066)(_2067,(int)2)) = _ptr__2065[_2067];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_2066);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_2068,_2069); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069) { return __mosek_2fusion_2BaseVariable__pick(_2068,_2069); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069) { return __mosek_2fusion_2BaseVariable__pick(_2068,_2069); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069){
  _checked_ptr_1<int> _ptr__2068(_2068 ? _2068->raw() : nullptr, _2068 ? _2068->size(0) : 0);
  _checked_ptr_1<int> _ptr__2069(_2069 ? _2069->raw() : nullptr, _2069 ? _2069->size(0) : 0);
  if ((((int)((shape)->size(0)) != (int)2) || ((int)((_2068)->size(0)) != (int)((_2069)->size(0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,2 > > _2070 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2068)->size(0)),(int)2)));
  int _9543 = (int)0;
  int _9544 = (int)((_2068)->size(0));
  for (int _2071 = _9543; _2071 < _9544; ++_2071)
  {
    {
      ((*_2070)(_2071,(int)0)) = _ptr__2068[_2071];
      ((*_2070)(_2071,(int)1)) = _ptr__2069[_2071];
    }
  }
  return _pubthis->__mosek_2fusion_2BaseVariable__pick(_2070);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _2072) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_2072); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,2 > > _2072) { return __mosek_2fusion_2BaseVariable__pick(_2072); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _2072) { return __mosek_2fusion_2BaseVariable__pick(_2072); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _2072){
  if (((int)((shape)->size(0)) != (int)((_2072)->size(1))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  bool _2073 = false;
  int _9545 = (int)0;
  int _9546 = (int)((_2072)->size(0));
  for (int _2074 = _9545; _2074 < _9546; ++_2074)
  {
    {
      int _9547 = (int)0;
      int _9548 = (int)((_2072)->size(1));
      for (int _2075 = _9547; _2075 < _9548; ++_2075)
      {
        {
          if (((((*_2072)(_2074,_2075)) < (int)0) || (((*_2072)(_2074,_2075)) >= ((*shape)(_2075)))))
          {
            {
              _2073 = true;
            }
          }
          {}
        }
      }
    }
  }
  if (_2073)
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  int _2076 = (int)((shape)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2077 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2076)));
  _checked_ptr_1<long long> _ptr__2077(_2077 ? _2077->raw() : nullptr,_2077 ? _2077->size(0) : 0);
  _ptr__2077[(_2076 - (int)1)] = (int)1;
  int _9549 = (int)1;
  int _9550 = _2076;
  for (int _2078 = _9549; _2078 < _9550; ++_2078)
  {
    {
      _ptr__2077[((_2076 - _2078) - (int)1)] = safe_mul( _ptr__2077[(_2076 - _2078)],((*shape)((_2076 - _2078))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2079 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2072)->size(0)))});
  _checked_ptr_1<int> _ptr__2079(_2079 ? _2079->raw() : nullptr,_2079 ? _2079->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2080;
  _checked_ptr_1<long long> _ptr__2080(_2080 ? _2080->raw() : nullptr,_2080 ? _2080->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2081 = nullptr;
  _checked_ptr_1<long long> _ptr__2081(_2081 ? _2081->raw() : nullptr,_2081 ? _2081->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _2080 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_2072)->size(0)))));
      _ptr__2080.update(_2080 ? _2080->raw() : nullptr, _2080 ? _2080->size(0) : 0);
      {
        int _9551 = (int)0;
        int _9552 = (int)((_2072)->size(0));
        for (int _2082 = _9551; _2082 < _9552; ++_2082)
        {
          {
            long long _2083 = (long long)0;
            int _9553 = (int)0;
            int _9554 = _2076;
            for (int _2084 = _9553; _2084 < _9554; ++_2084)
            {
              {
                _2083 += safe_mul( _ptr__2077[_2084],((*_2072)(_2082,_2084)) );
              }
            }
            _ptr__2080[_2082] = ((*nativeidxs)(_2083));
          }
        }
      }
    }
  }
  else
  {
    {
      int _2085 = (int)0;
      int _9555 = (int)0;
      int _9556 = (int)((_2072)->size(0));
      for (int _2086 = _9555; _2086 < _9556; ++_2086)
      {
        {
          long long _2087 = (long long)0;
          int _9557 = (int)0;
          int _9558 = _2076;
          for (int _2088 = _9557; _2088 < _9558; ++_2088)
          {
            {
              _2087 += safe_mul( _ptr__2077[_2088],((*_2072)(_2086,_2088)) );
            }
          }
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,_2087) >= (int)0))
          {
            {
              ++ _2085;
            }
          }
          {}
        }
      }
      _2080 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2085)));
      _ptr__2080.update(_2080 ? _2080->raw() : nullptr, _2080 ? _2080->size(0) : 0);
      _2081 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2085)));
      _ptr__2081.update(_2081 ? _2081->raw() : nullptr, _2081 ? _2081->size(0) : 0);
      {
        int _2089 = (int)0;
        int _9559 = (int)0;
        int _9560 = (int)((_2072)->size(0));
        for (int _2090 = _9559; _2090 < _9560; ++_2090)
        {
          {
            long long _2091 = (long long)0;
            int _9561 = (int)0;
            int _9562 = _2076;
            for (int _2092 = _9561; _2092 < _9562; ++_2092)
            {
              {
                _2091 += safe_mul( _ptr__2077[_2092],((*_2072)(_2090,_2092)) );
              }
            }
            int _2093 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_2091);
            if ((_2093 >= (int)0))
            {
              {
                _ptr__2080[_2089] = ((*nativeidxs)(_2093));
                _ptr__2081[_2089] = _2090;
                ++ _2089;
              }
            }
            {}
          }
        }
      }
      if ((_2085 == (int)((_2072)->size(0))))
      {
        {
          _2081 = nullptr;
          _ptr__2081.update(_2081 ? _2081->raw() : nullptr, _2081 ? _2081->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_2079,_2081,_2080)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2094) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__pick(_2094); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::pick(std::shared_ptr< monty::ndarray< int,1 > > _2094) { return __mosek_2fusion_2BaseVariable__pick(_2094); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2094) { return __mosek_2fusion_2BaseVariable__pick(_2094); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2094){
  _checked_ptr_1<int> _ptr__2094(_2094 ? _2094->raw() : nullptr, _2094 ? _2094->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  bool _2095 = false;
  int _9563 = (int)0;
  int _9564 = (int)((_2094)->size(0));
  for (int _2096 = _9563; _2096 < _9564; ++_2096)
  {
    {
      if (((_ptr__2094[_2096] < (int)0) || (_ptr__2094[_2096] >= ((*shape)((int)0)))))
      {
        {
          _2095 = true;
        }
      }
      {}
    }
  }
  if (_2095)
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< long long,1 > > _2097;
  _checked_ptr_1<long long> _ptr__2097(_2097 ? _2097->raw() : nullptr,_2097 ? _2097->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2098 = nullptr;
  _checked_ptr_1<long long> _ptr__2098(_2098 ? _2098->raw() : nullptr,_2098 ? _2098->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      std::vector<long long> _9565;
      for (int _2099 = (int)0, _9566 = (int)((_2094)->size(0)); _2099 < _9566 ; ++_2099)
      {
        _9565.push_back(((*nativeidxs)(_ptr__2094[_2099])));
      }
      auto _9567 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9565.size()),_9565.begin(),_9565.end()));
      _2097 = _9567;
      _ptr__2097.update(_2097 ? _2097->raw() : nullptr, _2097 ? _2097->size(0) : 0);
    }
  }
  else
  {
    {
      int _2100 = (int)0;
      int _9568 = (int)0;
      int _9569 = (int)((_2094)->size(0));
      for (int _2101 = _9568; _2101 < _9569; ++_2101)
      {
        {
          if ((::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__2094[_2101])) >= (int)0))
          {
            {
              ++ _2100;
            }
          }
          {}
        }
      }
      _2097 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2100)));
      _ptr__2097.update(_2097 ? _2097->raw() : nullptr, _2097 ? _2097->size(0) : 0);
      _2098 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2100)));
      _ptr__2098.update(_2098 ? _2098->raw() : nullptr, _2098 ? _2098->size(0) : 0);
      int _2102 = (int)0;
      int _9570 = (int)0;
      int _9571 = (int)((_2094)->size(0));
      for (int _2103 = _9570; _2103 < _9571; ++_2103)
      {
        {
          int _2104 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,(long long)(_ptr__2094[_2103]));
          if ((_2104 >= (int)0))
          {
            {
              _ptr__2098[_2102] = _2103;
              _ptr__2097[_2102] = ((*nativeidxs)(_2104));
              ++ _2102;
            }
          }
          {}
        }
      }
      if ((_2100 == (int)((_2094)->size(0))))
      {
        {
          _2098 = nullptr;
          _ptr__2098.update(_2098 ? _2098->raw() : nullptr, _2098 ? _2098->size(0) : 0);
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2094)->size(0)))}),_2098,_2097)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag(int _2105) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(_2105); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag(int _2105) { return __mosek_2fusion_2BaseVariable__antidiag(_2105); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag(int _2105) { return __mosek_2fusion_2BaseVariable__antidiag(_2105); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(int _2105){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  else if(((_2105 >= ((*shape)((int)1))) || ((-_2105) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_2105 >= (int)0))
  {
    {
      int _9572;
      bool _9573 = (((*shape)((int)0)) < (((*shape)((int)1)) - _2105));
      if (_9573)
      {
        _9572 = ((*shape)((int)0));
      }
      else
      {
        _9572 = (((*shape)((int)1)) - _2105);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(((((*shape)((int)1)) - (int)1) - _2105))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_9572);
    }
  }
  else
  {
    {
      int _9574;
      bool _9575 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_2105 ));
      if (_9575)
      {
        _9574 = ((*shape)((int)1));
      }
      else
      {
        _9574 = safe_add( ((*shape)((int)0)),_2105 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_2105)),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_9574);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__antidiag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__antidiag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("antidiag() only works on two-dimensional objects"));
    }
  }
  {}
  int _9576;
  bool _9577 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_9577)
  {
    _9576 = ((*shape)((int)0));
  }
  else
  {
    _9576 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((((*shape)((int)1)) - (int)1))}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((-(int)1))}),_9576);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag(int _2106) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(_2106); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag(int _2106) { return __mosek_2fusion_2BaseVariable__diag(_2106); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag(int _2106) { return __mosek_2fusion_2BaseVariable__diag(_2106); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(int _2106){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  else if(((_2106 >= ((*shape)((int)1))) || ((-_2106) >= ((*shape)((int)2)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Diagonal index out of bounds"));
    }
  }
  {}
  if ((_2106 >= (int)0))
  {
    {
      int _9578;
      bool _9579 = (((*shape)((int)0)) < (((*shape)((int)1)) - _2106));
      if (_9579)
      {
        _9578 = ((*shape)((int)0));
      }
      else
      {
        _9578 = (((*shape)((int)1)) - _2106);
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)(_2106)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_9578);
    }
  }
  else
  {
    {
      int _9580;
      bool _9581 = (((*shape)((int)1)) < safe_add( ((*shape)((int)0)),_2106 ));
      if (_9581)
      {
        _9580 = ((*shape)((int)1));
      }
      else
      {
        _9580 = safe_add( ((*shape)((int)0)),_2106 );
      }
      return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((-_2106)),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_9580);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__diag() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::diag() { return __mosek_2fusion_2BaseVariable__diag(); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__diag(){
  if (((int)((shape)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("diag() only works on two-dimensional objects"));
    }
  }
  {}
  int _9582;
  bool _9583 = (((*shape)((int)0)) < ((*shape)((int)1)));
  if (_9583)
  {
    _9582 = ((*shape)((int)0));
  }
  else
  {
    _9582 = ((*shape)((int)1));
  }
  return __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1)}),_9582);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _2107,std::shared_ptr< monty::ndarray< int,1 > > _2108,int _2109){
  _checked_ptr_1<int> _ptr__2107(_2107 ? _2107->raw() : nullptr, _2107 ? _2107->size(0) : 0);
  _checked_ptr_1<int> _ptr__2108(_2108 ? _2108->raw() : nullptr, _2108 ? _2108->size(0) : 0);
  int _2110 = (int)((shape)->size(0));
  if (((_2110 != (int)((_2107)->size(0))) || (_2110 != (int)((_2108)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid start or step definition"));
    }
  }
  {}
  int _9584 = (int)0;
  int _9585 = _2110;
  for (int _2111 = _9584; _2111 < _9585; ++_2111)
  {
    {
      if (((_ptr__2107[_2111] < (int)0) || (_ptr__2107[_2111] >= ((*shape)(_2111)))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Start element is out of bounds"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _2112 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2110)));
  _checked_ptr_1<long long> _ptr__2112(_2112 ? _2112->raw() : nullptr,_2112 ? _2112->size(0) : 0);
  _ptr__2112[(_2110 - (int)1)] = (int)1;
  int _9586 = (int)1;
  int _9587 = _2110;
  for (int _2113 = _9586; _2113 < _9587; ++_2113)
  {
    {
      _ptr__2112[((_2110 - _2113) - (int)1)] = safe_mul( _ptr__2112[(_2110 - _2113)],((*shape)((_2110 - _2113))) );
    }
  }
  long long _2114 = (long long)0;
  int _9588 = (int)0;
  int _9589 = (int)((_2108)->size(0));
  for (int _2115 = _9588; _2115 < _9589; ++_2115)
  {
    {
      _2114 += safe_mul( _ptr__2107[_2115],_ptr__2112[_2115] );
    }
  }
  long long _2116 = (long long)0;
  int _9590 = (int)0;
  int _9591 = (int)((_2108)->size(0));
  for (int _2117 = _9590; _2117 < _9591; ++_2117)
  {
    {
      _2116 += safe_mul( _ptr__2108[_2117],_ptr__2112[_2117] );
    }
  }
  if ((NULL == sparsity.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2118 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2109)));
      _checked_ptr_1<long long> _ptr__2118(_2118 ? _2118->raw() : nullptr,_2118 ? _2118->size(0) : 0);
      int _9592 = (int)0;
      int _9593 = _2109;
      for (int _2119 = _9592; _2119 < _9593; ++_2119)
      {
        {
          _ptr__2118[_2119] = ((*nativeidxs)(safe_add( _2114,safe_mul( _2116,_2119 ) )));
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2109)}),nullptr,_2118)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _2120 = (int)0;
      int _9594 = (int)0;
      int _9595 = _2109;
      for (int _2121 = _9594; _2121 < _9595; ++_2121)
      {
        {
          long long _2122 = safe_add( _2114,safe_mul( _2116,_2121 ) );
          int _2123 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_2122);
          if ((_2123 >= (int)0))
          {
            {
              ++ _2120;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2124 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2120)));
      _checked_ptr_1<long long> _ptr__2124(_2124 ? _2124->raw() : nullptr,_2124 ? _2124->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2125 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2120)));
      _checked_ptr_1<long long> _ptr__2125(_2125 ? _2125->raw() : nullptr,_2125 ? _2125->size(0) : 0);
      int _2126 = (int)0;
      int _9596 = (int)0;
      int _9597 = _2109;
      for (int _2127 = _9596; _2127 < _9597; ++_2127)
      {
        {
          _ptr__2124[_2127] = ((*nativeidxs)(safe_add( _2114,safe_mul( _2116,_2127 ) )));
          long long _2128 = safe_add( _2114,safe_mul( _2116,_2127 ) );
          int _2129 = ::mosek::fusion::p_CommonTools::binarySearch(sparsity,_2128);
          if ((_2129 >= (int)0))
          {
            {
              _ptr__2125[_2126] = _2127;
              _ptr__2124[_2126] = ((*nativeidxs)(_2129));
              ++ _2126;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2109)}),_2125,_2124)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _2130,std::shared_ptr< monty::ndarray< int,1 > > _2131) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_2130,_2131); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(std::shared_ptr< monty::ndarray< int,1 > > _2130,std::shared_ptr< monty::ndarray< int,1 > > _2131) { return __mosek_2fusion_2BaseVariable__slice(_2130,_2131); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _2130,std::shared_ptr< monty::ndarray< int,1 > > _2131) { return __mosek_2fusion_2BaseVariable__slice(_2130,_2131); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _2130,std::shared_ptr< monty::ndarray< int,1 > > _2131){
  _checked_ptr_1<int> _ptr__2130(_2130 ? _2130->raw() : nullptr, _2130 ? _2130->size(0) : 0);
  _checked_ptr_1<int> _ptr__2131(_2131 ? _2131->raw() : nullptr, _2131 ? _2131->size(0) : 0);
  if (((int)((_2130)->size(0)) != (int)((_2131)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if(((int)((_2130)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _9598 = (int)0;
      int _9599 = (int)((shape)->size(0));
      for (int _2132 = _9598; _2132 < _9599; ++_2132)
      {
        {
          if (((_ptr__2130[_2132] < (int)0) || (_ptr__2131[_2132] > ((*shape)(_2132)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
            }
          }
          else if((_ptr__2130[_2132] > _ptr__2131[_2132]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
            }
          }
          {}
        }
      }
      int _2133 = (int)((shape)->size(0));
      std::vector<int> _9600;
      for (int _2135 = (int)0, _9601 = _2133; _2135 < _9601 ; ++_2135)
      {
        _9600.push_back((_ptr__2131[_2135] - _ptr__2130[_2135]));
      }
      auto _9602 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9600.size()),_9600.begin(),_9600.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2134 = _9602;
      _checked_ptr_1<int> _ptr__2134(_2134 ? _2134->raw() : nullptr,_2134 ? _2134->size(0) : 0);
      int _2136 = (int)1;
      int _9603 = (int)0;
      int _9604 = _2133;
      for (int _2137 = _9603; _2137 < _9604; ++_2137)
      {
        {
          _2136 *= (_ptr__2131[_2137] - _ptr__2130[_2137]);
        }
      }
      if ((_2136 == (int)0))
      {
        {
          return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
        }
      }
      else if((NULL != sparsity.get()))
      {
        {
          int _2138 = (int)0;
          std::shared_ptr< monty::ndarray< int,1 > > _2139 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2133)));
          _checked_ptr_1<int> _ptr__2139(_2139 ? _2139->raw() : nullptr,_2139 ? _2139->size(0) : 0);
          int _9605 = (int)0;
          int _9606 = (int)((sparsity)->size(0));
          for (int _2140 = _9605; _2140 < _9606; ++_2140)
          {
            {
              long long _2141 = ((*sparsity)(_2140));
              int _9607 = (int)1;
              int _9608 = _2133;
              for (int _2142 = _9607; _2142 < _9608; ++_2142)
              {
                {
                  _ptr__2139[(_2133 - _2142)] = (int)(_2141 % ((*shape)((_2133 - _2142))));
                  _2141 /= ((*shape)((_2133 - _2142)));
                }
              }
              _ptr__2139[(int)0] = (int)_2141;
              int _2143 = (int)0;
              while ( ((_ptr__2139[_2143] >= _ptr__2130[_2143]) && (_ptr__2139[_2143] < _ptr__2131[_2143])) )
              {
                {
                  ++ _2143;
                }
              }
              if ((_2143 == _2133))
              {
                {
                  ++ _2138;
                }
              }
              {}
            }
          }
          int _2144 = (int)0;
          std::shared_ptr< monty::ndarray< long long,1 > > _2145 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2138)));
          _checked_ptr_1<long long> _ptr__2145(_2145 ? _2145->raw() : nullptr,_2145 ? _2145->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _2146 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2138)));
          _checked_ptr_1<long long> _ptr__2146(_2146 ? _2146->raw() : nullptr,_2146 ? _2146->size(0) : 0);
          int _9609 = (int)0;
          int _9610 = (int)((sparsity)->size(0));
          for (int _2147 = _9609; _2147 < _9610; ++_2147)
          {
            {
              long long _2148 = ((*sparsity)(_2147));
              int _9611 = (int)1;
              int _9612 = _2133;
              for (int _2149 = _9611; _2149 < _9612; ++_2149)
              {
                {
                  _ptr__2139[(_2133 - _2149)] = (int)(_2148 % ((*shape)((_2133 - _2149))));
                  _2148 /= ((*shape)((_2133 - _2149)));
                }
              }
              _ptr__2139[(int)0] = (int)_2148;
              int _2150 = (int)0;
              while ( ((_ptr__2139[_2150] >= _ptr__2130[_2150]) && (_ptr__2139[_2150] < _ptr__2131[_2150])) )
              {
                {
                  ++ _2150;
                }
              }
              if ((_2150 == _2133))
              {
                {
                  _ptr__2145[_2144] = ((*nativeidxs)(_2147));
                  int _2151 = (int)0;
                  int _9613 = (int)0;
                  int _9614 = _2133;
                  for (int _2152 = _9613; _2152 < _9614; ++_2152)
                  {
                    {
                      _2151 = safe_add( safe_mul( _2151,_ptr__2134[_2152] ),(_ptr__2139[_2152] - _ptr__2130[_2152]) );
                    }
                  }
                  _ptr__2146[_2144] = _2151;
                  ++ _2144;
                }
              }
              {}
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_2134,_2146,_2145)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _2153 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2136)));
          _checked_ptr_1<long long> _ptr__2153(_2153 ? _2153->raw() : nullptr,_2153 ? _2153->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2154 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2133)));
            _checked_ptr_1<int> _ptr__2154(_2154 ? _2154->raw() : nullptr,_2154 ? _2154->size(0) : 0);
            _ptr__2154[(_2133 - (int)1)] = (int)1;
            int _9615 = (int)1;
            int _9616 = _2133;
            for (int _2155 = _9615; _2155 < _9616; ++_2155)
            {
              {
                _ptr__2154[((_2133 - _2155) - (int)1)] = safe_mul( _ptr__2154[(_2133 - _2155)],((*shape)((_2133 - _2155))) );
              }
            }
            int _2156 = (int)0;
            int _9617 = (int)0;
            int _9618 = _2133;
            for (int _2157 = _9617; _2157 < _9618; ++_2157)
            {
              {
                _2156 += safe_mul( _ptr__2130[_2157],_ptr__2154[_2157] );
              }
            }
            std::vector<int> _9619;
            for (int _2159 = (int)0, _9620 = _2133; _2159 < _9620 ; ++_2159)
            {
              _9619.push_back(_2156);
            }
            auto _9621 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9619.size()),_9619.begin(),_9619.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2158 = _9621;
            _checked_ptr_1<int> _ptr__2158(_2158 ? _2158->raw() : nullptr,_2158 ? _2158->size(0) : 0);
            std::vector<int> _9622;
            for (int _2161 = (int)0, _9623 = _2133; _2161 < _9623 ; ++_2161)
            {
              _9622.push_back(_ptr__2130[_2161]);
            }
            auto _9624 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9622.size()),_9622.begin(),_9622.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2160 = _9624;
            _checked_ptr_1<int> _ptr__2160(_2160 ? _2160->raw() : nullptr,_2160 ? _2160->size(0) : 0);
            int _9625 = (int)0;
            int _9626 = _2136;
            for (int _2162 = _9625; _2162 < _9626; ++_2162)
            {
              {
                _ptr__2153[_2162] = ((*nativeidxs)(_ptr__2158[(_2133 - (int)1)]));
                _ptr__2160[(_2133 - (int)1)] += (int)1;
                _ptr__2158[(_2133 - (int)1)] += _ptr__2154[(_2133 - (int)1)];
                if ((_ptr__2160[(_2133 - (int)1)] >= _ptr__2131[(_2133 - (int)1)]))
                {
                  {
                    int _2163 = (_2133 - (int)1);
                    while ( ((_2163 > (int)0) && (_ptr__2160[_2163] >= _ptr__2131[_2163])) )
                    {
                      {
                        _ptr__2160[_2163] = _ptr__2130[_2163];
                        _ptr__2160[(_2163 - (int)1)] += (int)1;
                        _ptr__2158[(_2163 - (int)1)] += _ptr__2154[(_2163 - (int)1)];
                        -- _2163;
                      }
                    }
                    int _9627 = safe_add( _2163,(int)1 );
                    int _9628 = _2133;
                    for (int _2164 = _9627; _2164 < _9628; ++_2164)
                    {
                      {
                        _ptr__2158[_2164] = _ptr__2158[_2163];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),_2134,nullptr,_2153)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__slice(int _2165,int _2166) { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__slice(_2165,_2166); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::slice(int _2165,int _2166) { return __mosek_2fusion_2BaseVariable__slice(_2165,_2166); }
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__slice(int _2165,int _2166) { return __mosek_2fusion_2BaseVariable__slice(_2165,_2166); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__slice(int _2165,int _2166){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2165 == (int)0) && (_2166 == ((*shape)((int)0)))))
  {
    {
      return (::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>();
    }
  }
  else if(((_2165 < (int)0) || (_2166 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2165 > _2166))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else if((_2165 == _2166))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((NULL != sparsity.get()))
  {
    {
      int _2167 = (_2166 - _2165);
      int _2168 = (int)0;
      int _2169 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_2165));
      int _2170 = ::mosek::fusion::p_CommonTools::binarySearchL(sparsity,(long long)(_2166));
      std::vector<long long> _9629;
      for (int _2171 = _2169, _9630 = _2170; _2171 < _9630 ; ++_2171)
      {
        _9629.push_back((((*sparsity)(_2171)) - _2165));
      }
      auto _9631 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9629.size()),_9629.begin(),_9629.end()));
      std::vector<long long> _9632;
      for (int _2172 = _2169, _9633 = _2170; _2172 < _9633 ; ++_2172)
      {
        _9632.push_back(((*nativeidxs)(_2172)));
      }
      auto _9634 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9632.size()),_9632.begin(),_9632.end()));
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2167)}),_9631,_9634)).as<::mosek::fusion::Variable>();
    }
  }
  else
  {
    {
      int _2173 = (_2166 - _2165);
      std::shared_ptr< monty::ndarray< long long,1 > > _2174 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2173)));
      _checked_ptr_1<long long> _ptr__2174(_2174 ? _2174->raw() : nullptr,_2174 ? _2174->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(nativeidxs,_2165,_2174,(int)0,_2173);
      return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_pubthis->__mosek_2fusion_2BaseVariable__getModel(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2173)}),nullptr,_2174)).as<::mosek::fusion::Variable>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable :: __mosek_2fusion_2BaseVariable__asExpr() { return mosek::fusion::p_BaseVariable::_get_impl(this)->__mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseVariable::__mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseVariable::__mosek_2fusion_2BaseVariable__asExpr(){
  return (::mosek::fusion::p_ExprFromVar::_new_ExprFromVar((::mosek::fusion::BaseVariable::t(_pubthis)).as<::mosek::fusion::Variable>())).as<::mosek::fusion::Expression>();
}
int mosek::fusion::BaseVariable :: inst(int _2175,std::shared_ptr< monty::ndarray< long long,1 > > _2176,int _2177,std::shared_ptr< monty::ndarray< long long,1 > > _2178) { return mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_2175,_2176,_2177,_2178); }int mosek::fusion::p_BaseVariable::inst(int _2175,std::shared_ptr< monty::ndarray< long long,1 > > _2176,int _2177,std::shared_ptr< monty::ndarray< long long,1 > > _2178){
  _checked_ptr_1<long long> _ptr__2176(_2176 ? _2176->raw() : nullptr, _2176 ? _2176->size(0) : 0);
  _checked_ptr_1<long long> _ptr__2178(_2178 ? _2178->raw() : nullptr, _2178 ? _2178->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2179 = mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs;
  _checked_ptr_1<long long> _ptr__2179(_2179 ? _2179->raw() : nullptr,_2179 ? _2179->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2180 = mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity;
  _checked_ptr_1<long long> _ptr__2180(_2180 ? _2180->raw() : nullptr,_2180 ? _2180->size(0) : 0);
  if ((NULL == _2180.get()))
  {
    {
      int _9635 = (int)0;
      int _9636 = (int)((_2179)->size(0));
      for (int _2181 = _9635; _2181 < _9636; ++_2181)
      {
        {
          _ptr__2176[safe_add( _2181,_2175 )] = _2181;
          _ptr__2178[safe_add( _2181,_2177 )] = _ptr__2179[_2181];
        }
      }
    }
  }
  else
  {
    {
      int _9637 = (int)0;
      int _9638 = (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->sparsity)->size(0));
      for (int _2182 = _9637; _2182 < _9638; ++_2182)
      {
        {
          _ptr__2176[safe_add( _2175,_2182 )] = _ptr__2180[_2182];
          _ptr__2178[safe_add( _2182,_2177 )] = _ptr__2179[_2182];
        }
      }
    }
  }
  return (int)((mosek::fusion::p_BaseVariable::_get_impl(::mosek::fusion::BaseVariable::t(_pubthis))->nativeidxs)->size(0));
}
int mosek::fusion::BaseVariable :: numInst() { return mosek::fusion::p_BaseVariable::_get_impl(this)->numInst(); }int mosek::fusion::p_BaseVariable::numInst(){
  return (int)((nativeidxs)->size(0));
}
void mosek::fusion::BaseVariable :: inst(int _2183,std::shared_ptr< monty::ndarray< long long,1 > > _2184) { mosek::fusion::p_BaseVariable::_get_impl(this)->inst(_2183,_2184); }void mosek::fusion::p_BaseVariable::inst(int _2183,std::shared_ptr< monty::ndarray< long long,1 > > _2184){
  _checked_ptr_1<long long> _ptr__2184(_2184 ? _2184->raw() : nullptr, _2184 ? _2184->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      int _9639 = (int)0;
      int _9640 = (int)((nativeidxs)->size(0));
      for (int _2185 = _9639; _2185 < _9640; ++_2185)
      {
        {
          _ptr__2184[safe_add( _2183,_2185 )] = ((*nativeidxs)(_2185));
        }
      }
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2186 = _pubthis->getShape();
      _checked_ptr_1<int> _ptr__2186(_2186 ? _2186->raw() : nullptr,_2186 ? _2186->size(0) : 0);
      int _2187 = (int)1;
      int _9641 = (int)0;
      int _9642 = (int)((_2186)->size(0));
      for (int _2188 = _9641; _2188 < _9642; ++_2188)
      {
        {
          _2187 *= _ptr__2186[_2188];
        }
      }
      int _9643 = (int)0;
      int _9644 = _2187;
      for (int _2189 = _9643; _2189 < _9644; ++_2189)
      {
        {
          _ptr__2184[safe_add( _2183,_2189 )] = (int)0;
        }
      }
      int _9645 = (int)0;
      int _9646 = (int)((sparsity)->size(0));
      for (int _2190 = _9645; _2190 < _9646; ++_2190)
      {
        {
          _ptr__2184[safe_add( _2183,((*sparsity)(_2190)) )] = ((*nativeidxs)(_2190));
        }
      }
    }
  }
}
void mosek::fusion::BaseVariable :: set_values(std::shared_ptr< monty::ndarray< double,1 > > _2191,bool _2192) { mosek::fusion::p_BaseVariable::_get_impl(this)->set_values(_2191,_2192); }void mosek::fusion::p_BaseVariable::set_values(std::shared_ptr< monty::ndarray< double,1 > > _2191,bool _2192){
  _checked_ptr_1<double> _ptr__2191(_2191 ? _2191->raw() : nullptr, _2191 ? _2191->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_2192,nativeidxs,_2191);
    }
  }
  else
  {
    {
      int _2193 = (int)1;
      int _9647 = (int)0;
      int _9648 = (int)((shape)->size(0));
      for (int _2194 = _9647; _2194 < _9648; ++_2194)
      {
        {
          _2193 *= ((*shape)(_2194));
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2195 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2193)));
      _checked_ptr_1<long long> _ptr__2195(_2195 ? _2195->raw() : nullptr,_2195 ? _2195->size(0) : 0);
      int _9649 = (int)0;
      int _9650 = (int)((nativeidxs)->size(0));
      for (int _2196 = _9649; _2196 < _9650; ++_2196)
      {
        {
          _ptr__2195[((*sparsity)(_2196))] = ((*nativeidxs)(_2196));
        }
      }
      _pubthis->__mosek_2fusion_2BaseVariable__getModel()->setVariableValues(_2192,_2195,_2191);
    }
  }
}
void mosek::fusion::p_BaseVariable::dual_lu(int _2197,std::shared_ptr< monty::ndarray< double,1 > > _2198,bool _2199){
  _checked_ptr_1<double> _ptr__2198(_2198 ? _2198->raw() : nullptr, _2198 ? _2198->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableDuals(_2199,nativeidxs,_2198,_2197);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2200 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__2200(_2200 ? _2200->raw() : nullptr,_2200 ? _2200->size(0) : 0);
      int _9651 = (int)0;
      int _9652 = (int)((sparsity)->size(0));
      for (int _2201 = _9651; _2201 < _9652; ++_2201)
      {
        {
          _ptr__2200[((*sparsity)(_2201))] = ((*nativeidxs)(_2201));
        }
      }
      model->getVariableDuals(_2199,_2200,_2198,_2197);
    }
  }
}
void mosek::fusion::BaseVariable :: values(int _2202,std::shared_ptr< monty::ndarray< double,1 > > _2203,bool _2204) { mosek::fusion::p_BaseVariable::_get_impl(this)->values(_2202,_2203,_2204); }void mosek::fusion::p_BaseVariable::values(int _2202,std::shared_ptr< monty::ndarray< double,1 > > _2203,bool _2204){
  _checked_ptr_1<double> _ptr__2203(_2203 ? _2203->raw() : nullptr, _2203 ? _2203->size(0) : 0);
  if ((NULL == sparsity.get()))
  {
    {
      model->getVariableValues(_2204,nativeidxs,_2203,_2202);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2205 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_pubthis->getSize())));
      _checked_ptr_1<long long> _ptr__2205(_2205 ? _2205->raw() : nullptr,_2205 ? _2205->size(0) : 0);
      int _9653 = (int)0;
      int _9654 = (int)((sparsity)->size(0));
      for (int _2206 = _9653; _2206 < _9654; ++_2206)
      {
        {
          _ptr__2205[((*sparsity)(_2206))] = ((*nativeidxs)(_2206));
        }
      }
      model->getVariableValues(_2204,_2205,_2203,_2202);
    }
  }
}
void mosek::fusion::BaseVariable :: make_continuous() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_continuous(); }void mosek::fusion::p_BaseVariable::make_continuous(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_continuous(nativeidxs);
}
void mosek::fusion::BaseVariable :: make_integer() { mosek::fusion::p_BaseVariable::_get_impl(this)->make_integer(); }void mosek::fusion::p_BaseVariable::make_integer(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2BaseVariable__getModel().get())->make_integer(nativeidxs);
}
void mosek::fusion::p_BaseVariable::destroy(){sparsity.reset();nativeidxs.reset();model.reset();shape.reset();}void mosek::fusion::BaseVariable::destroy() { mosek::fusion::p_BaseVariable::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Variable::getModel() { return __mosek_2fusion_2Variable__getModel(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::fromTril(int _2214) { return __mosek_2fusion_2Variable__fromTril(_2214); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::tril() { return __mosek_2fusion_2Variable__tril(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _2215,int _2216,int _2217) { return __mosek_2fusion_2Variable__reshape(_2215,_2216,_2217); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _2218,int _2219) { return __mosek_2fusion_2Variable__reshape(_2218,_2219); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(int _2220) { return __mosek_2fusion_2Variable__reshape(_2220); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::reshape(std::shared_ptr< monty::ndarray< int,1 > > _2221) { return __mosek_2fusion_2Variable__reshape(_2221); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::transpose() { return __mosek_2fusion_2Variable__transpose(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _2227,std::shared_ptr< monty::ndarray< int,1 > > _2228,std::shared_ptr< monty::ndarray< int,1 > > _2229) { return __mosek_2fusion_2Variable__pick(_2227,_2228,_2229); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _2230,std::shared_ptr< monty::ndarray< int,1 > > _2231) { return __mosek_2fusion_2Variable__pick(_2230,_2231); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _2232) { return __mosek_2fusion_2Variable__pick(_2232); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,2 > > _2232) { return __mosek_2fusion_2Variable__pick(_2232); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _2233) { return __mosek_2fusion_2Variable__pick(_2233); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::pick(std::shared_ptr< monty::ndarray< int,1 > > _2233) { return __mosek_2fusion_2Variable__pick(_2233); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag() { return __mosek_2fusion_2Variable__antidiag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::antidiag(int _2234) { return __mosek_2fusion_2Variable__antidiag(_2234); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag() { return __mosek_2fusion_2Variable__diag(); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::diag(int _2235) { return __mosek_2fusion_2Variable__diag(_2235); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _2236) { return __mosek_2fusion_2Variable__index(_2236); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(std::shared_ptr< monty::ndarray< int,1 > > _2236) { return __mosek_2fusion_2Variable__index(_2236); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _2237,int _2238,int _2239) { return __mosek_2fusion_2Variable__index(_2237,_2238,_2239); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _2240,int _2241) { return __mosek_2fusion_2Variable__index(_2240,_2241); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__index(int _2242) { return __mosek_2fusion_2Variable__index(_2242); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::index(int _2242) { return __mosek_2fusion_2Variable__index(_2242); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _2243,std::shared_ptr< monty::ndarray< int,1 > > _2244) { return __mosek_2fusion_2Variable__slice(_2243,_2244); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(std::shared_ptr< monty::ndarray< int,1 > > _2243,std::shared_ptr< monty::ndarray< int,1 > > _2244) { return __mosek_2fusion_2Variable__slice(_2243,_2244); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::__mosek_2fusion_2Expression__slice(int _2245,int _2246) { return __mosek_2fusion_2Variable__slice(_2245,_2246); }
monty::rc_ptr< mosek::fusion::Variable > mosek::fusion::Variable::slice(int _2245,int _2246) { return __mosek_2fusion_2Variable__slice(_2245,_2246); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Variable::asExpr() { return __mosek_2fusion_2Variable__asExpr(); }
mosek::fusion::Var::Var(mosek::fusion::p_Var *_impl) : _impl(_impl) { /*std::cout << "Var() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Var::~Var() { delete _impl; _impl = nullptr; }mosek::fusion::p_Var::p_Var  (::mosek::fusion::Var * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::empty  ( std::shared_ptr< monty::ndarray< int,1 > > _2247) { return mosek::fusion::p_Var::empty(_2247); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::empty(std::shared_ptr< monty::ndarray< int,1 > > _2247){
  _checked_ptr_1<int> _ptr__2247(_2247 ? _2247->raw() : nullptr, _2247 ? _2247->size(0) : 0);
  int _9655 = (int)0;
  int _9656 = (int)((_2247)->size(0));
  for (int _2248 = _9655; _2248 < _9656; ++_2248)
  {
    {
      if ((_ptr__2247[_2248] < (int)0))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid shape"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_NilVariable::_new_NilVariable(_2247)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::compress  ( monty::rc_ptr< ::mosek::fusion::Variable > _2249) { return mosek::fusion::p_Var::compress(_2249); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::compress(monty::rc_ptr< ::mosek::fusion::Variable > _2249){
  std::shared_ptr< monty::ndarray< int,1 > > _2250 = _2249->getShape();
  _checked_ptr_1<int> _ptr__2250(_2250 ? _2250->raw() : nullptr,_2250 ? _2250->size(0) : 0);
  int _2251 = (int)((_2250)->size(0));
  int _2252 = (int)0;
  int _9657 = (int)0;
  int _9658 = _2251;
  for (int _2253 = _9657; _2253 < _9658; ++_2253)
  {
    {
      if ((_ptr__2250[_2253] != (int)1))
      {
        {
          ++ _2252;
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2254 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2252)));
  _checked_ptr_1<int> _ptr__2254(_2254 ? _2254->raw() : nullptr,_2254 ? _2254->size(0) : 0);
  {
    int _2255 = (int)0;
    int _9659 = (int)0;
    int _9660 = _2251;
    for (int _2256 = _9659; _2256 < _9660; ++_2256)
    {
      {
        if ((_ptr__2250[_2256] != (int)1))
        {
          {
            _ptr__2254[_2255] = _ptr__2250[_2256];
            ++ _2255;
          }
        }
        {}
      }
    }
  }
  return ::mosek::fusion::p_Var::reshape(_2249,_2254);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _2257,    int _2258) { return mosek::fusion::p_Var::reshape(_2257,_2258); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _2257,int _2258){
  return ::mosek::fusion::p_Var::reshape(_2257,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2258)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _2259,    int _2260,    int _2261) { return mosek::fusion::p_Var::reshape(_2259,_2260,_2261); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _2259,int _2260,int _2261){
  return ::mosek::fusion::p_Var::reshape(_2259,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2260),(int)(_2261)}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::flatten  ( monty::rc_ptr< ::mosek::fusion::Variable > _2262) { return mosek::fusion::p_Var::flatten(_2262); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::flatten(monty::rc_ptr< ::mosek::fusion::Variable > _2262){
  return ::mosek::fusion::p_Var::reshape(_2262,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)::mosek::fusion::p_Set::size(_2262->getShape()))}));
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::reshape  ( monty::rc_ptr< ::mosek::fusion::Variable > _2263,    std::shared_ptr< monty::ndarray< int,1 > > _2264) { return mosek::fusion::p_Var::reshape(_2263,_2264); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::reshape(monty::rc_ptr< ::mosek::fusion::Variable > _2263,std::shared_ptr< monty::ndarray< int,1 > > _2264){
  _checked_ptr_1<int> _ptr__2264(_2264 ? _2264->raw() : nullptr, _2264 ? _2264->size(0) : 0);
  return _2263->__mosek_2fusion_2Variable__reshape(_2264);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _2265,std::shared_ptr< monty::ndarray< int,1 > > _2266){
  _checked_ptr_1<int> _ptr__2266(_2266 ? _2266->raw() : nullptr, _2266 ? _2266->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2267;
  _checked_ptr_1<long long> _ptr__2267(_2267 ? _2267->raw() : nullptr,_2267 ? _2267->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2268;
  _checked_ptr_1<long long> _ptr__2268(_2268 ? _2268->raw() : nullptr,_2268 ? _2268->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2269 = _2265->getShape();
  _checked_ptr_1<int> _ptr__2269(_2269 ? _2269->raw() : nullptr,_2269 ? _2269->size(0) : 0);
  int _2270 = (int)((_2269)->size(0));
  int _2271 = (int)1;
  int _9661 = (int)0;
  int _9662 = _2270;
  for (int _2272 = _9661; _2272 < _9662; ++_2272)
  {
    {
      _2271 *= _ptr__2269[_2272];
    }
  }
  int _2273 = _2265->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2274 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2270)));
  _checked_ptr_1<long long> _ptr__2274(_2274 ? _2274->raw() : nullptr,_2274 ? _2274->size(0) : 0);
  _ptr__2274[(_2270 - (int)1)] = (int)1;
  int _9663 = (int)1;
  int _9664 = _2270;
  for (int _2275 = _9663; _2275 < _9664; ++_2275)
  {
    {
      _ptr__2274[((_2270 - _2275) - (int)1)] = safe_mul( _ptr__2274[(_2270 - _2275)],_ptr__2269[_ptr__2266[(_2270 - _2275)]] );
    }
  }
  if ((_2273 < _2271))
  {
    {
      _2267 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2273)));
      _ptr__2267.update(_2267 ? _2267->raw() : nullptr, _2267 ? _2267->size(0) : 0);
      _2268 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2273)));
      _ptr__2268.update(_2268 ? _2268->raw() : nullptr, _2268 ? _2268->size(0) : 0);
      _2265->inst((int)0,_2267,(int)0,_2268);
    }
  }
  else
  {
    {
      _2267 = nullptr;
      _ptr__2267.update(_2267 ? _2267->raw() : nullptr, _2267 ? _2267->size(0) : 0);
      _2268 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2273)));
      _ptr__2268.update(_2268 ? _2268->raw() : nullptr, _2268 ? _2268->size(0) : 0);
      _2265->inst((int)0,_2268);
    }
  }
  if ((NULL == _2267.get()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2276 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2273)));
      _checked_ptr_1<long long> _ptr__2276(_2276 ? _2276->raw() : nullptr,_2276 ? _2276->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _2277 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2270)));
        _checked_ptr_1<int> _ptr__2277(_2277 ? _2277->raw() : nullptr,_2277 ? _2277->size(0) : 0);
        int _9665 = (int)0;
        int _9666 = _2273;
        for (int _2278 = _9665; _2278 < _9666; ++_2278)
        {
          {
            int _2279 = _2278;
            int _9667 = (int)0;
            int _9668 = _2270;
            for (int _2280 = _9667; _2280 < _9668; ++_2280)
            {
              {
                _ptr__2277[((_2270 - _2278) - (int)1)] = (_2279 % _ptr__2269[((_2270 - _2278) - (int)1)]);
                _2279 /= _ptr__2269[((_2270 - _2278) - (int)1)];
              }
            }
            int _2281 = (int)0;
            int _9669 = (int)0;
            int _9670 = _2270;
            for (int _2282 = _9669; _2282 < _9670; ++_2282)
            {
              {
                _2281 += (int)safe_mul( _ptr__2277[_ptr__2266[_2282]],_ptr__2274[_2282] );
              }
            }
            _ptr__2276[_2281] = _ptr__2268[_2278];
          }
        }
      }
      _2268 = _2276;
      _ptr__2268.update(_2268 ? _2268->raw() : nullptr, _2268 ? _2268->size(0) : 0);
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2283 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2273)));
      _checked_ptr_1<long long> _ptr__2283(_2283 ? _2283->raw() : nullptr,_2283 ? _2283->size(0) : 0);
      {
        std::shared_ptr< monty::ndarray< int,1 > > _2284 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2270)));
        _checked_ptr_1<int> _ptr__2284(_2284 ? _2284->raw() : nullptr,_2284 ? _2284->size(0) : 0);
        int _9671 = (int)0;
        int _9672 = _2273;
        for (int _2285 = _9671; _2285 < _9672; ++_2285)
        {
          {
            int _2286 = _2285;
            int _9673 = (int)0;
            int _9674 = _2270;
            for (int _2287 = _9673; _2287 < _9674; ++_2287)
            {
              {
                _ptr__2284[((_2270 - _2285) - (int)1)] = (_2286 % _ptr__2269[((_2270 - _2285) - (int)1)]);
                _2286 /= _ptr__2269[((_2270 - _2285) - (int)1)];
              }
            }
            int _2288 = (int)0;
            int _9675 = (int)0;
            int _9676 = _2270;
            for (int _2289 = _9675; _2289 < _9676; ++_2289)
            {
              {
                _2288 += (int)safe_mul( _ptr__2284[_ptr__2266[_2289]],_ptr__2274[_2289] );
              }
            }
            _ptr__2283[_2285] = _2288;
          }
        }
      }
      std::vector<long long> _9677;
      for (int _2291 = (int)0, _9678 = _2273; _2291 < _9678 ; ++_2291)
      {
        _9677.push_back(_2291);
      }
      auto _9679 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9677.size()),_9677.begin(),_9677.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _2290 = _9679;
      _checked_ptr_1<long long> _ptr__2290(_2290 ? _2290->raw() : nullptr,_2290 ? _2290->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2290,_2283,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2273));
      std::vector<long long> _9680;
      for (int _2292 = (int)0, _9681 = _2273; _2292 < _9681 ; ++_2292)
      {
        _9680.push_back(_ptr__2267[_ptr__2290[_2292]]);
      }
      auto _9682 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9680.size()),_9680.begin(),_9680.end()));
      _2267 = _9682;
      _ptr__2267.update(_2267 ? _2267->raw() : nullptr, _2267 ? _2267->size(0) : 0);
      std::vector<long long> _9683;
      for (int _2293 = (int)0, _9684 = _2273; _2293 < _9684 ; ++_2293)
      {
        _9683.push_back(_ptr__2268[_ptr__2290[_2293]]);
      }
      auto _9685 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9683.size()),_9683.begin(),_9683.end()));
      _2268 = _9685;
      _ptr__2268.update(_2268 ? _2268->raw() : nullptr, _2268 ? _2268->size(0) : 0);
    }
  }
  std::vector<int> _9686;
  for (int _2294 = (int)0, _9687 = _2270; _2294 < _9687 ; ++_2294)
  {
    _9686.push_back(_ptr__2269[_ptr__2266[_2294]]);
  }
  auto _9688 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9686.size()),_9686.begin(),_9686.end()));
  return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2265->__mosek_2fusion_2Variable__getModel(),_9688,_2267,_2268)).as<::mosek::fusion::Variable>();
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _2295,    int _2296) { return mosek::fusion::p_Var::hrepeat(_2295,_2296); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _2295,int _2296){
  return ::mosek::fusion::p_Var::drepeat(_2295,(int)1,_2296);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vrepeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _2297,    int _2298) { return mosek::fusion::p_Var::vrepeat(_2297,_2298); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _2297,int _2298){
  return ::mosek::fusion::p_Var::drepeat(_2297,(int)0,_2298);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _2299,    int _2300) { return mosek::fusion::p_Var::repeat(_2299,_2300); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _2299,int _2300){
  return ::mosek::fusion::p_Var::drepeat(_2299,(int)0,_2300);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _2301,    int _2302,    int _2303) { return mosek::fusion::p_Var::repeat(_2301,_2302,_2303); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _2301,int _2302,int _2303){
  return ::mosek::fusion::p_Var::drepeat(_2301,_2302,_2303);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _2304,int _2305,int _2306){
  if ((_2306 < (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot repeat less than 0 times"));
    }
  }
  else if((_2306 == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if((_2306 == (int)1))
  {
    {
      return _2304;
    }
  }
  else
  {
    {
      monty::rc_ptr< ::mosek::fusion::Model > _2307 = _2304->__mosek_2fusion_2Variable__getModel();
      std::shared_ptr< monty::ndarray< int,1 > > _2308 = _2304->getShape();
      _checked_ptr_1<int> _ptr__2308(_2308 ? _2308->raw() : nullptr,_2308 ? _2308->size(0) : 0);
      int _2309 = (int)((_2308)->size(0));
      if (((_2305 < (int)0) || (_2305 > _2309)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      long long _2310 = ::mosek::fusion::p_Set::size(_2308);
      int _2311 = _2304->numInst();
      int _2312 = safe_mul( _2311,_2306 );
      int _2313 = (int)1;
      int _9689 = (int)0;
      int _9690 = _2305;
      for (int _2314 = _9689; _2314 < _9690; ++_2314)
      {
        {
          _2313 *= _ptr__2308[_2314];
        }
      }
      int _9691;
      bool _9692 = (_2305 < _2309);
      if (_9692)
      {
        _9691 = _ptr__2308[_2305];
      }
      else
      {
        _9691 = (int)1;
      }
      int _2315 = _9691;
      int _2316 = safe_mul( _2315,_2306 );
      int _2317 = (int)1;
      int _9693 = safe_add( _2305,(int)1 );
      int _9694 = _2309;
      for (int _2318 = _9693; _2318 < _9694; ++_2318)
      {
        {
          _2317 *= _ptr__2308[_2318];
        }
      }
      int _9695;
      bool _9696 = (_2305 < _2309);
      if (_9696)
      {
        _9695 = _2309;
      }
      else
      {
        _9695 = safe_add( _2305,(int)1 );
      }
      int _2319 = _9695;
      std::shared_ptr< monty::ndarray< int,1 > > _2320 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2319)));
      _checked_ptr_1<int> _ptr__2320(_2320 ? _2320->raw() : nullptr,_2320 ? _2320->size(0) : 0);
      int _9697 = (int)0;
      int _9698 = _2309;
      for (int _2321 = _9697; _2321 < _9698; ++_2321)
      {
        {
          _ptr__2320[_2321] = _ptr__2308[_2321];
        }
      }
      int _9699 = _2309;
      int _9700 = _2319;
      for (int _2322 = _9699; _2322 < _9700; ++_2322)
      {
        {
          _ptr__2320[_2322] = (int)1;
        }
      }
      _ptr__2320[_2305] = _2316;
      if ((_2311 < _2310))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _2323 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2311)));
          _checked_ptr_1<long long> _ptr__2323(_2323 ? _2323->raw() : nullptr,_2323 ? _2323->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _2324 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2311)));
          _checked_ptr_1<long long> _ptr__2324(_2324 ? _2324->raw() : nullptr,_2324 ? _2324->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _2325 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2312)));
          _checked_ptr_1<long long> _ptr__2325(_2325 ? _2325->raw() : nullptr,_2325 ? _2325->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _2326 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2312)));
          _checked_ptr_1<long long> _ptr__2326(_2326 ? _2326->raw() : nullptr,_2326 ? _2326->size(0) : 0);
          _2304->inst((int)0,_2324,(int)0,_2323);
          {
            int _2327 = safe_mul( _2316,_2317 );
            int _2328 = safe_mul( _2315,_2317 );
            int _2329 = _2317;
            if ((_2305 == (int)0))
            {
              {
                int _2330 = (int)0;
                int _9701 = (int)0;
                int _9702 = _2306;
                for (int _2331 = _9701; _2331 < _9702; ++_2331)
                {
                  {
                    int _9703 = (int)0;
                    int _9704 = _2311;
                    for (int _2332 = _9703; _2332 < _9704; ++_2332)
                    {
                      {
                        _ptr__2326[_2330] = safe_add( _ptr__2324[_2332],safe_mul( _2331,_2310 ) );
                        _ptr__2325[_2330] = _ptr__2323[_2332];
                        ++ _2330;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2307,_2320,_2326,_2325)).as<::mosek::fusion::Variable>();
              }
            }
            else if((_2305 >= _2309))
            {
              {
                int _2333 = (int)0;
                int _9705 = (int)0;
                int _9706 = _2311;
                for (int _2334 = _9705; _2334 < _9706; ++_2334)
                {
                  {
                    int _9707 = (int)0;
                    int _9708 = _2306;
                    for (int _2335 = _9707; _2335 < _9708; ++_2335)
                    {
                      {
                        _ptr__2326[_2333] = safe_add( safe_mul( _ptr__2324[_2334],_2306 ),_2335 );
                        _ptr__2325[_2333] = _ptr__2323[_2334];
                        ++ _2333;
                      }
                    }
                  }
                }
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2307,_2320,_2326,_2325)).as<::mosek::fusion::Variable>();
              }
            }
            else
            {
              {
                int _2336 = (int)0;
                int _9709 = (int)0;
                int _9710 = _2311;
                for (int _2337 = _9709; _2337 < _9710; ++_2337)
                {
                  {
                    long long _2338 = (_ptr__2324[_2337] / _2328);
                    long long _2339 = ((_ptr__2324[_2337] / _2329) % _2315);
                    long long _2340 = (_ptr__2324[_2337] % _2317);
                    int _9711 = (int)0;
                    int _9712 = _2306;
                    for (int _2341 = _9711; _2341 < _9712; ++_2341)
                    {
                      {
                        _ptr__2326[_2336] = safe_add( safe_add( safe_mul( _2338,_2327 ),safe_mul( safe_add( _2339,safe_mul( _2315,_2341 ) ),_2317 ) ),_2340 );
                        _ptr__2325[_2336] = _ptr__2323[_2337];
                        ++ _2336;
                      }
                    }
                  }
                }
                int _2342 = (int)1;
                int _9713 = (int)0;
                int _9714 = _2319;
                for (int _2343 = _9713; _2343 < _9714; ++_2343)
                {
                  {
                    if ((_2342 < _ptr__2320[_2343]))
                    {
                      {
                        _2342 = _ptr__2320[_2343];
                      }
                    }
                    {}
                  }
                }
                std::shared_ptr< monty::ndarray< int,1 > > _2344 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2312)));
                _checked_ptr_1<int> _ptr__2344(_2344 ? _2344->raw() : nullptr,_2344 ? _2344->size(0) : 0);
                std::shared_ptr< monty::ndarray< int,1 > > _2345 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2312)));
                _checked_ptr_1<int> _ptr__2345(_2345 ? _2345->raw() : nullptr,_2345 ? _2345->size(0) : 0);
                {
                  std::shared_ptr< monty::ndarray< int,1 > > _2346 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2342,(int)1 ))));
                  _checked_ptr_1<int> _ptr__2346(_2346 ? _2346->raw() : nullptr,_2346 ? _2346->size(0) : 0);
                  std::shared_ptr< monty::ndarray< long long,1 > > _2347 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2319)));
                  _checked_ptr_1<long long> _ptr__2347(_2347 ? _2347->raw() : nullptr,_2347 ? _2347->size(0) : 0);
                  _ptr__2347[(_2319 - (int)1)] = (int)1;
                  int _9715 = (int)1;
                  int _9716 = _2319;
                  for (int _2348 = _9715; _2348 < _9716; ++_2348)
                  {
                    {
                      _ptr__2347[((_2319 - _2348) - (int)1)] = safe_mul( _ptr__2347[(_2319 - _2348)],_ptr__2320[(_2319 - _2348)] );
                    }
                  }
                  int _9717 = (int)0;
                  int _9718 = _2312;
                  for (int _2349 = _9717; _2349 < _9718; ++_2349)
                  {
                    {
                      _ptr__2344[_2349] = _2349;
                    }
                  }
                  int _9719 = (int)0;
                  int _9720 = _2319;
                  for (int _2350 = _9719; _2350 < _9720; ++_2350)
                  {
                    {
                      int _2351 = ((_2319 - _2350) - (int)1);
                      int _9721 = (int)0;
                      int _9722 = safe_add( _ptr__2320[_2351],(int)1 );
                      for (int _2352 = _9721; _2352 < _9722; ++_2352)
                      {
                        {
                          _ptr__2346[_2352] = (int)0;
                        }
                      }
                      int _9723 = (int)0;
                      int _9724 = _2312;
                      for (int _2353 = _9723; _2353 < _9724; ++_2353)
                      {
                        {
                          ++ _ptr__2346[safe_add( ((_ptr__2326[_2353] / _ptr__2347[_2351]) % _ptr__2320[_2351]),(int)1 )];
                        }
                      }
                      int _9725 = (int)0;
                      int _9726 = _ptr__2320[_2351];
                      for (int _2354 = _9725; _2354 < _9726; ++_2354)
                      {
                        {
                          _ptr__2346[safe_add( _2354,(int)1 )] += _ptr__2346[_2354];
                        }
                      }
                      int _9727 = (int)0;
                      int _9728 = _2312;
                      for (int _2355 = _9727; _2355 < _9728; ++_2355)
                      {
                        {
                          int _2356 = _ptr__2344[_2355];
                          long long _2357 = ((_ptr__2326[_2356] / _ptr__2347[_2351]) % _ptr__2320[_2351]);
                          _ptr__2345[_ptr__2346[_2357]] = _2356;
                          ++ _ptr__2346[_2357];
                        }
                      }
                      std::shared_ptr< monty::ndarray< int,1 > > _2358 = _2344;
                      _checked_ptr_1<int> _ptr__2358(_2358 ? _2358->raw() : nullptr,_2358 ? _2358->size(0) : 0);
                      _2344 = _2345;
                      _ptr__2344.update(_2344 ? _2344->raw() : nullptr, _2344 ? _2344->size(0) : 0);
                      _2345 = _2358;
                      _ptr__2345.update(_2345 ? _2345->raw() : nullptr, _2345 ? _2345->size(0) : 0);
                    }
                  }
                }
                std::vector<long long> _9729;
                for (int _2359 = (int)0, _9730 = _2312; _2359 < _9730 ; ++_2359)
                {
                  _9729.push_back(_ptr__2326[_ptr__2344[_2359]]);
                }
                auto _9731 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9729.size()),_9729.begin(),_9729.end()));
                std::vector<long long> _9732;
                for (int _2360 = (int)0, _9733 = _2312; _2360 < _9733 ; ++_2360)
                {
                  _9732.push_back(_ptr__2325[_ptr__2344[_2360]]);
                }
                auto _9734 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9732.size()),_9732.begin(),_9732.end()));
                return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2307,_2320,_9731,_9734)).as<::mosek::fusion::Variable>();
              }
            }
          }
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _2361 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2311)));
          _checked_ptr_1<long long> _ptr__2361(_2361 ? _2361->raw() : nullptr,_2361 ? _2361->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _2362 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( _2311,_2306 ))));
          _checked_ptr_1<long long> _ptr__2362(_2362 ? _2362->raw() : nullptr,_2362 ? _2362->size(0) : 0);
          _2304->inst((int)0,_2361);
          int _2363 = safe_mul( _2316,_2317 );
          int _2364 = _2317;
          int _2365 = (int)0;
          int _9735 = (int)0;
          int _9736 = _2313;
          for (int _2366 = _9735; _2366 < _9736; ++_2366)
          {
            {
              int _9737 = (int)0;
              int _9738 = _2315;
              for (int _2367 = _9737; _2367 < _9738; ++_2367)
              {
                {
                  int _9739 = (int)0;
                  int _9740 = _2317;
                  for (int _2368 = _9739; _2368 < _9740; ++_2368)
                  {
                    {
                      int _9741 = (int)0;
                      int _9742 = _2306;
                      for (int _2369 = _9741; _2369 < _9742; ++_2369)
                      {
                        {
                          _ptr__2362[safe_add( safe_add( safe_mul( _2366,_2363 ),safe_mul( safe_add( _2367,safe_mul( _2369,_2315 ) ),_2364 ) ),_2368 )] = _ptr__2361[_2365];
                        }
                      }
                      ++ _2365;
                    }
                  }
                }
              }
            }
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2307,_2320,nullptr,_2362)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _2370) { return mosek::fusion::p_Var::stack(_2370); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _2370){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _9743;
  for (int _2371 = (int)0, _9744 = (int)((_2370)->size(0)); _2371 < _9744 ; ++_2371)
  {
    _9743.push_back(::mosek::fusion::p_Var::dstack(((*_2370)(_2371)),(int)1));
  }
  auto _9745 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_9743.size()),_9743.begin(),_9743.end()));
  return ::mosek::fusion::p_Var::dstack(_9745,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2372,    monty::rc_ptr< ::mosek::fusion::Variable > _2373,    monty::rc_ptr< ::mosek::fusion::Variable > _2374) { return mosek::fusion::p_Var::vstack(_2372,_2373,_2374); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _2372,monty::rc_ptr< ::mosek::fusion::Variable > _2373,monty::rc_ptr< ::mosek::fusion::Variable > _2374){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2372.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2373.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2374.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2375,    monty::rc_ptr< ::mosek::fusion::Variable > _2376) { return mosek::fusion::p_Var::vstack(_2375,_2376); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(monty::rc_ptr< ::mosek::fusion::Variable > _2375,monty::rc_ptr< ::mosek::fusion::Variable > _2376){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2375.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2376.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2377) { return mosek::fusion::p_Var::vstack(_2377); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2377){
  return ::mosek::fusion::p_Var::dstack(_2377,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2378,    monty::rc_ptr< ::mosek::fusion::Variable > _2379,    monty::rc_ptr< ::mosek::fusion::Variable > _2380) { return mosek::fusion::p_Var::hstack(_2378,_2379,_2380); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _2378,monty::rc_ptr< ::mosek::fusion::Variable > _2379,monty::rc_ptr< ::mosek::fusion::Variable > _2380){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2378.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2379.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2380.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2381,    monty::rc_ptr< ::mosek::fusion::Variable > _2382) { return mosek::fusion::p_Var::hstack(_2381,_2382); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(monty::rc_ptr< ::mosek::fusion::Variable > _2381,monty::rc_ptr< ::mosek::fusion::Variable > _2382){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2381.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2382.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2383) { return mosek::fusion::p_Var::hstack(_2383); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2383){
  return ::mosek::fusion::p_Var::dstack(_2383,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2384,    monty::rc_ptr< ::mosek::fusion::Variable > _2385,    monty::rc_ptr< ::mosek::fusion::Variable > _2386,    int _2387) { return mosek::fusion::p_Var::stack(_2384,_2385,_2386,_2387); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _2384,monty::rc_ptr< ::mosek::fusion::Variable > _2385,monty::rc_ptr< ::mosek::fusion::Variable > _2386,int _2387){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2384.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2385.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2386.get())}),_2387);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( monty::rc_ptr< ::mosek::fusion::Variable > _2388,    monty::rc_ptr< ::mosek::fusion::Variable > _2389,    int _2390) { return mosek::fusion::p_Var::stack(_2388,_2389,_2390); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(monty::rc_ptr< ::mosek::fusion::Variable > _2388,monty::rc_ptr< ::mosek::fusion::Variable > _2389,int _2390){
  return ::mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >{::monty::rc_ptr<::mosek::fusion::Variable>(_2388.get()),::monty::rc_ptr<::mosek::fusion::Variable>(_2389.get())}),_2390);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2391,    int _2392) { return mosek::fusion::p_Var::stack(_2391,_2392); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2391,int _2392){
  int _2393 = _2392;
  int _9746 = (int)0;
  int _9747 = (int)((_2391)->size(0));
  for (int _2394 = _9746; _2394 < _9747; ++_2394)
  {
    {
      if ((_2393 < ((*_2391)(_2394))->getND()))
      {
        {
          _2393 = ((*_2391)(_2394))->getND();
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Var::dstack(_2391,_2392);
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::Var::promote  ( monty::rc_ptr< ::mosek::fusion::Variable > _2395,    int _2396) { return mosek::fusion::p_Var::promote(_2395,_2396); }monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::promote(monty::rc_ptr< ::mosek::fusion::Variable > _2395,int _2396){
  if ((_2396 > _2395->getND()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2397 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2396)));
      _checked_ptr_1<int> _ptr__2397(_2397 ? _2397->raw() : nullptr,_2397 ? _2397->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2398 = _2395->getShape();
      _checked_ptr_1<int> _ptr__2398(_2398 ? _2398->raw() : nullptr,_2398 ? _2398->size(0) : 0);
      int _9748 = (int)0;
      int _9749 = (int)((_2398)->size(0));
      for (int _2399 = _9748; _2399 < _9749; ++_2399)
      {
        {
          _ptr__2397[_2399] = _ptr__2398[_2399];
        }
      }
      int _9750 = (int)((_2398)->size(0));
      int _9751 = _2396;
      for (int _2400 = _9750; _2400 < _9751; ++_2400)
      {
        {
          _ptr__2397[_2400] = (int)1;
        }
      }
      return _2395->__mosek_2fusion_2Variable__reshape(_2397);
    }
  }
  else
  {
    {
      return _2395;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Variable > mosek::fusion::p_Var::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2401,int _2402){
  if ((_2402 < (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Model > _2403 = nullptr;
  {
    int _9752 = (int)0;
    int _9753 = (int)((_2401)->size(0));
    for (int _2404 = _9752; _2404 < _9753; ++_2404)
    {
      {
        if ((NULL == _2403.get()))
        {
          {
            _2403 = ((*_2401)(_2404))->__mosek_2fusion_2Variable__getModel();
          }
        }
        else if(((NULL != ((*_2401)(_2404))->__mosek_2fusion_2Variable__getModel().get()) && (((*_2401)(_2404))->__mosek_2fusion_2Variable__getModel() != _2403)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2405 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _9754;
            bool _9755 = ((int)((mosek::fusion::p_Model::_get_impl(_2403.get())->getName()).size()) > (int)0);
            if (_9755)
            {
              _9754 = mosek::fusion::p_Model::_get_impl(_2403.get())->getName();
            }
            else
            {
              _9754 = std::string ("?");
            }
            std::string _2406 = _9754;
            std::string _9756;
            bool _9757 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2401)(_2404))->__mosek_2fusion_2Variable__getModel().get())->getName()).size()) > (int)0);
            if (_9757)
            {
              _9756 = mosek::fusion::p_Model::_get_impl(((*_2401)(_2404))->__mosek_2fusion_2Variable__getModel().get())->getName();
            }
            else
            {
              _9756 = std::string ("?");
            }
            std::string _2407 = _9756;
            _2405->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Variables belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2406)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2407)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2405->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2401)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>();
    }
  }
  else if(((int)((_2401)->size(0)) == (int)1))
  {
    {
      return ((*_2401)((int)1));
    }
  }
  else
  {
    {
      int _2408 = (int)((_2401)->size(0));
      std::vector<int> _9758;
      for (int _2410 = (int)0, _9759 = _2408; _2410 < _9759 ; ++_2410)
      {
        _9758.push_back(((*_2401)(_2410))->numInst());
      }
      auto _9760 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9758.size()),_9758.begin(),_9758.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2409 = _9760;
      _checked_ptr_1<int> _ptr__2409(_2409 ? _2409->raw() : nullptr,_2409 ? _2409->size(0) : 0);
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _9761;
      for (int _2412 = (int)0, _9762 = _2408; _2412 < _9762 ; ++_2412)
      {
        _9761.push_back(((*_2401)(_2412))->getShape());
      }
      auto _9763 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_9761.size()),_9761.begin(),_9761.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2411 = _9763;
      std::vector<int> _9764;
      for (int _2414 = (int)0, _9765 = _2408; _2414 < _9765 ; ++_2414)
      {
        _9764.push_back((int)((((*_2411)(_2414)))->size(0)));
      }
      auto _9766 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9764.size()),_9764.begin(),_9764.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2413 = _9766;
      _checked_ptr_1<int> _ptr__2413(_2413 ? _2413->raw() : nullptr,_2413 ? _2413->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2415 = ((*_2411)((int)0));
      _checked_ptr_1<int> _ptr__2415(_2415 ? _2415->raw() : nullptr,_2415 ? _2415->size(0) : 0);
      int _2416 = _ptr__2413[(int)0];
      int _2417 = (int)0;
      int _9767 = (int)0;
      int _9768 = _2408;
      for (int _2418 = _9767; _2418 < _9768; ++_2418)
      {
        {
          _2417 += _ptr__2409[_2418];
        }
      }
      int _2419 = safe_add( _2402,(int)1 );
      int _9769 = (int)0;
      int _9770 = _2408;
      for (int _2420 = _9769; _2420 < _9770; ++_2420)
      {
        {
          if ((_2419 < _ptr__2413[_2420]))
          {
            {
              _2419 = _ptr__2413[_2420];
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2421 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2419)));
      _checked_ptr_1<int> _ptr__2421(_2421 ? _2421->raw() : nullptr,_2421 ? _2421->size(0) : 0);
      int _9771 = (int)0;
      int _9772 = _2416;
      for (int _2422 = _9771; _2422 < _9772; ++_2422)
      {
        {
          _ptr__2421[_2422] = _ptr__2415[_2422];
        }
      }
      int _9773 = _2416;
      int _9774 = _2419;
      for (int _2423 = _9773; _2423 < _9774; ++_2423)
      {
        {
          _ptr__2421[_2423] = (int)1;
        }
      }
      _ptr__2421[_2402] = (int)0;
      int _9775 = (int)0;
      int _9776 = _2408;
      for (int _2424 = _9775; _2424 < _9776; ++_2424)
      {
        {
          int _9777;
          bool _9778 = ((int)((((*_2411)(_2424)))->size(0)) > _2402);
          if (_9778)
          {
            _9777 = ((*((*_2411)(_2424)))(_2402));
          }
          else
          {
            _9777 = (int)1;
          }
          _ptr__2421[_2402] += _9777;
        }
      }
      int _9779 = (int)0;
      int _9780 = _2408;
      for (int _2425 = _9779; _2425 < _9780; ++_2425)
      {
        {
          int _9781 = (int)0;
          int _9782 = (int)((((*_2411)(_2425)))->size(0));
          for (int _2426 = _9781; _2426 < _9782; ++_2426)
          {
            {
              if (((_2426 != _2402) && (((*((*_2411)(_2425)))(_2426)) != _ptr__2421[_2426])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
          int _9783 = (int)((((*_2411)(_2425)))->size(0));
          int _9784 = _2419;
          for (int _2427 = _9783; _2427 < _9784; ++_2427)
          {
            {
              if (((_2427 != _2402) && ((int)1 != _ptr__2421[_2427])))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Variable dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< long long,1 > > _2428 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2417)));
      _checked_ptr_1<long long> _ptr__2428(_2428 ? _2428->raw() : nullptr,_2428 ? _2428->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _2429 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2417)));
      _checked_ptr_1<long long> _ptr__2429(_2429 ? _2429->raw() : nullptr,_2429 ? _2429->size(0) : 0);
      std::vector<int> _9785;
      for (int _2431 = (int)0, _9786 = (int)((_2401)->size(0)); _2431 < _9786 ; ++_2431)
      {
        int _9787;
        bool _9788 = (_2402 < (int)((((*_2411)(_2431)))->size(0)));
        if (_9788)
        {
          _9787 = ((*((*_2411)(_2431)))(_2402));
        }
        else
        {
          _9787 = (int)1;
        }
        _9785.push_back(_9787);
      }
      auto _9789 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9785.size()),_9785.begin(),_9785.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2430 = _9789;
      _checked_ptr_1<int> _ptr__2430(_2430 ? _2430->raw() : nullptr,_2430 ? _2430->size(0) : 0);
      int _2432 = (int)1;
      int _9790 = (int)0;
      int _9791 = _2402;
      for (int _2433 = _9790; _2433 < _9791; ++_2433)
      {
        {
          int _9792;
          bool _9793 = (_2433 < (int)((_2415)->size(0)));
          if (_9793)
          {
            _9792 = _ptr__2415[_2433];
          }
          else
          {
            _9792 = (int)1;
          }
          _2432 *= _9792;
        }
      }
      int _2434 = (int)0;
      int _9794 = (int)0;
      int _9795 = _2408;
      for (int _2435 = _9794; _2435 < _9795; ++_2435)
      {
        {
          _2434 += _ptr__2430[_2435];
        }
      }
      int _2436 = (int)1;
      int _9796 = safe_add( _2402,(int)1 );
      int _9797 = (int)((_2415)->size(0));
      for (int _2437 = _9796; _2437 < _9797; ++_2437)
      {
        {
          _2436 *= _ptr__2415[_2437];
        }
      }
      if ((_2432 == (int)1))
      {
        {
          int _2438 = (int)0;
          long long _2439 = (int)0;
          int _9798 = (int)0;
          int _9799 = _2408;
          for (int _2440 = _9798; _2440 < _9799; ++_2440)
          {
            {
              ((*_2401)(_2440))->inst(_2438,_2429,_2438,_2428);
              int _9800 = (int)0;
              int _9801 = _ptr__2409[_2440];
              for (int _2441 = _9800; _2441 < _9801; ++_2441)
              {
                {
                  _ptr__2429[_2438] += _2439;
                  ++ _2438;
                }
              }
              _2439 += ::mosek::fusion::p_Set::size(((*_2411)(_2440)));
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _9802;
          bool _9803 = (_2417 < safe_mul( safe_mul( _2432,_2434 ),_2436 ));
          if (_9803)
          {
            _9802 = _2429;
          }
          else
          {
            _9802 = nullptr;
          }
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2403,_2421,_9802,_2428)).as<::mosek::fusion::Variable>();
        }
      }
      else
      {
        {
          int _2442 = (int)0;
          int _9804 = (int)0;
          int _9805 = _2408;
          for (int _2443 = _9804; _2443 < _9805; ++_2443)
          {
            {
              _2442 += ((*_2401)(_2443))->inst(_2442,_2429,_2442,_2428);
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2444 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2417)));
          _checked_ptr_1<int> _ptr__2444(_2444 ? _2444->raw() : nullptr,_2444 ? _2444->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2445 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2417)));
          _checked_ptr_1<int> _ptr__2445(_2445 ? _2445->raw() : nullptr,_2445 ? _2445->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2446 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2408)));
          _checked_ptr_1<int> _ptr__2446(_2446 ? _2446->raw() : nullptr,_2446 ? _2446->size(0) : 0);
          int _9806 = (int)0;
          int _9807 = (_2408 - (int)1);
          for (int _2447 = _9806; _2447 < _9807; ++_2447)
          {
            {
              _ptr__2446[safe_add( _2447,(int)1 )] = safe_add( _ptr__2446[_2447],_ptr__2430[_2447] );
            }
          }
          int _9808 = (int)0;
          int _9809 = _2417;
          for (int _2448 = _9808; _2448 < _9809; ++_2448)
          {
            {
              _ptr__2444[_2448] = _2448;
            }
          }
          int _2449 = (int)0;
          int _9810 = (int)0;
          int _9811 = _2408;
          for (int _2450 = _9810; _2450 < _9811; ++_2450)
          {
            {
              int _9812 = (int)0;
              int _9813 = _ptr__2409[_2450];
              for (int _2451 = _9812; _2451 < _9813; ++_2451)
              {
                {
                  long long _2452 = (_ptr__2429[_2449] / safe_mul( _ptr__2430[_2450],_2436 ));
                  long long _2453 = ((_ptr__2429[_2449] / _2436) % _ptr__2430[_2450]);
                  long long _2454 = (_ptr__2429[_2449] % _2436);
                  _ptr__2429[_2449] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _2452,_2434 ),_2453 ),_ptr__2446[_2450] ),_2436 ),_2454 );
                  ++ _2449;
                }
              }
            }
          }
          int _2455 = (int)1;
          int _9814 = (int)0;
          int _9815 = _2419;
          for (int _2456 = _9814; _2456 < _9815; ++_2456)
          {
            {
              int _9816;
              bool _9817 = (_2455 < _ptr__2421[_2456]);
              if (_9817)
              {
                _9816 = _ptr__2421[_2456];
              }
              else
              {
                _9816 = _2455;
              }
              _2455 = _9816;
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _2457 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2419)));
          _checked_ptr_1<long long> _ptr__2457(_2457 ? _2457->raw() : nullptr,_2457 ? _2457->size(0) : 0);
          _ptr__2457[(_2419 - (int)1)] = (int)1;
          int _9818 = (int)1;
          int _9819 = _2419;
          for (int _2458 = _9818; _2458 < _9819; ++_2458)
          {
            {
              _ptr__2457[((_2419 - _2458) - (int)1)] = safe_mul( _ptr__2457[(_2419 - _2458)],_ptr__2421[(_2419 - _2458)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _2459 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2455,(int)1 ))));
          _checked_ptr_1<int> _ptr__2459(_2459 ? _2459->raw() : nullptr,_2459 ? _2459->size(0) : 0);
          int _9820 = (int)0;
          int _9821 = _2419;
          for (int _2460 = _9820; _2460 < _9821; ++_2460)
          {
            {
              int _2461 = ((_2419 - _2460) - (int)1);
              int _9822 = (int)0;
              int _9823 = safe_add( _ptr__2421[_2461],(int)1 );
              for (int _2462 = _9822; _2462 < _9823; ++_2462)
              {
                {
                  _ptr__2459[_2462] = (int)0;
                }
              }
              int _9824 = (int)0;
              int _9825 = _2417;
              for (int _2463 = _9824; _2463 < _9825; ++_2463)
              {
                {
                  ++ _ptr__2459[safe_add( ((_ptr__2429[_2463] / _ptr__2457[_2461]) % _ptr__2421[_2461]),(int)1 )];
                }
              }
              int _9826 = (int)0;
              int _9827 = _ptr__2421[_2461];
              for (int _2464 = _9826; _2464 < _9827; ++_2464)
              {
                {
                  _ptr__2459[safe_add( _2464,(int)1 )] += _ptr__2459[_2464];
                }
              }
              int _9828 = (int)0;
              int _9829 = _2417;
              for (int _2465 = _9828; _2465 < _9829; ++_2465)
              {
                {
                  int _2466 = _ptr__2444[_2465];
                  long long _2467 = ((_ptr__2429[_2466] / _ptr__2457[_2461]) % _ptr__2421[_2461]);
                  _ptr__2445[_ptr__2459[_2467]] = _2466;
                  ++ _ptr__2459[_2467];
                }
              }
              std::shared_ptr< monty::ndarray< int,1 > > _2468 = _2444;
              _checked_ptr_1<int> _ptr__2468(_2468 ? _2468->raw() : nullptr,_2468 ? _2468->size(0) : 0);
              _2444 = _2445;
              _ptr__2444.update(_2444 ? _2444->raw() : nullptr, _2444 ? _2444->size(0) : 0);
              _2445 = _2468;
              _ptr__2445.update(_2445 ? _2445->raw() : nullptr, _2445 ? _2445->size(0) : 0);
            }
          }
          std::shared_ptr< monty::ndarray< long long,1 > > _9830;
          bool _9831 = (_2417 < safe_mul( safe_mul( _2432,_2434 ),_2436 ));
          if (_9831)
          {
            std::vector<long long> _9832;
            for (int _2469 = (int)0, _9833 = _2417; _2469 < _9833 ; ++_2469)
            {
              _9832.push_back(_ptr__2429[_ptr__2444[_2469]]);
            }
            auto _9834 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9832.size()),_9832.begin(),_9832.end()));
            _9830 = _9834;
          }
          else
          {
            _9830 = nullptr;
          }
          std::vector<long long> _9835;
          for (int _2470 = (int)0, _9836 = _2417; _2470 < _9836 ; ++_2470)
          {
            _9835.push_back(_ptr__2428[_ptr__2444[_2470]]);
          }
          auto _9837 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9835.size()),_9835.begin(),_9835.end()));
          return (::mosek::fusion::p_SliceVariable::_new_SliceVariable(_2403,_2421,_9830,_9837)).as<::mosek::fusion::Variable>();
        }
      }
    }
  }
}
void mosek::fusion::p_Var::destroy(){}void mosek::fusion::Var::destroy() { mosek::fusion::p_Var::_get_impl(this)->destroy(); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint(mosek::fusion::p_LinearPSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearPSDConstraint()" << this << std::endl; */ }mosek::fusion::LinearPSDConstraint::~LinearPSDConstraint() {  /* std::cout << "~LinearPSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearPSDConstraint::p_LinearPSDConstraint  (::mosek::fusion::LinearPSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2471,    monty::rc_ptr< ::mosek::fusion::Model > _2472){ return new mosek::fusion::LinearPSDConstraint(_2471,_2472); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2471,    monty::rc_ptr< ::mosek::fusion::Model > _2472) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2471,_2472); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2471,    monty::rc_ptr< ::mosek::fusion::Model > _2472){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2471,_2472);
    conid = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2471)->conid;
    slackidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2471)->slackidxs;
    nativeidxs = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2471)->nativeidxs;
    conedim = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2471)->conedim;
    shape = mosek::fusion::p_LinearPSDConstraint::_get_impl(_2471)->shape;
  }
}mosek::fusion::LinearPSDConstraint::t mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2473,    const std::string &  _2474,    int _2475,    std::shared_ptr< monty::ndarray< int,1 > > _2476,    int _2477,    std::shared_ptr< monty::ndarray< int,1 > > _2478,    std::shared_ptr< monty::ndarray< long long,1 > > _2479){ return new mosek::fusion::LinearPSDConstraint(_2473,_2474,_2475,_2476,_2477,_2478,_2479); }mosek::fusion::LinearPSDConstraint::LinearPSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2473,    const std::string &  _2474,    int _2475,    std::shared_ptr< monty::ndarray< int,1 > > _2476,    int _2477,    std::shared_ptr< monty::ndarray< int,1 > > _2478,    std::shared_ptr< monty::ndarray< long long,1 > > _2479) :    LinearPSDConstraint(new mosek::fusion::p_LinearPSDConstraint(this)){ mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->_initialize(_2473,_2474,_2475,_2476,_2477,_2478,_2479); }void mosek::fusion::p_LinearPSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2473,    const std::string &  _2474,    int _2475,    std::shared_ptr< monty::ndarray< int,1 > > _2476,    int _2477,    std::shared_ptr< monty::ndarray< int,1 > > _2478,    std::shared_ptr< monty::ndarray< long long,1 > > _2479){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2476(_2476 ? _2476->raw() : nullptr, _2476 ? _2476->size(0) : 0);
    _checked_ptr_1<int> _ptr__2478(_2478 ? _2478->raw() : nullptr, _2478 ? _2478->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2479(_2479 ? _2479->raw() : nullptr, _2479 ? _2479->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2473,_2474,_2476,_2478,_2475);
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conid = _2475;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->slackidxs = _2479;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->nativeidxs = _2478;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->conedim = _2477;
    mosek::fusion::p_LinearPSDConstraint::_get_impl(::mosek::fusion::LinearPSDConstraint::t(_pubthis))->shape = _2476;
  }
}void mosek::fusion::p_LinearPSDConstraint::domainToString(long long _2480,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2481){
  std::shared_ptr< monty::ndarray< int,1 > > _2482 = ::mosek::fusion::p_Set::idxtokey(shape,_2480);
  _checked_ptr_1<int> _ptr__2482(_2482 ? _2482->raw() : nullptr,_2482 ? _2482->size(0) : 0);
  _2481->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" : element ("))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2482[(int)0]);
  int _9838 = (int)1;
  int _9839 = (int)((_2482)->size(0));
  for (int _2483 = _9838; _2483 < _9839; ++_2483)
  {
    {
      _2481->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2482[_2483]);
    }
  }
  _2481->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") in a positive semi-definite cone of size ("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
  int _9840 = (int)1;
  int _9841 = (int)((_2482)->size(0));
  for (int _2484 = _9840; _2484 < _9841; ++_2484)
  {
    {
      _2481->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_2484)));
    }
  }
  _2481->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearPSDConstraint::__mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2485){
  return (::mosek::fusion::p_LinearPSDConstraint::_new_LinearPSDConstraint(::mosek::fusion::LinearPSDConstraint::t(_pubthis),_2485)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearPSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::LinearPSDConstraint::destroy() { mosek::fusion::p_LinearPSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::PSDConstraint::PSDConstraint(mosek::fusion::p_PSDConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "PSDConstraint()" << this << std::endl; */ }mosek::fusion::PSDConstraint::~PSDConstraint() {  /* std::cout << "~PSDConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_PSDConstraint::p_PSDConstraint  (::mosek::fusion::PSDConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2486,    monty::rc_ptr< ::mosek::fusion::Model > _2487){ return new mosek::fusion::PSDConstraint(_2486,_2487); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2486,    monty::rc_ptr< ::mosek::fusion::Model > _2487) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2486,_2487); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2486,    monty::rc_ptr< ::mosek::fusion::Model > _2487){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2486,_2487);
    conid = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->conid;
    name = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->name;
    shape = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->shape;
    slackidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->slackidxs;
    nativeidxs = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->nativeidxs;
    names_flushed = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->names_flushed;
    conedim0 = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->conedim0;
    conedim1 = mosek::fusion::p_PSDConstraint::_get_impl(_2486)->conedim1;
  }
}mosek::fusion::PSDConstraint::t mosek::fusion::p_PSDConstraint::_new_PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2488,    const std::string &  _2489,    int _2490,    std::shared_ptr< monty::ndarray< int,1 > > _2491,    int _2492,    int _2493,    std::shared_ptr< monty::ndarray< long long,1 > > _2494,    std::shared_ptr< monty::ndarray< int,1 > > _2495){ return new mosek::fusion::PSDConstraint(_2488,_2489,_2490,_2491,_2492,_2493,_2494,_2495); }mosek::fusion::PSDConstraint::PSDConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2488,    const std::string &  _2489,    int _2490,    std::shared_ptr< monty::ndarray< int,1 > > _2491,    int _2492,    int _2493,    std::shared_ptr< monty::ndarray< long long,1 > > _2494,    std::shared_ptr< monty::ndarray< int,1 > > _2495) :    PSDConstraint(new mosek::fusion::p_PSDConstraint(this)){ mosek::fusion::p_PSDConstraint::_get_impl(this)->_initialize(_2488,_2489,_2490,_2491,_2492,_2493,_2494,_2495); }void mosek::fusion::p_PSDConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2488,    const std::string &  _2489,    int _2490,    std::shared_ptr< monty::ndarray< int,1 > > _2491,    int _2492,    int _2493,    std::shared_ptr< monty::ndarray< long long,1 > > _2494,    std::shared_ptr< monty::ndarray< int,1 > > _2495){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2491(_2491 ? _2491->raw() : nullptr, _2491 ? _2491->size(0) : 0);
    _checked_ptr_1<long long> _ptr__2494(_2494 ? _2494->raw() : nullptr, _2494 ? _2494->size(0) : 0);
    _checked_ptr_1<int> _ptr__2495(_2495 ? _2495->raw() : nullptr, _2495 ? _2495->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2488,_2489,_2491,::mosek::fusion::p_PSDConstraint::computenidxs(_2491,_2492,_2493,_2495),_2490);
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conid = _2490;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->nativeidxs = _2495;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->slackidxs = _2494;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->name = _2489;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->shape = _2491;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim0 = _2492;
    mosek::fusion::p_PSDConstraint::_get_impl(::mosek::fusion::PSDConstraint::t(_pubthis))->conedim1 = _2493;
    names_flushed = false;
  }
}std::string mosek::fusion::PSDConstraint :: toString() { return mosek::fusion::p_PSDConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_PSDConstraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("PSDConstraint.toString not implemented"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_PSDConstraint::__mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2496){
  return (::mosek::fusion::p_PSDConstraint::_new_PSDConstraint(::mosek::fusion::PSDConstraint::t(_pubthis),_2496)).as<::mosek::fusion::ModelConstraint>();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_PSDConstraint::computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2497,int _2498,int _2499,std::shared_ptr< monty::ndarray< int,1 > > _2500){
  _checked_ptr_1<int> _ptr__2497(_2497 ? _2497->raw() : nullptr, _2497 ? _2497->size(0) : 0);
  _checked_ptr_1<int> _ptr__2500(_2500 ? _2500->raw() : nullptr, _2500 ? _2500->size(0) : 0);
  int _2501 = (int)((_2497)->size(0));
  bool _2502 = (_2498 < _2499);
  int _9842;
  bool _9843 = _2502;
  if (_9843)
  {
    _9842 = _2498;
  }
  else
  {
    _9842 = _2499;
  }
  int _2503 = _9842;
  int _9844;
  bool _9845 = _2502;
  if (_9845)
  {
    _9844 = _2499;
  }
  else
  {
    _9844 = _2498;
  }
  int _2504 = _9844;
  std::shared_ptr< monty::ndarray< int,1 > > _2505 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1),(int)((int)1)});
  _checked_ptr_1<int> _ptr__2505(_2505 ? _2505->raw() : nullptr,_2505 ? _2505->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2506 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__2506(_2506 ? _2506->raw() : nullptr,_2506 ? _2506->size(0) : 0);
  int _2507 = (int)1;
  int _9846 = (int)0;
  int _9847 = (int)((_2497)->size(0));
  for (int _2508 = _9846; _2508 < _9847; ++_2508)
  {
    {
      _2507 *= _ptr__2497[_2508];
    }
  }
  int _9848 = (int)0;
  int _9849 = _2503;
  for (int _2509 = _9848; _2509 < _9849; ++_2509)
  {
    {
      _ptr__2505[(int)0] *= _ptr__2497[_2509];
    }
  }
  _ptr__2505[(int)1] = _ptr__2497[_2503];
  int _9850 = safe_add( _2503,(int)1 );
  int _9851 = _2504;
  for (int _2510 = _9850; _2510 < _9851; ++_2510)
  {
    {
      _ptr__2505[(int)2] *= _ptr__2497[_2510];
    }
  }
  _ptr__2505[(int)3] = _ptr__2497[_2504];
  int _9852 = safe_add( _2504,(int)1 );
  int _9853 = _2501;
  for (int _2511 = _9852; _2511 < _9853; ++_2511)
  {
    {
      _ptr__2505[(int)4] *= _ptr__2497[_2511];
    }
  }
  _ptr__2506[(int)4] = (int)1;
  int _9854 = (int)1;
  int _9855 = (int)5;
  for (int _2512 = _9854; _2512 < _9855; ++_2512)
  {
    {
      _ptr__2506[(((int)5 - _2512) - (int)1)] = safe_mul( _ptr__2506[((int)5 - _2512)],_ptr__2505[((int)5 - _2512)] );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2513 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2507)));
  _checked_ptr_1<int> _ptr__2513(_2513 ? _2513->raw() : nullptr,_2513 ? _2513->size(0) : 0);
  int _2514 = (int)0;
  if (_2502)
  {
    {
      int _9856 = (int)0;
      int _9857 = _ptr__2505[(int)0];
      for (int _2515 = _9856; _2515 < _9857; ++_2515)
      {
        {
          int _9858 = (int)0;
          int _9859 = _ptr__2505[(int)1];
          for (int _2516 = _9858; _2516 < _9859; ++_2516)
          {
            {
              int _9860 = (int)0;
              int _9861 = _ptr__2505[(int)2];
              for (int _2517 = _9860; _2517 < _9861; ++_2517)
              {
                {
                  int _9862 = _2516;
                  int _9863 = _ptr__2505[(int)1];
                  for (int _2518 = _9862; _2518 < _9863; ++_2518)
                  {
                    {
                      int _9864 = (int)0;
                      int _9865 = _ptr__2505[(int)4];
                      for (int _2519 = _9864; _2519 < _9865; ++_2519)
                      {
                        {
                          _ptr__2513[safe_add( safe_add( safe_add( safe_add( safe_mul( _2515,_ptr__2506[(int)0] ),safe_mul( _2516,_ptr__2506[(int)1] ) ),safe_mul( _2517,_ptr__2506[(int)2] ) ),safe_mul( _2518,_ptr__2506[(int)3] ) ),safe_mul( _2519,_ptr__2506[(int)4] ) )] = _ptr__2500[_2514];
                          _ptr__2513[safe_add( safe_add( safe_add( safe_add( safe_mul( _2515,_ptr__2506[(int)0] ),safe_mul( _2518,_ptr__2506[(int)1] ) ),safe_mul( _2517,_ptr__2506[(int)2] ) ),safe_mul( _2516,_ptr__2506[(int)3] ) ),safe_mul( _2519,_ptr__2506[(int)4] ) )] = _ptr__2500[_2514];
                          ++ _2514;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _9866 = (int)0;
      int _9867 = _ptr__2505[(int)0];
      for (int _2520 = _9866; _2520 < _9867; ++_2520)
      {
        {
          int _9868 = (int)0;
          int _9869 = _ptr__2505[(int)1];
          for (int _2521 = _9868; _2521 < _9869; ++_2521)
          {
            {
              int _9870 = (int)0;
              int _9871 = _ptr__2505[(int)2];
              for (int _2522 = _9870; _2522 < _9871; ++_2522)
              {
                {
                  int _9872 = (int)0;
                  int _9873 = safe_add( _2521,(int)1 );
                  for (int _2523 = _9872; _2523 < _9873; ++_2523)
                  {
                    {
                      int _9874 = (int)0;
                      int _9875 = _ptr__2505[(int)4];
                      for (int _2524 = _9874; _2524 < _9875; ++_2524)
                      {
                        {
                          _ptr__2513[safe_add( safe_add( safe_add( safe_add( safe_mul( _2520,_ptr__2506[(int)0] ),safe_mul( _2521,_ptr__2506[(int)1] ) ),safe_mul( _2522,_ptr__2506[(int)2] ) ),safe_mul( _2523,_ptr__2506[(int)3] ) ),safe_mul( _2524,_ptr__2506[(int)4] ) )] = _ptr__2500[_2514];
                          _ptr__2513[safe_add( safe_add( safe_add( safe_add( safe_mul( _2520,_ptr__2506[(int)0] ),safe_mul( _2523,_ptr__2506[(int)1] ) ),safe_mul( _2522,_ptr__2506[(int)2] ) ),safe_mul( _2521,_ptr__2506[(int)3] ) ),safe_mul( _2524,_ptr__2506[(int)4] ) )] = _ptr__2500[_2514];
                          ++ _2514;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  return _2513;
}
void mosek::fusion::p_PSDConstraint::destroy(){shape.reset();slackidxs.reset();nativeidxs.reset();}void mosek::fusion::PSDConstraint::destroy() { mosek::fusion::p_PSDConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConstraintCache::ConstraintCache(mosek::fusion::p_ConstraintCache *_impl) : _impl(_impl) { /*std::cout << "ConstraintCache() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConstraintCache::~ConstraintCache() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConstraintCache::p_ConstraintCache  (::mosek::fusion::ConstraintCache * _pubthis) :     _pubthis(_pubthis){}std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barmatidx() { return _impl->barmatidx; }
void mosek::fusion::ConstraintCache::set_barmatidx(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barmatidx = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubj() { return _impl->barsubj; }
void mosek::fusion::ConstraintCache::set_barsubj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubj = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_barsubi() { return _impl->barsubi; }
void mosek::fusion::ConstraintCache::set_barsubi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->barsubi = _val; }
long long mosek::fusion::ConstraintCache::get_nbarnz() { return _impl->nbarnz; }
void mosek::fusion::ConstraintCache::set_nbarnz(long long _val) { _impl->nbarnz = _val; }
long long mosek::fusion::ConstraintCache::get_nunordered() { return _impl->nunordered; }
void mosek::fusion::ConstraintCache::set_nunordered(long long _val) { _impl->nunordered = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subi() { return _impl->buffer_subi; }
void mosek::fusion::ConstraintCache::set_buffer_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_buffer_subj() { return _impl->buffer_subj; }
void mosek::fusion::ConstraintCache::set_buffer_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->buffer_subj = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_buffer_cof() { return _impl->buffer_cof; }
void mosek::fusion::ConstraintCache::set_buffer_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->buffer_cof = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_bfix() { return _impl->bfix; }
void mosek::fusion::ConstraintCache::set_bfix(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->bfix = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ConstraintCache::get_cof() { return _impl->cof; }
void mosek::fusion::ConstraintCache::set_cof(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->cof = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subi() { return _impl->subi; }
void mosek::fusion::ConstraintCache::set_subi(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subi = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ConstraintCache::get_subj() { return _impl->subj; }
void mosek::fusion::ConstraintCache::set_subj(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->subj = _val; }
long long mosek::fusion::ConstraintCache::get_nnz() { return _impl->nnz; }
void mosek::fusion::ConstraintCache::set_nnz(long long _val) { _impl->nnz = _val; }
int mosek::fusion::ConstraintCache::get_nrows() { return _impl->nrows; }
void mosek::fusion::ConstraintCache::set_nrows(int _val) { _impl->nrows = _val; }
mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2525){ return new mosek::fusion::ConstraintCache(_2525); }mosek::fusion::ConstraintCache::ConstraintCache  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2525) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2525); }void mosek::fusion::p_ConstraintCache::_initialize  (monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2525){monty::rc_reserve __reserve_this(_pubthis);   {
    nrows = mosek::fusion::p_ConstraintCache::_get_impl(_2525)->nrows;
    nnz = mosek::fusion::p_ConstraintCache::_get_impl(_2525)->nnz;
    std::shared_ptr< monty::ndarray< int,1 > > _9876;
    bool _9877 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->subj.get());
    if (_9877)
    {
      _9876 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->subj);
    }
    else
    {
      _9876 = nullptr;
    }
    subj = _9876;
    std::shared_ptr< monty::ndarray< int,1 > > _9878;
    bool _9879 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->subi.get());
    if (_9879)
    {
      _9878 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->subi);
    }
    else
    {
      _9878 = nullptr;
    }
    subi = _9878;
    std::shared_ptr< monty::ndarray< double,1 > > _9880;
    bool _9881 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->cof.get());
    if (_9881)
    {
      _9880 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->cof);
    }
    else
    {
      _9880 = nullptr;
    }
    cof = _9880;
    std::shared_ptr< monty::ndarray< double,1 > > _9882;
    bool _9883 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->bfix.get());
    if (_9883)
    {
      _9882 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->bfix);
    }
    else
    {
      _9882 = nullptr;
    }
    bfix = _9882;
    std::shared_ptr< monty::ndarray< double,1 > > _9884;
    bool _9885 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->buffer_cof.get());
    if (_9885)
    {
      _9884 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->buffer_cof);
    }
    else
    {
      _9884 = nullptr;
    }
    buffer_cof = _9884;
    std::shared_ptr< monty::ndarray< int,1 > > _9886;
    bool _9887 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->buffer_subj.get());
    if (_9887)
    {
      _9886 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->buffer_subj);
    }
    else
    {
      _9886 = nullptr;
    }
    buffer_subj = _9886;
    std::shared_ptr< monty::ndarray< int,1 > > _9888;
    bool _9889 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->buffer_subi.get());
    if (_9889)
    {
      _9888 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->buffer_subi);
    }
    else
    {
      _9888 = nullptr;
    }
    buffer_subi = _9888;
    nunordered = mosek::fusion::p_ConstraintCache::_get_impl(_2525)->nunordered;
    nbarnz = mosek::fusion::p_ConstraintCache::_get_impl(_2525)->nbarnz;
    std::shared_ptr< monty::ndarray< int,1 > > _9890;
    bool _9891 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->barsubi.get());
    if (_9891)
    {
      _9890 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->barsubi);
    }
    else
    {
      _9890 = nullptr;
    }
    barsubi = _9890;
    std::shared_ptr< monty::ndarray< int,1 > > _9892;
    bool _9893 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->barsubj.get());
    if (_9893)
    {
      _9892 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->barsubj);
    }
    else
    {
      _9892 = nullptr;
    }
    barsubj = _9892;
    std::shared_ptr< monty::ndarray< int,1 > > _9894;
    bool _9895 = (NULL != mosek::fusion::p_ConstraintCache::_get_impl(_2525)->barmatidx.get());
    if (_9895)
    {
      _9894 = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_ConstraintCache::_get_impl(_2525)->barmatidx);
    }
    else
    {
      _9894 = nullptr;
    }
    barmatidx = _9894;
  }
}mosek::fusion::ConstraintCache::t mosek::fusion::p_ConstraintCache::_new_ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2526,    std::shared_ptr< monty::ndarray< double,1 > > _2527,    std::shared_ptr< monty::ndarray< int,1 > > _2528,    std::shared_ptr< monty::ndarray< double,1 > > _2529,    std::shared_ptr< monty::ndarray< int,1 > > _2530,    std::shared_ptr< monty::ndarray< int,1 > > _2531,    std::shared_ptr< monty::ndarray< int,1 > > _2532){ return new mosek::fusion::ConstraintCache(_2526,_2527,_2528,_2529,_2530,_2531,_2532); }mosek::fusion::ConstraintCache::ConstraintCache  (std::shared_ptr< monty::ndarray< long long,1 > > _2526,    std::shared_ptr< monty::ndarray< double,1 > > _2527,    std::shared_ptr< monty::ndarray< int,1 > > _2528,    std::shared_ptr< monty::ndarray< double,1 > > _2529,    std::shared_ptr< monty::ndarray< int,1 > > _2530,    std::shared_ptr< monty::ndarray< int,1 > > _2531,    std::shared_ptr< monty::ndarray< int,1 > > _2532) :    ConstraintCache(new mosek::fusion::p_ConstraintCache(this)){ mosek::fusion::p_ConstraintCache::_get_impl(this)->_initialize(_2526,_2527,_2528,_2529,_2530,_2531,_2532); }void mosek::fusion::p_ConstraintCache::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _2526,    std::shared_ptr< monty::ndarray< double,1 > > _2527,    std::shared_ptr< monty::ndarray< int,1 > > _2528,    std::shared_ptr< monty::ndarray< double,1 > > _2529,    std::shared_ptr< monty::ndarray< int,1 > > _2530,    std::shared_ptr< monty::ndarray< int,1 > > _2531,    std::shared_ptr< monty::ndarray< int,1 > > _2532){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__2526(_2526 ? _2526->raw() : nullptr, _2526 ? _2526->size(0) : 0);
    _checked_ptr_1<double> _ptr__2527(_2527 ? _2527->raw() : nullptr, _2527 ? _2527->size(0) : 0);
    _checked_ptr_1<int> _ptr__2528(_2528 ? _2528->raw() : nullptr, _2528 ? _2528->size(0) : 0);
    _checked_ptr_1<double> _ptr__2529(_2529 ? _2529->raw() : nullptr, _2529 ? _2529->size(0) : 0);
    _checked_ptr_1<int> _ptr__2530(_2530 ? _2530->raw() : nullptr, _2530 ? _2530->size(0) : 0);
    _checked_ptr_1<int> _ptr__2531(_2531 ? _2531->raw() : nullptr, _2531 ? _2531->size(0) : 0);
    _checked_ptr_1<int> _ptr__2532(_2532 ? _2532->raw() : nullptr, _2532 ? _2532->size(0) : 0);
    nrows = ((int)((_2526)->size(0)) - (int)1);
    nnz = _ptr__2526[((int)((_2526)->size(0)) - (int)1)];
    subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nnz)));
    cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nnz)));
    if ((NULL != _2529.get()))
    {
      {
        bfix = _2529;
      }
    }
    else
    {
      {
        bfix = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(nrows)));
      }
    }
    if (((NULL != _2530.get()) && ((NULL != _2531.get()) && (NULL != _2532.get()))))
    {
      {
        nbarnz = (int)((_2530)->size(0));
        if ((nbarnz > (int)((_2531)->size(0))))
        {
          {
            nbarnz = (int)((_2531)->size(0));
          }
        }
        {}
        if ((nbarnz > (int)((_2532)->size(0))))
        {
          {
            nbarnz = (int)((_2532)->size(0));
          }
        }
        {}
        barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(nbarnz)));
        ::mosek::fusion::Utils::Tools::arraycopy(_2530,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2531,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
        ::mosek::fusion::Utils::Tools::arraycopy(_2532,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
      }
    }
    else
    {
      {
        nbarnz = (int)0;
        barsubi = nullptr;
        barsubj = nullptr;
        barmatidx = nullptr;
      }
    }
    ::mosek::fusion::Utils::Tools::arraycopy(_2528,(long long)0,subj,(long long)0,nnz);
    ::mosek::fusion::Utils::Tools::arraycopy(_2527,(long long)0,cof,(long long)0,nnz);
    int _9896 = (int)0;
    int _9897 = nrows;
    for (int _2533 = _9896; _2533 < _9897; ++_2533)
    {
      {
        long long _9898 = _ptr__2526[_2533];
        long long _9899 = _ptr__2526[safe_add( _2533,(int)1 )];
        for (long long _2534 = _9898; _2534 < _9899; ++_2534)
        {
          {
            ((*subi)(_2534)) = _2533;
          }
        }
      }
    }
    buffer_cof = nullptr;
    buffer_subj = nullptr;
    buffer_subi = nullptr;
    nunordered = (long long)0;
  }
}void mosek::fusion::p_ConstraintCache::unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2535){
  _checked_ptr_1<double> _ptr__2535(_2535 ? _2535->raw() : nullptr, _2535 ? _2535->size(0) : 0);
  int _9900 = (int)0;
  int _9901 = nrows;
  for (int _2536 = _9900; _2536 < _9901; ++_2536)
  {
    {
      ((*bfix)(_2536)) = (((*bfix)(_2536)) + _ptr__2535[_2536]);
    }
  }
}
long long mosek::fusion::p_ConstraintCache::order_barentries(){
  std::vector<long long> _9902;
  for (long long _2538 = (long long)0, _9903 = nbarnz; _2538 < _9903 ; ++_2538)
  {
    _9902.push_back(_2538);
  }
  auto _9904 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9902.size()),_9902.begin(),_9902.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _2537 = _9904;
  _checked_ptr_1<long long> _ptr__2537(_2537 ? _2537->raw() : nullptr,_2537 ? _2537->size(0) : 0);
  if ((!::mosek::fusion::p_Sort::issorted(_2537,barsubi,barsubj,(long long)((int)0),nbarnz,false)))
  {
    {
      ::mosek::fusion::p_Sort::argsort(_2537,barsubi,barsubj,(long long)((int)0),nbarnz,false);
      std::shared_ptr< monty::ndarray< int,1 > > _2539 = barsubi;
      _checked_ptr_1<int> _ptr__2539(_2539 ? _2539->raw() : nullptr,_2539 ? _2539->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2540 = barsubj;
      _checked_ptr_1<int> _ptr__2540(_2540 ? _2540->raw() : nullptr,_2540 ? _2540->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2541 = barmatidx;
      _checked_ptr_1<int> _ptr__2541(_2541 ? _2541->raw() : nullptr,_2541 ? _2541->size(0) : 0);
      std::vector<int> _9905;
      for (long long _2542 = (int)0, _9906 = nbarnz; _2542 < _9906 ; ++_2542)
      {
        _9905.push_back(_ptr__2539[_ptr__2537[_2542]]);
      }
      auto _9907 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9905.size()),_9905.begin(),_9905.end()));
      barsubi = _9907;
      std::vector<int> _9908;
      for (long long _2543 = (int)0, _9909 = nbarnz; _2543 < _9909 ; ++_2543)
      {
        _9908.push_back(_ptr__2540[_ptr__2537[_2543]]);
      }
      auto _9910 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9908.size()),_9908.begin(),_9908.end()));
      barsubj = _9910;
      std::vector<int> _9911;
      for (long long _2544 = (int)0, _9912 = nbarnz; _2544 < _9912 ; ++_2544)
      {
        _9911.push_back(_ptr__2541[_ptr__2537[_2544]]);
      }
      auto _9913 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9911.size()),_9911.begin(),_9911.end()));
      barmatidx = _9913;
    }
  }
  {}
  return nbarnz;
}
void mosek::fusion::p_ConstraintCache::add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2545,std::shared_ptr< monty::ndarray< int,1 > > _2546,std::shared_ptr< monty::ndarray< int,1 > > _2547){
  _checked_ptr_1<int> _ptr__2545(_2545 ? _2545->raw() : nullptr, _2545 ? _2545->size(0) : 0);
  _checked_ptr_1<int> _ptr__2546(_2546 ? _2546->raw() : nullptr, _2546 ? _2546->size(0) : 0);
  _checked_ptr_1<int> _ptr__2547(_2547 ? _2547->raw() : nullptr, _2547 ? _2547->size(0) : 0);
  if ((NULL != _2545.get()))
  {
    {
      int _2548 = (int)((_2545)->size(0));
      if (((int)((_2545)->size(0)) <= safe_add( nbarnz,_2548 )))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2549 = barsubi;
          _checked_ptr_1<int> _ptr__2549(_2549 ? _2549->raw() : nullptr,_2549 ? _2549->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2550 = barsubj;
          _checked_ptr_1<int> _ptr__2550(_2550 ? _2550->raw() : nullptr,_2550 ? _2550->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2551 = barmatidx;
          _checked_ptr_1<int> _ptr__2551(_2551 ? _2551->raw() : nullptr,_2551 ? _2551->size(0) : 0);
          long long _9914;
          bool _9915 = (safe_mul( (int)2,nbarnz ) > safe_add( nbarnz,_2548 ));
          if (_9915)
          {
            _9914 = safe_mul( (int)2,nbarnz );
          }
          else
          {
            _9914 = safe_add( nbarnz,safe_mul( _2548,(int)2 ) );
          }
          long long _2552 = _9914;
          barsubi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2552)));
          barsubj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2552)));
          barmatidx = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2552)));
          if ((nbarnz > (int)0))
          {
            {
              ::mosek::fusion::Utils::Tools::arraycopy(_2549,(long long)((int)0),barsubi,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2550,(long long)((int)0),barsubj,(long long)((int)0),nbarnz);
              ::mosek::fusion::Utils::Tools::arraycopy(_2551,(long long)((int)0),barmatidx,(long long)((int)0),nbarnz);
            }
          }
          {}
        }
      }
      {}
      ::mosek::fusion::Utils::Tools::arraycopy(_2545,(long long)((int)0),barsubi,nbarnz,(long long)(_2548));
      ::mosek::fusion::Utils::Tools::arraycopy(_2546,(long long)((int)0),barsubj,nbarnz,(long long)(_2548));
      ::mosek::fusion::Utils::Tools::arraycopy(_2547,(long long)((int)0),barmatidx,nbarnz,(long long)(_2548));
      nbarnz += _2548;
    }
  }
  {}
}
void mosek::fusion::p_ConstraintCache::unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2553,std::shared_ptr< monty::ndarray< int,1 > > _2554,std::shared_ptr< monty::ndarray< double,1 > > _2555,std::shared_ptr< monty::ndarray< double,1 > > _2556){
  _checked_ptr_1<long long> _ptr__2553(_2553 ? _2553->raw() : nullptr, _2553 ? _2553->size(0) : 0);
  _checked_ptr_1<int> _ptr__2554(_2554 ? _2554->raw() : nullptr, _2554 ? _2554->size(0) : 0);
  _checked_ptr_1<double> _ptr__2555(_2555 ? _2555->raw() : nullptr, _2555 ? _2555->size(0) : 0);
  _checked_ptr_1<double> _ptr__2556(_2556 ? _2556->raw() : nullptr, _2556 ? _2556->size(0) : 0);
  long long _2557 = safe_add( nunordered,_ptr__2553[nrows] );
  long long _2558 = _ptr__2553[nrows];
  std::shared_ptr< monty::ndarray< int,1 > > _2559;
  _checked_ptr_1<int> _ptr__2559(_2559 ? _2559->raw() : nullptr,_2559 ? _2559->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2560;
  _checked_ptr_1<int> _ptr__2560(_2560 ? _2560->raw() : nullptr,_2560 ? _2560->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2561;
  _checked_ptr_1<double> _ptr__2561(_2561 ? _2561->raw() : nullptr,_2561 ? _2561->size(0) : 0);
  if (((NULL == buffer_cof.get()) || ((int)((buffer_cof)->size(0)) < _2557)))
  {
    {
      _2559 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2557)));
      _ptr__2559.update(_2559 ? _2559->raw() : nullptr, _2559 ? _2559->size(0) : 0);
      _2560 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2557)));
      _ptr__2560.update(_2560 ? _2560->raw() : nullptr, _2560 ? _2560->size(0) : 0);
      _2561 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2557)));
      _ptr__2561.update(_2561 ? _2561->raw() : nullptr, _2561 ? _2561->size(0) : 0);
      if ((NULL != buffer_cof.get()))
      {
        {
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subi,(long long)0,_2559,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_subj,(long long)0,_2560,(long long)0,nunordered);
          ::mosek::fusion::Utils::Tools::arraycopy(buffer_cof,(long long)0,_2561,(long long)0,nunordered);
        }
      }
      {}
    }
  }
  else
  {
    {
      _2559 = buffer_subi;
      _ptr__2559.update(_2559 ? _2559->raw() : nullptr, _2559 ? _2559->size(0) : 0);
      _2560 = buffer_subj;
      _ptr__2560.update(_2560 ? _2560->raw() : nullptr, _2560 ? _2560->size(0) : 0);
      _2561 = buffer_cof;
      _ptr__2561.update(_2561 ? _2561->raw() : nullptr, _2561 ? _2561->size(0) : 0);
    }
  }
  int _9916 = (int)0;
  int _9917 = nrows;
  for (int _2562 = _9916; _2562 < _9917; ++_2562)
  {
    {
      long long _9918 = _ptr__2553[_2562];
      long long _9919 = _ptr__2553[safe_add( _2562,(int)1 )];
      for (long long _2563 = _9918; _2563 < _9919; ++_2563)
      {
        {
          _ptr__2559[safe_add( nunordered,_2563 )] = _2562;
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(_2554,(long long)0,_2560,nunordered,_2558);
  ::mosek::fusion::Utils::Tools::arraycopy(_2555,(long long)0,_2561,nunordered,_2558);
  buffer_subi = _2559;
  buffer_subj = _2560;
  buffer_cof = _2561;
  if ((NULL != _2556.get()))
  {
    {
      int _9920 = (int)0;
      int _9921 = nrows;
      for (int _2564 = _9920; _2564 < _9921; ++_2564)
      {
        {
          ((*bfix)(_2564)) = (((*bfix)(_2564)) + _ptr__2556[_2564]);
        }
      }
    }
  }
  {}
  nunordered = _2557;
}
void mosek::fusion::ConstraintCache :: add(std::shared_ptr< monty::ndarray< long long,1 > > _2565,std::shared_ptr< monty::ndarray< int,1 > > _2566,std::shared_ptr< monty::ndarray< double,1 > > _2567,std::shared_ptr< monty::ndarray< double,1 > > _2568) { mosek::fusion::p_ConstraintCache::_get_impl(this)->add(_2565,_2566,_2567,_2568); }void mosek::fusion::p_ConstraintCache::add(std::shared_ptr< monty::ndarray< long long,1 > > _2565,std::shared_ptr< monty::ndarray< int,1 > > _2566,std::shared_ptr< monty::ndarray< double,1 > > _2567,std::shared_ptr< monty::ndarray< double,1 > > _2568){
  _checked_ptr_1<long long> _ptr__2565(_2565 ? _2565->raw() : nullptr, _2565 ? _2565->size(0) : 0);
  _checked_ptr_1<int> _ptr__2566(_2566 ? _2566->raw() : nullptr, _2566 ? _2566->size(0) : 0);
  _checked_ptr_1<double> _ptr__2567(_2567 ? _2567->raw() : nullptr, _2567 ? _2567->size(0) : 0);
  _checked_ptr_1<double> _ptr__2568(_2568 ? _2568->raw() : nullptr, _2568 ? _2568->size(0) : 0);
  if ((((int)((_2565)->size(0)) != safe_add( nrows,(int)1 )) || ((NULL != _2568.get()) && ((int)((_2568)->size(0)) != nrows))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching expression lengths"));
    }
  }
  {}
  unchecked_add_l(_2565,_2566,_2567,_2568);
}
long long mosek::fusion::ConstraintCache :: flush(std::shared_ptr< monty::ndarray< int,1 > > _2569,std::shared_ptr< monty::ndarray< int,1 > > _2570,std::shared_ptr< monty::ndarray< double,1 > > _2571,std::shared_ptr< monty::ndarray< double,1 > > _2572) { return mosek::fusion::p_ConstraintCache::_get_impl(this)->flush(_2569,_2570,_2571,_2572); }long long mosek::fusion::p_ConstraintCache::flush(std::shared_ptr< monty::ndarray< int,1 > > _2569,std::shared_ptr< monty::ndarray< int,1 > > _2570,std::shared_ptr< monty::ndarray< double,1 > > _2571,std::shared_ptr< monty::ndarray< double,1 > > _2572){
  _checked_ptr_1<int> _ptr__2569(_2569 ? _2569->raw() : nullptr, _2569 ? _2569->size(0) : 0);
  _checked_ptr_1<int> _ptr__2570(_2570 ? _2570->raw() : nullptr, _2570 ? _2570->size(0) : 0);
  _checked_ptr_1<double> _ptr__2571(_2571 ? _2571->raw() : nullptr, _2571 ? _2571->size(0) : 0);
  _checked_ptr_1<double> _ptr__2572(_2572 ? _2572->raw() : nullptr, _2572 ? _2572->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _2573 = nullptr;
  _checked_ptr_1<long long> _ptr__2573(_2573 ? _2573->raw() : nullptr,_2573 ? _2573->size(0) : 0);
  if (((NULL != bfix.get()) && (NULL != _2572.get())))
  {
    {
      int _9922 = (int)0;
      int _9923 = nrows;
      for (int _2574 = _9922; _2574 < _9923; ++_2574)
      {
        {
          _ptr__2572[_2574] = ((*bfix)(_2574));
        }
      }
    }
  }
  {}
  if ((nunordered == (long long)0))
  {
    {
      return (long long)0;
    }
  }
  {}
  bool _2575 = false;
  {
    int _2576 = (int)1;
    while ( ((_2576 < nunordered) && ((((*buffer_subi)((_2576 - (int)1))) < ((*buffer_subi)(_2576))) || ((((*buffer_subi)((_2576 - (int)1))) == ((*buffer_subi)(_2576))) && (((*buffer_subj)((_2576 - (int)1))) <= ((*buffer_subj)(_2576)))))) )
    {
      {
        ++ _2576;
      }
    }
    _2575 = (_2576 == nunordered);
  }
  if ((!_2575))
  {
    {
      std::vector<long long> _9924;
      for (long long _2577 = (int)0, _9925 = nunordered; _2577 < _9925 ; ++_2577)
      {
        _9924.push_back(_2577);
      }
      auto _9926 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9924.size()),_9924.begin(),_9924.end()));
      _2573 = _9926;
      _ptr__2573.update(_2573 ? _2573->raw() : nullptr, _2573 ? _2573->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_2573,buffer_subi,buffer_subj,(long long)0,nunordered);
    }
  }
  {}
  long long _2578 = nnz;
  std::shared_ptr< monty::ndarray< int,1 > > _2579 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2578 ))));
  _checked_ptr_1<int> _ptr__2579(_2579 ? _2579->raw() : nullptr,_2579 ? _2579->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2580 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( nunordered,_2578 ))));
  _checked_ptr_1<int> _ptr__2580(_2580 ? _2580->raw() : nullptr,_2580 ? _2580->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _2581 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_add( nunordered,_2578 ))));
  _checked_ptr_1<double> _ptr__2581(_2581 ? _2581->raw() : nullptr,_2581 ? _2581->size(0) : 0);
  long long _2582 = (long long)0;
  if (_2575)
  {
    {
      long long _2583 = (long long)0;
      int _2584 = (int)0;
      long long _2585 = nunordered;
      long long _2586 = _2578;
      int _2587 = (int)0;
      int _2588 = (int)0;
      while ( ((_2588 < _2586) && (_2587 < _2585)) )
      {
        {
          if (((((*subi)(_2588)) < ((*buffer_subi)(_2587))) || ((((*subi)(_2588)) == ((*buffer_subi)(_2587))) && (((*subj)(_2588)) < ((*buffer_subj)(_2587))))))
          {
            {
              _ptr__2579[_2584] = ((*subi)(_2588));
              _ptr__2580[_2584] = ((*subj)(_2588));
              _ptr__2581[_2584] = ((*cof)(_2588));
              ++ _2588;
              ++ _2584;
            }
          }
          else if(((((*subi)(_2588)) > ((*buffer_subi)(_2587))) || ((((*subi)(_2588)) == ((*buffer_subi)(_2587))) && (((*subj)(_2588)) > ((*buffer_subj)(_2587))))))
          {
            {
              _ptr__2579[_2584] = ((*buffer_subi)(_2587));
              _ptr__2580[_2584] = ((*buffer_subj)(_2587));
              _ptr__2581[_2584] = ((*buffer_cof)(_2587));
              _ptr__2569[_2582] = _ptr__2579[_2584];
              _ptr__2570[_2582] = _ptr__2580[_2584];
              _ptr__2571[_2582] = _ptr__2581[_2584];
              ++ _2582;
              ++ _2587;
              ++ _2584;
            }
          }
          else
          {
            {
              _ptr__2579[_2584] = ((*subi)(_2588));
              _ptr__2580[_2584] = ((*subj)(_2588));
              _ptr__2581[_2584] = ((*cof)(_2588));
              while ( ((_2588 < (int)((subi)->size(0))) && ((_2587 < (int)((buffer_subi)->size(0))) && ((((*subi)(_2588)) == ((*buffer_subi)(_2587))) && (((*subj)(_2588)) == ((*buffer_subj)(_2587)))))) )
              {
                {
                  _ptr__2581[_2584] = (_ptr__2581[_2584] + ((*buffer_cof)(_2587)));
                  ++ _2587;
                }
              }
              _ptr__2569[_2582] = _ptr__2579[_2584];
              _ptr__2570[_2582] = _ptr__2580[_2584];
              _ptr__2571[_2582] = _ptr__2581[_2584];
              ++ _2582;
              ++ _2588;
              ++ _2584;
            }
          }
        }
      }
      while ( (_2588 < _2586) )
      {
        {
          _ptr__2579[_2584] = ((*subi)(_2588));
          _ptr__2580[_2584] = ((*subj)(_2588));
          _ptr__2581[_2584] = ((*cof)(_2588));
          ++ _2588;
          ++ _2584;
        }
      }
      while ( (_2587 < _2585) )
      {
        {
          _ptr__2579[_2584] = ((*buffer_subi)(_2587));
          _ptr__2580[_2584] = ((*buffer_subj)(_2587));
          _ptr__2581[_2584] = ((*buffer_cof)(_2587));
          _ptr__2569[_2582] = _ptr__2579[_2584];
          _ptr__2570[_2582] = _ptr__2580[_2584];
          _ptr__2571[_2582] = _ptr__2581[_2584];
          ++ _2582;
          ++ _2587;
          ++ _2584;
        }
      }
      nnz = _2584;
    }
  }
  else
  {
    {
      long long _2589 = (long long)0;
      int _2590 = (int)0;
      long long _2591 = nunordered;
      long long _2592 = _2578;
      int _2593 = (int)0;
      int _2594 = (int)0;
      while ( ((_2594 < _2592) && (_2593 < _2591)) )
      {
        {
          if (((((*subi)(_2594)) < ((*buffer_subi)(_ptr__2573[_2593]))) || ((((*subi)(_2594)) == ((*buffer_subi)(_ptr__2573[_2593]))) && (((*subj)(_2594)) < ((*buffer_subj)(_ptr__2573[_2593]))))))
          {
            {
              _ptr__2579[_2590] = ((*subi)(_2594));
              _ptr__2580[_2590] = ((*subj)(_2594));
              _ptr__2581[_2590] = ((*cof)(_2594));
              ++ _2594;
              ++ _2590;
            }
          }
          else if(((((*subi)(_2594)) > ((*buffer_subi)(_ptr__2573[_2593]))) || ((((*subi)(_2594)) == ((*buffer_subi)(_ptr__2573[_2593]))) && (((*subj)(_2594)) > ((*buffer_subj)(_ptr__2573[_2593]))))))
          {
            {
              _ptr__2579[_2590] = ((*buffer_subi)(_ptr__2573[_2593]));
              _ptr__2580[_2590] = ((*buffer_subj)(_ptr__2573[_2593]));
              _ptr__2581[_2590] = ((*buffer_cof)(_ptr__2573[_2593]));
              _ptr__2569[_2582] = _ptr__2579[_2590];
              _ptr__2570[_2582] = _ptr__2580[_2590];
              _ptr__2571[_2582] = _ptr__2581[_2590];
              ++ _2582;
              ++ _2593;
              ++ _2590;
            }
          }
          else
          {
            {
              _ptr__2579[_2590] = ((*subi)(_2594));
              _ptr__2580[_2590] = ((*subj)(_2594));
              _ptr__2581[_2590] = ((*cof)(_2594));
              while ( ((((*subi)(_2594)) == ((*buffer_subi)(_ptr__2573[_2593]))) && (((*subj)(_2594)) == ((*buffer_subj)(_ptr__2573[_2593])))) )
              {
                {
                  _ptr__2581[_2590] = (_ptr__2581[_2590] + ((*buffer_cof)(_ptr__2573[_2593])));
                  ++ _2593;
                }
              }
              _ptr__2569[_2582] = _ptr__2579[_2590];
              _ptr__2570[_2582] = _ptr__2580[_2590];
              _ptr__2571[_2582] = _ptr__2581[_2590];
              ++ _2582;
              ++ _2594;
              ++ _2590;
            }
          }
        }
      }
      nnz = _2590;
    }
  }
  subi = _2579;
  subj = _2580;
  cof = _2581;
  nunordered = (long long)0;
  return _2582;
}
long long mosek::fusion::ConstraintCache :: numUnsorted() { return mosek::fusion::p_ConstraintCache::_get_impl(this)->numUnsorted(); }long long mosek::fusion::p_ConstraintCache::numUnsorted(){
  return nunordered;
}
monty::rc_ptr< ::mosek::fusion::ConstraintCache > mosek::fusion::p_ConstraintCache::__mosek_2fusion_2ConstraintCache__clone(){
  return ::mosek::fusion::p_ConstraintCache::_new_ConstraintCache(::mosek::fusion::ConstraintCache::t(_pubthis));
}
void mosek::fusion::p_ConstraintCache::destroy(){barmatidx.reset();barsubj.reset();barsubi.reset();buffer_subi.reset();buffer_subj.reset();buffer_cof.reset();bfix.reset();cof.reset();subi.reset();subj.reset();}void mosek::fusion::ConstraintCache::destroy() { mosek::fusion::p_ConstraintCache::_get_impl(this)->destroy(); }mosek::fusion::BoundInterfaceConstraint::BoundInterfaceConstraint(mosek::fusion::p_BoundInterfaceConstraint *_impl) : mosek::fusion::SliceConstraint(_impl) { /*std::cout << "BoundInterfaceConstraint()" << this << std::endl; */ }mosek::fusion::BoundInterfaceConstraint::~BoundInterfaceConstraint() {  /* std::cout << "~BoundInterfaceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_BoundInterfaceConstraint::p_BoundInterfaceConstraint  (::mosek::fusion::BoundInterfaceConstraint * _pubthis) :     mosek::fusion::p_SliceConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::BoundInterfaceConstraint::t mosek::fusion::p_BoundInterfaceConstraint::_new_BoundInterfaceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2595,    std::shared_ptr< monty::ndarray< int,1 > > _2596,    std::shared_ptr< monty::ndarray< int,1 > > _2597,    bool _2598){ return new mosek::fusion::BoundInterfaceConstraint(_2595,_2596,_2597,_2598); }mosek::fusion::BoundInterfaceConstraint::BoundInterfaceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2595,    std::shared_ptr< monty::ndarray< int,1 > > _2596,    std::shared_ptr< monty::ndarray< int,1 > > _2597,    bool _2598) :    BoundInterfaceConstraint(new mosek::fusion::p_BoundInterfaceConstraint(this)){ mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->_initialize(_2595,_2596,_2597,_2598); }void mosek::fusion::p_BoundInterfaceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2595,    std::shared_ptr< monty::ndarray< int,1 > > _2596,    std::shared_ptr< monty::ndarray< int,1 > > _2597,    bool _2598){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2596(_2596 ? _2596->raw() : nullptr, _2596 ? _2596->size(0) : 0);
    _checked_ptr_1<int> _ptr__2597(_2597 ? _2597->raw() : nullptr, _2597 ? _2597->size(0) : 0);
    mosek::fusion::p_SliceConstraint::_initialize(_2595,_2596,_2597);
    mosek::fusion::p_BoundInterfaceConstraint::_get_impl(::mosek::fusion::BoundInterfaceConstraint::t(_pubthis))->islower = _2598;
  }
}mosek::fusion::BoundInterfaceConstraint::t mosek::fusion::p_BoundInterfaceConstraint::_new_BoundInterfaceConstraint  (monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2599,    bool _2600){ return new mosek::fusion::BoundInterfaceConstraint(_2599,_2600); }mosek::fusion::BoundInterfaceConstraint::BoundInterfaceConstraint  (monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2599,    bool _2600) :    BoundInterfaceConstraint(new mosek::fusion::p_BoundInterfaceConstraint(this)){ mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->_initialize(_2599,_2600); }void mosek::fusion::p_BoundInterfaceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2599,    bool _2600){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SliceConstraint::_initialize(_2599);
    mosek::fusion::p_BoundInterfaceConstraint::_get_impl(::mosek::fusion::BoundInterfaceConstraint::t(_pubthis))->islower = _2600;
  }
}std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::BoundInterfaceConstraint :: dual() { return mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_BoundInterfaceConstraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2601 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_pubthis->getSize())));
  _checked_ptr_1<double> _ptr__2601(_2601 ? _2601->raw() : nullptr,_2601 ? _2601->size(0) : 0);
  dual_lu((int)0,_2601,islower);
  return _2601;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint :: __mosek_2fusion_2BoundInterfaceConstraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603) { return mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->__mosek_2fusion_2BoundInterfaceConstraint__slice(_2602,_2603); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603) { return __mosek_2fusion_2BoundInterfaceConstraint__slice(_2602,_2603); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603) { return __mosek_2fusion_2BoundInterfaceConstraint__slice(_2602,_2603); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_BoundInterfaceConstraint::__mosek_2fusion_2BoundInterfaceConstraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603){
  _checked_ptr_1<int> _ptr__2602(_2602 ? _2602->raw() : nullptr, _2602 ? _2602->size(0) : 0);
  _checked_ptr_1<int> _ptr__2603(_2603 ? _2603->raw() : nullptr, _2603 ? _2603->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Constraint > _2604 = ::mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(_2602,_2603);
  return (__mosek_2fusion_2BoundInterfaceConstraint__from_(_2604)).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint :: __mosek_2fusion_2BoundInterfaceConstraint__slice(int _2605,int _2606) { return mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->__mosek_2fusion_2BoundInterfaceConstraint__slice(_2605,_2606); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::slice(int _2605,int _2606) { return __mosek_2fusion_2BoundInterfaceConstraint__slice(_2605,_2606); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::__mosek_2fusion_2Constraint__slice(int _2605,int _2606) { return __mosek_2fusion_2BoundInterfaceConstraint__slice(_2605,_2606); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_BoundInterfaceConstraint::__mosek_2fusion_2BoundInterfaceConstraint__slice(int _2605,int _2606){
  monty::rc_ptr< ::mosek::fusion::Constraint > _2607 = ::mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(_2605,_2606);
  return (__mosek_2fusion_2BoundInterfaceConstraint__from_(_2607)).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint :: __mosek_2fusion_2BoundInterfaceConstraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2608) { return mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->__mosek_2fusion_2BoundInterfaceConstraint__index(_2608); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2608) { return __mosek_2fusion_2BoundInterfaceConstraint__index(_2608); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2608) { return __mosek_2fusion_2BoundInterfaceConstraint__index(_2608); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_BoundInterfaceConstraint::__mosek_2fusion_2BoundInterfaceConstraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2608){
  _checked_ptr_1<int> _ptr__2608(_2608 ? _2608->raw() : nullptr, _2608 ? _2608->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Constraint > _2609 = ::mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(_2608);
  return (__mosek_2fusion_2BoundInterfaceConstraint__from_(_2609)).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint :: __mosek_2fusion_2BoundInterfaceConstraint__index(int _2610) { return mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->__mosek_2fusion_2BoundInterfaceConstraint__index(_2610); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::index(int _2610) { return __mosek_2fusion_2BoundInterfaceConstraint__index(_2610); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::BoundInterfaceConstraint::__mosek_2fusion_2Constraint__index(int _2610) { return __mosek_2fusion_2BoundInterfaceConstraint__index(_2610); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_BoundInterfaceConstraint::__mosek_2fusion_2BoundInterfaceConstraint__index(int _2610){
  monty::rc_ptr< ::mosek::fusion::Constraint > _2611 = ::mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(_2610);
  return (__mosek_2fusion_2BoundInterfaceConstraint__from_(_2611)).as<::mosek::fusion::Constraint>();
}
monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > mosek::fusion::p_BoundInterfaceConstraint::__mosek_2fusion_2BoundInterfaceConstraint__from_(monty::rc_ptr< ::mosek::fusion::Constraint > _2612){
  monty::rc_ptr< ::mosek::fusion::Constraint > _9927 = _2612;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::SliceConstraint*>(_9927.get()))
  {
    ::mosek::fusion::SliceConstraint::t _2613 (dynamic_cast<::mosek::fusion::SliceConstraint*>(_9927.get()));
    {
      return ::mosek::fusion::p_BoundInterfaceConstraint::_new_BoundInterfaceConstraint(_2613,islower);
    }
  }
  else
  {
    mosek::fusion::Constraint::t _2614 = _9927;
    {
      return nullptr;
    }
  }
}
void mosek::fusion::p_BoundInterfaceConstraint::destroy(){}void mosek::fusion::BoundInterfaceConstraint::destroy() { mosek::fusion::p_BoundInterfaceConstraint::_get_impl(this)->destroy(); }mosek::fusion::SliceConstraint::SliceConstraint(mosek::fusion::p_SliceConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "SliceConstraint()" << this << std::endl; */ }mosek::fusion::SliceConstraint::~SliceConstraint() {  /* std::cout << "~SliceConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_SliceConstraint::p_SliceConstraint  (::mosek::fusion::SliceConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2615){ return new mosek::fusion::SliceConstraint(_2615); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2615) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2615); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2615){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2615,_2615->__mosek_2fusion_2Constraint__getModel());
  }
}mosek::fusion::SliceConstraint::t mosek::fusion::p_SliceConstraint::_new_SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2616,    std::shared_ptr< monty::ndarray< int,1 > > _2617,    std::shared_ptr< monty::ndarray< int,1 > > _2618){ return new mosek::fusion::SliceConstraint(_2616,_2617,_2618); }mosek::fusion::SliceConstraint::SliceConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2616,    std::shared_ptr< monty::ndarray< int,1 > > _2617,    std::shared_ptr< monty::ndarray< int,1 > > _2618) :    SliceConstraint(new mosek::fusion::p_SliceConstraint(this)){ mosek::fusion::p_SliceConstraint::_get_impl(this)->_initialize(_2616,_2617,_2618); }void mosek::fusion::p_SliceConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2616,    std::shared_ptr< monty::ndarray< int,1 > > _2617,    std::shared_ptr< monty::ndarray< int,1 > > _2618){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2617(_2617 ? _2617->raw() : nullptr, _2617 ? _2617->size(0) : 0);
    _checked_ptr_1<int> _ptr__2618(_2618 ? _2618->raw() : nullptr, _2618 ? _2618->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2616,_2617,_2618);
  }
}std::string mosek::fusion::SliceConstraint :: toString() { return mosek::fusion::p_SliceConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_SliceConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2619 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2619->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SliceConstraint()"));
  return _2619->toString();
}
void mosek::fusion::p_SliceConstraint::destroy(){}void mosek::fusion::SliceConstraint::destroy() { mosek::fusion::p_SliceConstraint::_get_impl(this)->destroy(); }mosek::fusion::RangedConstraint::RangedConstraint(mosek::fusion::p_RangedConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "RangedConstraint()" << this << std::endl; */ }mosek::fusion::RangedConstraint::~RangedConstraint() {  /* std::cout << "~RangedConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_RangedConstraint::p_RangedConstraint  (::mosek::fusion::RangedConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2620,    monty::rc_ptr< ::mosek::fusion::Model > _2621){ return new mosek::fusion::RangedConstraint(_2620,_2621); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2620,    monty::rc_ptr< ::mosek::fusion::Model > _2621) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2620,_2621); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2620,    monty::rc_ptr< ::mosek::fusion::Model > _2621){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2620,_2621);
    shape = mosek::fusion::p_RangedConstraint::_get_impl(_2620)->shape;
    nativeidxs = mosek::fusion::p_RangedConstraint::_get_impl(_2620)->nativeidxs;
  }
}mosek::fusion::RangedConstraint::t mosek::fusion::p_RangedConstraint::_new_RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2622,    const std::string &  _2623,    std::shared_ptr< monty::ndarray< int,1 > > _2624,    std::shared_ptr< monty::ndarray< int,1 > > _2625,    int _2626){ return new mosek::fusion::RangedConstraint(_2622,_2623,_2624,_2625,_2626); }mosek::fusion::RangedConstraint::RangedConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2622,    const std::string &  _2623,    std::shared_ptr< monty::ndarray< int,1 > > _2624,    std::shared_ptr< monty::ndarray< int,1 > > _2625,    int _2626) :    RangedConstraint(new mosek::fusion::p_RangedConstraint(this)){ mosek::fusion::p_RangedConstraint::_get_impl(this)->_initialize(_2622,_2623,_2624,_2625,_2626); }void mosek::fusion::p_RangedConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2622,    const std::string &  _2623,    std::shared_ptr< monty::ndarray< int,1 > > _2624,    std::shared_ptr< monty::ndarray< int,1 > > _2625,    int _2626){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2624(_2624 ? _2624->raw() : nullptr, _2624 ? _2624->size(0) : 0);
    _checked_ptr_1<int> _ptr__2625(_2625 ? _2625->raw() : nullptr, _2625 ? _2625->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2622,_2623,_2624,_2625,_2626);
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->shape = _2624;
    mosek::fusion::p_RangedConstraint::_get_impl(::mosek::fusion::RangedConstraint::t(_pubthis))->nativeidxs = _2625;
  }
}monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > mosek::fusion::RangedConstraint :: __mosek_2fusion_2RangedConstraint__upperBoundCon() { return mosek::fusion::p_RangedConstraint::_get_impl(this)->__mosek_2fusion_2RangedConstraint__upperBoundCon(); }monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > mosek::fusion::RangedConstraint::upperBoundCon() { return __mosek_2fusion_2RangedConstraint__upperBoundCon(); }
monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__upperBoundCon(){
  return ::mosek::fusion::p_BoundInterfaceConstraint::_new_BoundInterfaceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),shape,nativeidxs,false);
}
monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > mosek::fusion::RangedConstraint :: __mosek_2fusion_2RangedConstraint__lowerBoundCon() { return mosek::fusion::p_RangedConstraint::_get_impl(this)->__mosek_2fusion_2RangedConstraint__lowerBoundCon(); }monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > mosek::fusion::RangedConstraint::lowerBoundCon() { return __mosek_2fusion_2RangedConstraint__lowerBoundCon(); }
monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__lowerBoundCon(){
  return ::mosek::fusion::p_BoundInterfaceConstraint::_new_BoundInterfaceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),shape,nativeidxs,true);
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_RangedConstraint::__mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2627){
  return (::mosek::fusion::p_RangedConstraint::_new_RangedConstraint(::mosek::fusion::RangedConstraint::t(_pubthis),_2627)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_RangedConstraint::destroy(){nativeidxs.reset();shape.reset();}void mosek::fusion::RangedConstraint::destroy() { mosek::fusion::p_RangedConstraint::_get_impl(this)->destroy(); }mosek::fusion::ConicConstraint::ConicConstraint(mosek::fusion::p_ConicConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "ConicConstraint()" << this << std::endl; */ }mosek::fusion::ConicConstraint::~ConicConstraint() {  /* std::cout << "~ConicConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ConicConstraint::p_ConicConstraint  (::mosek::fusion::ConicConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2628,    monty::rc_ptr< ::mosek::fusion::Model > _2629){ return new mosek::fusion::ConicConstraint(_2628,_2629); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2628,    monty::rc_ptr< ::mosek::fusion::Model > _2629) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2628,_2629); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2628,    monty::rc_ptr< ::mosek::fusion::Model > _2629){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2628,_2629);
    dom = mosek::fusion::p_ConicConstraint::_get_impl(_2628)->dom;
    conid = mosek::fusion::p_ConicConstraint::_get_impl(_2628)->conid;
    shape = mosek::fusion::p_ConicConstraint::_get_impl(_2628)->shape;
    name = mosek::fusion::p_ConicConstraint::_get_impl(_2628)->name;
    nativeidxs = mosek::fusion::p_ConicConstraint::_get_impl(_2628)->nativeidxs;
    nativeslack = mosek::fusion::p_ConicConstraint::_get_impl(_2628)->nativeslack;
    names_flushed = mosek::fusion::p_ConicConstraint::_get_impl(_2628)->names_flushed;
  }
}mosek::fusion::ConicConstraint::t mosek::fusion::p_ConicConstraint::_new_ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2630,    const std::string &  _2631,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2632,    std::shared_ptr< monty::ndarray< int,1 > > _2633,    int _2634,    std::shared_ptr< monty::ndarray< int,1 > > _2635,    std::shared_ptr< monty::ndarray< int,1 > > _2636){ return new mosek::fusion::ConicConstraint(_2630,_2631,_2632,_2633,_2634,_2635,_2636); }mosek::fusion::ConicConstraint::ConicConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2630,    const std::string &  _2631,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2632,    std::shared_ptr< monty::ndarray< int,1 > > _2633,    int _2634,    std::shared_ptr< monty::ndarray< int,1 > > _2635,    std::shared_ptr< monty::ndarray< int,1 > > _2636) :    ConicConstraint(new mosek::fusion::p_ConicConstraint(this)){ mosek::fusion::p_ConicConstraint::_get_impl(this)->_initialize(_2630,_2631,_2632,_2633,_2634,_2635,_2636); }void mosek::fusion::p_ConicConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2630,    const std::string &  _2631,    monty::rc_ptr< ::mosek::fusion::ConeDomain > _2632,    std::shared_ptr< monty::ndarray< int,1 > > _2633,    int _2634,    std::shared_ptr< monty::ndarray< int,1 > > _2635,    std::shared_ptr< monty::ndarray< int,1 > > _2636){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2633(_2633 ? _2633->raw() : nullptr, _2633 ? _2633->size(0) : 0);
    _checked_ptr_1<int> _ptr__2635(_2635 ? _2635->raw() : nullptr, _2635 ? _2635->size(0) : 0);
    _checked_ptr_1<int> _ptr__2636(_2636 ? _2636->raw() : nullptr, _2636 ? _2636->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2630,_2631,_2633,_2635,_2634);
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->dom = _2632;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->shape = _2633;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->name = _2631;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeidxs = _2635;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->nativeslack = _2636;
    mosek::fusion::p_ConicConstraint::_get_impl(::mosek::fusion::ConicConstraint::t(_pubthis))->conid = _2634;
    names_flushed = false;
  }
}void mosek::fusion::p_ConicConstraint::flushNames(){
  ::mosek::fusion::p_ModelConstraint::flushNames();
  int _2637 = (int)((nativeslack)->size(0));
  monty::rc_ptr< ::mosek::fusion::Model > _2638 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if (((!names_flushed) && ((int)((name).size()) > (int)0)))
  {
    {
      if (((int)((name).size()) == (int)0))
      {
        {
          int _9928 = (int)0;
          int _9929 = _2637;
          for (int _2639 = _9928; _2639 < _9929; ++_2639)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2638.get())->task_var_name(((*nativeslack)(_2639)),std::string (""));
            }
          }
        }
      }
      else
      {
        {
          monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2640 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
          int _9930 = (int)0;
          int _9931 = _2637;
          for (int _2641 = _9930; _2641 < _9931; ++_2641)
          {
            {
              mosek::fusion::p_Model::_get_impl(_2638.get())->task_var_name(((*nativeslack)(_2641)),_2640->__mosek_2fusion_2Utils_2StringBuffer__clear()->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["))->__mosek_2fusion_2Utils_2StringBuffer__a(::mosek::fusion::p_Set::indexToString(shape,(long long)(_2641)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("].coneslack"))->toString());
            }
          }
        }
      }
      names_flushed = true;
    }
  }
  {}
}
std::string mosek::fusion::ConicConstraint :: toString() { return mosek::fusion::p_ConicConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ConicConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2642 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2642->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ConicConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2642->toString();
}
void mosek::fusion::p_ConicConstraint::domainToString(long long _2643,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2644){
  throw ::mosek::fusion::UnimplementedError(std::string ("ConicConstraint.domainToString"));
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_ConicConstraint::__mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2645){
  return (::mosek::fusion::p_ConicConstraint::_new_ConicConstraint(::mosek::fusion::ConicConstraint::t(_pubthis),_2645)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_ConicConstraint::destroy(){nativeslack.reset();nativeidxs.reset();shape.reset();dom.reset();}void mosek::fusion::ConicConstraint::destroy() { mosek::fusion::p_ConicConstraint::_get_impl(this)->destroy(); }mosek::fusion::LinearConstraint::LinearConstraint(mosek::fusion::p_LinearConstraint *_impl) : mosek::fusion::ModelConstraint(_impl) { /*std::cout << "LinearConstraint()" << this << std::endl; */ }mosek::fusion::LinearConstraint::~LinearConstraint() {  /* std::cout << "~LinearConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_LinearConstraint::p_LinearConstraint  (::mosek::fusion::LinearConstraint * _pubthis) :     mosek::fusion::p_ModelConstraint(_pubthis),    _pubthis(_pubthis){}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2646,    monty::rc_ptr< ::mosek::fusion::Model > _2647){ return new mosek::fusion::LinearConstraint(_2646,_2647); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2646,    monty::rc_ptr< ::mosek::fusion::Model > _2647) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2646,_2647); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2646,    monty::rc_ptr< ::mosek::fusion::Model > _2647){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ModelConstraint::_initialize(_2646,_2647);
    conid = mosek::fusion::p_LinearConstraint::_get_impl(_2646)->conid;
    name = mosek::fusion::p_LinearConstraint::_get_impl(_2646)->name;
  }
}mosek::fusion::LinearConstraint::t mosek::fusion::p_LinearConstraint::_new_LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2648,    const std::string &  _2649,    int _2650,    std::shared_ptr< monty::ndarray< int,1 > > _2651,    std::shared_ptr< monty::ndarray< int,1 > > _2652){ return new mosek::fusion::LinearConstraint(_2648,_2649,_2650,_2651,_2652); }mosek::fusion::LinearConstraint::LinearConstraint  (monty::rc_ptr< ::mosek::fusion::Model > _2648,    const std::string &  _2649,    int _2650,    std::shared_ptr< monty::ndarray< int,1 > > _2651,    std::shared_ptr< monty::ndarray< int,1 > > _2652) :    LinearConstraint(new mosek::fusion::p_LinearConstraint(this)){ mosek::fusion::p_LinearConstraint::_get_impl(this)->_initialize(_2648,_2649,_2650,_2651,_2652); }void mosek::fusion::p_LinearConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2648,    const std::string &  _2649,    int _2650,    std::shared_ptr< monty::ndarray< int,1 > > _2651,    std::shared_ptr< monty::ndarray< int,1 > > _2652){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2651(_2651 ? _2651->raw() : nullptr, _2651 ? _2651->size(0) : 0);
    _checked_ptr_1<int> _ptr__2652(_2652 ? _2652->raw() : nullptr, _2652 ? _2652->size(0) : 0);
    mosek::fusion::p_ModelConstraint::_initialize(_2648,_2649,_2651,_2652,_2650);
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->conid = _2650;
    mosek::fusion::p_LinearConstraint::_get_impl(::mosek::fusion::LinearConstraint::t(_pubthis))->name = _2649;
  }
}std::string mosek::fusion::LinearConstraint :: toString() { return mosek::fusion::p_LinearConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_LinearConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2653 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2653->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("LinearConstraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2653->toString();
}
void mosek::fusion::p_LinearConstraint::domainToString(long long _2654,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2655){
}
monty::rc_ptr< ::mosek::fusion::ModelConstraint > mosek::fusion::p_LinearConstraint::__mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2656){
  return (::mosek::fusion::p_LinearConstraint::_new_LinearConstraint(::mosek::fusion::LinearConstraint::t(_pubthis),_2656)).as<::mosek::fusion::ModelConstraint>();
}
void mosek::fusion::p_LinearConstraint::destroy(){}void mosek::fusion::LinearConstraint::destroy() { mosek::fusion::p_LinearConstraint::_get_impl(this)->destroy(); }mosek::fusion::ModelConstraint::ModelConstraint(mosek::fusion::p_ModelConstraint *_impl) : mosek::fusion::Constraint(_impl) { /*std::cout << "ModelConstraint()" << this << std::endl; */ }mosek::fusion::ModelConstraint::~ModelConstraint() {  /* std::cout << "~ModelConstraint()" << this << std::endl << std::flush; */ }mosek::fusion::p_ModelConstraint::p_ModelConstraint  (::mosek::fusion::ModelConstraint * _pubthis) :     mosek::fusion::p_Constraint(_pubthis),    _pubthis(_pubthis){}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2657,    monty::rc_ptr< ::mosek::fusion::Model > _2658){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Constraint::_initialize(_2657,_2658);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->conid = mosek::fusion::p_ModelConstraint::_get_impl(_2657)->conid;
    name = mosek::fusion::p_ModelConstraint::_get_impl(_2657)->name;
    names_flushed = mosek::fusion::p_ModelConstraint::_get_impl(_2657)->names_flushed;
    nativeidxs = mosek::fusion::p_ModelConstraint::_get_impl(_2657)->nativeidxs;
    shape = mosek::fusion::p_ModelConstraint::_get_impl(_2657)->shape;
  }
}void mosek::fusion::p_ModelConstraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2659,    const std::string &  _2660,    std::shared_ptr< monty::ndarray< int,1 > > _2661,    std::shared_ptr< monty::ndarray< int,1 > > _2662,    int _2663){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2661(_2661 ? _2661->raw() : nullptr, _2661 ? _2661->size(0) : 0);
    _checked_ptr_1<int> _ptr__2662(_2662 ? _2662->raw() : nullptr, _2662 ? _2662->size(0) : 0);
    mosek::fusion::p_Constraint::_initialize(_2659,_2661,_2662);
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->name = _2660;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->names_flushed = false;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->nativeidxs = _2662;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->shape = _2661;
    mosek::fusion::p_ModelConstraint::_get_impl(::mosek::fusion::ModelConstraint::t(_pubthis))->conid = _2663;
  }
}std::string mosek::fusion::ModelConstraint :: toString() { return mosek::fusion::p_ModelConstraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_ModelConstraint::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2664 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2664->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraint('"))->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("')"));
  return _2664->toString();
}
void mosek::fusion::p_ModelConstraint::flushNames(){
  monty::rc_ptr< ::mosek::fusion::Model > _2665 = _pubthis->__mosek_2fusion_2Constraint__getModel();
  if ((!names_flushed))
  {
    {
      if ((_pubthis->getSize() == (int)0))
      {
        {
          names_flushed = true;
        }
      }
      else
      {
        {
          if (((int)((name).size()) == (int)0))
          {
            {
              mosek::fusion::p_Model::_get_impl(_2665.get())->connames(nativeidxs,std::string (""),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_pubthis->getSize())}),std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
            }
          }
          else
          {
            {
              monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2666 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
              _2666->__mosek_2fusion_2Utils_2StringBuffer__a(name)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("["));
              if ((_pubthis->getND() > (int)0))
              {
                {
                  _2666->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("%0"));
                  int _9932 = (int)1;
                  int _9933 = _pubthis->getND();
                  for (int _2667 = _9932; _2667 < _9933; ++_2667)
                  {
                    {
                      _2666->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",%"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2667);
                    }
                  }
                }
              }
              {}
              _2666->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"));
              std::shared_ptr< monty::ndarray< int,1 > > _9934;
              bool _9935 = (_pubthis->getND() > (int)0);
              if (_9935)
              {
                _9934 = _pubthis->getShape();
              }
              else
              {
                _9934 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1)});
              }
              mosek::fusion::p_Model::_get_impl(_2665.get())->connames(nativeidxs,_2666->toString(),_9934,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr));
              names_flushed = true;
            }
          }
        }
      }
    }
  }
  {}
}
void mosek::fusion::ModelConstraint :: remove() { mosek::fusion::p_ModelConstraint::_get_impl(this)->remove(); }void mosek::fusion::p_ModelConstraint::remove(){
  mosek::fusion::p_Model::_get_impl(_pubthis->__mosek_2fusion_2Constraint__getModel().get())->removeConstraintBlock(conid);
}
void mosek::fusion::p_ModelConstraint::destroy(){shape.reset();nativeidxs.reset();}void mosek::fusion::ModelConstraint::destroy() { mosek::fusion::p_ModelConstraint::_get_impl(this)->destroy(); }mosek::fusion::Constraint::Constraint(mosek::fusion::p_Constraint *_impl) : _impl(_impl) { /*std::cout << "Constraint() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Constraint::~Constraint() { delete _impl; _impl = nullptr; }mosek::fusion::p_Constraint::p_Constraint  (::mosek::fusion::Constraint * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Constraint > _2669,    monty::rc_ptr< ::mosek::fusion::Model > _2670){monty::rc_reserve __reserve_this(_pubthis);   {
    model = _2670;
    shape = mosek::fusion::p_Constraint::_get_impl(_2669)->shape;
    nativeidxs = mosek::fusion::p_Constraint::_get_impl(_2669)->nativeidxs;
  }
}void mosek::fusion::p_Constraint::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _2671,    std::shared_ptr< monty::ndarray< int,1 > > _2672,    std::shared_ptr< monty::ndarray< int,1 > > _2673){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2672(_2672 ? _2672->raw() : nullptr, _2672 ? _2672->size(0) : 0);
    _checked_ptr_1<int> _ptr__2673(_2673 ? _2673->raw() : nullptr, _2673 ? _2673->size(0) : 0);
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->model = _2671;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->shape = _2672;
    mosek::fusion::p_Constraint::_get_impl(::mosek::fusion::Constraint::t(_pubthis))->nativeidxs = _2673;
  }
}std::string mosek::fusion::Constraint :: toString() { return mosek::fusion::p_Constraint::_get_impl(this)->toString(); }std::string mosek::fusion::p_Constraint::toString(){
  throw ::mosek::fusion::UnimplementedError(std::string ("Constraint.toString"));
}
void mosek::fusion::p_Constraint::toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2674,long long _2675,std::shared_ptr< monty::ndarray< std::string,1 > > _2676){
  _checked_ptr_1<long long> _ptr__2674(_2674 ? _2674->raw() : nullptr, _2674 ? _2674->size(0) : 0);
}
void mosek::fusion::p_Constraint::dual_lu(int _2677,std::shared_ptr< monty::ndarray< double,1 > > _2678,bool _2679){
  _checked_ptr_1<double> _ptr__2678(_2678 ? _2678->raw() : nullptr, _2678 ? _2678->size(0) : 0);
  model->getConstraintDuals(_2679,nativeidxs,_2678,_2677);
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: dual() { return mosek::fusion::p_Constraint::_get_impl(this)->dual(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::dual(){
  std::shared_ptr< monty::ndarray< double,1 > > _2680 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2680(_2680 ? _2680->raw() : nullptr,_2680 ? _2680->size(0) : 0);
  values(false,(int)0,_2680);
  return _2680;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::Constraint :: level() { return mosek::fusion::p_Constraint::_get_impl(this)->level(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_Constraint::level(){
  std::shared_ptr< monty::ndarray< double,1 > > _2681 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)((nativeidxs)->size(0)))));
  _checked_ptr_1<double> _ptr__2681(_2681 ? _2681->raw() : nullptr,_2681 ? _2681->size(0) : 0);
  values(true,(int)0,_2681);
  return _2681;
}
void mosek::fusion::p_Constraint::values(bool _2682,int _2683,std::shared_ptr< monty::ndarray< double,1 > > _2684){
  _checked_ptr_1<double> _ptr__2684(_2684 ? _2684->raw() : nullptr, _2684 ? _2684->size(0) : 0);
  model->getConstraintValues(_2682,nativeidxs,_2684,_2683);
}
void mosek::fusion::Constraint :: remove() { mosek::fusion::p_Constraint::_get_impl(this)->remove(); }void mosek::fusion::p_Constraint::remove(){
  throw ::mosek::fusion::DeletionError(std::string ("Only original constraints can be removed"));
}
void mosek::fusion::Constraint :: update(std::shared_ptr< monty::ndarray< double,1 > > _2685) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2685); }void mosek::fusion::p_Constraint::update(std::shared_ptr< monty::ndarray< double,1 > > _2685){
  _checked_ptr_1<double> _ptr__2685(_2685 ? _2685->raw() : nullptr, _2685 ? _2685->size(0) : 0);
  _pubthis->update(::mosek::fusion::p_Expr::reshape(::mosek::fusion::p_Expr::constTerm(_2685),_pubthis->getShape()),(::mosek::fusion::p_NilVariable::_new_NilVariable()).as<::mosek::fusion::Variable>(),true);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2686) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2686); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2686){
  std::shared_ptr< monty::ndarray< int,1 > > _2687 = _2686->getShape();
  _checked_ptr_1<int> _ptr__2687(_2687 ? _2687->raw() : nullptr,_2687 ? _2687->size(0) : 0);
  if (((int)((shape)->size(0)) < (int)((_2687)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _9936 = (int)0;
  int _9937 = (int)((_2687)->size(0));
  for (int _2688 = _9936; _2688 < _9937; ++_2688)
  {
    {
      if ((_ptr__2687[_2688] != ((*shape)(_2688))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _9938 = (int)((_2687)->size(0));
  int _9939 = (int)((shape)->size(0));
  for (int _2689 = _9938; _2689 < _9939; ++_2689)
  {
    {
      if ((((*shape)(_2689)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2686);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2690,monty::rc_ptr< ::mosek::fusion::Variable > _2691,bool _2692) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2690,_2691,_2692); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2690,monty::rc_ptr< ::mosek::fusion::Variable > _2691,bool _2692){
  int _2693 = _pubthis->getND();
  std::shared_ptr< monty::ndarray< int,1 > > _2694 = _2690->getShape();
  _checked_ptr_1<int> _ptr__2694(_2694 ? _2694->raw() : nullptr,_2694 ? _2694->size(0) : 0);
  if ((_2693 < (int)((_2694)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
    }
  }
  {}
  int _9940 = (int)0;
  int _9941 = (int)((_2694)->size(0));
  for (int _2695 = _9940; _2695 < _9941; ++_2695)
  {
    {
      if ((_ptr__2694[_2695] != ((*shape)(_2695))))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _9942 = (int)((_2694)->size(0));
  int _9943 = (int)((shape)->size(0));
  for (int _2696 = _9942; _2696 < _9943; ++_2696)
  {
    {
      if ((((*shape)(_2696)) != (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Expression shape does not match constraint"));
        }
      }
      {}
    }
  }
  int _2697 = _2691->numInst();
  std::shared_ptr< monty::ndarray< long long,1 > > _2698 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2697)));
  _checked_ptr_1<long long> _ptr__2698(_2698 ? _2698->raw() : nullptr,_2698 ? _2698->size(0) : 0);
  if ((_2697 < _2691->getSize()))
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _2699 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2697)));
      _checked_ptr_1<long long> _ptr__2699(_2699 ? _2699->raw() : nullptr,_2699 ? _2699->size(0) : 0);
      _2691->inst((int)0,_2699,(int)0,_2698);
    }
  }
  else
  {
    {
      _2691->inst((int)0,_2698);
    }
  }
  int _9944 = (int)0;
  int _9945 = _2697;
  for (int _2700 = _9944; _2700 < _9945; ++_2700)
  {
    {
      if ((_ptr__2698[_2700] < (int)0))
      {
        {
          throw ::mosek::fusion::UpdateError(std::string ("Semidefinite terms cannot be updated"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _2701;
  _checked_ptr_1<int> _ptr__2701(_2701 ? _2701->raw() : nullptr,_2701 ? _2701->size(0) : 0);
  {
    bool _2702 = true;
    int _9946 = (int)0;
    int _9947 = (_2697 - (int)1);
    for (int _2703 = _9946; _2703 < _9947; ++_2703)
    {
      {
        _2702 = (_2702 && (_ptr__2698[_2703] < _ptr__2698[safe_add( _2703,(int)1 )]));
      }
    }
    if (_2702)
    {
      {
        if ((!_2692))
        {
          {
            std::vector<int> _9948;
            for (int _2704 = (int)0, _9949 = _2697; _2704 < _9949 ; ++_2704)
            {
              _9948.push_back((int)_ptr__2698[_2704]);
            }
            auto _9950 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9948.size()),_9948.begin(),_9948.end()));
            _2701 = _9950;
            _ptr__2701.update(_2701 ? _2701->raw() : nullptr, _2701 ? _2701->size(0) : 0);
          }
        }
        else
        {
          {
            _2701 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _2697,(int)1 ))));
            _ptr__2701.update(_2701 ? _2701->raw() : nullptr, _2701 ? _2701->size(0) : 0);
            _ptr__2701[(int)0] = (int)0;
            int _9951 = (int)0;
            int _9952 = _2697;
            for (int _2705 = _9951; _2705 < _9952; ++_2705)
            {
              {
                _ptr__2701[safe_add( (int)1,_2705 )] = (int)_ptr__2698[_2705];
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::vector<long long> _9953;
        for (int _2707 = (int)0, _9954 = _2697; _2707 < _9954 ; ++_2707)
        {
          _9953.push_back(_2707);
        }
        auto _9955 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_9953.size()),_9953.begin(),_9953.end()));
        std::shared_ptr< monty::ndarray< long long,1 > > _2706 = _9955;
        _checked_ptr_1<long long> _ptr__2706(_2706 ? _2706->raw() : nullptr,_2706 ? _2706->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_2706,_2698,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_2697));
        int _2708 = (int)1;
        int _9956 = (int)1;
        int _9957 = _2697;
        for (int _2709 = _9956; _2709 < _9957; ++_2709)
        {
          {
            if ((_ptr__2698[_ptr__2706[(_2709 - (int)1)]] < _ptr__2698[_ptr__2706[_2709]]))
            {
              {
                ++ _2708;
              }
            }
            {}
          }
        }
        if (_2692)
        {
          {
            _2708 += (int)1;
          }
        }
        {}
        _2701 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2708)));
        _ptr__2701.update(_2701 ? _2701->raw() : nullptr, _2701 ? _2701->size(0) : 0);
        int _2710 = (int)0;
        if (_2692)
        {
          {
            _ptr__2701[(int)0] = (int)0;
            ++ _2710;
          }
        }
        {}
        _ptr__2701[_2710] = (int)_ptr__2698[_ptr__2706[(int)0]];
        int _9958 = (int)1;
        int _9959 = _2697;
        for (int _2711 = _9958; _2711 < _9959; ++_2711)
        {
          {
            if ((_ptr__2698[(_2711 - (int)1)] < _ptr__2698[_2711]))
            {
              {
                _ptr__2701[_2710] = (int)_ptr__2698[_ptr__2706[_2711]];
                ++ _2710;
              }
            }
            {}
          }
        }
      }
    }
  }
  mosek::fusion::p_Model::_get_impl(model.get())->update(nativeidxs,_2690,_2701);
}
void mosek::fusion::Constraint :: update(monty::rc_ptr< ::mosek::fusion::Expression > _2712,monty::rc_ptr< ::mosek::fusion::Variable > _2713) { mosek::fusion::p_Constraint::_get_impl(this)->update(_2712,_2713); }void mosek::fusion::p_Constraint::update(monty::rc_ptr< ::mosek::fusion::Expression > _2712,monty::rc_ptr< ::mosek::fusion::Variable > _2713){
  _pubthis->update(_2712,_2713,false);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__get_model() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__get_model(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::get_model() { return __mosek_2fusion_2Constraint__get_model(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__get_model(){
  return model;
}
int mosek::fusion::Constraint :: get_nd() { return mosek::fusion::p_Constraint::_get_impl(this)->get_nd(); }int mosek::fusion::p_Constraint::get_nd(){
  return (int)((shape)->size(0));
}
long long mosek::fusion::Constraint :: size() { return mosek::fusion::p_Constraint::_get_impl(this)->size(); }long long mosek::fusion::p_Constraint::size(){
  long long _2714 = (int)1;
  int _9960 = (int)0;
  int _9961 = (int)((shape)->size(0));
  for (int _2715 = _9960; _2715 < _9961; ++_2715)
  {
    {
      _2714 *= ((*shape)(_2715));
    }
  }
  return _2714;
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2716,    int _2717) { return mosek::fusion::p_Constraint::stack(_2716,_2717); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2716,int _2717){
  return ::mosek::fusion::p_Constraint::dstack(_2716,_2717);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2718,    monty::rc_ptr< ::mosek::fusion::Constraint > _2719,    monty::rc_ptr< ::mosek::fusion::Constraint > _2720,    int _2721) { return mosek::fusion::p_Constraint::stack(_2718,_2719,_2720,_2721); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2718,monty::rc_ptr< ::mosek::fusion::Constraint > _2719,monty::rc_ptr< ::mosek::fusion::Constraint > _2720,int _2721){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2718.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2719.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2720.get())}),_2721);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::stack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2722,    monty::rc_ptr< ::mosek::fusion::Constraint > _2723,    int _2724) { return mosek::fusion::p_Constraint::stack(_2722,_2723,_2724); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2722,monty::rc_ptr< ::mosek::fusion::Constraint > _2723,int _2724){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2722.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2723.get())}),_2724);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2725) { return mosek::fusion::p_Constraint::hstack(_2725); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2725){
  return ::mosek::fusion::p_Constraint::dstack(_2725,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2726) { return mosek::fusion::p_Constraint::vstack(_2726); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2726){
  return ::mosek::fusion::p_Constraint::dstack(_2726,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2727,    monty::rc_ptr< ::mosek::fusion::Constraint > _2728,    monty::rc_ptr< ::mosek::fusion::Constraint > _2729) { return mosek::fusion::p_Constraint::hstack(_2727,_2728,_2729); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2727,monty::rc_ptr< ::mosek::fusion::Constraint > _2728,monty::rc_ptr< ::mosek::fusion::Constraint > _2729){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2727.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2728.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2729.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2730,    monty::rc_ptr< ::mosek::fusion::Constraint > _2731,    monty::rc_ptr< ::mosek::fusion::Constraint > _2732) { return mosek::fusion::p_Constraint::vstack(_2730,_2731,_2732); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2730,monty::rc_ptr< ::mosek::fusion::Constraint > _2731,monty::rc_ptr< ::mosek::fusion::Constraint > _2732){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2730.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2731.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2732.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::hstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2733,    monty::rc_ptr< ::mosek::fusion::Constraint > _2734) { return mosek::fusion::p_Constraint::hstack(_2733,_2734); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2733,monty::rc_ptr< ::mosek::fusion::Constraint > _2734){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2733.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2734.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::vstack  ( monty::rc_ptr< ::mosek::fusion::Constraint > _2735,    monty::rc_ptr< ::mosek::fusion::Constraint > _2736) { return mosek::fusion::p_Constraint::vstack(_2735,_2736); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2735,monty::rc_ptr< ::mosek::fusion::Constraint > _2736){
  return ::mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 >{::monty::rc_ptr<::mosek::fusion::Constraint>(_2735.get()),::monty::rc_ptr<::mosek::fusion::Constraint>(_2736.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2737,int _2738){
  monty::rc_ptr< ::mosek::fusion::Model > _2739 = nullptr;
  {
    int _9962 = (int)0;
    int _9963 = (int)((_2737)->size(0));
    for (int _2740 = _9962; _2740 < _9963; ++_2740)
    {
      {
        if ((NULL == _2739.get()))
        {
          {
            _2739 = ((*_2737)(_2740))->__mosek_2fusion_2Constraint__getModel();
          }
        }
        else if(((NULL != mosek::fusion::p_Constraint::_get_impl(((*_2737)(_2740)))->model.get()) && (mosek::fusion::p_Constraint::_get_impl(((*_2737)(_2740)))->model != _2739)))
        {
          {
            monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2741 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
            std::string _9964;
            bool _9965 = ((int)((mosek::fusion::p_Model::_get_impl(_2739.get())->getName()).size()) > (int)0);
            if (_9965)
            {
              _9964 = mosek::fusion::p_Model::_get_impl(_2739.get())->getName();
            }
            else
            {
              _9964 = std::string ("?");
            }
            std::string _2742 = _9964;
            std::string _9966;
            bool _9967 = ((int)((mosek::fusion::p_Model::_get_impl(((*_2737)(_2740))->__mosek_2fusion_2Constraint__getModel().get())->getName()).size()) > (int)0);
            if (_9967)
            {
              _9966 = mosek::fusion::p_Model::_get_impl(((*_2737)(_2740))->__mosek_2fusion_2Constraint__getModel().get())->getName();
            }
            else
            {
              _9966 = std::string ("?");
            }
            std::string _2743 = _9966;
            _2741->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Constraints belong to different models: '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2742)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("' and '"))->__mosek_2fusion_2Utils_2StringBuffer__a(_2743)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("'"));
            throw ::mosek::fusion::ModelError(_2741->toString());
          }
        }
        {}
      }
    }
  }
  if (((int)((_2737)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
    }
  }
  else if(((int)((_2737)->size(0)) == (int)1))
  {
    {
      return ((*_2737)((int)1));
    }
  }
  else
  {
    {
      int _2744 = (int)((_2737)->size(0));
      int _2745 = (int)1;
      int _9968 = (int)0;
      int _9969 = _2744;
      for (int _2746 = _9968; _2746 < _9969; ++_2746)
      {
        {
          int _9970;
          bool _9971 = (((*_2737)(_2746))->getND() > _2745);
          if (_9971)
          {
            _9970 = ((*_2737)(_2746))->getND();
          }
          else
          {
            _9970 = _2745;
          }
          _2745 = _9970;
        }
      }
      if ((_2738 == _2745))
      {
        {
          ++ _2745;
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,2 > > _2747 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2744,_2745)));
      int _9972 = (int)0;
      int _9973 = _2744;
      for (int _2748 = _9972; _2748 < _9973; ++_2748)
      {
        {
          int _9974 = (int)0;
          int _9975 = _2745;
          for (int _2749 = _9974; _2749 < _9975; ++_2749)
          {
            {
              ((*_2747)(_2748,_2749)) = (int)1;
            }
          }
        }
      }
      std::vector<int> _9976;
      for (int _2751 = (int)0, _9977 = _2744; _2751 < _9977 ; ++_2751)
      {
        _9976.push_back(((*_2737)(_2751))->getSize());
      }
      auto _9978 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9976.size()),_9976.begin(),_9976.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2750 = _9978;
      _checked_ptr_1<int> _ptr__2750(_2750 ? _2750->raw() : nullptr,_2750 ? _2750->size(0) : 0);
      int _2752 = (int)0;
      int _9979 = (int)0;
      int _9980 = _2744;
      for (int _2753 = _9979; _2753 < _9980; ++_2753)
      {
        {
          _2752 += _ptr__2750[_2753];
        }
      }
      int _9981 = (int)0;
      int _9982 = _2744;
      for (int _2754 = _9981; _2754 < _9982; ++_2754)
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2755 = ((*_2737)(_2754))->getShape();
          _checked_ptr_1<int> _ptr__2755(_2755 ? _2755->raw() : nullptr,_2755 ? _2755->size(0) : 0);
          int _9983 = (int)0;
          int _9984 = (int)((_2755)->size(0));
          for (int _2756 = _9983; _2756 < _9984; ++_2756)
          {
            {
              ((*_2747)(_2754,_2756)) = _ptr__2755[_2756];
            }
          }
        }
      }
      if (((_2738 < (int)0) || (_2738 > _2745)))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
        }
      }
      {}
      int _9985 = (int)0;
      int _9986 = _2738;
      for (int _2757 = _9985; _2757 < _9986; ++_2757)
      {
        {
          int _9987 = (int)1;
          int _9988 = _2744;
          for (int _2758 = _9987; _2758 < _9988; ++_2758)
          {
            {
              if ((((*_2747)((int)0,_2757)) != ((*_2747)(_2758,_2757))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      int _9989 = safe_add( _2738,(int)1 );
      int _9990 = _2745;
      for (int _2759 = _9989; _2759 < _9990; ++_2759)
      {
        {
          int _9991 = (int)1;
          int _9992 = _2744;
          for (int _2760 = _9991; _2760 < _9992; ++_2760)
          {
            {
              if ((((*_2747)((int)0,_2759)) != ((*_2747)(_2760,_2759))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("Constraint dimensions do not match"));
                }
              }
              {}
            }
          }
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _2761 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2752)));
      _checked_ptr_1<int> _ptr__2761(_2761 ? _2761->raw() : nullptr,_2761 ? _2761->size(0) : 0);
      std::vector<int> _9993;
      for (int _2763 = (int)0, _9994 = _2745; _2763 < _9994 ; ++_2763)
      {
        _9993.push_back(((*_2747)((int)0,_2763)));
      }
      auto _9995 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_9993.size()),_9993.begin(),_9993.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2762 = _9995;
      _checked_ptr_1<int> _ptr__2762(_2762 ? _2762->raw() : nullptr,_2762 ? _2762->size(0) : 0);
      int _9996 = (int)1;
      int _9997 = _2744;
      for (int _2764 = _9996; _2764 < _9997; ++_2764)
      {
        {
          _ptr__2762[_2738] += ((*_2747)(_2764,_2738));
        }
      }
      {
        int _2765 = (int)((_2762)->size(0));
        std::shared_ptr< monty::ndarray< long long,1 > > _2766 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( (int)((_2737)->size(0)),(int)1 ))));
        _checked_ptr_1<long long> _ptr__2766(_2766 ? _2766->raw() : nullptr,_2766 ? _2766->size(0) : 0);
        int _9998 = (int)0;
        int _9999 = (int)((_2737)->size(0));
        for (int _2767 = _9998; _2767 < _9999; ++_2767)
        {
          {
            _ptr__2766[safe_add( _2767,(int)1 )] = safe_add( _ptr__2766[_2767],((*_2747)(_2767,_2738)) );
          }
        }
        if ((_2738 == (int)0))
        {
          {
            int _2768 = (int)0;
            int _10000 = (int)0;
            int _10001 = _2744;
            for (int _2769 = _10000; _2769 < _10001; ++_2769)
            {
              {
                int _2770 = (int)((mosek::fusion::p_Constraint::_get_impl(((*_2737)(_2769)))->nativeidxs)->size(0));
                ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_Constraint::_get_impl(((*_2737)(_2769)))->nativeidxs,(int)0,_2761,_2768,_2770);
                _2768 += _2770;
              }
            }
          }
        }
        else
        {
          {
            std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _10002;
            for (int _2772 = (int)0, _10003 = _2744; _2772 < _10003 ; ++_2772)
            {
              _10002.push_back(mosek::fusion::p_Constraint::_get_impl(((*_2737)(_2772)))->nativeidxs);
            }
            auto _10004 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_10002.size()),_10002.begin(),_10002.end()));
            std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _2771 = _10004;
            if ((_2738 < _2745))
            {
              {
                int _2773 = (int)1;
                int _10005 = (int)0;
                int _10006 = _2738;
                for (int _2774 = _10005; _2774 < _10006; ++_2774)
                {
                  {
                    _2773 *= _ptr__2762[_2774];
                  }
                }
                int _2775 = (int)1;
                int _10007 = safe_add( _2738,(int)1 );
                int _10008 = _2745;
                for (int _2776 = _10007; _2776 < _10008; ++_2776)
                {
                  {
                    _2775 *= _ptr__2762[_2776];
                  }
                }
                int _2777 = (int)0;
                int _10009 = (int)0;
                int _10010 = _2773;
                for (int _2778 = _10009; _2778 < _10010; ++_2778)
                {
                  {
                    int _10011 = (int)0;
                    int _10012 = _2744;
                    for (int _2779 = _10011; _2779 < _10012; ++_2779)
                    {
                      {
                        int _2780 = (int)0;
                        int _2781 = ((*_2747)(_2779,_2738));
                        int _10013 = (int)0;
                        int _10014 = _2781;
                        for (int _2782 = _10013; _2782 < _10014; ++_2782)
                        {
                          {
                            int _10015 = (int)0;
                            int _10016 = _2775;
                            for (int _2783 = _10015; _2783 < _10016; ++_2783)
                            {
                              {
                                _ptr__2761[_2777] = ((*mosek::fusion::p_Constraint::_get_impl(((*_2737)(_2744)))->nativeidxs)(safe_add( safe_mul( safe_mul( _2778,_2775 ),_2781 ),_2780 )));
                                ++ _2777;
                                ++ _2780;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
            else
            {
              {
                int _2784 = (int)1;
                int _10017 = (int)0;
                int _10018 = _2745;
                for (int _2785 = _10017; _2785 < _10018; ++_2785)
                {
                  {
                    _2784 *= _ptr__2762[_2785];
                  }
                }
                int _2786 = (int)0;
                int _10019 = (int)0;
                int _10020 = _2784;
                for (int _2787 = _10019; _2787 < _10020; ++_2787)
                {
                  {
                    int _10021 = (int)0;
                    int _10022 = _2744;
                    for (int _2788 = _10021; _2788 < _10022; ++_2788)
                    {
                      {
                        _ptr__2761[_2786] = ((*((*_2771)(_2788)))(_2787));
                        ++ _2786;
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_2739,_2762,_2761)).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2789) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2789); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(std::shared_ptr< monty::ndarray< int,1 > > _2789) { return __mosek_2fusion_2Constraint__index(_2789); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2789){
  _checked_ptr_1<int> _ptr__2789(_2789 ? _2789->raw() : nullptr, _2789 ? _2789->size(0) : 0);
  if (((int)((_2789)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _10023 = (int)0;
      int _10024 = (int)((shape)->size(0));
      for (int _2790 = _10023; _2790 < _10024; ++_2790)
      {
        {
          if (((_ptr__2789[_2790] < (int)0) || (_ptr__2789[_2790] > ((*shape)(_2790)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("index is out of bounds"));
            }
          }
          {}
        }
      }
      int _2791 = (int)((shape)->size(0));
      std::shared_ptr< monty::ndarray< long long,1 > > _2792 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2791)));
      _checked_ptr_1<long long> _ptr__2792(_2792 ? _2792->raw() : nullptr,_2792 ? _2792->size(0) : 0);
      _ptr__2792[(_2791 - (int)1)] = (int)1;
      int _10025 = (int)1;
      int _10026 = _2791;
      for (int _2793 = _10025; _2793 < _10026; ++_2793)
      {
        {
          _ptr__2792[((_2791 - _2793) - (int)1)] = safe_mul( _ptr__2792[(_2791 - _2793)],((*shape)(_2793)) );
        }
      }
      int _2794 = (int)0;
      int _10027 = (int)0;
      int _10028 = _2791;
      for (int _2795 = _10027; _2795 < _10028; ++_2795)
      {
        {
          _2794 += (int)safe_mul( _ptr__2792[_2795],_ptr__2789[_2795] );
        }
      }
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2794)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__index(int _2796) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__index(_2796); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::index(int _2796) { return __mosek_2fusion_2Constraint__index(_2796); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__index(int _2796){
  if ((((int)((shape)->size(0)) == (int)0) && (_2796 == (int)0)))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  else if(((_2796 < (int)0) || (_2796 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index is out of bounds"));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nativeidxs)(_2796)))}))).as<::mosek::fusion::Constraint>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2797,std::shared_ptr< monty::ndarray< int,1 > > _2798) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2797,_2798); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(std::shared_ptr< monty::ndarray< int,1 > > _2797,std::shared_ptr< monty::ndarray< int,1 > > _2798) { return __mosek_2fusion_2Constraint__slice(_2797,_2798); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2797,std::shared_ptr< monty::ndarray< int,1 > > _2798){
  _checked_ptr_1<int> _ptr__2797(_2797 ? _2797->raw() : nullptr, _2797 ? _2797->size(0) : 0);
  _checked_ptr_1<int> _ptr__2798(_2798 ? _2798->raw() : nullptr, _2798 ? _2798->size(0) : 0);
  if (((int)((_2797)->size(0)) != (int)((_2798)->size(0))))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
    }
  }
  else if(((int)((_2797)->size(0)) != (int)((shape)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("variable shape and slice do not match"));
    }
  }
  else
  {
    {
      int _10029 = (int)0;
      int _10030 = (int)((shape)->size(0));
      for (int _2799 = _10029; _2799 < _10030; ++_2799)
      {
        {
          if (((_ptr__2797[_2799] < (int)0) || (_ptr__2798[_2799] > ((*shape)(_2799)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("slice is out of bounds"));
            }
          }
          else if((_ptr__2797[_2799] > _ptr__2798[_2799]))
          {
            {
              throw ::mosek::fusion::SliceError(std::string ("invalid slice"));
            }
          }
          {}
        }
      }
      int _2800 = (int)((shape)->size(0));
      std::vector<int> _10031;
      for (int _2802 = (int)0, _10032 = _2800; _2802 < _10032 ; ++_2802)
      {
        _10031.push_back((_ptr__2798[_2802] - _ptr__2797[_2802]));
      }
      auto _10033 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10031.size()),_10031.begin(),_10031.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _2801 = _10033;
      _checked_ptr_1<int> _ptr__2801(_2801 ? _2801->raw() : nullptr,_2801 ? _2801->size(0) : 0);
      int _2803 = (int)1;
      int _10034 = (int)0;
      int _10035 = _2800;
      for (int _2804 = _10034; _2804 < _10035; ++_2804)
      {
        {
          _2803 *= (_ptr__2798[_2804] - _ptr__2797[_2804]);
        }
      }
      if ((_2803 == (int)0))
      {
        {
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,_2801,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Constraint>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _2805 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2803)));
          _checked_ptr_1<int> _ptr__2805(_2805 ? _2805->raw() : nullptr,_2805 ? _2805->size(0) : 0);
          {
            std::shared_ptr< monty::ndarray< int,1 > > _2806 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2800)));
            _checked_ptr_1<int> _ptr__2806(_2806 ? _2806->raw() : nullptr,_2806 ? _2806->size(0) : 0);
            _ptr__2806[(_2800 - (int)1)] = (int)1;
            int _10036 = (int)1;
            int _10037 = _2800;
            for (int _2807 = _10036; _2807 < _10037; ++_2807)
            {
              {
                _ptr__2806[((_2800 - _2807) - (int)1)] = safe_mul( _ptr__2806[(_2800 - _2807)],((*shape)((_2800 - _2807))) );
              }
            }
            int _2808 = (int)0;
            int _10038 = (int)0;
            int _10039 = _2800;
            for (int _2809 = _10038; _2809 < _10039; ++_2809)
            {
              {
                _2808 += safe_mul( _ptr__2797[_2809],_ptr__2806[_2809] );
              }
            }
            std::vector<int> _10040;
            for (int _2811 = (int)0, _10041 = _2800; _2811 < _10041 ; ++_2811)
            {
              _10040.push_back(_2808);
            }
            auto _10042 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10040.size()),_10040.begin(),_10040.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2810 = _10042;
            _checked_ptr_1<int> _ptr__2810(_2810 ? _2810->raw() : nullptr,_2810 ? _2810->size(0) : 0);
            std::vector<int> _10043;
            for (int _2813 = (int)0, _10044 = _2800; _2813 < _10044 ; ++_2813)
            {
              _10043.push_back(_ptr__2797[_2813]);
            }
            auto _10045 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10043.size()),_10043.begin(),_10043.end()));
            std::shared_ptr< monty::ndarray< int,1 > > _2812 = _10045;
            _checked_ptr_1<int> _ptr__2812(_2812 ? _2812->raw() : nullptr,_2812 ? _2812->size(0) : 0);
            int _10046 = (int)0;
            int _10047 = _2803;
            for (int _2814 = _10046; _2814 < _10047; ++_2814)
            {
              {
                _ptr__2805[_2814] = ((*nativeidxs)(_ptr__2810[(_2800 - (int)1)]));
                _ptr__2812[(_2800 - (int)1)] += (int)1;
                _ptr__2810[(_2800 - (int)1)] += _ptr__2806[(_2800 - (int)1)];
                if ((_ptr__2812[(_2800 - (int)1)] >= _ptr__2798[(_2800 - (int)1)]))
                {
                  {
                    int _2815 = (_2800 - (int)1);
                    while ( ((_2815 > (int)0) && (_ptr__2812[_2815] >= _ptr__2798[_2815])) )
                    {
                      {
                        _ptr__2812[_2815] = _ptr__2797[_2815];
                        _ptr__2812[(_2815 - (int)1)] += (int)1;
                        _ptr__2810[(_2815 - (int)1)] += _ptr__2806[(_2815 - (int)1)];
                        -- _2815;
                      }
                    }
                    int _10048 = safe_add( _2815,(int)1 );
                    int _10049 = _2800;
                    for (int _2816 = _10048; _2816 < _10049; ++_2816)
                    {
                      {
                        _ptr__2810[_2816] = _ptr__2810[_2815];
                      }
                    }
                  }
                }
                {}
              }
            }
          }
          return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(_pubthis->__mosek_2fusion_2Constraint__getModel(),_2801,_2805)).as<::mosek::fusion::Constraint>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__slice(int _2817,int _2818) { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__slice(_2817,_2818); }monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::Constraint::slice(int _2817,int _2818) { return __mosek_2fusion_2Constraint__slice(_2817,_2818); }
monty::rc_ptr< ::mosek::fusion::Constraint > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__slice(int _2817,int _2818){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable shape and slice do not match"));
    }
  }
  {}
  if (((_2817 == (int)0) && (_2818 == ((*shape)((int)0)))))
  {
    {
      return ::mosek::fusion::Constraint::t(_pubthis);
    }
  }
  else if(((_2817 < (int)0) || (_2818 > ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
    }
  }
  else if((_2817 > _2818))
  {
    {
      throw ::mosek::fusion::SliceError(std::string ("Invalid slice"));
    }
  }
  else
  {
    {
      std::vector<int> _10050;
      for (int _2819 = _2817, _10051 = _2818; _2819 < _10051 ; ++_2819)
      {
        _10050.push_back(((*nativeidxs)(_2819)));
      }
      auto _10052 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10050.size()),_10050.begin(),_10050.end()));
      return (::mosek::fusion::p_SliceConstraint::_new_SliceConstraint(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((_2818 - _2817))}),_10052)).as<::mosek::fusion::Constraint>();
    }
  }
}
int mosek::fusion::Constraint :: getND() { return mosek::fusion::p_Constraint::_get_impl(this)->getND(); }int mosek::fusion::p_Constraint::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::Constraint :: getSize() { return mosek::fusion::p_Constraint::_get_impl(this)->getSize(); }int mosek::fusion::p_Constraint::getSize(){
  int _2820 = (int)1;
  int _10053 = (int)0;
  int _10054 = (int)((shape)->size(0));
  for (int _2821 = _10053; _2821 < _10054; ++_2821)
  {
    {
      _2820 *= ((*shape)(_2821));
    }
  }
  return _2820;
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint :: __mosek_2fusion_2Constraint__getModel() { return mosek::fusion::p_Constraint::_get_impl(this)->__mosek_2fusion_2Constraint__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::Constraint::getModel() { return __mosek_2fusion_2Constraint__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Constraint::__mosek_2fusion_2Constraint__getModel(){
  return model;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Constraint :: getShape() { return mosek::fusion::p_Constraint::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getShape(){
  std::vector<int> _10055;
  for (int _2822 = (int)0, _10056 = (int)((shape)->size(0)); _2822 < _10056 ; ++_2822)
  {
    _10055.push_back(((*shape)(_2822)));
  }
  auto _10057 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10055.size()),_10055.begin(),_10055.end()));
  return _10057;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Constraint::getNativeidxs(){
  return nativeidxs;
}
void mosek::fusion::p_Constraint::destroy(){nativeidxs.reset();shape.reset();model.reset();}void mosek::fusion::Constraint::destroy() { mosek::fusion::p_Constraint::_get_impl(this)->destroy(); }mosek::fusion::Set::Set(mosek::fusion::p_Set *_impl) : _impl(_impl) { /*std::cout << "Set() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Set::~Set() { delete _impl; _impl = nullptr; }mosek::fusion::p_Set::p_Set  (::mosek::fusion::Set * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::Set::size  ( std::shared_ptr< monty::ndarray< int,1 > > _2823) { return mosek::fusion::p_Set::size(_2823); }long long mosek::fusion::p_Set::size(std::shared_ptr< monty::ndarray< int,1 > > _2823){
  _checked_ptr_1<int> _ptr__2823(_2823 ? _2823->raw() : nullptr, _2823 ? _2823->size(0) : 0);
  long long _2824 = (long long)1;
  int _10058 = (int)0;
  int _10059 = (int)((_2823)->size(0));
  for (int _2825 = _10058; _2825 < _10059; ++_2825)
  {
    {
      _2824 *= _ptr__2823[_2825];
    }
  }
  return _2824;
}
bool mosek::fusion::Set::match  ( std::shared_ptr< monty::ndarray< int,1 > > _2826,    std::shared_ptr< monty::ndarray< int,1 > > _2827) { return mosek::fusion::p_Set::match(_2826,_2827); }bool mosek::fusion::p_Set::match(std::shared_ptr< monty::ndarray< int,1 > > _2826,std::shared_ptr< monty::ndarray< int,1 > > _2827){
  _checked_ptr_1<int> _ptr__2826(_2826 ? _2826->raw() : nullptr, _2826 ? _2826->size(0) : 0);
  _checked_ptr_1<int> _ptr__2827(_2827 ? _2827->raw() : nullptr, _2827 ? _2827->size(0) : 0);
  if (((int)((_2826)->size(0)) != (int)((_2827)->size(0))))
  {
    {
      return false;
    }
  }
  {}
  int _10060 = (int)0;
  int _10061 = (int)((_2826)->size(0));
  for (int _2828 = _10060; _2828 < _10061; ++_2828)
  {
    {
      if ((_ptr__2826[_2828] != _ptr__2827[_2828]))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
long long mosek::fusion::Set::linearidx  ( std::shared_ptr< monty::ndarray< int,1 > > _2829,    std::shared_ptr< monty::ndarray< int,1 > > _2830) { return mosek::fusion::p_Set::linearidx(_2829,_2830); }long long mosek::fusion::p_Set::linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2829,std::shared_ptr< monty::ndarray< int,1 > > _2830){
  _checked_ptr_1<int> _ptr__2829(_2829 ? _2829->raw() : nullptr, _2829 ? _2829->size(0) : 0);
  _checked_ptr_1<int> _ptr__2830(_2830 ? _2830->raw() : nullptr, _2830 ? _2830->size(0) : 0);
  long long _2831 = _ptr__2830[(int)0];
  int _10062 = (int)1;
  int _10063 = (int)((_2830)->size(0));
  for (int _2832 = _10062; _2832 < _10063; ++_2832)
  {
    {
      _2831 = safe_add( safe_mul( _2831,_ptr__2829[_2832] ),_ptr__2830[_2832] );
    }
  }
  return _2831;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2833,    long long _2834) { return mosek::fusion::p_Set::idxtokey(_2833,_2834); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2833,long long _2834){
  _checked_ptr_1<int> _ptr__2833(_2833 ? _2833->raw() : nullptr, _2833 ? _2833->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2835 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_2833)->size(0)))));
  _checked_ptr_1<int> _ptr__2835(_2835 ? _2835->raw() : nullptr,_2835 ? _2835->size(0) : 0);
  ::mosek::fusion::p_Set::idxtokey(_2833,_2834,_2835);
  return _2835;
}
void mosek::fusion::Set::idxtokey  ( std::shared_ptr< monty::ndarray< int,1 > > _2836,    long long _2837,    std::shared_ptr< monty::ndarray< int,1 > > _2838) { mosek::fusion::p_Set::idxtokey(_2836,_2837,_2838); }void mosek::fusion::p_Set::idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2836,long long _2837,std::shared_ptr< monty::ndarray< int,1 > > _2838){
  _checked_ptr_1<int> _ptr__2836(_2836 ? _2836->raw() : nullptr, _2836 ? _2836->size(0) : 0);
  _checked_ptr_1<int> _ptr__2838(_2838 ? _2838->raw() : nullptr, _2838 ? _2838->size(0) : 0);
  int _2839 = (int)((_2836)->size(0));
  if ((_2839 > (int)0))
  {
    {
      long long _2840 = _2837;
      int _10064 = (int)0;
      int _10065 = (_2839 - (int)1);
      for (int _2841 = _10064; _2841 < _10065; ++_2841)
      {
        {
          _ptr__2838[((_2839 - _2841) - (int)1)] = (int)(_2840 % _ptr__2836[((_2839 - _2841) - (int)1)]);
          _2840 /= _ptr__2836[((_2839 - _2841) - (int)1)];
        }
      }
      _ptr__2838[(int)0] = (int)_2840;
    }
  }
  {}
}
std::string mosek::fusion::Set::indexToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2842,    long long _2843) { return mosek::fusion::p_Set::indexToString(_2842,_2843); }std::string mosek::fusion::p_Set::indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2842,long long _2843){
  _checked_ptr_1<int> _ptr__2842(_2842 ? _2842->raw() : nullptr, _2842 ? _2842->size(0) : 0);
  int _2844 = (int)((_2842)->size(0));
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2845 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  if ((_2844 == (int)0))
  {
    {
      return std::string ("0");
    }
  }
  else if((_2844 == (int)1))
  {
    {
      return _2845->__mosek_2fusion_2Utils_2StringBuffer__a(_2843)->toString();
    }
  }
  else
  {
    {
      long long _2846 = _2843;
      std::shared_ptr< monty::ndarray< int,1 > > _2847 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2844)));
      _checked_ptr_1<int> _ptr__2847(_2847 ? _2847->raw() : nullptr,_2847 ? _2847->size(0) : 0);
      int _10066 = (int)1;
      int _10067 = _2844;
      for (int _2848 = _10066; _2848 < _10067; ++_2848)
      {
        {
          _ptr__2847[(_2844 - _2848)] = (int)(_2846 % _ptr__2842[(_2844 - _2848)]);
          _2846 /= _ptr__2842[(_2844 - _2848)];
        }
      }
      _ptr__2847[(int)0] = (int)_2846;
      _2845->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2847[(int)0]);
      int _10068 = (int)1;
      int _10069 = _2844;
      for (int _2849 = _10068; _2849 < _10069; ++_2849)
      {
        {
          _2845->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2847[_2849]);
        }
      }
      return _2845->toString();
    }
  }
}
std::string mosek::fusion::Set::keyToString  ( std::shared_ptr< monty::ndarray< int,1 > > _2850) { return mosek::fusion::p_Set::keyToString(_2850); }std::string mosek::fusion::p_Set::keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2850){
  _checked_ptr_1<int> _ptr__2850(_2850 ? _2850->raw() : nullptr, _2850 ? _2850->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2851 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _2851->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2850[(int)0]);
  int _10070 = (int)1;
  int _10071 = (int)((_2850)->size(0));
  for (int _2852 = _10070; _2852 < _10071; ++_2852)
  {
    {
      _2851->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_ptr__2850[_2852]);
    }
  }
  return _2851->toString();
}
void mosek::fusion::Set::indexToKey  ( std::shared_ptr< monty::ndarray< int,1 > > _2853,    long long _2854,    std::shared_ptr< monty::ndarray< int,1 > > _2855) { mosek::fusion::p_Set::indexToKey(_2853,_2854,_2855); }void mosek::fusion::p_Set::indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2853,long long _2854,std::shared_ptr< monty::ndarray< int,1 > > _2855){
  _checked_ptr_1<int> _ptr__2853(_2853 ? _2853->raw() : nullptr, _2853 ? _2853->size(0) : 0);
  _checked_ptr_1<int> _ptr__2855(_2855 ? _2855->raw() : nullptr, _2855 ? _2855->size(0) : 0);
  int _2856 = (int)((_2853)->size(0));
  if ((_2856 == (int)1))
  {
    {
      _ptr__2855[(int)0] = (int)_2854;
    }
  }
  else
  {
    {
      long long _2857 = _2854;
      int _10072 = (int)1;
      int _10073 = _2856;
      for (int _2858 = _10072; _2858 < _10073; ++_2858)
      {
        {
          _ptr__2855[(_2856 - _2858)] = (int)(_2857 % _ptr__2853[(_2856 - _2858)]);
          _2857 /= _ptr__2853[(_2856 - _2858)];
        }
      }
      _ptr__2855[(int)0] = (int)_2857;
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::Set::strides  ( std::shared_ptr< monty::ndarray< int,1 > > _2859) { return mosek::fusion::p_Set::strides(_2859); }std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_Set::strides(std::shared_ptr< monty::ndarray< int,1 > > _2859){
  _checked_ptr_1<int> _ptr__2859(_2859 ? _2859->raw() : nullptr, _2859 ? _2859->size(0) : 0);
  int _2860 = (int)((_2859)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _2861 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_2860)));
  _checked_ptr_1<long long> _ptr__2861(_2861 ? _2861->raw() : nullptr,_2861 ? _2861->size(0) : 0);
  _ptr__2861[(_2860 - (int)1)] = (int)1;
  int _10074 = (int)1;
  int _10075 = _2860;
  for (int _2862 = _10074; _2862 < _10075; ++_2862)
  {
    {
      _ptr__2861[((_2860 - _2862) - (int)1)] = safe_mul( _ptr__2861[(_2860 - _2862)],_ptr__2859[(_2860 - _2862)] );
    }
  }
  return _2861;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2863,    std::shared_ptr< monty::ndarray< int,1 > > _2864) { return mosek::fusion::p_Set::make(_2863,_2864); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2863,std::shared_ptr< monty::ndarray< int,1 > > _2864){
  _checked_ptr_1<int> _ptr__2863(_2863 ? _2863->raw() : nullptr, _2863 ? _2863->size(0) : 0);
  _checked_ptr_1<int> _ptr__2864(_2864 ? _2864->raw() : nullptr, _2864 ? _2864->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _2865 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( (int)((_2863)->size(0)),(int)((_2864)->size(0)) ))));
  _checked_ptr_1<int> _ptr__2865(_2865 ? _2865->raw() : nullptr,_2865 ? _2865->size(0) : 0);
  int _10076 = (int)0;
  int _10077 = (int)((_2863)->size(0));
  for (int _2866 = _10076; _2866 < _10077; ++_2866)
  {
    {
      _ptr__2865[_2866] = _ptr__2863[_2866];
    }
  }
  int _10078 = (int)0;
  int _10079 = (int)((_2864)->size(0));
  for (int _2867 = _10078; _2867 < _10079; ++_2867)
  {
    {
      _ptr__2865[safe_add( (int)((_2863)->size(0)),_2867 )] = _ptr__2864[_2867];
    }
  }
  return _2865;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< int,1 > > _2868) { return mosek::fusion::p_Set::make(_2868); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< int,1 > > _2868){
  _checked_ptr_1<int> _ptr__2868(_2868 ? _2868->raw() : nullptr, _2868 ? _2868->size(0) : 0);
  std::vector<int> _10080;
  for (int _2869 = (int)0, _10081 = (int)((_2868)->size(0)); _2869 < _10081 ; ++_2869)
  {
    _10080.push_back(_ptr__2868[_2869]);
  }
  auto _10082 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10080.size()),_10080.begin(),_10080.end()));
  return _10082;
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2870,    int _2871,    int _2872) { return mosek::fusion::p_Set::make(_2870,_2871,_2872); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2870,int _2871,int _2872){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2870),(int)(_2871),(int)(_2872)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2873,    int _2874) { return mosek::fusion::p_Set::make(_2873,_2874); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2873,int _2874){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2873),(int)(_2874)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( int _2875) { return mosek::fusion::p_Set::make(_2875); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(int _2875){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2875)});
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::scalar  ( ) { return mosek::fusion::p_Set::scalar(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::scalar(){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Set::make  ( std::shared_ptr< monty::ndarray< std::string,1 > > _2876) { return mosek::fusion::p_Set::make(_2876); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Set::make(std::shared_ptr< monty::ndarray< std::string,1 > > _2876){
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_2876)->size(0)))});
}
void mosek::fusion::p_Set::destroy(){}void mosek::fusion::Set::destroy() { mosek::fusion::p_Set::_get_impl(this)->destroy(); }mosek::fusion::ConeDomain::ConeDomain(mosek::fusion::p_ConeDomain *_impl) : _impl(_impl) { /*std::cout << "ConeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ConeDomain::~ConeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_ConeDomain::p_ConeDomain  (::mosek::fusion::ConeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2877,    double _2878,    std::shared_ptr< monty::ndarray< int,1 > > _2879){ return new mosek::fusion::ConeDomain(_2877,_2878,_2879); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2877,    double _2878,    std::shared_ptr< monty::ndarray< int,1 > > _2879) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2877,_2878,_2879); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2877,    double _2878,    std::shared_ptr< monty::ndarray< int,1 > > _2879){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2879(_2879 ? _2879->raw() : nullptr, _2879 ? _2879->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _10083;
    bool _10084 = (NULL != _2879.get());
    if (_10084)
    {
      _10083 = ::mosek::fusion::p_Set::make(_2879);
    }
    else
    {
      _10083 = nullptr;
    }
    shape = _10083;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2878;
    key = _2877;
    axisidx = (int)0;
    axisset = false;
    int_flag = false;
    mosek::fusion::p_ConeDomain::_get_impl(::mosek::fusion::ConeDomain::t(_pubthis))->alpha = _2878;
  }
}mosek::fusion::ConeDomain::t mosek::fusion::p_ConeDomain::_new_ConeDomain  (mosek::fusion::QConeKey _2880,    std::shared_ptr< monty::ndarray< int,1 > > _2881){ return new mosek::fusion::ConeDomain(_2880,_2881); }mosek::fusion::ConeDomain::ConeDomain  (mosek::fusion::QConeKey _2880,    std::shared_ptr< monty::ndarray< int,1 > > _2881) :    ConeDomain(new mosek::fusion::p_ConeDomain(this)){ mosek::fusion::p_ConeDomain::_get_impl(this)->_initialize(_2880,_2881); }void mosek::fusion::p_ConeDomain::_initialize  (mosek::fusion::QConeKey _2880,    std::shared_ptr< monty::ndarray< int,1 > > _2881){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2881(_2881 ? _2881->raw() : nullptr, _2881 ? _2881->size(0) : 0);
    mosek::fusion::p_ConeDomain::_initialize(_2880,1.0,_2881);
  }
}bool mosek::fusion::p_ConeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2882){
  _checked_ptr_1<int> _ptr__2882(_2882 ? _2882->raw() : nullptr, _2882 ? _2882->size(0) : 0);
  return ((NULL == shape.get()) || ::mosek::fusion::p_Set::match(_2882,shape));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__integral() { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::integral() { return __mosek_2fusion_2ConeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__integral(){
  int_flag = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
bool mosek::fusion::ConeDomain :: axisIsSet() { return mosek::fusion::p_ConeDomain::_get_impl(this)->axisIsSet(); }bool mosek::fusion::p_ConeDomain::axisIsSet(){
  return axisset;
}
int mosek::fusion::ConeDomain :: getAxis() { return mosek::fusion::p_ConeDomain::_get_impl(this)->getAxis(); }int mosek::fusion::p_ConeDomain::getAxis(){
  return axisidx;
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain :: __mosek_2fusion_2ConeDomain__axis(int _2883) { return mosek::fusion::p_ConeDomain::_get_impl(this)->__mosek_2fusion_2ConeDomain__axis(_2883); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::ConeDomain::axis(int _2883) { return __mosek_2fusion_2ConeDomain__axis(_2883); }
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_ConeDomain::__mosek_2fusion_2ConeDomain__axis(int _2883){
  axisidx = _2883;
  axisset = true;
  return ::mosek::fusion::ConeDomain::t(_pubthis);
}
void mosek::fusion::p_ConeDomain::destroy(){shape.reset();}void mosek::fusion::ConeDomain::destroy() { mosek::fusion::p_ConeDomain::_get_impl(this)->destroy(); }mosek::fusion::LinPSDDomain::LinPSDDomain(mosek::fusion::p_LinPSDDomain *_impl) : _impl(_impl) { /*std::cout << "LinPSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinPSDDomain::~LinPSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinPSDDomain::p_LinPSDDomain  (::mosek::fusion::LinPSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2884,    int _2885){ return new mosek::fusion::LinPSDDomain(_2884,_2885); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2884,    int _2885) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2884,_2885); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2884,    int _2885){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2884(_2884 ? _2884->raw() : nullptr, _2884 ? _2884->size(0) : 0);
    mosek::fusion::p_LinPSDDomain::_get_impl(::mosek::fusion::LinPSDDomain::t(_pubthis))->conedim = _2885;
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2884);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2886){ return new mosek::fusion::LinPSDDomain(_2886); }mosek::fusion::LinPSDDomain::LinPSDDomain  (std::shared_ptr< monty::ndarray< int,1 > > _2886) :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(_2886); }void mosek::fusion::p_LinPSDDomain::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _2886){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2886(_2886 ? _2886->raw() : nullptr, _2886 ? _2886->size(0) : 0);
    shape = ::mosek::fusion::Utils::Tools::arraycopy(_2886);
    conedim = ((int)((shape)->size(0)) - (int)1);
  }
}mosek::fusion::LinPSDDomain::t mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain  (){ return new mosek::fusion::LinPSDDomain(); }mosek::fusion::LinPSDDomain::LinPSDDomain  () :    LinPSDDomain(new mosek::fusion::p_LinPSDDomain(this)){ mosek::fusion::p_LinPSDDomain::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinPSDDomain::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    conedim = (int)0;
    shape = nullptr;
  }
}void mosek::fusion::p_LinPSDDomain::destroy(){shape.reset();}void mosek::fusion::LinPSDDomain::destroy() { mosek::fusion::p_LinPSDDomain::_get_impl(this)->destroy(); }mosek::fusion::PSDDomain::PSDDomain(mosek::fusion::p_PSDDomain *_impl) : _impl(_impl) { /*std::cout << "PSDDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::PSDDomain::~PSDDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_PSDDomain::p_PSDDomain  (::mosek::fusion::PSDDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2887,    std::shared_ptr< monty::ndarray< int,1 > > _2888,    int _2889,    int _2890){ return new mosek::fusion::PSDDomain(_2887,_2888,_2889,_2890); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2887,    std::shared_ptr< monty::ndarray< int,1 > > _2888,    int _2889,    int _2890) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2887,_2888,_2889,_2890); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2887,    std::shared_ptr< monty::ndarray< int,1 > > _2888,    int _2889,    int _2890){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2888(_2888 ? _2888->raw() : nullptr, _2888 ? _2888->size(0) : 0);
    axisIsSet = true;
    shape = _2888;
    key = _2887;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2889;
    mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2890;
    int _2891 = (int)((shape)->size(0));
    if (((!(((int)((shape)->size(0)) > _2889) && (((int)((shape)->size(0)) > _2890) && ((_2889 >= (int)0) && ((_2890 >= (int)0) && (_2889 != _2890)))))) && (((*shape)(_2889)) == ((*shape)(_2890)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
      }
    }
    {}
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2892,    std::shared_ptr< monty::ndarray< int,1 > > _2893){ return new mosek::fusion::PSDDomain(_2892,_2893); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2892,    std::shared_ptr< monty::ndarray< int,1 > > _2893) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2892,_2893); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2892,    std::shared_ptr< monty::ndarray< int,1 > > _2893){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__2893(_2893 ? _2893->raw() : nullptr, _2893 ? _2893->size(0) : 0);
    mosek::fusion::p_PSDDomain::_initialize(_2892,_2893,((int)((_2893)->size(0)) - (int)2),((int)((_2893)->size(0)) - (int)1));
  }
}mosek::fusion::PSDDomain::t mosek::fusion::p_PSDDomain::_new_PSDDomain  (mosek::fusion::PSDKey _2894){ return new mosek::fusion::PSDDomain(_2894); }mosek::fusion::PSDDomain::PSDDomain  (mosek::fusion::PSDKey _2894) :    PSDDomain(new mosek::fusion::p_PSDDomain(this)){ mosek::fusion::p_PSDDomain::_get_impl(this)->_initialize(_2894); }void mosek::fusion::p_PSDDomain::_initialize  (mosek::fusion::PSDKey _2894){monty::rc_reserve __reserve_this(_pubthis);   {
    shape = nullptr;
    key = _2894;
    conedim1 = (int)0;
    conedim2 = (int)0;
    axisIsSet = false;
  }
}monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain :: __mosek_2fusion_2PSDDomain__axis(int _2895,int _2896) { return mosek::fusion::p_PSDDomain::_get_impl(this)->__mosek_2fusion_2PSDDomain__axis(_2895,_2896); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::PSDDomain::axis(int _2895,int _2896) { return __mosek_2fusion_2PSDDomain__axis(_2895,_2896); }
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_PSDDomain::__mosek_2fusion_2PSDDomain__axis(int _2895,int _2896){
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim1 = _2895;
  mosek::fusion::p_PSDDomain::_get_impl(::mosek::fusion::PSDDomain::t(_pubthis))->conedim2 = _2896;
  axisIsSet = true;
  if (((NULL == shape.get()) && (!((_2895 >= (int)0) && ((_2896 >= (int)0) && (_2895 != _2896))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  else if(((NULL != shape.get()) && ((!(((int)((shape)->size(0)) > _2895) && (((int)((shape)->size(0)) > _2896) && ((_2895 >= (int)0) && ((_2896 >= (int)0) && (_2895 != _2896)))))) && (((*shape)(_2895)) == ((*shape)(_2896))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape or cone dimensions"));
    }
  }
  {}
  return ::mosek::fusion::PSDDomain::t(_pubthis);
}
void mosek::fusion::p_PSDDomain::destroy(){shape.reset();}void mosek::fusion::PSDDomain::destroy() { mosek::fusion::p_PSDDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain(mosek::fusion::p_SymmetricRangeDomain *_impl) : mosek::fusion::RangeDomain(_impl) { /*std::cout << "SymmetricRangeDomain()" << this << std::endl; */ }mosek::fusion::SymmetricRangeDomain::~SymmetricRangeDomain() {  /* std::cout << "~SymmetricRangeDomain()" << this << std::endl << std::flush; */ }mosek::fusion::p_SymmetricRangeDomain::p_SymmetricRangeDomain  (::mosek::fusion::SymmetricRangeDomain * _pubthis) :     mosek::fusion::p_RangeDomain(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SymmetricRangeDomain::t mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2897){ return new mosek::fusion::SymmetricRangeDomain(_2897); }mosek::fusion::SymmetricRangeDomain::SymmetricRangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2897) :    SymmetricRangeDomain(new mosek::fusion::p_SymmetricRangeDomain(this)){ mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->_initialize(_2897); }void mosek::fusion::p_SymmetricRangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2897){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_RangeDomain::_initialize(_2897);
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _10085;
    bool _10086 = (NULL == shape.get());
    if (_10086)
    {
      _10085 = (int)0;
    }
    else
    {
      _10085 = ((*shape)((int)0));
    }
    dim = _10085;
  }
}void mosek::fusion::p_SymmetricRangeDomain::destroy(){}void mosek::fusion::SymmetricRangeDomain::destroy() { mosek::fusion::p_SymmetricRangeDomain::_get_impl(this)->destroy(); }mosek::fusion::RangeDomain::RangeDomain(mosek::fusion::p_RangeDomain *_impl) : _impl(_impl) { /*std::cout << "RangeDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::RangeDomain::~RangeDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_RangeDomain::p_RangeDomain  (::mosek::fusion::RangeDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2898,    std::shared_ptr< monty::ndarray< double,1 > > _2899,    std::shared_ptr< monty::ndarray< double,1 > > _2900,    std::shared_ptr< monty::ndarray< int,1 > > _2901){ return new mosek::fusion::RangeDomain(_2898,_2899,_2900,_2901); }mosek::fusion::RangeDomain::RangeDomain  (bool _2898,    std::shared_ptr< monty::ndarray< double,1 > > _2899,    std::shared_ptr< monty::ndarray< double,1 > > _2900,    std::shared_ptr< monty::ndarray< int,1 > > _2901) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2898,_2899,_2900,_2901); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2898,    std::shared_ptr< monty::ndarray< double,1 > > _2899,    std::shared_ptr< monty::ndarray< double,1 > > _2900,    std::shared_ptr< monty::ndarray< int,1 > > _2901){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2899(_2899 ? _2899->raw() : nullptr, _2899 ? _2899->size(0) : 0);
    _checked_ptr_1<double> _ptr__2900(_2900 ? _2900->raw() : nullptr, _2900 ? _2900->size(0) : 0);
    _checked_ptr_1<int> _ptr__2901(_2901 ? _2901->raw() : nullptr, _2901 ? _2901->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2898,_2899,_2900,_2901,nullptr,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2902,    std::shared_ptr< monty::ndarray< double,1 > > _2903,    std::shared_ptr< monty::ndarray< double,1 > > _2904,    std::shared_ptr< monty::ndarray< int,1 > > _2905,    std::shared_ptr< monty::ndarray< int,2 > > _2906){ return new mosek::fusion::RangeDomain(_2902,_2903,_2904,_2905,_2906); }mosek::fusion::RangeDomain::RangeDomain  (bool _2902,    std::shared_ptr< monty::ndarray< double,1 > > _2903,    std::shared_ptr< monty::ndarray< double,1 > > _2904,    std::shared_ptr< monty::ndarray< int,1 > > _2905,    std::shared_ptr< monty::ndarray< int,2 > > _2906) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2902,_2903,_2904,_2905,_2906); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2902,    std::shared_ptr< monty::ndarray< double,1 > > _2903,    std::shared_ptr< monty::ndarray< double,1 > > _2904,    std::shared_ptr< monty::ndarray< int,1 > > _2905,    std::shared_ptr< monty::ndarray< int,2 > > _2906){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2903(_2903 ? _2903->raw() : nullptr, _2903 ? _2903->size(0) : 0);
    _checked_ptr_1<double> _ptr__2904(_2904 ? _2904->raw() : nullptr, _2904 ? _2904->size(0) : 0);
    _checked_ptr_1<int> _ptr__2905(_2905 ? _2905->raw() : nullptr, _2905 ? _2905->size(0) : 0);
    mosek::fusion::p_RangeDomain::_initialize(_2902,_2903,_2904,_2905,_2906,(int)1);
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (bool _2907,    std::shared_ptr< monty::ndarray< double,1 > > _2908,    std::shared_ptr< monty::ndarray< double,1 > > _2909,    std::shared_ptr< monty::ndarray< int,1 > > _2910,    std::shared_ptr< monty::ndarray< int,2 > > _2911,    int _2912){ return new mosek::fusion::RangeDomain(_2907,_2908,_2909,_2910,_2911,_2912); }mosek::fusion::RangeDomain::RangeDomain  (bool _2907,    std::shared_ptr< monty::ndarray< double,1 > > _2908,    std::shared_ptr< monty::ndarray< double,1 > > _2909,    std::shared_ptr< monty::ndarray< int,1 > > _2910,    std::shared_ptr< monty::ndarray< int,2 > > _2911,    int _2912) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2907,_2908,_2909,_2910,_2911,_2912); }void mosek::fusion::p_RangeDomain::_initialize  (bool _2907,    std::shared_ptr< monty::ndarray< double,1 > > _2908,    std::shared_ptr< monty::ndarray< double,1 > > _2909,    std::shared_ptr< monty::ndarray< int,1 > > _2910,    std::shared_ptr< monty::ndarray< int,2 > > _2911,    int _2912){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2908(_2908 ? _2908->raw() : nullptr, _2908 ? _2908->size(0) : 0);
    _checked_ptr_1<double> _ptr__2909(_2909 ? _2909->raw() : nullptr, _2909 ? _2909->size(0) : 0);
    _checked_ptr_1<int> _ptr__2910(_2910 ? _2910->raw() : nullptr, _2910 ? _2910->size(0) : 0);
    cardinal_flag = false;
    shape = _2910;
    sparsity = nullptr;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->scalable = _2907;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->ub = _2909;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->lb = _2908;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = _2911;
    mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::RangeDomain::t mosek::fusion::p_RangeDomain::_new_RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2913){ return new mosek::fusion::RangeDomain(_2913); }mosek::fusion::RangeDomain::RangeDomain  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2913) :    RangeDomain(new mosek::fusion::p_RangeDomain(this)){ mosek::fusion::p_RangeDomain::_get_impl(this)->_initialize(_2913); }void mosek::fusion::p_RangeDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::RangeDomain > _2913){monty::rc_reserve __reserve_this(_pubthis);   {
    cardinal_flag = mosek::fusion::p_RangeDomain::_get_impl(_2913)->cardinal_flag;
    sparsity = mosek::fusion::p_RangeDomain::_get_impl(_2913)->sparsity;
    scalable = mosek::fusion::p_RangeDomain::_get_impl(_2913)->scalable;
    shape = mosek::fusion::p_RangeDomain::_get_impl(_2913)->shape;
    ub = mosek::fusion::p_RangeDomain::_get_impl(_2913)->ub;
    lb = mosek::fusion::p_RangeDomain::_get_impl(_2913)->lb;
    empty = mosek::fusion::p_RangeDomain::_get_impl(_2913)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__symmetric() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::RangeDomain::symmetric() { return __mosek_2fusion_2RangeDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricRangeDomain::_new_SymmetricRangeDomain(::mosek::fusion::RangeDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2914) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2914); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2914) { return __mosek_2fusion_2RangeDomain__sparse(_2914); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2914){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2914)->size(0)),(int)((_2914)->size(1)))));
  {
    int _2915 = (int)0;
    for(;(_2915 < (int)((_2914)->size(0)));++ _2915)
    {
      {
        {
          int _2916 = (int)0;
          for(;(_2916 < (int)((_2914)->size(1)));++ _2916)
          {
            {
              ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2915,_2916)) = ((*_2914)(_2915,_2916));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2917) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(_2917); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2917) { return __mosek_2fusion_2RangeDomain__sparse(_2917); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2917){
  _checked_ptr_1<int> _ptr__2917(_2917 ? _2917->raw() : nullptr, _2917 ? _2917->size(0) : 0);
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2917)->size(0)),(int)1)));
  int _10087 = (int)0;
  int _10088 = (int)((_2917)->size(0));
  for (int _2918 = _10087; _2918 < _10088; ++_2918)
  {
    {
      ((*mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity)(_2918,(int)0)) = _ptr__2917[_2918];
    }
  }
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__sparse() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::sparse() { return __mosek_2fusion_2RangeDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__sparse(){
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_RangeDomain::_get_impl(::mosek::fusion::RangeDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__integral() { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__integral(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::integral() { return __mosek_2fusion_2RangeDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(int _2919,int _2920,int _2921) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2919,_2920,_2921); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(int _2919,int _2920,int _2921) { return __mosek_2fusion_2RangeDomain__withShape(_2919,_2920,_2921); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(int _2919,int _2920,int _2921){
  shape = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2919),(int)(_2920),(int)(_2921)});
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(int _2922,int _2923) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2922,_2923); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(int _2922,int _2923) { return __mosek_2fusion_2RangeDomain__withShape(_2922,_2923); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(int _2922,int _2923){
  shape = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2922),(int)(_2923)});
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(int _2924) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2924); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(int _2924) { return __mosek_2fusion_2RangeDomain__withShape(_2924); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(int _2924){
  shape = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2924)});
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain :: __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2925) { return mosek::fusion::p_RangeDomain::_get_impl(this)->__mosek_2fusion_2RangeDomain__withShape(_2925); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::RangeDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2925) { return __mosek_2fusion_2RangeDomain__withShape(_2925); }
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_RangeDomain::__mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2925){
  _checked_ptr_1<int> _ptr__2925(_2925 ? _2925->raw() : nullptr, _2925 ? _2925->size(0) : 0);
  shape = _2925;
  return ::mosek::fusion::RangeDomain::t(_pubthis);
}
bool mosek::fusion::p_RangeDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2926){
  _checked_ptr_1<int> _ptr__2926(_2926 ? _2926->raw() : nullptr, _2926 ? _2926->size(0) : 0);
  if (scalable)
  {
    {
      return true;
    }
  }
  else if(((int)((shape)->size(0)) != (int)((_2926)->size(0))))
  {
    {
      return false;
    }
  }
  else
  {
    {
      int _10089 = (int)0;
      int _10090 = (int)((shape)->size(0));
      for (int _2927 = _10089; _2927 < _10090; ++_2927)
      {
        {
          if ((((*shape)(_2927)) != _ptr__2926[_2927]))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  return true;
}
void mosek::fusion::p_RangeDomain::destroy(){ub.reset();lb.reset();sparsity.reset();shape.reset();}void mosek::fusion::RangeDomain::destroy() { mosek::fusion::p_RangeDomain::_get_impl(this)->destroy(); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain(mosek::fusion::p_SymmetricLinearDomain *_impl) : _impl(_impl) { /*std::cout << "SymmetricLinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricLinearDomain::~SymmetricLinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricLinearDomain::p_SymmetricLinearDomain  (::mosek::fusion::SymmetricLinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricLinearDomain::t mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2928){ return new mosek::fusion::SymmetricLinearDomain(_2928); }mosek::fusion::SymmetricLinearDomain::SymmetricLinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2928) :    SymmetricLinearDomain(new mosek::fusion::p_SymmetricLinearDomain(this)){ mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->_initialize(_2928); }void mosek::fusion::p_SymmetricLinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2928){monty::rc_reserve __reserve_this(_pubthis);   {
    dom = _2928;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2928)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2928)->key;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2928)->cardinal_flag;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2928)->sparsity;
    if (((NULL != shape.get()) && (((int)((shape)->size(0)) != (int)2) || (((*shape)((int)0)) != ((*shape)((int)1))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Only square domains can be symmetric"));
      }
    }
    {}
    int _10091;
    bool _10092 = (NULL == shape.get());
    if (_10092)
    {
      _10091 = (int)0;
    }
    else
    {
      _10091 = ((*shape)((int)0));
    }
    dim = _10091;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2929) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2929); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2929) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2929); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2929){
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2929)->size(0)),(int)((_2929)->size(1)))));
  {
    int _2930 = (int)0;
    for(;(_2930 < (int)((_2929)->size(0)));++ _2930)
    {
      {
        {
          int _2931 = (int)0;
          for(;(_2931 < (int)((_2929)->size(1)));++ _2931)
          {
            {
              ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2930,_2931)) = ((*_2929)(_2930,_2931));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2932) { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__sparse(_2932); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2932) { return __mosek_2fusion_2SymmetricLinearDomain__sparse(_2932); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2932){
  _checked_ptr_1<int> _ptr__2932(_2932 ? _2932->raw() : nullptr, _2932 ? _2932->size(0) : 0);
  mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2932)->size(0)),(int)1)));
  int _10093 = (int)0;
  int _10094 = (int)((_2932)->size(0));
  for (int _2933 = _10093; _2933 < _10094; ++_2933)
  {
    {
      ((*mosek::fusion::p_SymmetricLinearDomain::_get_impl(::mosek::fusion::SymmetricLinearDomain::t(_pubthis))->sparsity)(_2933,(int)0)) = _ptr__2932[_2933];
    }
  }
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain :: __mosek_2fusion_2SymmetricLinearDomain__integral() { return mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->__mosek_2fusion_2SymmetricLinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::SymmetricLinearDomain::integral() { return __mosek_2fusion_2SymmetricLinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_SymmetricLinearDomain::__mosek_2fusion_2SymmetricLinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::SymmetricLinearDomain::t(_pubthis);
}
bool mosek::fusion::p_SymmetricLinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2934){
  _checked_ptr_1<int> _ptr__2934(_2934 ? _2934->raw() : nullptr, _2934 ? _2934->size(0) : 0);
  int _10095 = (int)0;
  int _10096 = (int)((_2934)->size(0));
  for (int _2935 = _10095; _2935 < _10096; ++_2935)
  {
    {
      if ((_ptr__2934[_2935] == ((*shape)(_2935))))
      {
        {
          return false;
        }
      }
      {}
    }
  }
  return true;
}
void mosek::fusion::p_SymmetricLinearDomain::destroy(){sparsity.reset();shape.reset();dom.reset();}void mosek::fusion::SymmetricLinearDomain::destroy() { mosek::fusion::p_SymmetricLinearDomain::_get_impl(this)->destroy(); }mosek::fusion::LinearDomain::LinearDomain(mosek::fusion::p_LinearDomain *_impl) : _impl(_impl) { /*std::cout << "LinearDomain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinearDomain::~LinearDomain() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinearDomain::p_LinearDomain  (::mosek::fusion::LinearDomain * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2936,    bool _2937,    std::shared_ptr< monty::ndarray< double,1 > > _2938,    std::shared_ptr< monty::ndarray< int,1 > > _2939){ return new mosek::fusion::LinearDomain(_2936,_2937,_2938,_2939); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2936,    bool _2937,    std::shared_ptr< monty::ndarray< double,1 > > _2938,    std::shared_ptr< monty::ndarray< int,1 > > _2939) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2936,_2937,_2938,_2939); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2936,    bool _2937,    std::shared_ptr< monty::ndarray< double,1 > > _2938,    std::shared_ptr< monty::ndarray< int,1 > > _2939){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2938(_2938 ? _2938->raw() : nullptr, _2938 ? _2938->size(0) : 0);
    _checked_ptr_1<int> _ptr__2939(_2939 ? _2939->raw() : nullptr, _2939 ? _2939->size(0) : 0);
    mosek::fusion::p_LinearDomain::_initialize(_2936,_2937,_2938,_2939,nullptr,(int)1);
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (mosek::fusion::RelationKey _2940,    bool _2941,    std::shared_ptr< monty::ndarray< double,1 > > _2942,    std::shared_ptr< monty::ndarray< int,1 > > _2943,    std::shared_ptr< monty::ndarray< int,2 > > _2944,    int _2945){ return new mosek::fusion::LinearDomain(_2940,_2941,_2942,_2943,_2944,_2945); }mosek::fusion::LinearDomain::LinearDomain  (mosek::fusion::RelationKey _2940,    bool _2941,    std::shared_ptr< monty::ndarray< double,1 > > _2942,    std::shared_ptr< monty::ndarray< int,1 > > _2943,    std::shared_ptr< monty::ndarray< int,2 > > _2944,    int _2945) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2940,_2941,_2942,_2943,_2944,_2945); }void mosek::fusion::p_LinearDomain::_initialize  (mosek::fusion::RelationKey _2940,    bool _2941,    std::shared_ptr< monty::ndarray< double,1 > > _2942,    std::shared_ptr< monty::ndarray< int,1 > > _2943,    std::shared_ptr< monty::ndarray< int,2 > > _2944,    int _2945){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__2942(_2942 ? _2942->raw() : nullptr, _2942 ? _2942->size(0) : 0);
    _checked_ptr_1<int> _ptr__2943(_2943 ? _2943->raw() : nullptr, _2943 ? _2943->size(0) : 0);
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->scalable = _2941;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->shape = _2943;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->key = _2940;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->bnd = _2942;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = _2944;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->cardinal_flag = false;
    mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  }
}mosek::fusion::LinearDomain::t mosek::fusion::p_LinearDomain::_new_LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2946){ return new mosek::fusion::LinearDomain(_2946); }mosek::fusion::LinearDomain::LinearDomain  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2946) :    LinearDomain(new mosek::fusion::p_LinearDomain(this)){ mosek::fusion::p_LinearDomain::_get_impl(this)->_initialize(_2946); }void mosek::fusion::p_LinearDomain::_initialize  (monty::rc_ptr< ::mosek::fusion::LinearDomain > _2946){monty::rc_reserve __reserve_this(_pubthis);   {
    scalable = mosek::fusion::p_LinearDomain::_get_impl(_2946)->scalable;
    shape = mosek::fusion::p_LinearDomain::_get_impl(_2946)->shape;
    key = mosek::fusion::p_LinearDomain::_get_impl(_2946)->key;
    bnd = mosek::fusion::p_LinearDomain::_get_impl(_2946)->bnd;
    sparsity = mosek::fusion::p_LinearDomain::_get_impl(_2946)->sparsity;
    cardinal_flag = mosek::fusion::p_LinearDomain::_get_impl(_2946)->cardinal_flag;
    empty = mosek::fusion::p_LinearDomain::_get_impl(_2946)->empty;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__symmetric() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__symmetric(); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::LinearDomain::symmetric() { return __mosek_2fusion_2LinearDomain__symmetric(); }
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__symmetric(){
  return ::mosek::fusion::p_SymmetricLinearDomain::_new_SymmetricLinearDomain(::mosek::fusion::LinearDomain::t(_pubthis));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2947) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2947); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,2 > > _2947) { return __mosek_2fusion_2LinearDomain__sparse(_2947); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2947){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2947)->size(0)),(int)((_2947)->size(1)))));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  {
    int _2948 = (int)0;
    for(;(_2948 < (int)((_2947)->size(0)));++ _2948)
    {
      {
        {
          int _2949 = (int)0;
          for(;(_2949 < (int)((_2947)->size(1)));++ _2949)
          {
            {
              ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2948,_2949)) = ((*_2947)(_2948,_2949));
            }
          }
        }
      }
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2950) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(_2950); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse(std::shared_ptr< monty::ndarray< int,1 > > _2950) { return __mosek_2fusion_2LinearDomain__sparse(_2950); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2950){
  _checked_ptr_1<int> _ptr__2950(_2950 ? _2950->raw() : nullptr, _2950 ? _2950->size(0) : 0);
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_2950)->size(0)),(int)1)));
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = false;
  int _10097 = (int)0;
  int _10098 = (int)((_2950)->size(0));
  for (int _2951 = _10097; _2951 < _10098; ++_2951)
  {
    {
      ((*mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity)(_2951,(int)0)) = _ptr__2950[_2951];
    }
  }
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__sparse() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__sparse(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::sparse() { return __mosek_2fusion_2LinearDomain__sparse(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__sparse(){
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->empty = true;
  mosek::fusion::p_LinearDomain::_get_impl(::mosek::fusion::LinearDomain::t(_pubthis))->sparsity = nullptr;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__integral() { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__integral(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::integral() { return __mosek_2fusion_2LinearDomain__integral(); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__integral(){
  cardinal_flag = true;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(int _2952,int _2953,int _2954) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2952,_2953,_2954); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(int _2952,int _2953,int _2954) { return __mosek_2fusion_2LinearDomain__withShape(_2952,_2953,_2954); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(int _2952,int _2953,int _2954){
  shape = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2952),(int)(_2953),(int)(_2954)});
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(int _2955,int _2956) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2955,_2956); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(int _2955,int _2956) { return __mosek_2fusion_2LinearDomain__withShape(_2955,_2956); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(int _2955,int _2956){
  shape = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2955),(int)(_2956)});
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(int _2957) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2957); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(int _2957) { return __mosek_2fusion_2LinearDomain__withShape(_2957); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(int _2957){
  shape = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2957)});
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain :: __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2958) { return mosek::fusion::p_LinearDomain::_get_impl(this)->__mosek_2fusion_2LinearDomain__withShape(_2958); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::LinearDomain::withShape(std::shared_ptr< monty::ndarray< int,1 > > _2958) { return __mosek_2fusion_2LinearDomain__withShape(_2958); }
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_LinearDomain::__mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2958){
  _checked_ptr_1<int> _ptr__2958(_2958 ? _2958->raw() : nullptr, _2958 ? _2958->size(0) : 0);
  shape = _2958;
  return ::mosek::fusion::LinearDomain::t(_pubthis);
}
bool mosek::fusion::p_LinearDomain::match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2959){
  _checked_ptr_1<int> _ptr__2959(_2959 ? _2959->raw() : nullptr, _2959 ? _2959->size(0) : 0);
  if ((!scalable))
  {
    {
      int _10099 = (int)0;
      int _10100 = (int)((_2959)->size(0));
      for (int _2960 = _10099; _2960 < _10100; ++_2960)
      {
        {
          if ((_ptr__2959[_2960] == ((*shape)(_2960))))
          {
            {
              return false;
            }
          }
          {}
        }
      }
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinearDomain::destroy(){sparsity.reset();bnd.reset();shape.reset();}void mosek::fusion::LinearDomain::destroy() { mosek::fusion::p_LinearDomain::_get_impl(this)->destroy(); }mosek::fusion::Domain::Domain(mosek::fusion::p_Domain *_impl) : _impl(_impl) { /*std::cout << "Domain() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Domain::~Domain() { delete _impl; _impl = nullptr; }mosek::fusion::p_Domain::p_Domain  (::mosek::fusion::Domain * _pubthis) :     _pubthis(_pubthis){}long long mosek::fusion::p_Domain::dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2961){
  _checked_ptr_1<int> _ptr__2961(_2961 ? _2961->raw() : nullptr, _2961 ? _2961->size(0) : 0);
  long long _2962 = (long long)1;
  int _10101 = (int)0;
  int _10102 = (int)((_2961)->size(0));
  for (int _2963 = _10101; _2963 < _10102; ++_2963)
  {
    {
      _2962 *= _ptr__2961[_2963];
    }
  }
  return _2962;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::mkRangedDomain(monty::rc_ptr< ::mosek::fusion::Matrix > _2964,monty::rc_ptr< ::mosek::fusion::Matrix > _2965){
  if (((mosek::fusion::p_Matrix::_get_impl(_2964)->dimi != mosek::fusion::p_Matrix::_get_impl(_2965)->dimi) || (mosek::fusion::p_Matrix::_get_impl(_2964)->dimj != mosek::fusion::p_Matrix::_get_impl(_2965)->dimj)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions in domain"));
    }
  }
  {}
  if ((_2964->isSparse() && _2965->isSparse()))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _2966 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2964->numNonzeros())));
      _checked_ptr_1<int> _ptr__2966(_2966 ? _2966->raw() : nullptr,_2966 ? _2966->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2967 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2964->numNonzeros())));
      _checked_ptr_1<int> _ptr__2967(_2967 ? _2967->raw() : nullptr,_2967 ? _2967->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2968 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2964->numNonzeros())));
      _checked_ptr_1<double> _ptr__2968(_2968 ? _2968->raw() : nullptr,_2968 ? _2968->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2969 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2965->numNonzeros())));
      _checked_ptr_1<int> _ptr__2969(_2969 ? _2969->raw() : nullptr,_2969 ? _2969->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _2970 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2965->numNonzeros())));
      _checked_ptr_1<int> _ptr__2970(_2970 ? _2970->raw() : nullptr,_2970 ? _2970->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2971 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2965->numNonzeros())));
      _checked_ptr_1<double> _ptr__2971(_2971 ? _2971->raw() : nullptr,_2971 ? _2971->size(0) : 0);
      _2964->getDataAsTriplets(_2966,_2967,_2968);
      _2965->getDataAsTriplets(_2969,_2970,_2971);
      long long _2972 = (int)0;
      {
        int _2973 = (int)0;
        int _2974 = (int)0;
        while ( ((_2974 < (int)((_2966)->size(0))) && (_2973 < (int)((_2969)->size(0)))) )
        {
          {
            if (((_ptr__2966[_2974] < _ptr__2969[_2973]) || ((_ptr__2966[_2974] == _ptr__2969[_2973]) && (_ptr__2967[_2974] < _ptr__2970[_2973]))))
            {
              {
                ++ _2972;
                ++ _2974;
              }
            }
            else
            {
              {
                if (((_ptr__2966[_2974] > _ptr__2969[_2973]) || ((_ptr__2966[_2974] == _ptr__2969[_2973]) && (_ptr__2967[_2974] > _ptr__2970[_2973]))))
                {
                  {
                    ++ _2972;
                    ++ _2973;
                  }
                }
                else
                {
                  {
                    ++ _2972;
                    ++ _2974;
                    ++ _2973;
                  }
                }
              }
            }
          }
        }
        _2972 += ((int)((_2966)->size(0)) - _2974);
        _2972 += ((int)((_2969)->size(0)) - _2973);
      }
      std::shared_ptr< monty::ndarray< int,2 > > _2975 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape(_2972,(int)2)));
      std::shared_ptr< monty::ndarray< double,1 > > _2976 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2972)));
      _checked_ptr_1<double> _ptr__2976(_2976 ? _2976->raw() : nullptr,_2976 ? _2976->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2977 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2972)));
      _checked_ptr_1<double> _ptr__2977(_2977 ? _2977->raw() : nullptr,_2977 ? _2977->size(0) : 0);
      {
        int _2978 = (int)0;
        int _2979 = (int)0;
        int _2980 = (int)0;
        while ( ((_2980 < (int)((_2966)->size(0))) && (_2979 < (int)((_2969)->size(0)))) )
        {
          {
            if (((_ptr__2966[_2980] < _ptr__2969[_2979]) || ((_ptr__2966[_2980] == _ptr__2969[_2979]) && (_ptr__2967[_2980] < _ptr__2970[_2979]))))
            {
              {
                ((*_2975)(_2978,(int)0)) = _ptr__2966[_2980];
                ((*_2975)(_2978,(int)1)) = _ptr__2967[_2980];
                _ptr__2976[_2978] = _ptr__2968[_2980];
                _ptr__2977[_2978] = 0.0;
                ++ _2978;
                ++ _2980;
              }
            }
            else
            {
              {
                if (((_ptr__2966[_2980] > _ptr__2969[_2979]) || ((_ptr__2966[_2980] == _ptr__2969[_2979]) && (_ptr__2967[_2980] > _ptr__2970[_2979]))))
                {
                  {
                    ((*_2975)(_2978,(int)0)) = _ptr__2969[_2979];
                    ((*_2975)(_2978,(int)1)) = _ptr__2970[_2979];
                    _ptr__2976[_2978] = 0.0;
                    _ptr__2977[_2978] = _ptr__2971[_2979];
                    ++ _2978;
                    ++ _2979;
                  }
                }
                else
                {
                  {
                    ((*_2975)(_2978,(int)0)) = _ptr__2969[_2979];
                    ((*_2975)(_2978,(int)1)) = _ptr__2970[_2979];
                    _ptr__2976[_2978] = _ptr__2968[_2979];
                    _ptr__2977[_2978] = _ptr__2971[_2979];
                    ++ _2978;
                    ++ _2980;
                    ++ _2979;
                  }
                }
              }
            }
          }
        }
        while ( (_2980 < (int)((_2966)->size(0))) )
        {
          {
            ((*_2975)(_2978,(int)0)) = _ptr__2966[_2980];
            ((*_2975)(_2978,(int)1)) = _ptr__2967[_2980];
            _ptr__2976[_2978] = _ptr__2968[_2980];
            _ptr__2977[_2978] = 0.0;
            ++ _2978;
            ++ _2980;
          }
        }
        while ( (_2979 < (int)((_2969)->size(0))) )
        {
          {
            ((*_2975)(_2978,(int)0)) = _ptr__2969[_2979];
            ((*_2975)(_2978,(int)1)) = _ptr__2970[_2979];
            _ptr__2976[_2978] = 0.0;
            _ptr__2977[_2978] = _ptr__2971[_2979];
            ++ _2978;
            ++ _2979;
          }
        }
      }
      return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2976,_2977,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2964)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2964)->dimj)}),_2975,(int)1);
    }
  }
  else
  {
    {
      int _2981 = mosek::fusion::p_Matrix::_get_impl(_2964)->dimj;
      int _2982 = mosek::fusion::p_Matrix::_get_impl(_2964)->dimi;
      int _2983 = safe_mul( _2982,_2981 );
      std::shared_ptr< monty::ndarray< double,1 > > _2984;
      _checked_ptr_1<double> _ptr__2984(_2984 ? _2984->raw() : nullptr,_2984 ? _2984->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _2985;
      _checked_ptr_1<double> _ptr__2985(_2985 ? _2985->raw() : nullptr,_2985 ? _2985->size(0) : 0);
      if (_2964->isSparse())
      {
        {
          _2984 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2983)));
          _ptr__2984.update(_2984 ? _2984->raw() : nullptr, _2984 ? _2984->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2986 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2964->numNonzeros())));
          _checked_ptr_1<int> _ptr__2986(_2986 ? _2986->raw() : nullptr,_2986 ? _2986->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2987 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2964->numNonzeros())));
          _checked_ptr_1<int> _ptr__2987(_2987 ? _2987->raw() : nullptr,_2987 ? _2987->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _2988 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2964->numNonzeros())));
          _checked_ptr_1<double> _ptr__2988(_2988 ? _2988->raw() : nullptr,_2988 ? _2988->size(0) : 0);
          _2964->getDataAsTriplets(_2986,_2987,_2988);
          int _10103 = (int)0;
          int _10104 = (int)((_2986)->size(0));
          for (int _2989 = _10103; _2989 < _10104; ++_2989)
          {
            {
              _ptr__2984[safe_add( safe_mul( _ptr__2986[_2989],_2981 ),_ptr__2987[_2989] )] = _ptr__2988[_2989];
            }
          }
        }
      }
      else
      {
        {
          _2984 = _2964->getDataAsArray();
          _ptr__2984.update(_2984 ? _2984->raw() : nullptr, _2984 ? _2984->size(0) : 0);
        }
      }
      if (_2965->isSparse())
      {
        {
          _2985 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2983)));
          _ptr__2985.update(_2985 ? _2985->raw() : nullptr, _2985 ? _2985->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2990 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2965->numNonzeros())));
          _checked_ptr_1<int> _ptr__2990(_2990 ? _2990->raw() : nullptr,_2990 ? _2990->size(0) : 0);
          std::shared_ptr< monty::ndarray< int,1 > > _2991 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_2965->numNonzeros())));
          _checked_ptr_1<int> _ptr__2991(_2991 ? _2991->raw() : nullptr,_2991 ? _2991->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _2992 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2965->numNonzeros())));
          _checked_ptr_1<double> _ptr__2992(_2992 ? _2992->raw() : nullptr,_2992 ? _2992->size(0) : 0);
          _2965->getDataAsTriplets(_2990,_2991,_2992);
          int _10105 = (int)0;
          int _10106 = (int)((_2990)->size(0));
          for (int _2993 = _10105; _2993 < _10106; ++_2993)
          {
            {
              _ptr__2985[safe_add( safe_mul( _ptr__2990[_2993],_2981 ),_ptr__2991[_2993] )] = _ptr__2992[_2993];
            }
          }
        }
      }
      else
      {
        {
          _2985 = _2965->getDataAsArray();
          _ptr__2985.update(_2985 ? _2985->raw() : nullptr, _2985 ? _2985->size(0) : 0);
        }
      }
      return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2984,_2985,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_2964)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_2964)->dimj)}),nullptr,(int)1);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::mkRangedDomain(std::shared_ptr< monty::ndarray< double,2 > > _2994,std::shared_ptr< monty::ndarray< double,2 > > _2995){
  if ((((int)((_2994)->size(0)) != (int)((_2995)->size(0))) || ((int)((_2994)->size(1)) != (int)((_2995)->size(1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions in domain"));
    }
  }
  {}
  int _2996 = (int)((_2994)->size(1));
  int _2997 = (int)((_2994)->size(0));
  int _2998 = safe_mul( _2997,_2996 );
  std::shared_ptr< monty::ndarray< double,1 > > _2999 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2998)));
  _checked_ptr_1<double> _ptr__2999(_2999 ? _2999->raw() : nullptr,_2999 ? _2999->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3000 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_2998)));
  _checked_ptr_1<double> _ptr__3000(_3000 ? _3000->raw() : nullptr,_3000 ? _3000->size(0) : 0);
  int _3001 = (int)0;
  int _10107 = (int)0;
  int _10108 = _2997;
  for (int _3002 = _10107; _3002 < _10108; ++_3002)
  {
    {
      int _10109 = (int)0;
      int _10110 = _2996;
      for (int _3003 = _10109; _3003 < _10110; ++_3003)
      {
        {
          _ptr__2999[_3001] = ((*_2994)(_3002,_3003));
          _ptr__3000[_3001] = ((*_2995)(_3002,_3003));
          ++ _3001;
        }
      }
    }
  }
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_2999,_3000,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_2997),(int)(_2996)}),nullptr,(int)1);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::mkLinearDomain(mosek::fusion::RelationKey _3004,monty::rc_ptr< ::mosek::fusion::Matrix > _3005){
  if (_3005->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _3006 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3005->numNonzeros())));
      _checked_ptr_1<int> _ptr__3006(_3006 ? _3006->raw() : nullptr,_3006 ? _3006->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3007 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3005->numNonzeros())));
      _checked_ptr_1<int> _ptr__3007(_3007 ? _3007->raw() : nullptr,_3007 ? _3007->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3008 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_3005->numNonzeros())));
      _checked_ptr_1<double> _ptr__3008(_3008 ? _3008->raw() : nullptr,_3008 ? _3008->size(0) : 0);
      _3005->getDataAsTriplets(_3006,_3007,_3008);
      std::shared_ptr< monty::ndarray< int,2 > > _3009 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_3006)->size(0)),(int)2)));
      int _10111 = (int)0;
      int _10112 = (int)((_3006)->size(0));
      for (int _3010 = _10111; _3010 < _10112; ++_3010)
      {
        {
          ((*_3009)(_3010,(int)0)) = _ptr__3006[_3010];
          ((*_3009)(_3010,(int)1)) = _ptr__3007[_3010];
        }
      }
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_3004,false,_3008,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_3005)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_3005)->dimj)}),_3009,(int)1);
    }
  }
  else
  {
    {
      return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(_3004,false,_3005->getDataAsArray(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(mosek::fusion::p_Matrix::_get_impl(_3005)->dimi),(int)(mosek::fusion::p_Matrix::_get_impl(_3005)->dimj)}),nullptr,(int)1);
    }
  }
}
long long mosek::fusion::p_Domain::prod(std::shared_ptr< monty::ndarray< int,1 > > _3011){
  _checked_ptr_1<int> _ptr__3011(_3011 ? _3011->raw() : nullptr, _3011 ? _3011->size(0) : 0);
  long long _3012 = (int)1;
  int _10113 = (int)0;
  int _10114 = (int)((_3011)->size(0));
  for (int _3013 = _10113; _3013 < _10114; ++_3013)
  {
    {
      _3012 *= _ptr__3011[_3013];
    }
  }
  return _3012;
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(bool _3014,std::shared_ptr< monty::ndarray< double,1 > > _3015,std::shared_ptr< monty::ndarray< double,1 > > _3016,std::shared_ptr< monty::ndarray< int,2 > > _3017,std::shared_ptr< monty::ndarray< int,1 > > _3018){
  _checked_ptr_1<double> _ptr__3015(_3015 ? _3015->raw() : nullptr, _3015 ? _3015->size(0) : 0);
  _checked_ptr_1<double> _ptr__3016(_3016 ? _3016->raw() : nullptr, _3016 ? _3016->size(0) : 0);
  _checked_ptr_1<int> _ptr__3018(_3018 ? _3018->raw() : nullptr, _3018 ? _3018->size(0) : 0);
  if (((!_3014) && ((int)((_3015)->size(0)) != (int)((_3016)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper and lower bounds."));
    }
  }
  {}
  if (((NULL != _3017.get()) && ((int)((_3017)->size(0)) != (int)((_3015)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of upper/lower bounds and sparsity."));
    }
  }
  {}
  int _10115 = (int)0;
  int _10116 = (int)((_3016)->size(0));
  for (int _3019 = _10115; _3019 < _10116; ++_3019)
  {
    {
      if ((_ptr__3015[_3019] > _ptr__3016[_3019]))
      {
        {
          throw ::mosek::fusion::DomainError(std::string ("Invalid range specified"));
        }
      }
      {}
    }
  }
  if (((NULL != _3018.get()) && (::mosek::fusion::p_Domain::dimsize(_3018) != (int)((_3015)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching dimensions."));
    }
  }
  {}
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(_3014,_3015,_3016,_3018)->__mosek_2fusion_2RangeDomain__sparse(_3017);
}
monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _3020) { return mosek::fusion::p_Domain::symmetric(_3020); }monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3020){
  return _3020->__mosek_2fusion_2RangeDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::Domain::symmetric  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _3021) { return mosek::fusion::p_Domain::symmetric(_3021); }monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > mosek::fusion::p_Domain::symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3021){
  return _3021->__mosek_2fusion_2LinearDomain__symmetric();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _3022,    std::shared_ptr< monty::ndarray< int,2 > > _3023) { return mosek::fusion::p_Domain::sparse(_3022,_3023); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3022,std::shared_ptr< monty::ndarray< int,2 > > _3023){
  return _3022->__mosek_2fusion_2RangeDomain__sparse(_3023);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _3024,    std::shared_ptr< monty::ndarray< int,1 > > _3025) { return mosek::fusion::p_Domain::sparse(_3024,_3025); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3024,std::shared_ptr< monty::ndarray< int,1 > > _3025){
  _checked_ptr_1<int> _ptr__3025(_3025 ? _3025->raw() : nullptr, _3025 ? _3025->size(0) : 0);
  return _3024->__mosek_2fusion_2RangeDomain__sparse(_3025);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _3026,    std::shared_ptr< monty::ndarray< int,2 > > _3027) { return mosek::fusion::p_Domain::sparse(_3026,_3027); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3026,std::shared_ptr< monty::ndarray< int,2 > > _3027){
  return _3026->__mosek_2fusion_2LinearDomain__sparse(_3027);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::sparse  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _3028,    std::shared_ptr< monty::ndarray< int,1 > > _3029) { return mosek::fusion::p_Domain::sparse(_3028,_3029); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3028,std::shared_ptr< monty::ndarray< int,1 > > _3029){
  _checked_ptr_1<int> _ptr__3029(_3029 ? _3029->raw() : nullptr, _3029 ? _3029->size(0) : 0);
  return _3028->__mosek_2fusion_2LinearDomain__sparse(_3029);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::RangeDomain > _3030) { return mosek::fusion::p_Domain::integral(_3030); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3030){
  return _3030->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::LinearDomain > _3031) { return mosek::fusion::p_Domain::integral(_3031); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3031){
  return _3031->__mosek_2fusion_2LinearDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::integral  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _3032) { return mosek::fusion::p_Domain::integral(_3032); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _3032){
  return _3032->__mosek_2fusion_2ConeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::axis  ( monty::rc_ptr< ::mosek::fusion::ConeDomain > _3033,    int _3034) { return mosek::fusion::p_Domain::axis(_3033,_3034); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _3033,int _3034){
  return _3033->__mosek_2fusion_2ConeDomain__axis(_3034);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _3035,    std::shared_ptr< monty::ndarray< int,1 > > _3036) { return mosek::fusion::p_Domain::inDPowerCone(_3035,_3036); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _3035,std::shared_ptr< monty::ndarray< int,1 > > _3036){
  _checked_ptr_1<int> _ptr__3036(_3036 ? _3036->raw() : nullptr, _3036 ? _3036->size(0) : 0);
  std::vector<int> _10117;
  for (int _3037 = (int)0, _10118 = (int)((_3036)->size(0)); _3037 < _10118 ; ++_3037)
  {
    _10117.push_back(_ptr__3036[_3037]);
  }
  auto _10119 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10117.size()),_10117.begin(),_10117.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_3035,_10119);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _3038,    int _3039) { return mosek::fusion::p_Domain::inDPowerCone(_3038,_3039); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _3038,int _3039){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_3038,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3039),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDPowerCone  ( double _3040) { return mosek::fusion::p_Domain::inDPowerCone(_3040); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDPowerCone(double _3040){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDPowCone,_3040,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _3041,    std::shared_ptr< monty::ndarray< int,1 > > _3042) { return mosek::fusion::p_Domain::inPPowerCone(_3041,_3042); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _3041,std::shared_ptr< monty::ndarray< int,1 > > _3042){
  _checked_ptr_1<int> _ptr__3042(_3042 ? _3042->raw() : nullptr, _3042 ? _3042->size(0) : 0);
  std::vector<int> _10120;
  for (int _3043 = (int)0, _10121 = (int)((_3042)->size(0)); _3043 < _10121 ; ++_3043)
  {
    _10120.push_back(_ptr__3042[_3043]);
  }
  auto _10122 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10120.size()),_10120.begin(),_10120.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_3041,_10122);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _3044,    int _3045) { return mosek::fusion::p_Domain::inPPowerCone(_3044,_3045); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _3044,int _3045){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_3044,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3045),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPPowerCone  ( double _3046) { return mosek::fusion::p_Domain::inPPowerCone(_3046); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPPowerCone(double _3046){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPPowCone,_3046,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _3047) { return mosek::fusion::p_Domain::inDExpCone(_3047); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _3047){
  _checked_ptr_1<int> _ptr__3047(_3047 ? _3047->raw() : nullptr, _3047 ? _3047->size(0) : 0);
  std::vector<int> _10123;
  for (int _3048 = (int)0, _10124 = (int)((_3047)->size(0)); _3048 < _10124 ; ++_3048)
  {
    _10123.push_back(_ptr__3047[_3048]);
  }
  auto _10125 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10123.size()),_10123.begin(),_10123.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,_10125);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( int _3049) { return mosek::fusion::p_Domain::inDExpCone(_3049); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(int _3049){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3049),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inDExpCone  ( ) { return mosek::fusion::p_Domain::inDExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inDExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InDExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( std::shared_ptr< monty::ndarray< int,1 > > _3050) { return mosek::fusion::p_Domain::inPExpCone(_3050); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _3050){
  _checked_ptr_1<int> _ptr__3050(_3050 ? _3050->raw() : nullptr, _3050 ? _3050->size(0) : 0);
  std::vector<int> _10126;
  for (int _3051 = (int)0, _10127 = (int)((_3050)->size(0)); _3051 < _10127 ; ++_3051)
  {
    _10126.push_back(_ptr__3050[_3051]);
  }
  auto _10128 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10126.size()),_10126.begin(),_10126.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,_10128);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( int _3052) { return mosek::fusion::p_Domain::inPExpCone(_3052); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(int _3052){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3052),(int)((int)3)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inPExpCone  ( ) { return mosek::fusion::p_Domain::inPExpCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inPExpCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InPExpCone,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _3053) { return mosek::fusion::p_Domain::inRotatedQCone(_3053); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _3053){
  _checked_ptr_1<int> _ptr__3053(_3053 ? _3053->raw() : nullptr, _3053 ? _3053->size(0) : 0);
  std::vector<int> _10129;
  for (int _3054 = (int)0, _10130 = (int)((_3053)->size(0)); _3054 < _10130 ; ++_3054)
  {
    _10129.push_back(_ptr__3053[_3054]);
  }
  auto _10131 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10129.size()),_10129.begin(),_10129.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,_10131);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _3055,    int _3056) { return mosek::fusion::p_Domain::inRotatedQCone(_3055,_3056); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _3055,int _3056){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3055),(int)(_3056)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( int _3057) { return mosek::fusion::p_Domain::inRotatedQCone(_3057); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(int _3057){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3057)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inRotatedQCone  ( ) { return mosek::fusion::p_Domain::inRotatedQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inRotatedQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InRotatedQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( std::shared_ptr< monty::ndarray< int,1 > > _3058) { return mosek::fusion::p_Domain::inQCone(_3058); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(std::shared_ptr< monty::ndarray< int,1 > > _3058){
  _checked_ptr_1<int> _ptr__3058(_3058 ? _3058->raw() : nullptr, _3058 ? _3058->size(0) : 0);
  std::vector<int> _10132;
  for (int _3059 = (int)0, _10133 = (int)((_3058)->size(0)); _3059 < _10133 ; ++_3059)
  {
    _10132.push_back(_ptr__3058[_3059]);
  }
  auto _10134 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10132.size()),_10132.begin(),_10132.end()));
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,_10134);
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _3060,    int _3061) { return mosek::fusion::p_Domain::inQCone(_3060,_3061); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _3060,int _3061){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3060),(int)(_3061)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( int _3062) { return mosek::fusion::p_Domain::inQCone(_3062); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(int _3062){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3062)}));
}
monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::Domain::inQCone  ( ) { return mosek::fusion::p_Domain::inQCone(); }monty::rc_ptr< ::mosek::fusion::ConeDomain > mosek::fusion::p_Domain::inQCone(){
  return ::mosek::fusion::p_ConeDomain::_new_ConeDomain(::mosek::fusion::QConeKey::InQCone,0.0,nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _3063,    int _3064) { return mosek::fusion::p_Domain::isLinPSD(_3063,_3064); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _3063,int _3064){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make(_3064,(safe_mul( _3063,safe_add( _3063,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( int _3065) { return mosek::fusion::p_Domain::isLinPSD(_3065); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(int _3065){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain(::mosek::fusion::p_Set::make((safe_mul( _3065,safe_add( _3065,(int)1 ) ) / (int)2)));
}
monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::Domain::isLinPSD  ( ) { return mosek::fusion::p_Domain::isLinPSD(); }monty::rc_ptr< ::mosek::fusion::LinPSDDomain > mosek::fusion::p_Domain::isLinPSD(){
  return ::mosek::fusion::p_LinPSDDomain::_new_LinPSDDomain();
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _3066,    int _3067) { return mosek::fusion::p_Domain::isTrilPSD(_3066,_3067); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _3066,int _3067){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3067),(int)(_3066),(int)(_3066)}),(int)1,(int)2);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( int _3068) { return mosek::fusion::p_Domain::isTrilPSD(_3068); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(int _3068){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3068),(int)(_3068)}),(int)0,(int)1);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::isTrilPSD  ( ) { return mosek::fusion::p_Domain::isTrilPSD(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::isTrilPSD(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsTrilPSD);
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _3069,    int _3070) { return mosek::fusion::p_Domain::inPSDCone(_3069,_3070); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _3069,int _3070){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3070),(int)(_3069),(int)(_3069)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( int _3071) { return mosek::fusion::p_Domain::inPSDCone(_3071); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(int _3071){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3071),(int)(_3071)}));
}
monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::Domain::inPSDCone  ( ) { return mosek::fusion::p_Domain::inPSDCone(); }monty::rc_ptr< ::mosek::fusion::PSDDomain > mosek::fusion::p_Domain::inPSDCone(){
  return ::mosek::fusion::p_PSDDomain::_new_PSDDomain(::mosek::fusion::PSDKey::IsSymPSD);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( ) { return mosek::fusion::p_Domain::binary(); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),nullptr)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( std::shared_ptr< monty::ndarray< int,1 > > _3072) { return mosek::fusion::p_Domain::binary(_3072); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(std::shared_ptr< monty::ndarray< int,1 > > _3072){
  _checked_ptr_1<int> _ptr__3072(_3072 ? _3072->raw() : nullptr, _3072 ? _3072->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),_3072)->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _3073,    int _3074) { return mosek::fusion::p_Domain::binary(_3073,_3074); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _3073,int _3074){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3073),(int)(_3074)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::binary  ( int _3075) { return mosek::fusion::p_Domain::binary(_3075); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::binary(int _3075){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(0.0)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(1.0)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3075)}))->__mosek_2fusion_2RangeDomain__integral();
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( monty::rc_ptr< ::mosek::fusion::Matrix > _3076,    monty::rc_ptr< ::mosek::fusion::Matrix > _3077) { return mosek::fusion::p_Domain::inRange(_3076,_3077); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(monty::rc_ptr< ::mosek::fusion::Matrix > _3076,monty::rc_ptr< ::mosek::fusion::Matrix > _3077){
  return ::mosek::fusion::p_Domain::mkRangedDomain(_3076,_3077);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,2 > > _3078,    std::shared_ptr< monty::ndarray< double,2 > > _3079) { return mosek::fusion::p_Domain::inRange(_3078,_3079); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,2 > > _3078,std::shared_ptr< monty::ndarray< double,2 > > _3079){
  return ::mosek::fusion::p_Domain::mkRangedDomain(_3078,_3079);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _3080,    std::shared_ptr< monty::ndarray< double,1 > > _3081,    std::shared_ptr< monty::ndarray< int,1 > > _3082) { return mosek::fusion::p_Domain::inRange(_3080,_3081,_3082); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _3080,std::shared_ptr< monty::ndarray< double,1 > > _3081,std::shared_ptr< monty::ndarray< int,1 > > _3082){
  _checked_ptr_1<double> _ptr__3080(_3080 ? _3080->raw() : nullptr, _3080 ? _3080->size(0) : 0);
  _checked_ptr_1<double> _ptr__3081(_3081 ? _3081->raw() : nullptr, _3081 ? _3081->size(0) : 0);
  _checked_ptr_1<int> _ptr__3082(_3082 ? _3082->raw() : nullptr, _3082 ? _3082->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_3080,_3081,_3082);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _3083,    double _3084,    std::shared_ptr< monty::ndarray< int,1 > > _3085) { return mosek::fusion::p_Domain::inRange(_3083,_3084,_3085); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _3083,double _3084,std::shared_ptr< monty::ndarray< int,1 > > _3085){
  _checked_ptr_1<double> _ptr__3083(_3083 ? _3083->raw() : nullptr, _3083 ? _3083->size(0) : 0);
  _checked_ptr_1<int> _ptr__3085(_3085 ? _3085->raw() : nullptr, _3085 ? _3085->size(0) : 0);
  std::vector<double> _10135;
  for (int _3086 = (int)0, _10136 = (int)((_3083)->size(0)); _3086 < _10136 ; ++_3086)
  {
    _10135.push_back(_3084);
  }
  auto _10137 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10135.size()),_10135.begin(),_10135.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_3083,_10137,_3085);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _3087,    std::shared_ptr< monty::ndarray< double,1 > > _3088,    std::shared_ptr< monty::ndarray< int,1 > > _3089) { return mosek::fusion::p_Domain::inRange(_3087,_3088,_3089); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _3087,std::shared_ptr< monty::ndarray< double,1 > > _3088,std::shared_ptr< monty::ndarray< int,1 > > _3089){
  _checked_ptr_1<double> _ptr__3088(_3088 ? _3088->raw() : nullptr, _3088 ? _3088->size(0) : 0);
  _checked_ptr_1<int> _ptr__3089(_3089 ? _3089->raw() : nullptr, _3089 ? _3089->size(0) : 0);
  std::vector<double> _10138;
  for (int _3090 = (int)0, _10139 = (int)((_3088)->size(0)); _3090 < _10139 ; ++_3090)
  {
    _10138.push_back(_3087);
  }
  auto _10140 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10138.size()),_10138.begin(),_10138.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_10140,_3088,_3089);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _3091,    double _3092,    std::shared_ptr< monty::ndarray< int,1 > > _3093) { return mosek::fusion::p_Domain::inRange(_3091,_3092,_3093); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _3091,double _3092,std::shared_ptr< monty::ndarray< int,1 > > _3093){
  _checked_ptr_1<int> _ptr__3093(_3093 ? _3093->raw() : nullptr, _3093 ? _3093->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3091)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3092)}),_3093);
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _3094,    std::shared_ptr< monty::ndarray< double,1 > > _3095) { return mosek::fusion::p_Domain::inRange(_3094,_3095); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _3094,std::shared_ptr< monty::ndarray< double,1 > > _3095){
  _checked_ptr_1<double> _ptr__3094(_3094 ? _3094->raw() : nullptr, _3094 ? _3094->size(0) : 0);
  _checked_ptr_1<double> _ptr__3095(_3095 ? _3095->raw() : nullptr, _3095 ? _3095->size(0) : 0);
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_3094,_3095,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3094)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( std::shared_ptr< monty::ndarray< double,1 > > _3096,    double _3097) { return mosek::fusion::p_Domain::inRange(_3096,_3097); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(std::shared_ptr< monty::ndarray< double,1 > > _3096,double _3097){
  _checked_ptr_1<double> _ptr__3096(_3096 ? _3096->raw() : nullptr, _3096 ? _3096->size(0) : 0);
  std::vector<double> _10141;
  for (int _3098 = (int)0, _10142 = (int)((_3096)->size(0)); _3098 < _10142 ; ++_3098)
  {
    _10141.push_back(_3097);
  }
  auto _10143 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10141.size()),_10141.begin(),_10141.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_3096,_10143,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3096)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _3099,    std::shared_ptr< monty::ndarray< double,1 > > _3100) { return mosek::fusion::p_Domain::inRange(_3099,_3100); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _3099,std::shared_ptr< monty::ndarray< double,1 > > _3100){
  _checked_ptr_1<double> _ptr__3100(_3100 ? _3100->raw() : nullptr, _3100 ? _3100->size(0) : 0);
  std::vector<double> _10144;
  for (int _3101 = (int)0, _10145 = (int)((_3100)->size(0)); _3101 < _10145 ; ++_3101)
  {
    _10144.push_back(_3099);
  }
  auto _10146 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10144.size()),_10144.begin(),_10144.end()));
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(false,_10146,_3100,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3100)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::Domain::inRange  ( double _3102,    double _3103) { return mosek::fusion::p_Domain::inRange(_3102,_3103); }monty::rc_ptr< ::mosek::fusion::RangeDomain > mosek::fusion::p_Domain::inRange(double _3102,double _3103){
  return ::mosek::fusion::p_RangeDomain::_new_RangeDomain(true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3102)}),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3103)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _3104) { return mosek::fusion::p_Domain::greaterThan(_3104); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _3104){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::GreaterThan,_3104);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _3105,    std::shared_ptr< monty::ndarray< int,1 > > _3106) { return mosek::fusion::p_Domain::greaterThan(_3105,_3106); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _3105,std::shared_ptr< monty::ndarray< int,1 > > _3106){
  _checked_ptr_1<double> _ptr__3105(_3105 ? _3105->raw() : nullptr, _3105 ? _3105->size(0) : 0);
  _checked_ptr_1<int> _ptr__3106(_3106 ? _3106->raw() : nullptr, _3106 ? _3106->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_3105),_3106);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,2 > > _3107) { return mosek::fusion::p_Domain::greaterThan(_3107); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _3107){
  std::vector<double> _10147;
  for (int _3108 = (int)0, _10148 = (int)((_3107)->size(0)); _3108 < _10148 ; ++_3108)
  {
    for (int _3109 = (int)0, _10149 = (int)((_3107)->size(1)); _3109 < _10149 ; ++_3109)
    {
      _10147.push_back(((*_3107)(_3108,_3109)));
    }
  }
  auto _10150 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10147.size()),_10147.begin(),_10147.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,_10150,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3107)->size(0))),(int)((int)((_3107)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( std::shared_ptr< monty::ndarray< double,1 > > _3110) { return mosek::fusion::p_Domain::greaterThan(_3110); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _3110){
  _checked_ptr_1<double> _ptr__3110(_3110 ? _3110->raw() : nullptr, _3110 ? _3110->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,false,::mosek::fusion::Utils::Tools::arraycopy(_3110),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3110)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _3111,    std::shared_ptr< monty::ndarray< int,1 > > _3112) { return mosek::fusion::p_Domain::greaterThan(_3111,_3112); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _3111,std::shared_ptr< monty::ndarray< int,1 > > _3112){
  _checked_ptr_1<int> _ptr__3112(_3112 ? _3112->raw() : nullptr, _3112 ? _3112->size(0) : 0);
  std::vector<double> _10151;
  for (long long _3113 = (int)0, _10152 = ::mosek::fusion::p_Domain::prod(_3112); _3113 < _10152 ; ++_3113)
  {
    _10151.push_back(_3111);
  }
  auto _10153 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10151.size()),_10151.begin(),_10151.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_10153,_3112);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _3114,    int _3115,    int _3116) { return mosek::fusion::p_Domain::greaterThan(_3114,_3115,_3116); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _3114,int _3115,int _3116){
  std::vector<double> _10154;
  for (int _3117 = (int)0, _10155 = safe_mul( _3116,_3115 ); _3117 < _10155 ; ++_3117)
  {
    _10154.push_back(_3114);
  }
  auto _10156 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10154.size()),_10154.begin(),_10154.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_10156,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3115),(int)(_3116)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _3118,    int _3119) { return mosek::fusion::p_Domain::greaterThan(_3118,_3119); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _3118,int _3119){
  std::vector<double> _10157;
  for (int _3120 = (int)0, _10158 = _3119; _3120 < _10158 ; ++_3120)
  {
    _10157.push_back(_3118);
  }
  auto _10159 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10157.size()),_10157.begin(),_10157.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,_10159,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3119)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::greaterThan  ( double _3121) { return mosek::fusion::p_Domain::greaterThan(_3121); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::greaterThan(double _3121){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::GreaterThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3121)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( monty::rc_ptr< ::mosek::fusion::Matrix > _3122) { return mosek::fusion::p_Domain::lessThan(_3122); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _3122){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::LessThan,_3122);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _3123,    std::shared_ptr< monty::ndarray< int,1 > > _3124) { return mosek::fusion::p_Domain::lessThan(_3123,_3124); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _3123,std::shared_ptr< monty::ndarray< int,1 > > _3124){
  _checked_ptr_1<double> _ptr__3123(_3123 ? _3123->raw() : nullptr, _3123 ? _3123->size(0) : 0);
  _checked_ptr_1<int> _ptr__3124(_3124 ? _3124->raw() : nullptr, _3124 ? _3124->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_3123),_3124);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,2 > > _3125) { return mosek::fusion::p_Domain::lessThan(_3125); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,2 > > _3125){
  std::vector<double> _10160;
  for (int _3126 = (int)0, _10161 = (int)((_3125)->size(0)); _3126 < _10161 ; ++_3126)
  {
    for (int _3127 = (int)0, _10162 = (int)((_3125)->size(1)); _3127 < _10162 ; ++_3127)
    {
      _10160.push_back(((*_3125)(_3126,_3127)));
    }
  }
  auto _10163 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10160.size()),_10160.begin(),_10160.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,_10163,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3125)->size(0))),(int)((int)((_3125)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( std::shared_ptr< monty::ndarray< double,1 > > _3128) { return mosek::fusion::p_Domain::lessThan(_3128); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(std::shared_ptr< monty::ndarray< double,1 > > _3128){
  _checked_ptr_1<double> _ptr__3128(_3128 ? _3128->raw() : nullptr, _3128 ? _3128->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,false,::mosek::fusion::Utils::Tools::arraycopy(_3128),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3128)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _3129,    std::shared_ptr< monty::ndarray< int,1 > > _3130) { return mosek::fusion::p_Domain::lessThan(_3129,_3130); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _3129,std::shared_ptr< monty::ndarray< int,1 > > _3130){
  _checked_ptr_1<int> _ptr__3130(_3130 ? _3130->raw() : nullptr, _3130 ? _3130->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3129)}),_3130);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _3131,    int _3132,    int _3133) { return mosek::fusion::p_Domain::lessThan(_3131,_3132,_3133); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _3131,int _3132,int _3133){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3131)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3132),(int)(_3133)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _3134,    int _3135) { return mosek::fusion::p_Domain::lessThan(_3134,_3135); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _3134,int _3135){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3134)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3135)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::lessThan  ( double _3136) { return mosek::fusion::p_Domain::lessThan(_3136); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::lessThan(double _3136){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::LessThan,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3136)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( monty::rc_ptr< ::mosek::fusion::Matrix > _3137) { return mosek::fusion::p_Domain::equalsTo(_3137); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _3137){
  return ::mosek::fusion::p_Domain::mkLinearDomain(::mosek::fusion::RelationKey::EqualsTo,_3137);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _3138,    std::shared_ptr< monty::ndarray< int,1 > > _3139) { return mosek::fusion::p_Domain::equalsTo(_3138,_3139); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _3138,std::shared_ptr< monty::ndarray< int,1 > > _3139){
  _checked_ptr_1<double> _ptr__3138(_3138 ? _3138->raw() : nullptr, _3138 ? _3138->size(0) : 0);
  _checked_ptr_1<int> _ptr__3139(_3139 ? _3139->raw() : nullptr, _3139 ? _3139->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_3138),_3139);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,2 > > _3140) { return mosek::fusion::p_Domain::equalsTo(_3140); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _3140){
  std::vector<double> _10164;
  for (int _3141 = (int)0, _10165 = (int)((_3140)->size(0)); _3141 < _10165 ; ++_3141)
  {
    for (int _3142 = (int)0, _10166 = (int)((_3140)->size(1)); _3142 < _10166 ; ++_3142)
    {
      _10164.push_back(((*_3140)(_3141,_3142)));
    }
  }
  auto _10167 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10164.size()),_10164.begin(),_10164.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,_10167,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3140)->size(0))),(int)((int)((_3140)->size(1)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( std::shared_ptr< monty::ndarray< double,1 > > _3143) { return mosek::fusion::p_Domain::equalsTo(_3143); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _3143){
  _checked_ptr_1<double> _ptr__3143(_3143 ? _3143->raw() : nullptr, _3143 ? _3143->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,false,::mosek::fusion::Utils::Tools::arraycopy(_3143),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_3143)->size(0)))}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _3144,    std::shared_ptr< monty::ndarray< int,1 > > _3145) { return mosek::fusion::p_Domain::equalsTo(_3144,_3145); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _3144,std::shared_ptr< monty::ndarray< int,1 > > _3145){
  _checked_ptr_1<int> _ptr__3145(_3145 ? _3145->raw() : nullptr, _3145 ? _3145->size(0) : 0);
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3144)}),_3145);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _3146,    int _3147,    int _3148) { return mosek::fusion::p_Domain::equalsTo(_3146,_3147,_3148); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _3146,int _3147,int _3148){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3146)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3147),(int)(_3148)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _3149,    int _3150) { return mosek::fusion::p_Domain::equalsTo(_3149,_3150); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _3149,int _3150){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3149)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3150)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::equalsTo  ( double _3151) { return mosek::fusion::p_Domain::equalsTo(_3151); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::equalsTo(double _3151){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::EqualsTo,true,std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >{(double)(_3151)}),nullptr);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( std::shared_ptr< monty::ndarray< int,1 > > _3152) { return mosek::fusion::p_Domain::unbounded(_3152); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(std::shared_ptr< monty::ndarray< int,1 > > _3152){
  _checked_ptr_1<int> _ptr__3152(_3152 ? _3152->raw() : nullptr, _3152 ? _3152->size(0) : 0);
  std::vector<int> _10168;
  for (int _3153 = (int)0, _10169 = (int)((_3152)->size(0)); _3153 < _10169 ; ++_3153)
  {
    _10168.push_back(_ptr__3152[_3153]);
  }
  auto _10170 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10168.size()),_10168.begin(),_10168.end()));
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,_10170);
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _3154,    int _3155) { return mosek::fusion::p_Domain::unbounded(_3154,_3155); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _3154,int _3155){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3154),(int)(_3155)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( int _3156) { return mosek::fusion::p_Domain::unbounded(_3156); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(int _3156){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,false,nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3156)}));
}
monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::Domain::unbounded  ( ) { return mosek::fusion::p_Domain::unbounded(); }monty::rc_ptr< ::mosek::fusion::LinearDomain > mosek::fusion::p_Domain::unbounded(){
  return ::mosek::fusion::p_LinearDomain::_new_LinearDomain(::mosek::fusion::RelationKey::IsFree,true,nullptr,nullptr);
}
void mosek::fusion::p_Domain::destroy(){}void mosek::fusion::Domain::destroy() { mosek::fusion::p_Domain::_get_impl(this)->destroy(); }mosek::fusion::ExprCode::ExprCode(mosek::fusion::p_ExprCode *_impl) : _impl(_impl) { /*std::cout << "ExprCode() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ExprCode::~ExprCode() { delete _impl; _impl = nullptr; }mosek::fusion::p_ExprCode::p_ExprCode  (::mosek::fusion::ExprCode * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::ExprCode::inplace_relocate  ( std::shared_ptr< monty::ndarray< int,1 > > _3157,    int _3158,    int _3159,    int _3160) { mosek::fusion::p_ExprCode::inplace_relocate(_3157,_3158,_3159,_3160); }void mosek::fusion::p_ExprCode::inplace_relocate(std::shared_ptr< monty::ndarray< int,1 > > _3157,int _3158,int _3159,int _3160){
  _checked_ptr_1<int> _ptr__3157(_3157 ? _3157->raw() : nullptr, _3157 ? _3157->size(0) : 0);
  int _10171 = (int)0;
  int _10172 = _3159;
  int _10173 = (int)2;
  for (int _3161 = _10171; _3161 < _10172; _3161 += _10173)
  {
    {
      if ((_ptr__3157[_3161] == (int)2))
      {
        {
          _ptr__3157[safe_add( _3161,(int)1 )] += _3160;
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprCode::op2str  ( int _3162) { return mosek::fusion::p_ExprCode::op2str(_3162); }std::string mosek::fusion::p_ExprCode::op2str(int _3162){
  if ((_3162 == 0))
  {
    {
      return std::string ("NOP");
    }
  }
  else if((_3162 == 1))
  {
    {
      return std::string ("PARAMREF");
    }
  }
  else if((_3162 == 2))
  {
    {
      return std::string ("CONST");
    }
  }
  else if((_3162 == 3))
  {
    {
      return std::string ("ADD");
    }
  }
  else if((_3162 == 4))
  {
    {
      return std::string ("NEG");
    }
  }
  else if((_3162 == 5))
  {
    {
      return std::string ("MUL");
    }
  }
  else if((_3162 == 6))
  {
    {
      return std::string ("INV");
    }
  }
  else if((_3162 == 8))
  {
    {
      return std::string ("SUM");
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("?("))->__mosek_2fusion_2Utils_2StringBuffer__a(_3162)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
}
void mosek::fusion::ExprCode::eval_add_list  ( std::shared_ptr< monty::ndarray< int,1 > > _3163,    std::shared_ptr< monty::ndarray< int,1 > > _3164,    std::shared_ptr< monty::ndarray< double,1 > > _3165,    int _3166,    std::shared_ptr< monty::ndarray< double,1 > > _3167,    std::shared_ptr< monty::ndarray< double,1 > > _3168,    monty::rc_ptr< ::mosek::fusion::WorkStack > _3169) { mosek::fusion::p_ExprCode::eval_add_list(_3163,_3164,_3165,_3166,_3167,_3168,_3169); }void mosek::fusion::p_ExprCode::eval_add_list(std::shared_ptr< monty::ndarray< int,1 > > _3163,std::shared_ptr< monty::ndarray< int,1 > > _3164,std::shared_ptr< monty::ndarray< double,1 > > _3165,int _3166,std::shared_ptr< monty::ndarray< double,1 > > _3167,std::shared_ptr< monty::ndarray< double,1 > > _3168,monty::rc_ptr< ::mosek::fusion::WorkStack > _3169){
  _checked_ptr_1<int> _ptr__3163(_3163 ? _3163->raw() : nullptr, _3163 ? _3163->size(0) : 0);
  _checked_ptr_1<int> _ptr__3164(_3164 ? _3164->raw() : nullptr, _3164 ? _3164->size(0) : 0);
  _checked_ptr_1<double> _ptr__3165(_3165 ? _3165->raw() : nullptr, _3165 ? _3165->size(0) : 0);
  _checked_ptr_1<double> _ptr__3167(_3167 ? _3167->raw() : nullptr, _3167 ? _3167->size(0) : 0);
  _checked_ptr_1<double> _ptr__3168(_3168 ? _3168->raw() : nullptr, _3168 ? _3168->size(0) : 0);
  int _3170 = _3169->allocf64((int)((_3163)->size(0)));
  int _3171 = (int)0;
  std::shared_ptr< monty::ndarray< double,1 > > _3172 = mosek::fusion::p_WorkStack::_get_impl(_3169)->f64;
  _checked_ptr_1<double> _ptr__3172(_3172 ? _3172->raw() : nullptr,_3172 ? _3172->size(0) : 0);
  int _10174 = (int)0;
  int _10175 = ((int)((_3164)->size(0)) - (int)1);
  for (int _3173 = _10174; _3173 < _10175; ++_3173)
  {
    {
      int _10176 = _ptr__3164[_3173];
      int _10177 = _ptr__3164[safe_add( _3173,(int)1 )];
      int _10178 = (int)2;
      for (int _3174 = _10176; _3174 < _10177; _3174 += _10178)
      {
        {
          if ((_ptr__3163[_3174] == 0))
          {
            {
            }
          }
          else if((_ptr__3163[_3174] == 1))
          {
            {
              _ptr__3172[safe_add( _3170,_3171 )] = _ptr__3168[_ptr__3163[safe_add( _3174,(int)1 )]];
              ++ _3171;
            }
          }
          else if((_ptr__3163[_3174] == 2))
          {
            {
              _ptr__3172[safe_add( _3170,_3171 )] = _ptr__3165[(_3174 / (int)2)];
              ++ _3171;
            }
          }
          else if((_ptr__3163[_3174] == 3))
          {
            {
              _ptr__3172[(safe_add( _3170,_3171 ) - (int)2)] = (_ptr__3172[(safe_add( _3170,_3171 ) - (int)1)] + _ptr__3172[(safe_add( _3170,_3171 ) - (int)2)]);
              -- _3171;
            }
          }
          else if((_ptr__3163[_3174] == 4))
          {
            {
              _ptr__3172[(safe_add( _3170,_3171 ) - (int)1)] = (-_ptr__3172[(safe_add( _3170,_3171 ) - (int)1)]);
            }
          }
          else if((_ptr__3163[_3174] == 5))
          {
            {
              _ptr__3172[(safe_add( _3170,_3171 ) - (int)2)] = (_ptr__3172[(safe_add( _3170,_3171 ) - (int)1)] * _ptr__3172[(safe_add( _3170,_3171 ) - (int)2)]);
              -- _3171;
            }
          }
          else if((_ptr__3163[_3174] == 6))
          {
            {
              _ptr__3172[(safe_add( _3170,_3171 ) - (int)1)] = (1.0 / _ptr__3172[(safe_add( _3170,_3171 ) - (int)1)]);
            }
          }
          else if((_ptr__3163[_3174] == 8))
          {
            {
              double _3175 = 0.0;
              int _10179 = (int)0;
              int _10180 = _ptr__3163[safe_add( _3174,(int)1 )];
              for (int _3176 = _10179; _3176 < _10180; ++_3176)
              {
                {
                  -- _3171;
                  _3175 += _ptr__3172[safe_add( _3170,_3171 )];
                }
              }
              _ptr__3172[safe_add( _3170,_3171 )] = _3175;
              ++ _3171;
            }
          }
          {}
        }
      }
      _ptr__3167[safe_add( _3166,_3173 )] += _ptr__3172[(safe_add( _3170,_3171 ) - (int)1)];
    }
  }
  _3169->clear();
}
void mosek::fusion::ExprCode::eval_add_list  ( std::shared_ptr< monty::ndarray< int,1 > > _3177,    std::shared_ptr< monty::ndarray< int,1 > > _3178,    std::shared_ptr< monty::ndarray< double,1 > > _3179,    std::shared_ptr< monty::ndarray< double,1 > > _3180,    std::shared_ptr< monty::ndarray< double,1 > > _3181,    monty::rc_ptr< ::mosek::fusion::WorkStack > _3182) { mosek::fusion::p_ExprCode::eval_add_list(_3177,_3178,_3179,_3180,_3181,_3182); }void mosek::fusion::p_ExprCode::eval_add_list(std::shared_ptr< monty::ndarray< int,1 > > _3177,std::shared_ptr< monty::ndarray< int,1 > > _3178,std::shared_ptr< monty::ndarray< double,1 > > _3179,std::shared_ptr< monty::ndarray< double,1 > > _3180,std::shared_ptr< monty::ndarray< double,1 > > _3181,monty::rc_ptr< ::mosek::fusion::WorkStack > _3182){
  _checked_ptr_1<int> _ptr__3177(_3177 ? _3177->raw() : nullptr, _3177 ? _3177->size(0) : 0);
  _checked_ptr_1<int> _ptr__3178(_3178 ? _3178->raw() : nullptr, _3178 ? _3178->size(0) : 0);
  _checked_ptr_1<double> _ptr__3179(_3179 ? _3179->raw() : nullptr, _3179 ? _3179->size(0) : 0);
  _checked_ptr_1<double> _ptr__3180(_3180 ? _3180->raw() : nullptr, _3180 ? _3180->size(0) : 0);
  _checked_ptr_1<double> _ptr__3181(_3181 ? _3181->raw() : nullptr, _3181 ? _3181->size(0) : 0);
  ::mosek::fusion::p_ExprCode::eval_add_list(_3177,_3178,_3179,(int)0,_3180,_3181,_3182);
}
int mosek::fusion::ExprCode::emit_sum  ( std::shared_ptr< monty::ndarray< int,1 > > _3183,    int _3184,    int _3185) { return mosek::fusion::p_ExprCode::emit_sum(_3183,_3184,_3185); }int mosek::fusion::p_ExprCode::emit_sum(std::shared_ptr< monty::ndarray< int,1 > > _3183,int _3184,int _3185){
  _checked_ptr_1<int> _ptr__3183(_3183 ? _3183->raw() : nullptr, _3183 ? _3183->size(0) : 0);
  _ptr__3183[_3184] = 8;
  _ptr__3183[safe_add( _3184,(int)1 )] = _3185;
  return (int)2;
}
int mosek::fusion::ExprCode::emit_inv  ( std::shared_ptr< monty::ndarray< int,1 > > _3186,    int _3187) { return mosek::fusion::p_ExprCode::emit_inv(_3186,_3187); }int mosek::fusion::p_ExprCode::emit_inv(std::shared_ptr< monty::ndarray< int,1 > > _3186,int _3187){
  _checked_ptr_1<int> _ptr__3186(_3186 ? _3186->raw() : nullptr, _3186 ? _3186->size(0) : 0);
  _ptr__3186[_3187] = 6;
  _ptr__3186[safe_add( _3187,(int)1 )] = (int)0;
  return (int)2;
}
int mosek::fusion::ExprCode::emit_mul  ( std::shared_ptr< monty::ndarray< int,1 > > _3188,    int _3189) { return mosek::fusion::p_ExprCode::emit_mul(_3188,_3189); }int mosek::fusion::p_ExprCode::emit_mul(std::shared_ptr< monty::ndarray< int,1 > > _3188,int _3189){
  _checked_ptr_1<int> _ptr__3188(_3188 ? _3188->raw() : nullptr, _3188 ? _3188->size(0) : 0);
  _ptr__3188[_3189] = 5;
  _ptr__3188[safe_add( _3189,(int)1 )] = (int)0;
  return (int)2;
}
int mosek::fusion::ExprCode::emit_neg  ( std::shared_ptr< monty::ndarray< int,1 > > _3190,    int _3191) { return mosek::fusion::p_ExprCode::emit_neg(_3190,_3191); }int mosek::fusion::p_ExprCode::emit_neg(std::shared_ptr< monty::ndarray< int,1 > > _3190,int _3191){
  _checked_ptr_1<int> _ptr__3190(_3190 ? _3190->raw() : nullptr, _3190 ? _3190->size(0) : 0);
  _ptr__3190[_3191] = 4;
  _ptr__3190[safe_add( _3191,(int)1 )] = (int)0;
  return (int)2;
}
int mosek::fusion::ExprCode::emit_add  ( std::shared_ptr< monty::ndarray< int,1 > > _3192,    int _3193) { return mosek::fusion::p_ExprCode::emit_add(_3192,_3193); }int mosek::fusion::p_ExprCode::emit_add(std::shared_ptr< monty::ndarray< int,1 > > _3192,int _3193){
  _checked_ptr_1<int> _ptr__3192(_3192 ? _3192->raw() : nullptr, _3192 ? _3192->size(0) : 0);
  _ptr__3192[_3193] = 3;
  _ptr__3192[safe_add( _3193,(int)1 )] = (int)0;
  return (int)2;
}
int mosek::fusion::ExprCode::emit_constref  ( std::shared_ptr< monty::ndarray< int,1 > > _3194,    int _3195,    int _3196) { return mosek::fusion::p_ExprCode::emit_constref(_3194,_3195,_3196); }int mosek::fusion::p_ExprCode::emit_constref(std::shared_ptr< monty::ndarray< int,1 > > _3194,int _3195,int _3196){
  _checked_ptr_1<int> _ptr__3194(_3194 ? _3194->raw() : nullptr, _3194 ? _3194->size(0) : 0);
  _ptr__3194[_3195] = 2;
  _ptr__3194[safe_add( _3195,(int)1 )] = _3196;
  return (int)2;
}
int mosek::fusion::ExprCode::emit_paramref  ( std::shared_ptr< monty::ndarray< int,1 > > _3197,    int _3198,    int _3199) { return mosek::fusion::p_ExprCode::emit_paramref(_3197,_3198,_3199); }int mosek::fusion::p_ExprCode::emit_paramref(std::shared_ptr< monty::ndarray< int,1 > > _3197,int _3198,int _3199){
  _checked_ptr_1<int> _ptr__3197(_3197 ? _3197->raw() : nullptr, _3197 ? _3197->size(0) : 0);
  _ptr__3197[_3198] = 1;
  _ptr__3197[safe_add( _3198,(int)1 )] = _3199;
  return (int)2;
}
int mosek::fusion::ExprCode::emit_nop  ( std::shared_ptr< monty::ndarray< int,1 > > _3200,    int _3201) { return mosek::fusion::p_ExprCode::emit_nop(_3200,_3201); }int mosek::fusion::p_ExprCode::emit_nop(std::shared_ptr< monty::ndarray< int,1 > > _3200,int _3201){
  _checked_ptr_1<int> _ptr__3200(_3200 ? _3200->raw() : nullptr, _3200 ? _3200->size(0) : 0);
  _ptr__3200[_3201] = 0;
  _ptr__3200[safe_add( _3201,(int)1 )] = (int)0;
  return (int)2;
}
void mosek::fusion::p_ExprCode::destroy(){}void mosek::fusion::ExprCode::destroy() { mosek::fusion::p_ExprCode::_get_impl(this)->destroy(); }mosek::fusion::ExprParameter::ExprParameter(mosek::fusion::p_ExprParameter *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprParameter()" << this << std::endl; */ }mosek::fusion::ExprParameter::~ExprParameter() {  /* std::cout << "~ExprParameter()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprParameter::p_ExprParameter  (::mosek::fusion::ExprParameter * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprParameter::t mosek::fusion::p_ExprParameter::_new_ExprParameter  (monty::rc_ptr< ::mosek::fusion::Parameter > _3202){ return new mosek::fusion::ExprParameter(_3202); }mosek::fusion::ExprParameter::ExprParameter  (monty::rc_ptr< ::mosek::fusion::Parameter > _3202) :    ExprParameter(new mosek::fusion::p_ExprParameter(this)){ mosek::fusion::p_ExprParameter::_get_impl(this)->_initialize(_3202); }void mosek::fusion::p_ExprParameter::_initialize  (monty::rc_ptr< ::mosek::fusion::Parameter > _3202){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3202->getShape());
    mosek::fusion::p_ExprParameter::_get_impl(::mosek::fusion::ExprParameter::t(_pubthis))->p = _3202;
  }
}void mosek::fusion::ExprParameter :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3203,monty::rc_ptr< ::mosek::fusion::WorkStack > _3204,monty::rc_ptr< ::mosek::fusion::WorkStack > _3205) { mosek::fusion::p_ExprParameter::_get_impl(this)->eval(_3203,_3204,_3205); }void mosek::fusion::p_ExprParameter::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3203,monty::rc_ptr< ::mosek::fusion::WorkStack > _3204,monty::rc_ptr< ::mosek::fusion::WorkStack > _3205){
  p->eval(_3203,_3204,_3205);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ExprParameter :: __mosek_2fusion_2ExprParameter__slice(std::shared_ptr< monty::ndarray< int,1 > > _3206,std::shared_ptr< monty::ndarray< int,1 > > _3207) { return mosek::fusion::p_ExprParameter::_get_impl(this)->__mosek_2fusion_2ExprParameter__slice(_3206,_3207); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ExprParameter::slice(std::shared_ptr< monty::ndarray< int,1 > > _3206,std::shared_ptr< monty::ndarray< int,1 > > _3207) { return __mosek_2fusion_2ExprParameter__slice(_3206,_3207); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ExprParameter::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _3206,std::shared_ptr< monty::ndarray< int,1 > > _3207) { return __mosek_2fusion_2ExprParameter__slice(_3206,_3207); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_ExprParameter::__mosek_2fusion_2ExprParameter__slice(std::shared_ptr< monty::ndarray< int,1 > > _3206,std::shared_ptr< monty::ndarray< int,1 > > _3207){
  _checked_ptr_1<int> _ptr__3206(_3206 ? _3206->raw() : nullptr, _3206 ? _3206->size(0) : 0);
  _checked_ptr_1<int> _ptr__3207(_3207 ? _3207->raw() : nullptr, _3207 ? _3207->size(0) : 0);
  return (::mosek::fusion::p_ExprParameter::_new_ExprParameter(p->__mosek_2fusion_2Parameter__slice(_3206,_3207))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ExprParameter :: __mosek_2fusion_2ExprParameter__slice(int _3208,int _3209) { return mosek::fusion::p_ExprParameter::_get_impl(this)->__mosek_2fusion_2ExprParameter__slice(_3208,_3209); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ExprParameter::slice(int _3208,int _3209) { return __mosek_2fusion_2ExprParameter__slice(_3208,_3209); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ExprParameter::__mosek_2fusion_2BaseExpression__slice(int _3208,int _3209) { return __mosek_2fusion_2ExprParameter__slice(_3208,_3209); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_ExprParameter::__mosek_2fusion_2ExprParameter__slice(int _3208,int _3209){
  return (::mosek::fusion::p_ExprParameter::_new_ExprParameter(p->__mosek_2fusion_2Parameter__slice(_3208,_3209))).as<::mosek::fusion::Expression>();
}
std::string mosek::fusion::ExprParameter :: toString() { return mosek::fusion::p_ExprParameter::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprParameter::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprParameter("))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprParameter::destroy(){p.reset();}void mosek::fusion::ExprParameter::destroy() { mosek::fusion::p_ExprParameter::_get_impl(this)->destroy(); }mosek::fusion::Param::Param(mosek::fusion::p_Param *_impl) : _impl(_impl) { /*std::cout << "Param() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Param::~Param() { delete _impl; _impl = nullptr; }mosek::fusion::p_Param::p_Param  (::mosek::fusion::Param * _pubthis) :     _pubthis(_pubthis){}monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::repeat  ( monty::rc_ptr< ::mosek::fusion::Parameter > _3210,    int _3211,    int _3212) { return mosek::fusion::p_Param::repeat(_3210,_3211,_3212); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::repeat(monty::rc_ptr< ::mosek::fusion::Parameter > _3210,int _3211,int _3212){
  std::vector<monty::rc_ptr< ::mosek::fusion::Parameter >> _10181;
  for (int _3213 = (int)0, _10182 = _3211; _3213 < _10182 ; ++_3213)
  {
    _10181.push_back(_3210);
  }
  auto _10183 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >(monty::shape(_10181.size()),_10181.begin(),_10181.end()));
  return ::mosek::fusion::p_Param::stack(_3212,_10183);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::stack  ( int _3214,    monty::rc_ptr< ::mosek::fusion::Parameter > _3215,    monty::rc_ptr< ::mosek::fusion::Parameter > _3216,    monty::rc_ptr< ::mosek::fusion::Parameter > _3217) { return mosek::fusion::p_Param::stack(_3214,_3215,_3216,_3217); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::stack(int _3214,monty::rc_ptr< ::mosek::fusion::Parameter > _3215,monty::rc_ptr< ::mosek::fusion::Parameter > _3216,monty::rc_ptr< ::mosek::fusion::Parameter > _3217){
  return ::mosek::fusion::p_Param::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >{::monty::rc_ptr<::mosek::fusion::Parameter>(_3215.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3216.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3217.get())}),_3214);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::stack  ( int _3218,    monty::rc_ptr< ::mosek::fusion::Parameter > _3219,    monty::rc_ptr< ::mosek::fusion::Parameter > _3220) { return mosek::fusion::p_Param::stack(_3218,_3219,_3220); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::stack(int _3218,monty::rc_ptr< ::mosek::fusion::Parameter > _3219,monty::rc_ptr< ::mosek::fusion::Parameter > _3220){
  return ::mosek::fusion::p_Param::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >{::monty::rc_ptr<::mosek::fusion::Parameter>(_3219.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3220.get())}),_3218);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::stack  ( int _3221,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3222) { return mosek::fusion::p_Param::stack(_3221,_3222); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::stack(int _3221,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3222){
  return ::mosek::fusion::p_Param::dstack(_3222,_3221);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >,1 > > _3223) { return mosek::fusion::p_Param::stack(_3223); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >,1 > > _3223){
  std::vector<monty::rc_ptr< ::mosek::fusion::Parameter >> _10184;
  for (int _3224 = (int)0, _10185 = (int)((_3223)->size(0)); _3224 < _10185 ; ++_3224)
  {
    _10184.push_back(::mosek::fusion::p_Param::hstack(((*_3223)(_3224))));
  }
  auto _10186 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >(monty::shape(_10184.size()),_10184.begin(),_10184.end()));
  return ::mosek::fusion::p_Param::vstack(_10186);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::hstack  ( monty::rc_ptr< ::mosek::fusion::Parameter > _3225,    monty::rc_ptr< ::mosek::fusion::Parameter > _3226,    monty::rc_ptr< ::mosek::fusion::Parameter > _3227) { return mosek::fusion::p_Param::hstack(_3225,_3226,_3227); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::hstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3225,monty::rc_ptr< ::mosek::fusion::Parameter > _3226,monty::rc_ptr< ::mosek::fusion::Parameter > _3227){
  return ::mosek::fusion::p_Param::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >{::monty::rc_ptr<::mosek::fusion::Parameter>(_3225.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3226.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3227.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::hstack  ( monty::rc_ptr< ::mosek::fusion::Parameter > _3228,    monty::rc_ptr< ::mosek::fusion::Parameter > _3229) { return mosek::fusion::p_Param::hstack(_3228,_3229); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::hstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3228,monty::rc_ptr< ::mosek::fusion::Parameter > _3229){
  return ::mosek::fusion::p_Param::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >{::monty::rc_ptr<::mosek::fusion::Parameter>(_3228.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3229.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3230) { return mosek::fusion::p_Param::hstack(_3230); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3230){
  return ::mosek::fusion::p_Param::dstack(_3230,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::vstack  ( monty::rc_ptr< ::mosek::fusion::Parameter > _3231,    monty::rc_ptr< ::mosek::fusion::Parameter > _3232,    monty::rc_ptr< ::mosek::fusion::Parameter > _3233) { return mosek::fusion::p_Param::vstack(_3231,_3232,_3233); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::vstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3231,monty::rc_ptr< ::mosek::fusion::Parameter > _3232,monty::rc_ptr< ::mosek::fusion::Parameter > _3233){
  return ::mosek::fusion::p_Param::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >{::monty::rc_ptr<::mosek::fusion::Parameter>(_3231.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3232.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3233.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::vstack  ( monty::rc_ptr< ::mosek::fusion::Parameter > _3234,    monty::rc_ptr< ::mosek::fusion::Parameter > _3235) { return mosek::fusion::p_Param::vstack(_3234,_3235); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::vstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3234,monty::rc_ptr< ::mosek::fusion::Parameter > _3235){
  return ::mosek::fusion::p_Param::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 >{::monty::rc_ptr<::mosek::fusion::Parameter>(_3234.get()),::monty::rc_ptr<::mosek::fusion::Parameter>(_3235.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::Param::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3236) { return mosek::fusion::p_Param::vstack(_3236); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3236){
  return ::mosek::fusion::p_Param::dstack(_3236,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_Param::dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3237,int _3238){
  if ((_3238 < (int)0))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid stacking dimension"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _3239 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)((_3237)->size(0)))));
  _checked_ptr_1<int> _ptr__3239(_3239 ? _3239->raw() : nullptr,_3239 ? _3239->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3240 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_3237)->size(0)))));
  _checked_ptr_1<long long> _ptr__3240(_3240 ? _3240->raw() : nullptr,_3240 ? _3240->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3241;
  _checked_ptr_1<int> _ptr__3241(_3241 ? _3241->raw() : nullptr,_3241 ? _3241->size(0) : 0);
  int _3242 = ((*_3237)((int)0))->getND();
  int _10187 = (int)1;
  int _10188 = (int)((_3237)->size(0));
  for (int _3243 = _10187; _3243 < _10188; ++_3243)
  {
    {
      if ((_3242 < ((*_3237)(_3243))->getND()))
      {
        {
          _3242 = ((*_3237)(_3243))->getND();
        }
      }
      {}
    }
  }
  if ((_3238 < _3242))
  {
    {
      int _3244 = (int)0;
      while ( ((_3244 < (int)((_3237)->size(0))) && (_3242 != ((*_3237)(_3244))->getND())) )
      {
        {
          ++ _3244;
        }
      }
      _3241 = ((*_3237)(_3244))->getShape();
      _ptr__3241.update(_3241 ? _3241->raw() : nullptr, _3241 ? _3241->size(0) : 0);
      {
        int _3245 = (int)0;
        while ( ((_3245 < (int)((_3237)->size(0))) && (_3242 != ((*_3237)(_3245))->getND())) )
        {
          {
            ++ _3245;
          }
        }
        _3241 = ((*_3237)(_3245))->getShape();
        _ptr__3241.update(_3241 ? _3241->raw() : nullptr, _3241 ? _3241->size(0) : 0);
      }
    }
  }
  else
  {
    {
      std::vector<int> _10189;
      for (int _3246 = (int)0, _10190 = safe_add( _3238,(int)1 ); _3246 < _10190 ; ++_3246)
      {
        _10189.push_back((int)1);
      }
      auto _10191 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10189.size()),_10189.begin(),_10189.end()));
      _3241 = _10191;
      _ptr__3241.update(_3241 ? _3241->raw() : nullptr, _3241 ? _3241->size(0) : 0);
      {
        int _3247 = (int)0;
        while ( ((_3247 < (int)((_3237)->size(0))) && (_3242 != ((*_3237)(_3247))->getND())) )
        {
          {
            ++ _3247;
          }
        }
        int _3248 = ((*_3237)(_3247))->getND();
        std::shared_ptr< monty::ndarray< int,1 > > _3249 = ((*_3237)(_3247))->getShape();
        _checked_ptr_1<int> _ptr__3249(_3249 ? _3249->raw() : nullptr,_3249 ? _3249->size(0) : 0);
        int _10192 = (int)0;
        int _10193 = _3248;
        for (int _3250 = _10192; _3250 < _10193; ++_3250)
        {
          {
            _ptr__3241[_3250] = _ptr__3249[_3250];
          }
        }
      }
    }
  }
  _3242 = (int)((_3241)->size(0));
  int _3251 = (int)0;
  {
    bool _3252 = false;
    int _10194 = (int)0;
    int _10195 = (int)((_3237)->size(0));
    for (int _3253 = _10194; _3253 < _10195; ++_3253)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _3254 = ((*_3237)(_3253))->getShape();
        _checked_ptr_1<int> _ptr__3254(_3254 ? _3254->raw() : nullptr,_3254 ? _3254->size(0) : 0);
        _ptr__3240[_3253] = ::mosek::fusion::p_Set::size(_3254);
        int _10196 = (int)0;
        int _10197 = (int)((_3254)->size(0));
        for (int _3255 = _10196; _3255 < _10197; ++_3255)
        {
          {
            _3252 = (_3252 && ((_3255 == _3238) || (_ptr__3254[_3255] == _ptr__3241[_3255])));
          }
        }
        if ((_3238 < (int)((_3254)->size(0))))
        {
          {
            _ptr__3239[_3253] = _ptr__3254[_3238];
            _3251 += _ptr__3254[_3238];
            int _10198 = (int)((_3254)->size(0));
            int _10199 = _3242;
            for (int _3256 = _10198; _3256 < _10199; ++_3256)
            {
              {
                _3252 = (_3252 && ((_3256 == _3238) || (_ptr__3241[_3256] == (int)1)));
              }
            }
          }
        }
        else
        {
          {
            _3251 += (int)1;
            _ptr__3239[_3253] = (int)1;
          }
        }
      }
    }
    if (_3252)
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for stacking"));
      }
    }
    {}
  }
  _ptr__3241[_3238] = _3251;
  std::vector<int> _10200;
  for (int _3258 = (int)0, _10201 = (int)((_3237)->size(0)); _3258 < _10201 ; ++_3258)
  {
    _10200.push_back(((*_3237)(_3258))->getNumNonzero());
  }
  auto _10202 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10200.size()),_10200.begin(),_10200.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _3257 = _10202;
  _checked_ptr_1<int> _ptr__3257(_3257 ? _3257->raw() : nullptr,_3257 ? _3257->size(0) : 0);
  int _3259 = (int)0;
  int _10203 = (int)0;
  int _10204 = (int)((_3257)->size(0));
  for (int _3260 = _10203; _3260 < _10204; ++_3260)
  {
    {
      _3259 += _ptr__3257[_3260];
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _3261 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3259)));
  _checked_ptr_1<long long> _ptr__3261(_3261 ? _3261->raw() : nullptr,_3261 ? _3261->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3262 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3259)));
  _checked_ptr_1<int> _ptr__3262(_3262 ? _3262->raw() : nullptr,_3262 ? _3262->size(0) : 0);
  long long _3263 = (int)1;
  int _10205 = (int)0;
  int _10206 = _3238;
  for (int _3264 = _10205; _3264 < _10206; ++_3264)
  {
    {
      _3263 *= _ptr__3241[_3264];
    }
  }
  long long _3265 = _3251;
  long long _3266 = (int)1;
  int _10207 = safe_add( _3238,(int)1 );
  int _10208 = _3242;
  for (int _3267 = _10207; _3267 < _10208; ++_3267)
  {
    {
      _3266 *= _ptr__3241[_3267];
    }
  }
  {
    int _3268 = (int)0;
    long long _3269 = (int)0;
    int _10209 = (int)0;
    int _10210 = (int)((_3237)->size(0));
    for (int _3270 = _10209; _3270 < _10210; ++_3270)
    {
      {
        int _3271 = ((*_3237)(_3270))->getNumNonzero();
        ((*_3237)(_3270))->getSp(_3261,_3268);
        ((*_3237)(_3270))->getAllIndexes(_3262,_3268);
        if ((_3238 == (int)0))
        {
          {
            int _10211 = _3268;
            int _10212 = safe_add( _3268,_3271 );
            for (int _3272 = _10211; _3272 < _10212; ++_3272)
            {
              {
                _ptr__3261[_3272] += _3269;
              }
            }
            _3269 += _ptr__3240[_3270];
          }
        }
        else
        {
          {
            int _10213 = _3268;
            int _10214 = safe_add( _3268,_3271 );
            for (int _3273 = _10213; _3273 < _10214; ++_3273)
            {
              {
                long long _3274 = (_ptr__3261[_3273] / safe_mul( _ptr__3239[_3270],_3266 ));
                long long _3275 = ((_ptr__3261[_3273] / _3266) % _ptr__3239[_3270]);
                long long _3276 = (_ptr__3261[_3273] % _3266);
                _ptr__3261[_3273] = safe_add( safe_add( safe_mul( _3274,safe_mul( _3251,_3266 ) ),safe_mul( safe_add( _3275,_3269 ),_3266 ) ),_3276 );
              }
            }
            _3269 += _ptr__3239[_3270];
          }
        }
        _3268 += _3271;
      }
    }
  }
  int _3277 = _ptr__3241[(int)0];
  int _10215 = (int)1;
  int _10216 = _3242;
  for (int _3278 = _10215; _3278 < _10216; ++_3278)
  {
    {
      if ((_3277 < _ptr__3241[_3278]))
      {
        {
          _3277 = _ptr__3241[_3278];
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _3279 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _3277,(int)1 ))));
  _checked_ptr_1<int> _ptr__3279(_3279 ? _3279->raw() : nullptr,_3279 ? _3279->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3280 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3259)));
  _checked_ptr_1<int> _ptr__3280(_3280 ? _3280->raw() : nullptr,_3280 ? _3280->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3281 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_3259)));
  _checked_ptr_1<int> _ptr__3281(_3281 ? _3281->raw() : nullptr,_3281 ? _3281->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3282 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_3242)));
  _checked_ptr_1<long long> _ptr__3282(_3282 ? _3282->raw() : nullptr,_3282 ? _3282->size(0) : 0);
  _ptr__3282[(_3242 - (int)1)] = (int)1;
  int _10217 = (int)1;
  int _10218 = _3242;
  for (int _3283 = _10217; _3283 < _10218; ++_3283)
  {
    {
      _ptr__3282[((_3242 - _3283) - (int)1)] = safe_mul( _ptr__3282[(_3242 - _3283)],_ptr__3241[(_3242 - _3283)] );
    }
  }
  int _10219 = (int)0;
  int _10220 = _3259;
  for (int _3284 = _10219; _3284 < _10220; ++_3284)
  {
    {
      _ptr__3280[_3284] = _3284;
    }
  }
  int _10221 = (int)0;
  int _10222 = _3242;
  for (int _3285 = _10221; _3285 < _10222; ++_3285)
  {
    {
      int _3286 = ((_3242 - _3285) - (int)1);
      int _10223 = (int)0;
      int _10224 = safe_add( _3277,(int)1 );
      for (int _3287 = _10223; _3287 < _10224; ++_3287)
      {
        {
          _ptr__3279[_3287] = (int)0;
        }
      }
      int _10225 = (int)0;
      int _10226 = _3259;
      for (int _3288 = _10225; _3288 < _10226; ++_3288)
      {
        {
          ++ _ptr__3279[safe_add( (int)1,((_ptr__3261[_3288] / _ptr__3282[_3286]) % _ptr__3241[_3286]) )];
        }
      }
      int _10227 = (int)0;
      int _10228 = _3277;
      for (int _3289 = _10227; _3289 < _10228; ++_3289)
      {
        {
          _ptr__3279[safe_add( _3289,(int)1 )] += _ptr__3279[_3289];
        }
      }
      int _10229 = (int)0;
      int _10230 = _3259;
      for (int _3290 = _10229; _3290 < _10230; ++_3290)
      {
        {
          long long _3291 = ((_ptr__3261[_ptr__3280[_3290]] / _ptr__3282[_3286]) % _ptr__3241[_3286]);
          _ptr__3281[_ptr__3279[_3291]] = _ptr__3280[_3290];
          ++ _ptr__3279[_3291];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _3292 = _3281;
      _checked_ptr_1<int> _ptr__3292(_3292 ? _3292->raw() : nullptr,_3292 ? _3292->size(0) : 0);
      _3281 = _3280;
      _ptr__3281.update(_3281 ? _3281->raw() : nullptr, _3281 ? _3281->size(0) : 0);
      _3280 = _3292;
      _ptr__3280.update(_3280 ? _3280->raw() : nullptr, _3280 ? _3280->size(0) : 0);
    }
  }
  std::vector<long long> _10231;
  for (int _3294 = (int)0, _10232 = _3259; _3294 < _10232 ; ++_3294)
  {
    _10231.push_back(_ptr__3261[_ptr__3280[_3294]]);
  }
  auto _10233 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_10231.size()),_10231.begin(),_10231.end()));
  std::shared_ptr< monty::ndarray< long long,1 > > _3293 = _10233;
  _checked_ptr_1<long long> _ptr__3293(_3293 ? _3293->raw() : nullptr,_3293 ? _3293->size(0) : 0);
  std::vector<int> _10234;
  for (int _3296 = (int)0, _10235 = _3259; _3296 < _10235 ; ++_3296)
  {
    _10234.push_back(_ptr__3262[_ptr__3280[_3296]]);
  }
  auto _10236 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10234.size()),_10234.begin(),_10234.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _3295 = _10236;
  _checked_ptr_1<int> _ptr__3295(_3295 ? _3295->raw() : nullptr,_3295 ? _3295->size(0) : 0);
  return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(((*_3237)((int)0))->__mosek_2fusion_2Parameter__getModel(),_3241,_3293,_3295)).as<::mosek::fusion::Parameter>();
}
void mosek::fusion::p_Param::destroy(){}void mosek::fusion::Param::destroy() { mosek::fusion::p_Param::_get_impl(this)->destroy(); }mosek::fusion::ExprMulParamScalarExpr::ExprMulParamScalarExpr(mosek::fusion::p_ExprMulParamScalarExpr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulParamScalarExpr()" << this << std::endl; */ }mosek::fusion::ExprMulParamScalarExpr::~ExprMulParamScalarExpr() {  /* std::cout << "~ExprMulParamScalarExpr()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulParamScalarExpr::p_ExprMulParamScalarExpr  (::mosek::fusion::ExprMulParamScalarExpr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulParamScalarExpr::t mosek::fusion::p_ExprMulParamScalarExpr::_new_ExprMulParamScalarExpr  (monty::rc_ptr< ::mosek::fusion::Parameter > _3297,    monty::rc_ptr< ::mosek::fusion::Expression > _3298){ return new mosek::fusion::ExprMulParamScalarExpr(_3297,_3298); }mosek::fusion::ExprMulParamScalarExpr::ExprMulParamScalarExpr  (monty::rc_ptr< ::mosek::fusion::Parameter > _3297,    monty::rc_ptr< ::mosek::fusion::Expression > _3298) :    ExprMulParamScalarExpr(new mosek::fusion::p_ExprMulParamScalarExpr(this)){ mosek::fusion::p_ExprMulParamScalarExpr::_get_impl(this)->_initialize(_3297,_3298); }void mosek::fusion::p_ExprMulParamScalarExpr::_initialize  (monty::rc_ptr< ::mosek::fusion::Parameter > _3297,    monty::rc_ptr< ::mosek::fusion::Expression > _3298){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3297->getShape());
    mosek::fusion::p_ExprMulParamScalarExpr::_get_impl(::mosek::fusion::ExprMulParamScalarExpr::t(_pubthis))->p = _3297;
    mosek::fusion::p_ExprMulParamScalarExpr::_get_impl(::mosek::fusion::ExprMulParamScalarExpr::t(_pubthis))->e = _3298;
    if ((_3298->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
  }
}void mosek::fusion::ExprMulParamScalarExpr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3299,monty::rc_ptr< ::mosek::fusion::WorkStack > _3300,monty::rc_ptr< ::mosek::fusion::WorkStack > _3301) { mosek::fusion::p_ExprMulParamScalarExpr::_get_impl(this)->eval(_3299,_3300,_3301); }void mosek::fusion::p_ExprMulParamScalarExpr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3299,monty::rc_ptr< ::mosek::fusion::WorkStack > _3300,monty::rc_ptr< ::mosek::fusion::WorkStack > _3301){
  e->eval(_3300,_3299,_3301);
  _3300->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3302 = mosek::fusion::p_WorkStack::_get_impl(_3300)->i32;
  _checked_ptr_1<int> _ptr__3302(_3302 ? _3302->raw() : nullptr,_3302 ? _3302->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3303 = mosek::fusion::p_WorkStack::_get_impl(_3300)->i64;
  _checked_ptr_1<long long> _ptr__3303(_3303 ? _3303->raw() : nullptr,_3303 ? _3303->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3304 = mosek::fusion::p_WorkStack::_get_impl(_3300)->f64;
  _checked_ptr_1<double> _ptr__3304(_3304 ? _3304->raw() : nullptr,_3304 ? _3304->size(0) : 0);
  int _3305 = mosek::fusion::p_WorkStack::_get_impl(_3300)->nd;
  if ((_3305 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _3306 = mosek::fusion::p_WorkStack::_get_impl(_3300)->nelem;
  int _3307 = mosek::fusion::p_WorkStack::_get_impl(_3300)->nnz;
  bool _3308 = mosek::fusion::p_WorkStack::_get_impl(_3300)->hassp;
  int _3309 = mosek::fusion::p_WorkStack::_get_impl(_3300)->ptr_base;
  int _3310 = mosek::fusion::p_WorkStack::_get_impl(_3300)->ncodeatom;
  int _3311 = mosek::fusion::p_WorkStack::_get_impl(_3300)->sp_base;
  int _3312 = mosek::fusion::p_WorkStack::_get_impl(_3300)->nidxs_base;
  int _3313 = mosek::fusion::p_WorkStack::_get_impl(_3300)->cof_base;
  int _3314 = mosek::fusion::p_WorkStack::_get_impl(_3300)->cconst_base;
  int _3315 = mosek::fusion::p_WorkStack::_get_impl(_3300)->codeptr_base;
  int _3316 = mosek::fusion::p_WorkStack::_get_impl(_3300)->code_base;
  int _3317 = p->getND();
  int _3318 = p->getNumNonzero();
  int _3319 = safe_mul( _3307,p->getNumNonzero() );
  bool _3320 = (p->getNumNonzero() < p->getSize());
  int _10237;
  bool _10238 = (_3310 > (int)0);
  if (_10238)
  {
    _10237 = safe_add( _3310,safe_mul( _3319,(int)4 ) );
  }
  else
  {
    _10237 = safe_mul( _3319,(int)3 );
  }
  int _3321 = _10237;
  int _3322 = _3301->alloci32(p->getNumNonzero());
  std::shared_ptr< monty::ndarray< int,1 > > _3323 = mosek::fusion::p_WorkStack::_get_impl(_3301)->i32;
  _checked_ptr_1<int> _ptr__3323(_3323 ? _3323->raw() : nullptr,_3323 ? _3323->size(0) : 0);
  p->getAllIndexes(_3323,_3322);
  _3299->alloc_expr(_3317,_3318,_3319,_3320,_3321);
  std::shared_ptr< monty::ndarray< long long,1 > > _3324 = mosek::fusion::p_WorkStack::_get_impl(_3299)->i64;
  _checked_ptr_1<long long> _ptr__3324(_3324 ? _3324->raw() : nullptr,_3324 ? _3324->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3325 = mosek::fusion::p_WorkStack::_get_impl(_3299)->f64;
  _checked_ptr_1<double> _ptr__3325(_3325 ? _3325->raw() : nullptr,_3325 ? _3325->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3326 = mosek::fusion::p_WorkStack::_get_impl(_3299)->i32;
  _checked_ptr_1<int> _ptr__3326(_3326 ? _3326->raw() : nullptr,_3326 ? _3326->size(0) : 0);
  int _3327 = mosek::fusion::p_WorkStack::_get_impl(_3299)->ptr_base;
  int _3328 = mosek::fusion::p_WorkStack::_get_impl(_3299)->nidxs_base;
  int _3329 = mosek::fusion::p_WorkStack::_get_impl(_3299)->sp_base;
  int _3330 = mosek::fusion::p_WorkStack::_get_impl(_3299)->cof_base;
  bool _3331 = mosek::fusion::p_WorkStack::_get_impl(_3299)->hassp;
  int _3332 = mosek::fusion::p_WorkStack::_get_impl(_3299)->shape_base;
  int _3333 = mosek::fusion::p_WorkStack::_get_impl(_3299)->codeptr_base;
  int _3334 = mosek::fusion::p_WorkStack::_get_impl(_3299)->code_base;
  int _3335 = mosek::fusion::p_WorkStack::_get_impl(_3299)->cconst_base;
  {
    int _10239 = (int)0;
    int _10240 = _3319;
    for (int _3336 = _10239; _3336 < _10240; ++_3336)
    {
      {
        _ptr__3325[safe_add( _3330,_3336 )] = 0.0;
      }
    }
    int _10241 = (int)0;
    int _10242 = safe_add( _3318,(int)1 );
    for (int _3337 = _10241; _3337 < _10242; ++_3337)
    {
      {
        _ptr__3326[safe_add( _3327,_3337 )] = safe_mul( _3337,_3307 );
      }
    }
    int _10243 = (int)0;
    int _10244 = _3317;
    for (int _3338 = _10243; _3338 < _10244; ++_3338)
    {
      {
        _ptr__3326[safe_add( _3332,_3338 )] = p->getDim(_3338);
      }
    }
    if (_3331)
    {
      {
        p->getSp(_3324,_3329);
      }
    }
    {}
    int _10245 = (int)0;
    int _10246 = _3319;
    for (int _3339 = _10245; _3339 < _10246; ++_3339)
    {
      {
        _ptr__3324[safe_add( _3328,_3339 )] = (-(int)999);
      }
    }
    {
      int _3340 = (int)0;
      int _10247 = (int)0;
      int _10248 = _3318;
      for (int _3341 = _10247; _3341 < _10248; ++_3341)
      {
        {
          int _10249 = (int)0;
          int _10250 = _3307;
          for (int _3342 = _10249; _3342 < _10250; ++_3342)
          {
            {
              _ptr__3324[safe_add( _3328,_3340 )] = _ptr__3303[safe_add( _3312,_3342 )];
              ++ _3340;
            }
          }
        }
      }
    }
    _ptr__3326[_3333] = (int)0;
    {
      if ((_3310 == (int)0))
      {
        {
          int _3343 = (int)0;
          int _3344 = (int)0;
          int _10251 = (int)0;
          int _10252 = _3318;
          for (int _3345 = _10251; _3345 < _10252; ++_3345)
          {
            {
              int _10253 = (int)0;
              int _10254 = _3307;
              for (int _3346 = _10253; _3346 < _10254; ++_3346)
              {
                {
                  _ptr__3326[safe_add( _3334,_3344 )] = 2;
                  _ptr__3325[safe_add( _3335,_3344 )] = _ptr__3304[safe_add( _3313,_3346 )];
                  ++ _3344;
                  _ptr__3326[safe_add( _3334,_3344 )] = 1;
                  _ptr__3325[safe_add( _3335,_3344 )] = _ptr__3323[safe_add( _3322,_3345 )];
                  ++ _3344;
                  _ptr__3326[safe_add( _3334,_3344 )] = 5;
                  ++ _3344;
                  _ptr__3326[safe_add( safe_add( _3333,_3343 ),(int)1 )] = _3344;
                  ++ _3343;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _3347 = (int)0;
          int _3348 = (int)0;
          int _10255 = (int)0;
          int _10256 = _3318;
          for (int _3349 = _10255; _3349 < _10256; ++_3349)
          {
            {
              int _10257 = (int)0;
              int _10258 = _3307;
              for (int _3350 = _10257; _3350 < _10258; ++_3350)
              {
                {
                  _ptr__3326[safe_add( _3334,_3347 )] = 2;
                  _ptr__3325[safe_add( _3335,_3347 )] = _ptr__3304[safe_add( _3313,_3350 )];
                  ++ _3347;
                  int _10259 = _ptr__3302[safe_add( _3315,_3350 )];
                  int _10260 = _ptr__3302[safe_add( safe_add( _3315,_3350 ),(int)1 )];
                  for (int _3351 = _10259; _3351 < _10260; ++_3351)
                  {
                    {
                      _ptr__3326[safe_add( _3334,_3347 )] = _ptr__3302[safe_add( _3316,_3351 )];
                      _ptr__3325[safe_add( _3335,_3347 )] = _ptr__3304[safe_add( _3314,_3351 )];
                      ++ _3347;
                    }
                  }
                  _ptr__3326[safe_add( _3334,_3347 )] = 3;
                  ++ _3347;
                  _ptr__3326[safe_add( _3334,_3347 )] = 1;
                  _ptr__3325[safe_add( _3335,_3347 )] = _ptr__3323[safe_add( _3322,_3349 )];
                  ++ _3347;
                  _ptr__3326[safe_add( _3334,_3347 )] = 5;
                  ++ _3347;
                  _ptr__3326[safe_add( safe_add( _3333,_3348 ),(int)1 )] = _3347;
                  ++ _3348;
                }
              }
            }
          }
        }
      }
    }
  }
  _3301->clear();
}
std::string mosek::fusion::ExprMulParamScalarExpr :: toString() { return mosek::fusion::p_ExprMulParamScalarExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulParamScalarExpr::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulParamScalarExpr("))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulParamScalarExpr::destroy(){e.reset();p.reset();}void mosek::fusion::ExprMulParamScalarExpr::destroy() { mosek::fusion::p_ExprMulParamScalarExpr::_get_impl(this)->destroy(); }mosek::fusion::ExprMulParamScalar::ExprMulParamScalar(mosek::fusion::p_ExprMulParamScalar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulParamScalar()" << this << std::endl; */ }mosek::fusion::ExprMulParamScalar::~ExprMulParamScalar() {  /* std::cout << "~ExprMulParamScalar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulParamScalar::p_ExprMulParamScalar  (::mosek::fusion::ExprMulParamScalar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulParamScalar::t mosek::fusion::p_ExprMulParamScalar::_new_ExprMulParamScalar  (monty::rc_ptr< ::mosek::fusion::Parameter > _3352,    monty::rc_ptr< ::mosek::fusion::Expression > _3353){ return new mosek::fusion::ExprMulParamScalar(_3352,_3353); }mosek::fusion::ExprMulParamScalar::ExprMulParamScalar  (monty::rc_ptr< ::mosek::fusion::Parameter > _3352,    monty::rc_ptr< ::mosek::fusion::Expression > _3353) :    ExprMulParamScalar(new mosek::fusion::p_ExprMulParamScalar(this)){ mosek::fusion::p_ExprMulParamScalar::_get_impl(this)->_initialize(_3352,_3353); }void mosek::fusion::p_ExprMulParamScalar::_initialize  (monty::rc_ptr< ::mosek::fusion::Parameter > _3352,    monty::rc_ptr< ::mosek::fusion::Expression > _3353){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3353->getShape());
    mosek::fusion::p_ExprMulParamScalar::_get_impl(::mosek::fusion::ExprMulParamScalar::t(_pubthis))->p = _3352;
    mosek::fusion::p_ExprMulParamScalar::_get_impl(::mosek::fusion::ExprMulParamScalar::t(_pubthis))->e = _3353;
    if ((_3352->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
  }
}void mosek::fusion::ExprMulParamScalar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3354,monty::rc_ptr< ::mosek::fusion::WorkStack > _3355,monty::rc_ptr< ::mosek::fusion::WorkStack > _3356) { mosek::fusion::p_ExprMulParamScalar::_get_impl(this)->eval(_3354,_3355,_3356); }void mosek::fusion::p_ExprMulParamScalar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3354,monty::rc_ptr< ::mosek::fusion::WorkStack > _3355,monty::rc_ptr< ::mosek::fusion::WorkStack > _3356){
  e->eval(_3355,_3354,_3356);
  _3355->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3357 = mosek::fusion::p_WorkStack::_get_impl(_3355)->i32;
  _checked_ptr_1<int> _ptr__3357(_3357 ? _3357->raw() : nullptr,_3357 ? _3357->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3358 = mosek::fusion::p_WorkStack::_get_impl(_3355)->i64;
  _checked_ptr_1<long long> _ptr__3358(_3358 ? _3358->raw() : nullptr,_3358 ? _3358->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3359 = mosek::fusion::p_WorkStack::_get_impl(_3355)->f64;
  _checked_ptr_1<double> _ptr__3359(_3359 ? _3359->raw() : nullptr,_3359 ? _3359->size(0) : 0);
  int _3360 = mosek::fusion::p_WorkStack::_get_impl(_3355)->nd;
  int _3361 = mosek::fusion::p_WorkStack::_get_impl(_3355)->nelem;
  int _3362 = mosek::fusion::p_WorkStack::_get_impl(_3355)->nnz;
  bool _3363 = mosek::fusion::p_WorkStack::_get_impl(_3355)->hassp;
  int _3364 = mosek::fusion::p_WorkStack::_get_impl(_3355)->ptr_base;
  int _3365 = mosek::fusion::p_WorkStack::_get_impl(_3355)->ncodeatom;
  int _3366 = mosek::fusion::p_WorkStack::_get_impl(_3355)->shape_base;
  int _3367 = mosek::fusion::p_WorkStack::_get_impl(_3355)->sp_base;
  int _3368 = mosek::fusion::p_WorkStack::_get_impl(_3355)->nidxs_base;
  int _3369 = mosek::fusion::p_WorkStack::_get_impl(_3355)->cof_base;
  int _3370 = mosek::fusion::p_WorkStack::_get_impl(_3355)->cconst_base;
  int _3371 = mosek::fusion::p_WorkStack::_get_impl(_3355)->codeptr_base;
  int _3372 = mosek::fusion::p_WorkStack::_get_impl(_3355)->code_base;
  int _3373 = _3360;
  int _3374 = _3361;
  int _3375 = _3362;
  bool _3376 = (p->getNumNonzero() < p->getSize());
  int _10261;
  bool _10262 = (_3365 == (int)0);
  if (_10262)
  {
    _10261 = safe_mul( _3362,(int)3 );
  }
  else
  {
    _10261 = safe_add( safe_mul( _3362,(int)4 ),_3365 );
  }
  int _3377 = _10261;
  _3354->alloc_expr(_3373,_3374,_3375,_3376,_3377);
  std::shared_ptr< monty::ndarray< long long,1 > > _3378 = mosek::fusion::p_WorkStack::_get_impl(_3354)->i64;
  _checked_ptr_1<long long> _ptr__3378(_3378 ? _3378->raw() : nullptr,_3378 ? _3378->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3379 = mosek::fusion::p_WorkStack::_get_impl(_3354)->f64;
  _checked_ptr_1<double> _ptr__3379(_3379 ? _3379->raw() : nullptr,_3379 ? _3379->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3380 = mosek::fusion::p_WorkStack::_get_impl(_3354)->i32;
  _checked_ptr_1<int> _ptr__3380(_3380 ? _3380->raw() : nullptr,_3380 ? _3380->size(0) : 0);
  int _3381 = mosek::fusion::p_WorkStack::_get_impl(_3354)->ptr_base;
  int _3382 = mosek::fusion::p_WorkStack::_get_impl(_3354)->nidxs_base;
  int _3383 = mosek::fusion::p_WorkStack::_get_impl(_3354)->sp_base;
  int _3384 = mosek::fusion::p_WorkStack::_get_impl(_3354)->cof_base;
  bool _3385 = mosek::fusion::p_WorkStack::_get_impl(_3354)->hassp;
  int _3386 = mosek::fusion::p_WorkStack::_get_impl(_3354)->shape_base;
  int _3387 = mosek::fusion::p_WorkStack::_get_impl(_3354)->codeptr_base;
  int _3388 = mosek::fusion::p_WorkStack::_get_impl(_3354)->code_base;
  int _3389 = mosek::fusion::p_WorkStack::_get_impl(_3354)->cconst_base;
  int _3390 = p->getIndex((int)0);
  {
    int _10263 = (int)0;
    int _10264 = _3375;
    for (int _3391 = _10263; _3391 < _10264; ++_3391)
    {
      {
        _ptr__3379[safe_add( _3384,_3391 )] = 0.0;
      }
    }
    int _10265 = (int)0;
    int _10266 = safe_add( _3374,(int)1 );
    for (int _3392 = _10265; _3392 < _10266; ++_3392)
    {
      {
        _ptr__3380[safe_add( _3381,_3392 )] = _ptr__3357[safe_add( _3364,_3392 )];
      }
    }
    int _10267 = (int)0;
    int _10268 = _3373;
    for (int _3393 = _10267; _3393 < _10268; ++_3393)
    {
      {
        _ptr__3380[safe_add( _3386,_3393 )] = _ptr__3357[safe_add( _3366,_3393 )];
      }
    }
    int _10269 = (int)0;
    int _10270 = _3362;
    for (int _3394 = _10269; _3394 < _10270; ++_3394)
    {
      {
        _ptr__3378[safe_add( _3382,_3394 )] = _ptr__3358[safe_add( _3368,_3394 )];
      }
    }
    if (_3385)
    {
      {
        int _10271 = (int)0;
        int _10272 = _3374;
        for (int _3395 = _10271; _3395 < _10272; ++_3395)
        {
          {
            _ptr__3378[safe_add( _3383,_3395 )] = _ptr__3358[safe_add( _3367,_3395 )];
          }
        }
      }
    }
    {}
    int _3396 = (int)0;
    _ptr__3380[_3387] = (int)0;
    int _10273 = (int)0;
    int _10274 = _3362;
    for (int _3397 = _10273; _3397 < _10274; ++_3397)
    {
      {
        _ptr__3380[safe_add( _3388,_3396 )] = 2;
        _ptr__3379[safe_add( _3389,_3396 )] = _ptr__3359[safe_add( _3369,_3397 )];
        ++ _3396;
        if ((_3365 > (int)0))
        {
          {
            int _10275 = _ptr__3357[safe_add( _3371,_3397 )];
            int _10276 = _ptr__3357[safe_add( safe_add( _3371,_3397 ),(int)1 )];
            for (int _3398 = _10275; _3398 < _10276; ++_3398)
            {
              {
                _ptr__3380[safe_add( _3388,_3396 )] = _ptr__3357[safe_add( _3372,_3398 )];
                ++ _3396;
              }
            }
            _ptr__3380[safe_add( _3388,_3396 )] = 3;
            ++ _3396;
          }
        }
        {}
        _ptr__3380[safe_add( _3388,_3396 )] = 1;
        _ptr__3379[safe_add( _3389,_3396 )] = _3390;
        ++ _3396;
        _ptr__3380[safe_add( _3388,_3396 )] = 5;
        ++ _3396;
        _ptr__3380[safe_add( safe_add( _3387,_3397 ),(int)1 )] = _3396;
      }
    }
  }
  _3356->clear();
}
std::string mosek::fusion::ExprMulParamScalar :: toString() { return mosek::fusion::p_ExprMulParamScalar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulParamScalar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulParamScalar("))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulParamScalar::destroy(){e.reset();p.reset();}void mosek::fusion::ExprMulParamScalar::destroy() { mosek::fusion::p_ExprMulParamScalar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulParamDiagLeft::ExprMulParamDiagLeft(mosek::fusion::p_ExprMulParamDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulParamDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulParamDiagLeft::~ExprMulParamDiagLeft() {  /* std::cout << "~ExprMulParamDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulParamDiagLeft::p_ExprMulParamDiagLeft  (::mosek::fusion::ExprMulParamDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulParamDiagLeft::t mosek::fusion::p_ExprMulParamDiagLeft::_new_ExprMulParamDiagLeft  (monty::rc_ptr< ::mosek::fusion::Parameter > _3399,    monty::rc_ptr< ::mosek::fusion::Expression > _3400){ return new mosek::fusion::ExprMulParamDiagLeft(_3399,_3400); }mosek::fusion::ExprMulParamDiagLeft::ExprMulParamDiagLeft  (monty::rc_ptr< ::mosek::fusion::Parameter > _3399,    monty::rc_ptr< ::mosek::fusion::Expression > _3400) :    ExprMulParamDiagLeft(new mosek::fusion::p_ExprMulParamDiagLeft(this)){ mosek::fusion::p_ExprMulParamDiagLeft::_get_impl(this)->_initialize(_3399,_3400); }void mosek::fusion::p_ExprMulParamDiagLeft::_initialize  (monty::rc_ptr< ::mosek::fusion::Parameter > _3399,    monty::rc_ptr< ::mosek::fusion::Expression > _3400){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3400->getDim((int)0))}));
    mosek::fusion::p_ExprMulParamDiagLeft::_get_impl(::mosek::fusion::ExprMulParamDiagLeft::t(_pubthis))->p = _3399;
    mosek::fusion::p_ExprMulParamDiagLeft::_get_impl(::mosek::fusion::ExprMulParamDiagLeft::t(_pubthis))->e = _3400;
    if (((_3399->getND() != (int)2) || (_3400->getND() != (int)2)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
    if (((_3399->getDim((int)1) != _3400->getDim((int)0)) || (_3399->getDim((int)0) != _3400->getDim((int)1))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
  }
}void mosek::fusion::ExprMulParamDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3401,monty::rc_ptr< ::mosek::fusion::WorkStack > _3402,monty::rc_ptr< ::mosek::fusion::WorkStack > _3403) { mosek::fusion::p_ExprMulParamDiagLeft::_get_impl(this)->eval(_3401,_3402,_3403); }void mosek::fusion::p_ExprMulParamDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3401,monty::rc_ptr< ::mosek::fusion::WorkStack > _3402,monty::rc_ptr< ::mosek::fusion::WorkStack > _3403){
  e->eval(_3402,_3401,_3403);
  _3402->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3404 = mosek::fusion::p_WorkStack::_get_impl(_3402)->i32;
  _checked_ptr_1<int> _ptr__3404(_3404 ? _3404->raw() : nullptr,_3404 ? _3404->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3405 = mosek::fusion::p_WorkStack::_get_impl(_3402)->i64;
  _checked_ptr_1<long long> _ptr__3405(_3405 ? _3405->raw() : nullptr,_3405 ? _3405->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3406 = mosek::fusion::p_WorkStack::_get_impl(_3402)->f64;
  _checked_ptr_1<double> _ptr__3406(_3406 ? _3406->raw() : nullptr,_3406 ? _3406->size(0) : 0);
  int _3407 = mosek::fusion::p_WorkStack::_get_impl(_3402)->nd;
  int _3408 = mosek::fusion::p_WorkStack::_get_impl(_3402)->nelem;
  int _3409 = mosek::fusion::p_WorkStack::_get_impl(_3402)->nnz;
  bool _3410 = mosek::fusion::p_WorkStack::_get_impl(_3402)->hassp;
  int _3411 = mosek::fusion::p_WorkStack::_get_impl(_3402)->ptr_base;
  int _3412 = mosek::fusion::p_WorkStack::_get_impl(_3402)->ncodeatom;
  int _3413 = mosek::fusion::p_WorkStack::_get_impl(_3402)->shape_base;
  int _3414 = mosek::fusion::p_WorkStack::_get_impl(_3402)->sp_base;
  int _3415 = mosek::fusion::p_WorkStack::_get_impl(_3402)->nidxs_base;
  int _3416 = mosek::fusion::p_WorkStack::_get_impl(_3402)->cof_base;
  int _3417 = mosek::fusion::p_WorkStack::_get_impl(_3402)->cconst_base;
  int _3418 = mosek::fusion::p_WorkStack::_get_impl(_3402)->codeptr_base;
  int _3419 = mosek::fusion::p_WorkStack::_get_impl(_3402)->code_base;
  if (((_3407 != (int)2) || ((_ptr__3404[_3413] != p->getDim((int)1)) || (_ptr__3404[safe_add( _3413,(int)1 )] != p->getDim((int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
    }
  }
  {}
  int _3420 = p->getNumNonzero();
  int _3421 = _3403->alloci64(_3420);
  std::shared_ptr< monty::ndarray< long long,1 > > _3422 = mosek::fusion::p_WorkStack::_get_impl(_3403)->i64;
  _checked_ptr_1<long long> _ptr__3422(_3422 ? _3422->raw() : nullptr,_3422 ? _3422->size(0) : 0);
  p->getSp(_3422,_3421);
  int _3423 = p->getDim((int)0);
  int _3424 = p->getDim((int)1);
  int _3425 = _ptr__3404[_3413];
  int _3426 = _ptr__3404[safe_add( _3413,(int)1 )];
  int _3427 = _3403->alloci32(p->getNumNonzero());
  std::shared_ptr< monty::ndarray< int,1 > > _3428 = mosek::fusion::p_WorkStack::_get_impl(_3403)->i32;
  _checked_ptr_1<int> _ptr__3428(_3428 ? _3428->raw() : nullptr,_3428 ? _3428->size(0) : 0);
  p->getAllIndexes(_3428,_3427);
  if (_3410)
  {
    {
      int _3429 = _3403->alloci32(_3408);
      int _3430 = _3403->alloci32(safe_add( _3426,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3431 = mosek::fusion::p_WorkStack::_get_impl(_3403)->i32;
      _checked_ptr_1<int> _ptr__3431(_3431 ? _3431->raw() : nullptr,_3431 ? _3431->size(0) : 0);
      int _10277 = (int)0;
      int _10278 = safe_add( _3426,(int)1 );
      for (int _3432 = _10277; _3432 < _10278; ++_3432)
      {
        {
          _ptr__3431[safe_add( _3430,_3432 )] = (int)0;
        }
      }
      int _10279 = (int)0;
      int _10280 = _3408;
      for (int _3433 = _10279; _3433 < _10280; ++_3433)
      {
        {
          ++ _ptr__3431[safe_add( safe_add( _3430,(_ptr__3405[safe_add( _3414,_3433 )] % _3426) ),(int)1 )];
        }
      }
      int _10281 = (int)0;
      int _10282 = _3426;
      for (int _3434 = _10281; _3434 < _10282; ++_3434)
      {
        {
          _ptr__3431[safe_add( safe_add( _3430,_3434 ),(int)1 )] += _ptr__3431[safe_add( _3430,_3434 )];
        }
      }
      int _10283 = (int)0;
      int _10284 = _3408;
      for (int _3435 = _10283; _3435 < _10284; ++_3435)
      {
        {
          long long _3436 = (_ptr__3405[safe_add( _3414,_3435 )] % _3426);
          _ptr__3431[safe_add( _3429,_ptr__3431[safe_add( _3430,_3436 )] )] = _3435;
          ++ _ptr__3431[safe_add( _3430,_3436 )];
        }
      }
      int _3437 = (int)0;
      int _3438 = (int)0;
      int _3439 = (int)0;
      {
        int _3440 = (int)0;
        int _3441 = (int)0;
        while ( ((_3441 < _3420) && (_3440 < _3408)) )
        {
          {
            int _3442 = _ptr__3431[safe_add( _3429,_3440 )];
            long long _3443 = (_ptr__3422[safe_add( _3421,_3441 )] / _3424);
            long long _3444 = (_ptr__3405[safe_add( _3414,_3442 )] % _3426);
            if ((_3443 < _3444))
            {
              {
                while ( ((_3441 < _3420) && (_ptr__3422[safe_add( _3421,_3441 )] < safe_mul( safe_add( _3443,(int)1 ),_3424 ))) )
                {
                  {
                    ++ _3441;
                  }
                }
              }
            }
            else if((_3444 < _3443))
            {
              {
                while ( ((_3440 < _3420) && ((_ptr__3405[safe_add( _3414,_ptr__3431[safe_add( _3429,_3440 )] )] % _3426) == _3444)) )
                {
                  {
                    ++ _3440;
                  }
                }
              }
            }
            else
            {
              {
                int _3445 = _3440;
                int _3446 = _3441;
                while ( ((_3441 < _3420) && (_ptr__3422[safe_add( _3421,_3441 )] < safe_mul( safe_add( _3443,(int)1 ),_3424 ))) )
                {
                  {
                    ++ _3441;
                  }
                }
                while ( ((_3440 < _3420) && ((_ptr__3405[safe_add( _3414,_ptr__3431[safe_add( _3429,_3440 )] )] % _3426) == _3444)) )
                {
                  {
                    ++ _3440;
                  }
                }
                bool _3447 = false;
                while ( ((_3446 < _3441) && (_3445 < _3440)) )
                {
                  {
                    long long _3448 = (_ptr__3422[safe_add( _3421,_3446 )] % _3424);
                    int _3449 = _ptr__3431[safe_add( _3429,_3445 )];
                    long long _3450 = (_ptr__3405[safe_add( _3414,_3449 )] / _3426);
                    if ((_3448 < _3450))
                    {
                      {
                        ++ _3446;
                      }
                    }
                    else if((_3448 > _3450))
                    {
                      {
                        ++ _3445;
                      }
                    }
                    else
                    {
                      {
                        _3438 += (_ptr__3404[safe_add( safe_add( _3411,_3449 ),(int)1 )] - _ptr__3404[safe_add( _3411,_3449 )]);
                        _3447 = true;
                        int _3451 = (_ptr__3404[safe_add( safe_add( _3411,_3449 ),(int)1 )] - _ptr__3404[safe_add( _3411,_3449 )]);
                        int _10285;
                        bool _10286 = (_3412 > (int)0);
                        if (_10286)
                        {
                          _10285 = safe_add( (_ptr__3404[safe_add( _3418,_ptr__3404[safe_add( safe_add( _3411,_3449 ),(int)1 )] )] - _ptr__3404[safe_add( _3418,_ptr__3404[safe_add( _3411,_3449 )] )]),safe_mul( (int)4,_3451 ) );
                        }
                        else
                        {
                          _10285 = safe_mul( (int)3,_3451 );
                        }
                        _3439 += _10285;
                        ++ _3446;
                        ++ _3445;
                      }
                    }
                  }
                }
                if (_3447)
                {
                  {
                    ++ _3437;
                  }
                }
                {}
              }
            }
          }
        }
      }
      int _3452 = (int)1;
      bool _3453 = (_3437 < _3423);
      _3401->alloc_expr(_3452,_3437,_3438,_3453,_3439);
      std::shared_ptr< monty::ndarray< long long,1 > > _3454 = mosek::fusion::p_WorkStack::_get_impl(_3401)->i64;
      _checked_ptr_1<long long> _ptr__3454(_3454 ? _3454->raw() : nullptr,_3454 ? _3454->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3455 = mosek::fusion::p_WorkStack::_get_impl(_3401)->f64;
      _checked_ptr_1<double> _ptr__3455(_3455 ? _3455->raw() : nullptr,_3455 ? _3455->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3456 = mosek::fusion::p_WorkStack::_get_impl(_3401)->i32;
      _checked_ptr_1<int> _ptr__3456(_3456 ? _3456->raw() : nullptr,_3456 ? _3456->size(0) : 0);
      int _3457 = mosek::fusion::p_WorkStack::_get_impl(_3401)->ptr_base;
      int _3458 = mosek::fusion::p_WorkStack::_get_impl(_3401)->nidxs_base;
      int _10287;
      bool _10288 = _3453;
      if (_10288)
      {
        _10287 = mosek::fusion::p_WorkStack::_get_impl(_3401)->sp_base;
      }
      else
      {
        _10287 = _3401->alloci64(_3437);
      }
      int _3459 = _10287;
      int _3460 = mosek::fusion::p_WorkStack::_get_impl(_3401)->cof_base;
      bool _3461 = mosek::fusion::p_WorkStack::_get_impl(_3401)->hassp;
      int _3462 = mosek::fusion::p_WorkStack::_get_impl(_3401)->shape_base;
      int _3463 = mosek::fusion::p_WorkStack::_get_impl(_3401)->codeptr_base;
      int _3464 = mosek::fusion::p_WorkStack::_get_impl(_3401)->code_base;
      int _3465 = mosek::fusion::p_WorkStack::_get_impl(_3401)->cconst_base;
      if ((_3437 > (int)0))
      {
        {
          _ptr__3456[_3457] = (int)0;
          if ((_3438 > (int)0))
          {
            {
              _ptr__3456[_3463] = (int)0;
            }
          }
          {}
          _ptr__3456[_3462] = (int)_3423;
          int _3466 = (int)0;
          int _3467 = (int)0;
          int _3468 = (int)0;
          int _3469 = (int)0;
          int _3470 = (int)0;
          while ( ((_3470 < _3420) && (_3469 < _3408)) )
          {
            {
              int _3471 = _ptr__3431[safe_add( _3429,_3469 )];
              long long _3472 = (_ptr__3422[safe_add( _3421,_3470 )] / _3424);
              long long _3473 = (_ptr__3405[safe_add( _3414,_3471 )] % _3426);
              if ((_3472 < _3473))
              {
                {
                  while ( ((_3470 < _3420) && (_ptr__3422[safe_add( _3421,_3470 )] < safe_mul( safe_add( _3472,(int)1 ),_3424 ))) )
                  {
                    {
                      ++ _3470;
                    }
                  }
                }
              }
              else if((_3473 < _3472))
              {
                {
                  while ( ((_3469 < _3420) && ((_ptr__3405[safe_add( _3414,_ptr__3431[safe_add( _3429,_3469 )] )] % _3426) == _3473)) )
                  {
                    {
                      ++ _3469;
                    }
                  }
                }
              }
              else
              {
                {
                  int _3474 = _3469;
                  int _3475 = _3470;
                  while ( ((_3470 < _3420) && (_ptr__3422[safe_add( _3421,_3470 )] < safe_mul( safe_add( _3472,(int)1 ),_3424 ))) )
                  {
                    {
                      ++ _3470;
                    }
                  }
                  while ( ((_3469 < _3420) && ((_ptr__3405[safe_add( _3414,_ptr__3431[safe_add( _3429,_3469 )] )] % _3426) == _3473)) )
                  {
                    {
                      ++ _3469;
                    }
                  }
                  int _3476 = (int)0;
                  while ( ((_3475 < _3470) && (_3474 < _3469)) )
                  {
                    {
                      long long _3477 = (_ptr__3422[safe_add( _3421,_3475 )] % _3424);
                      int _3478 = _ptr__3431[safe_add( _3429,_3474 )];
                      long long _3479 = (_ptr__3405[safe_add( _3414,_3478 )] / _3426);
                      if ((_3477 < _3479))
                      {
                        {
                          ++ _3475;
                        }
                      }
                      else if((_3477 > _3479))
                      {
                        {
                          ++ _3474;
                        }
                      }
                      else
                      {
                        {
                          int _10289 = _ptr__3404[safe_add( _3411,_3478 )];
                          int _10290 = _ptr__3404[safe_add( safe_add( _3411,_3478 ),(int)1 )];
                          for (int _3480 = _10289; _3480 < _10290; ++_3480)
                          {
                            {
                              _ptr__3455[safe_add( _3460,_3468 )] = 0.0;
                              _ptr__3454[safe_add( _3458,_3468 )] = _ptr__3405[safe_add( _3415,_3480 )];
                              _ptr__3456[safe_add( _3464,_3466 )] = 2;
                              _ptr__3455[safe_add( _3465,_3466 )] = _ptr__3406[safe_add( _3416,_3480 )];
                              ++ _3466;
                              if ((_3412 > (int)0))
                              {
                                {
                                  int _10291 = _ptr__3404[safe_add( _3418,_3480 )];
                                  int _10292 = _ptr__3404[safe_add( safe_add( _3418,_3480 ),(int)1 )];
                                  for (int _3481 = _10291; _3481 < _10292; ++_3481)
                                  {
                                    {
                                      _ptr__3456[safe_add( _3464,_3466 )] = _ptr__3404[safe_add( _3419,_3481 )];
                                      _ptr__3455[safe_add( _3465,_3466 )] = _ptr__3406[safe_add( _3417,_3481 )];
                                      ++ _3466;
                                    }
                                  }
                                  _ptr__3456[safe_add( _3464,_3466 )] = 3;
                                  ++ _3466;
                                }
                              }
                              {}
                              _ptr__3456[safe_add( _3464,_3466 )] = 1;
                              _ptr__3455[safe_add( _3465,_3466 )] = _ptr__3431[safe_add( _3427,_3475 )];
                              ++ _3466;
                              _ptr__3456[safe_add( _3464,_3466 )] = 5;
                              ++ _3466;
                              _ptr__3456[safe_add( safe_add( _3463,_3468 ),(int)1 )] = _3466;
                              ++ _3468;
                            }
                          }
                          ++ _3475;
                          ++ _3474;
                          ++ _3476;
                        }
                      }
                    }
                  }
                  if ((_3476 > (int)0))
                  {
                    {
                      _ptr__3454[safe_add( _3459,_3467 )] = _3472;
                      _ptr__3456[safe_add( safe_add( _3457,_3467 ),(int)1 )] = _3468;
                      ++ _3467;
                    }
                  }
                  {}
                }
              }
            }
          }
        }
      }
      {}
      if ((!_3461))
      {
        {
          _3401->popi64(_3437);
        }
      }
      {}
      _3403->clear();
    }
  }
  else
  {
    {
      int _3482 = (int)0;
      int _3483 = (int)0;
      int _3484 = (int)0;
      std::shared_ptr< monty::ndarray< int,1 > > _3485 = mosek::fusion::p_WorkStack::_get_impl(_3403)->i32;
      _checked_ptr_1<int> _ptr__3485(_3485 ? _3485->raw() : nullptr,_3485 ? _3485->size(0) : 0);
      {
        int _3486 = (int)0;
        while ( (_3486 < _3420) )
        {
          {
            long long _3487 = (_ptr__3422[safe_add( _3421,_3486 )] / _3424);
            long long _3488 = safe_mul( safe_add( _3487,(int)1 ),_3424 );
            bool _3489 = false;
            while ( ((_3486 < _3420) && (_ptr__3422[safe_add( _3421,_3486 )] < _3488)) )
            {
              {
                long long _3490 = (_ptr__3422[safe_add( _3421,_3486 )] % _3424);
                long long _3491 = safe_add( safe_mul( _3490,_3426 ),_3487 );
                int _3492 = (_ptr__3404[safe_add( safe_add( _3411,_3491 ),(int)1 )] - _ptr__3404[safe_add( _3411,_3491 )]);
                _3483 += _3492;
                _3489 = true;
                int _10293;
                bool _10294 = (_3412 > (int)0);
                if (_10294)
                {
                  _10293 = safe_add( (_ptr__3404[safe_add( _3418,_ptr__3404[safe_add( safe_add( _3411,_3491 ),(int)1 )] )] - _ptr__3404[safe_add( _3418,_ptr__3404[safe_add( _3411,_3491 )] )]),safe_mul( _3492,(int)4 ) );
                }
                else
                {
                  _10293 = safe_mul( _3492,(int)3 );
                }
                _3484 += _10293;
                ++ _3486;
              }
            }
            if (_3489)
            {
              {
                ++ _3482;
              }
            }
            {}
          }
        }
      }
      int _3493 = (int)1;
      bool _3494 = (_3482 < _3423);
      _3401->alloc_expr(_3493,_3482,_3483,_3494,_3484);
      std::shared_ptr< monty::ndarray< long long,1 > > _3495 = mosek::fusion::p_WorkStack::_get_impl(_3401)->i64;
      _checked_ptr_1<long long> _ptr__3495(_3495 ? _3495->raw() : nullptr,_3495 ? _3495->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3496 = mosek::fusion::p_WorkStack::_get_impl(_3401)->f64;
      _checked_ptr_1<double> _ptr__3496(_3496 ? _3496->raw() : nullptr,_3496 ? _3496->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3497 = mosek::fusion::p_WorkStack::_get_impl(_3401)->i32;
      _checked_ptr_1<int> _ptr__3497(_3497 ? _3497->raw() : nullptr,_3497 ? _3497->size(0) : 0);
      int _3498 = mosek::fusion::p_WorkStack::_get_impl(_3401)->ptr_base;
      int _3499 = mosek::fusion::p_WorkStack::_get_impl(_3401)->nidxs_base;
      int _10295;
      bool _10296 = _3494;
      if (_10296)
      {
        _10295 = mosek::fusion::p_WorkStack::_get_impl(_3401)->sp_base;
      }
      else
      {
        _10295 = _3401->alloci64(_3482);
      }
      int _3500 = _10295;
      int _3501 = mosek::fusion::p_WorkStack::_get_impl(_3401)->cof_base;
      bool _3502 = mosek::fusion::p_WorkStack::_get_impl(_3401)->hassp;
      int _3503 = mosek::fusion::p_WorkStack::_get_impl(_3401)->shape_base;
      int _3504 = mosek::fusion::p_WorkStack::_get_impl(_3401)->codeptr_base;
      int _3505 = mosek::fusion::p_WorkStack::_get_impl(_3401)->code_base;
      int _3506 = mosek::fusion::p_WorkStack::_get_impl(_3401)->cconst_base;
      {
        _ptr__3497[_3498] = (int)0;
        _ptr__3497[_3504] = (int)0;
        _ptr__3497[_3503] = (int)_3423;
        int _3507 = (int)0;
        int _3508 = (int)0;
        int _3509 = (int)0;
        int _3510 = (int)0;
        while ( (_3510 < _3420) )
        {
          {
            long long _3511 = (_ptr__3422[safe_add( _3421,_3510 )] / _3424);
            long long _3512 = safe_mul( safe_add( _3511,(int)1 ),_3424 );
            int _3513 = (int)0;
            while ( ((_3510 < _3420) && (_ptr__3422[safe_add( _3421,_3510 )] < _3512)) )
            {
              {
                long long _3514 = (_ptr__3422[safe_add( _3421,_3510 )] % _3424);
                long long _3515 = safe_add( safe_mul( _3514,_3426 ),_3511 );
                int _10297 = _ptr__3404[safe_add( _3411,_3515 )];
                int _10298 = _ptr__3404[safe_add( safe_add( _3411,_3515 ),(int)1 )];
                for (int _3516 = _10297; _3516 < _10298; ++_3516)
                {
                  {
                    _ptr__3495[safe_add( _3499,_3509 )] = _ptr__3405[safe_add( _3415,_3516 )];
                    _ptr__3496[safe_add( _3501,_3509 )] = 0.0;
                    _ptr__3497[safe_add( _3505,_3507 )] = 2;
                    _ptr__3496[safe_add( _3506,_3507 )] = _ptr__3406[safe_add( _3416,_3516 )];
                    ++ _3507;
                    if ((_3412 > (int)0))
                    {
                      {
                        int _10299 = _ptr__3404[safe_add( _3418,_3516 )];
                        int _10300 = _ptr__3404[safe_add( safe_add( _3418,_3516 ),(int)1 )];
                        for (int _3517 = _10299; _3517 < _10300; ++_3517)
                        {
                          {
                            _ptr__3497[safe_add( _3505,_3507 )] = _ptr__3404[safe_add( _3419,_3517 )];
                            _ptr__3496[safe_add( _3506,_3507 )] = _ptr__3406[safe_add( _3417,_3517 )];
                            ++ _3507;
                          }
                        }
                        _ptr__3497[safe_add( _3505,_3507 )] = 3;
                        ++ _3507;
                      }
                    }
                    {}
                    _ptr__3497[safe_add( _3505,_3507 )] = 1;
                    _ptr__3496[safe_add( _3506,_3507 )] = _ptr__3485[safe_add( _3427,_3510 )];
                    ++ _3507;
                    _ptr__3497[safe_add( _3505,_3507 )] = 5;
                    ++ _3507;
                    _ptr__3497[safe_add( safe_add( _3504,_3509 ),(int)1 )] = _3507;
                    ++ _3509;
                  }
                }
                ++ _3513;
                ++ _3510;
              }
            }
            if ((_3513 > (int)0))
            {
              {
                _ptr__3495[safe_add( _3500,_3508 )] = _3511;
                _ptr__3497[safe_add( safe_add( _3498,_3508 ),(int)1 )] = _3509;
                ++ _3508;
              }
            }
            {}
          }
        }
      }
      if ((!_3502))
      {
        {
          _3401->popi64(_3482);
        }
      }
      {}
      _3403->clear();
    }
  }
}
std::string mosek::fusion::ExprMulParamDiagLeft :: toString() { return mosek::fusion::p_ExprMulParamDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulParamDiagLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulParamDiagLeft("))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulParamDiagLeft::destroy(){e.reset();p.reset();}void mosek::fusion::ExprMulParamDiagLeft::destroy() { mosek::fusion::p_ExprMulParamDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulParamDiagRight::ExprMulParamDiagRight(mosek::fusion::p_ExprMulParamDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulParamDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulParamDiagRight::~ExprMulParamDiagRight() {  /* std::cout << "~ExprMulParamDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulParamDiagRight::p_ExprMulParamDiagRight  (::mosek::fusion::ExprMulParamDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulParamDiagRight::t mosek::fusion::p_ExprMulParamDiagRight::_new_ExprMulParamDiagRight  (monty::rc_ptr< ::mosek::fusion::Expression > _3518,    monty::rc_ptr< ::mosek::fusion::Parameter > _3519){ return new mosek::fusion::ExprMulParamDiagRight(_3518,_3519); }mosek::fusion::ExprMulParamDiagRight::ExprMulParamDiagRight  (monty::rc_ptr< ::mosek::fusion::Expression > _3518,    monty::rc_ptr< ::mosek::fusion::Parameter > _3519) :    ExprMulParamDiagRight(new mosek::fusion::p_ExprMulParamDiagRight(this)){ mosek::fusion::p_ExprMulParamDiagRight::_get_impl(this)->_initialize(_3518,_3519); }void mosek::fusion::p_ExprMulParamDiagRight::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3518,    monty::rc_ptr< ::mosek::fusion::Parameter > _3519){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3518->getDim((int)0))}));
    mosek::fusion::p_ExprMulParamDiagRight::_get_impl(::mosek::fusion::ExprMulParamDiagRight::t(_pubthis))->p = _3519;
    mosek::fusion::p_ExprMulParamDiagRight::_get_impl(::mosek::fusion::ExprMulParamDiagRight::t(_pubthis))->e = _3518;
    if (((_3519->getND() != (int)2) || (_3518->getND() != (int)2)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
    if (((_3519->getDim((int)1) != _3518->getDim((int)0)) || (_3519->getDim((int)0) != _3518->getDim((int)1))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
  }
}void mosek::fusion::ExprMulParamDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3520,monty::rc_ptr< ::mosek::fusion::WorkStack > _3521,monty::rc_ptr< ::mosek::fusion::WorkStack > _3522) { mosek::fusion::p_ExprMulParamDiagRight::_get_impl(this)->eval(_3520,_3521,_3522); }void mosek::fusion::p_ExprMulParamDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3520,monty::rc_ptr< ::mosek::fusion::WorkStack > _3521,monty::rc_ptr< ::mosek::fusion::WorkStack > _3522){
  e->eval(_3521,_3520,_3522);
  _3521->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3523 = mosek::fusion::p_WorkStack::_get_impl(_3521)->i32;
  _checked_ptr_1<int> _ptr__3523(_3523 ? _3523->raw() : nullptr,_3523 ? _3523->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3524 = mosek::fusion::p_WorkStack::_get_impl(_3521)->i64;
  _checked_ptr_1<long long> _ptr__3524(_3524 ? _3524->raw() : nullptr,_3524 ? _3524->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3525 = mosek::fusion::p_WorkStack::_get_impl(_3521)->f64;
  _checked_ptr_1<double> _ptr__3525(_3525 ? _3525->raw() : nullptr,_3525 ? _3525->size(0) : 0);
  int _3526 = mosek::fusion::p_WorkStack::_get_impl(_3521)->nd;
  int _3527 = mosek::fusion::p_WorkStack::_get_impl(_3521)->nelem;
  int _3528 = mosek::fusion::p_WorkStack::_get_impl(_3521)->nnz;
  bool _3529 = mosek::fusion::p_WorkStack::_get_impl(_3521)->hassp;
  int _3530 = mosek::fusion::p_WorkStack::_get_impl(_3521)->ptr_base;
  int _3531 = mosek::fusion::p_WorkStack::_get_impl(_3521)->ncodeatom;
  int _3532 = mosek::fusion::p_WorkStack::_get_impl(_3521)->shape_base;
  int _3533 = mosek::fusion::p_WorkStack::_get_impl(_3521)->sp_base;
  int _3534 = mosek::fusion::p_WorkStack::_get_impl(_3521)->nidxs_base;
  int _3535 = mosek::fusion::p_WorkStack::_get_impl(_3521)->cof_base;
  int _3536 = mosek::fusion::p_WorkStack::_get_impl(_3521)->cconst_base;
  int _3537 = mosek::fusion::p_WorkStack::_get_impl(_3521)->codeptr_base;
  int _3538 = mosek::fusion::p_WorkStack::_get_impl(_3521)->code_base;
  if (((_3526 != (int)2) || ((_ptr__3523[_3532] != p->getDim((int)1)) || (_ptr__3523[safe_add( _3532,(int)1 )] != p->getDim((int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
    }
  }
  {}
  int _3539 = p->getNumNonzero();
  int _3540 = _3522->alloci64(_3539);
  std::shared_ptr< monty::ndarray< long long,1 > > _3541 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i64;
  _checked_ptr_1<long long> _ptr__3541(_3541 ? _3541->raw() : nullptr,_3541 ? _3541->size(0) : 0);
  int _3542 = _3522->alloci32(p->getNumNonzero());
  std::shared_ptr< monty::ndarray< int,1 > > _3543 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i32;
  _checked_ptr_1<int> _ptr__3543(_3543 ? _3543->raw() : nullptr,_3543 ? _3543->size(0) : 0);
  p->getAllIndexes(_3543,_3542);
  p->getSp(_3541,_3540);
  int _3544 = p->getDim((int)0);
  int _3545 = p->getDim((int)1);
  int _3546 = _ptr__3523[_3532];
  int _3547 = _ptr__3523[safe_add( _3532,(int)1 )];
  int _3548 = _3522->alloci32(_3539);
  int _3549 = _3522->alloci32(safe_add( _3545,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _3550 = mosek::fusion::p_WorkStack::_get_impl(_3522)->i32;
  _checked_ptr_1<int> _ptr__3550(_3550 ? _3550->raw() : nullptr,_3550 ? _3550->size(0) : 0);
  int _10301 = (int)0;
  int _10302 = safe_add( _3545,(int)1 );
  for (int _3551 = _10301; _3551 < _10302; ++_3551)
  {
    {
      _ptr__3550[safe_add( _3549,_3551 )] = (int)0;
    }
  }
  int _10303 = (int)0;
  int _10304 = _3539;
  for (int _3552 = _10303; _3552 < _10304; ++_3552)
  {
    {
      ++ _ptr__3550[safe_add( safe_add( _3549,(_ptr__3541[safe_add( _3540,_3552 )] % _3545) ),(int)1 )];
    }
  }
  int _10305 = (int)1;
  int _10306 = _3545;
  for (int _3553 = _10305; _3553 < _10306; ++_3553)
  {
    {
      _ptr__3550[safe_add( _3549,_3553 )] += _ptr__3550[(safe_add( _3549,_3553 ) - (int)1)];
    }
  }
  int _10307 = (int)0;
  int _10308 = _3539;
  for (int _3554 = _10307; _3554 < _10308; ++_3554)
  {
    {
      long long _3555 = (_ptr__3541[safe_add( _3540,_3554 )] % _3545);
      _ptr__3550[safe_add( _3548,_ptr__3550[safe_add( _3549,_3555 )] )] = _3554;
      ++ _ptr__3550[safe_add( _3549,_3555 )];
    }
  }
  if (_3529)
  {
    {
      int _3556 = (int)0;
      int _3557 = (int)0;
      int _3558 = (int)0;
      int _3559 = (int)0;
      int _3560 = (int)0;
      while ( ((_3560 < _3527) && (_3559 < _3539)) )
      {
        {
          long long _3561 = (_ptr__3524[safe_add( _3533,_3560 )] / _3547);
          long long _3562 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3559 )] )] % _3545);
          if ((_3561 < _3562))
          {
            {
              ++ _3560;
            }
          }
          else if((_3561 > _3562))
          {
            {
              ++ _3559;
            }
          }
          else
          {
            {
              int _3563 = _3560;
              ++ _3560;
              int _3564 = _3559;
              ++ _3559;
              while ( ((_3560 < _3527) && ((_ptr__3524[safe_add( _3533,_3560 )] / _3547) == _3561)) )
              {
                {
                  ++ _3560;
                }
              }
              while ( ((_3559 < _3539) && ((_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3559 )] )] % _3545) == _3562)) )
              {
                {
                  ++ _3559;
                }
              }
              int _3565 = _3564;
              int _3566 = _3563;
              bool _3567 = false;
              while ( ((_3566 < _3560) && (_3565 < _3559)) )
              {
                {
                  long long _3568 = (_ptr__3524[safe_add( _3533,_3566 )] % _3547);
                  long long _3569 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3565 )] )] / _3545);
                  if ((_3568 < _3569))
                  {
                    {
                      ++ _3566;
                    }
                  }
                  else if((_3568 > _3569))
                  {
                    {
                      ++ _3565;
                    }
                  }
                  else
                  {
                    {
                      _3567 = true;
                      int _3570 = (_ptr__3523[safe_add( safe_add( _3530,_3566 ),(int)1 )] - _ptr__3523[safe_add( _3530,_3566 )]);
                      _3558 += _3570;
                      int _10309;
                      bool _10310 = (_3531 > (int)0);
                      if (_10310)
                      {
                        _10309 = safe_add( (_ptr__3523[safe_add( _3537,_ptr__3523[safe_add( safe_add( _3530,_3566 ),(int)1 )] )] - _ptr__3523[safe_add( _3537,_ptr__3523[safe_add( _3530,_3566 )] )]),safe_mul( _3570,(int)4 ) );
                      }
                      else
                      {
                        _10309 = safe_mul( _3570,(int)3 );
                      }
                      _3556 += _10309;
                      ++ _3566;
                      ++ _3565;
                    }
                  }
                }
              }
              if (_3567)
              {
                {
                  ++ _3557;
                }
              }
              {}
            }
          }
        }
      }
      int _3571 = (int)1;
      bool _3572 = (_3557 < _3546);
      _3520->alloc_expr(_3571,_3557,_3558,_3572,_3556);
      int _3573 = mosek::fusion::p_WorkStack::_get_impl(_3520)->ptr_base;
      int _3574 = mosek::fusion::p_WorkStack::_get_impl(_3520)->nidxs_base;
      int _10311;
      bool _10312 = _3572;
      if (_10312)
      {
        _10311 = mosek::fusion::p_WorkStack::_get_impl(_3520)->sp_base;
      }
      else
      {
        _10311 = _3520->alloci64(_3557);
      }
      int _3575 = _10311;
      int _3576 = mosek::fusion::p_WorkStack::_get_impl(_3520)->cof_base;
      bool _3577 = mosek::fusion::p_WorkStack::_get_impl(_3520)->hassp;
      int _3578 = mosek::fusion::p_WorkStack::_get_impl(_3520)->shape_base;
      int _3579 = mosek::fusion::p_WorkStack::_get_impl(_3520)->codeptr_base;
      int _3580 = mosek::fusion::p_WorkStack::_get_impl(_3520)->code_base;
      int _3581 = mosek::fusion::p_WorkStack::_get_impl(_3520)->cconst_base;
      std::shared_ptr< monty::ndarray< long long,1 > > _3582 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i64;
      _checked_ptr_1<long long> _ptr__3582(_3582 ? _3582->raw() : nullptr,_3582 ? _3582->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3583 = mosek::fusion::p_WorkStack::_get_impl(_3520)->f64;
      _checked_ptr_1<double> _ptr__3583(_3583 ? _3583->raw() : nullptr,_3583 ? _3583->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3584 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i32;
      _checked_ptr_1<int> _ptr__3584(_3584 ? _3584->raw() : nullptr,_3584 ? _3584->size(0) : 0);
      if ((_3557 > (int)0))
      {
        {
          _ptr__3584[_3573] = (int)0;
          if ((_3556 > (int)0))
          {
            {
              _ptr__3584[_3579] = (int)0;
            }
          }
          {}
          _ptr__3584[_3578] = (int)_3546;
          int _3585 = (int)0;
          int _3586 = (int)0;
          int _3587 = (int)0;
          int _3588 = (int)0;
          int _3589 = (int)0;
          while ( ((_3589 < _3527) && (_3588 < _3539)) )
          {
            {
              long long _3590 = (_ptr__3524[safe_add( _3533,_3589 )] / _3547);
              long long _3591 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3588 )] )] % _3545);
              if ((_3590 < _3591))
              {
                {
                  while ( ((_3589 < _3527) && ((_ptr__3524[safe_add( _3533,_3589 )] / _3547) == _3590)) )
                  {
                    {
                      ++ _3589;
                    }
                  }
                }
              }
              else if((_3590 > _3591))
              {
                {
                  while ( ((_3588 < _3539) && ((_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3588 )] )] % _3545) == _3591)) )
                  {
                    {
                      ++ _3588;
                    }
                  }
                }
              }
              else
              {
                {
                  int _3592 = _3589;
                  ++ _3589;
                  int _3593 = _3588;
                  ++ _3588;
                  while ( ((_3589 < _3527) && ((_ptr__3524[safe_add( _3533,_3589 )] / _3547) == _3590)) )
                  {
                    {
                      ++ _3589;
                    }
                  }
                  while ( ((_3588 < _3539) && ((_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3588 )] )] % _3545) == _3591)) )
                  {
                    {
                      ++ _3588;
                    }
                  }
                  int _3594 = _3593;
                  int _3595 = _3592;
                  int _3596 = (int)0;
                  while ( ((_3595 < _3589) && (_3594 < _3588)) )
                  {
                    {
                      long long _3597 = (_ptr__3524[safe_add( _3533,_3595 )] % _3547);
                      long long _3598 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3594 )] )] / _3545);
                      if ((_3597 < _3598))
                      {
                        {
                          ++ _3595;
                        }
                      }
                      else if((_3597 > _3598))
                      {
                        {
                          ++ _3594;
                        }
                      }
                      else
                      {
                        {
                          int _10313 = _ptr__3523[safe_add( _3530,_3595 )];
                          int _10314 = _ptr__3523[safe_add( safe_add( _3530,_3595 ),(int)1 )];
                          for (int _3599 = _10313; _3599 < _10314; ++_3599)
                          {
                            {
                              _ptr__3582[safe_add( _3574,_3587 )] = _ptr__3524[safe_add( _3534,_3599 )];
                              _ptr__3583[safe_add( _3576,_3587 )] = 0.0;
                              _ptr__3584[safe_add( _3580,_3585 )] = 2;
                              _ptr__3583[safe_add( _3581,_3585 )] = _ptr__3525[safe_add( _3535,_3599 )];
                              ++ _3585;
                              if ((_3531 > (int)0))
                              {
                                {
                                  int _10315 = _ptr__3523[safe_add( _3537,_3599 )];
                                  int _10316 = _ptr__3523[safe_add( safe_add( _3537,_3599 ),(int)1 )];
                                  for (int _3600 = _10315; _3600 < _10316; ++_3600)
                                  {
                                    {
                                      _ptr__3584[safe_add( _3580,_3585 )] = _ptr__3523[safe_add( _3538,_3600 )];
                                      _ptr__3583[safe_add( _3581,_3585 )] = _ptr__3525[safe_add( _3536,_3600 )];
                                      ++ _3585;
                                    }
                                  }
                                  _ptr__3584[safe_add( _3580,_3585 )] = 3;
                                  ++ _3585;
                                }
                              }
                              {}
                              _ptr__3584[safe_add( _3580,_3585 )] = 1;
                              _ptr__3583[safe_add( _3581,_3585 )] = _ptr__3550[safe_add( _3542,_ptr__3550[safe_add( _3548,_3594 )] )];
                              ++ _3585;
                              _ptr__3584[safe_add( _3580,_3585 )] = 5;
                              ++ _3585;
                              _ptr__3584[safe_add( safe_add( _3579,_3587 ),(int)1 )] = _3585;
                              ++ _3587;
                            }
                          }
                          ++ _3596;
                          ++ _3595;
                          ++ _3594;
                        }
                      }
                    }
                  }
                  if ((_3596 > (int)0))
                  {
                    {
                      _ptr__3582[safe_add( _3575,_3586 )] = _3590;
                      _ptr__3584[safe_add( safe_add( _3573,_3586 ),(int)1 )] = _3587;
                      ++ _3586;
                    }
                  }
                  {}
                }
              }
            }
          }
          if ((_3557 > _ptr__3584[_3578]))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid shape"));
            }
          }
          {}
          if ((_3586 != _3557))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid num elements"));
            }
          }
          {}
          if ((_3587 != _3587))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid num nonzeros"));
            }
          }
          {}
        }
      }
      {}
      if ((!_3577))
      {
        {
          _3520->popi64(_3557);
        }
      }
      {}
      _3522->clear();
    }
  }
  else
  {
    {
      int _3601 = (int)0;
      int _3602 = (int)0;
      int _3603 = (int)0;
      int _3604 = (int)0;
      while ( (_3604 < _3539) )
      {
        {
          long long _3605 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3604 )] )] % _3545);
          int _3606 = _3604;
          ++ _3604;
          while ( ((_3604 < _3539) && ((_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3604 )] )] % _3545) == _3605)) )
          {
            {
              ++ _3604;
            }
          }
          int _10317 = _3606;
          int _10318 = _3604;
          for (int _3607 = _10317; _3607 < _10318; ++_3607)
          {
            {
              long long _3608 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3604 )] )] / _3545);
              long long _3609 = safe_add( safe_mul( _3605,_3547 ),_3608 );
              int _3610 = (_ptr__3523[safe_add( safe_add( _3530,_3609 ),(int)1 )] - _ptr__3523[safe_add( _3530,_3609 )]);
              _3603 += _3610;
              int _10319;
              bool _10320 = (_3531 > (int)0);
              if (_10320)
              {
                _10319 = safe_add( (_ptr__3523[safe_add( _3537,_ptr__3523[safe_add( safe_add( _3530,_3609 ),(int)1 )] )] - _ptr__3523[safe_add( _3537,_ptr__3523[safe_add( _3530,_3609 )] )]),safe_mul( _3610,(int)4 ) );
              }
              else
              {
                _10319 = safe_mul( _3610,(int)3 );
              }
              _3601 += _10319;
            }
          }
          ++ _3602;
        }
      }
      int _3611 = (int)1;
      bool _3612 = (_3602 < _3546);
      _3520->alloc_expr(_3611,_3602,_3603,_3612,_3601);
      int _3613 = mosek::fusion::p_WorkStack::_get_impl(_3520)->ptr_base;
      int _3614 = mosek::fusion::p_WorkStack::_get_impl(_3520)->nidxs_base;
      int _10321;
      bool _10322 = _3612;
      if (_10322)
      {
        _10321 = mosek::fusion::p_WorkStack::_get_impl(_3520)->sp_base;
      }
      else
      {
        _10321 = _3520->alloci64(_3602);
      }
      int _3615 = _10321;
      int _3616 = mosek::fusion::p_WorkStack::_get_impl(_3520)->cof_base;
      bool _3617 = mosek::fusion::p_WorkStack::_get_impl(_3520)->hassp;
      int _3618 = mosek::fusion::p_WorkStack::_get_impl(_3520)->shape_base;
      int _3619 = mosek::fusion::p_WorkStack::_get_impl(_3520)->codeptr_base;
      int _3620 = mosek::fusion::p_WorkStack::_get_impl(_3520)->code_base;
      int _3621 = mosek::fusion::p_WorkStack::_get_impl(_3520)->cconst_base;
      std::shared_ptr< monty::ndarray< long long,1 > > _3622 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i64;
      _checked_ptr_1<long long> _ptr__3622(_3622 ? _3622->raw() : nullptr,_3622 ? _3622->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3623 = mosek::fusion::p_WorkStack::_get_impl(_3520)->f64;
      _checked_ptr_1<double> _ptr__3623(_3623 ? _3623->raw() : nullptr,_3623 ? _3623->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3624 = mosek::fusion::p_WorkStack::_get_impl(_3520)->i32;
      _checked_ptr_1<int> _ptr__3624(_3624 ? _3624->raw() : nullptr,_3624 ? _3624->size(0) : 0);
      {
        _ptr__3624[_3613] = (int)0;
        _ptr__3624[_3619] = (int)0;
        _ptr__3624[_3618] = (int)_3546;
        int _3625 = (int)0;
        int _3626 = (int)0;
        int _3627 = (int)0;
        int _3628 = (int)0;
        while ( (_3628 < _3539) )
        {
          {
            long long _3629 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3628 )] )] % _3545);
            int _3630 = _3628;
            ++ _3628;
            while ( ((_3628 < _3539) && ((_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3628 )] )] % _3545) == _3629)) )
            {
              {
                ++ _3628;
              }
            }
            int _10323 = _3630;
            int _10324 = _3628;
            for (int _3631 = _10323; _3631 < _10324; ++_3631)
            {
              {
                long long _3632 = (_ptr__3541[safe_add( _3540,_ptr__3550[safe_add( _3548,_3631 )] )] / _3545);
                long long _3633 = safe_add( safe_mul( _3629,_3547 ),_3632 );
                int _10325 = _ptr__3523[safe_add( _3530,_3633 )];
                int _10326 = _ptr__3523[safe_add( safe_add( _3530,_3633 ),(int)1 )];
                for (int _3634 = _10325; _3634 < _10326; ++_3634)
                {
                  {
                    _ptr__3622[safe_add( _3614,_3627 )] = _ptr__3524[safe_add( _3534,_3634 )];
                    _ptr__3623[safe_add( _3616,_3627 )] = 0.0;
                    _ptr__3624[safe_add( _3620,_3625 )] = 2;
                    _ptr__3623[safe_add( _3621,_3625 )] = _ptr__3525[safe_add( _3535,_3634 )];
                    ++ _3625;
                    if ((_3531 > (int)0))
                    {
                      {
                        int _10327 = _ptr__3523[safe_add( _3537,_3634 )];
                        int _10328 = _ptr__3523[safe_add( safe_add( _3537,_3634 ),(int)1 )];
                        for (int _3635 = _10327; _3635 < _10328; ++_3635)
                        {
                          {
                            _ptr__3624[safe_add( _3620,_3625 )] = _ptr__3523[safe_add( _3538,_3635 )];
                            _ptr__3623[safe_add( _3621,_3625 )] = _ptr__3525[safe_add( _3536,_3635 )];
                            ++ _3625;
                          }
                        }
                        _ptr__3624[safe_add( _3620,_3625 )] = 3;
                        ++ _3625;
                      }
                    }
                    {}
                    _ptr__3624[safe_add( _3620,_3625 )] = 1;
                    _ptr__3623[safe_add( _3621,_3625 )] = _ptr__3550[safe_add( _3542,_ptr__3550[safe_add( _3548,_3631 )] )];
                    ++ _3625;
                    _ptr__3624[safe_add( _3620,_3625 )] = 5;
                    ++ _3625;
                    _ptr__3624[safe_add( safe_add( _3619,_3627 ),(int)1 )] = _3625;
                    ++ _3627;
                  }
                }
              }
            }
            _ptr__3622[safe_add( _3615,_3626 )] = _3629;
            _ptr__3624[safe_add( safe_add( _3613,_3626 ),(int)1 )] = _3627;
            ++ _3626;
          }
        }
        if ((_3602 > _ptr__3624[_3618]))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid shape"));
          }
        }
        {}
        if ((_3626 != _3602))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid num elements"));
          }
        }
        {}
        if ((_3627 != _3603))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid num nonzeros"));
          }
        }
        {}
      }
      if ((!_3617))
      {
        {
          _3520->popi64(_3602);
        }
      }
      {}
      _3522->clear();
    }
  }
}
std::string mosek::fusion::ExprMulParamDiagRight :: toString() { return mosek::fusion::p_ExprMulParamDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulParamDiagRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulParamDiagRight("))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulParamDiagRight::destroy(){e.reset();p.reset();}void mosek::fusion::ExprMulParamDiagRight::destroy() { mosek::fusion::p_ExprMulParamDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprDotParam::ExprDotParam(mosek::fusion::p_ExprDotParam *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDotParam()" << this << std::endl; */ }mosek::fusion::ExprDotParam::~ExprDotParam() {  /* std::cout << "~ExprDotParam()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDotParam::p_ExprDotParam  (::mosek::fusion::ExprDotParam * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDotParam::t mosek::fusion::p_ExprDotParam::_new_ExprDotParam  (monty::rc_ptr< ::mosek::fusion::Parameter > _3636,    monty::rc_ptr< ::mosek::fusion::Expression > _3637){ return new mosek::fusion::ExprDotParam(_3636,_3637); }mosek::fusion::ExprDotParam::ExprDotParam  (monty::rc_ptr< ::mosek::fusion::Parameter > _3636,    monty::rc_ptr< ::mosek::fusion::Expression > _3637) :    ExprDotParam(new mosek::fusion::p_ExprDotParam(this)){ mosek::fusion::p_ExprDotParam::_get_impl(this)->_initialize(_3636,_3637); }void mosek::fusion::p_ExprDotParam::_initialize  (monty::rc_ptr< ::mosek::fusion::Parameter > _3636,    monty::rc_ptr< ::mosek::fusion::Expression > _3637){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprDotParam::_get_impl(::mosek::fusion::ExprDotParam::t(_pubthis))->p = _3636;
    mosek::fusion::p_ExprDotParam::_get_impl(::mosek::fusion::ExprDotParam::t(_pubthis))->e = _3637;
    if ((_3636->getND() != _3637->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    int _10329 = (int)0;
    int _10330 = _3636->getND();
    for (int _3638 = _10329; _3638 < _10330; ++_3638)
    {
      {
        if ((_3636->getDim(_3638) != _3637->getDim(_3638)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprDotParam :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3639,monty::rc_ptr< ::mosek::fusion::WorkStack > _3640,monty::rc_ptr< ::mosek::fusion::WorkStack > _3641) { mosek::fusion::p_ExprDotParam::_get_impl(this)->eval(_3639,_3640,_3641); }void mosek::fusion::p_ExprDotParam::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3639,monty::rc_ptr< ::mosek::fusion::WorkStack > _3640,monty::rc_ptr< ::mosek::fusion::WorkStack > _3641){
  e->eval(_3640,_3639,_3641);
  _3640->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3642 = mosek::fusion::p_WorkStack::_get_impl(_3640)->i32;
  _checked_ptr_1<int> _ptr__3642(_3642 ? _3642->raw() : nullptr,_3642 ? _3642->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3643 = mosek::fusion::p_WorkStack::_get_impl(_3640)->i64;
  _checked_ptr_1<long long> _ptr__3643(_3643 ? _3643->raw() : nullptr,_3643 ? _3643->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3644 = mosek::fusion::p_WorkStack::_get_impl(_3640)->f64;
  _checked_ptr_1<double> _ptr__3644(_3644 ? _3644->raw() : nullptr,_3644 ? _3644->size(0) : 0);
  int _3645 = mosek::fusion::p_WorkStack::_get_impl(_3640)->nd;
  int _3646 = mosek::fusion::p_WorkStack::_get_impl(_3640)->nelem;
  int _3647 = mosek::fusion::p_WorkStack::_get_impl(_3640)->nnz;
  bool _3648 = mosek::fusion::p_WorkStack::_get_impl(_3640)->hassp;
  int _3649 = mosek::fusion::p_WorkStack::_get_impl(_3640)->ptr_base;
  int _3650 = mosek::fusion::p_WorkStack::_get_impl(_3640)->ncodeatom;
  int _3651 = mosek::fusion::p_WorkStack::_get_impl(_3640)->shape_base;
  int _3652 = mosek::fusion::p_WorkStack::_get_impl(_3640)->sp_base;
  int _3653 = mosek::fusion::p_WorkStack::_get_impl(_3640)->nidxs_base;
  int _3654 = mosek::fusion::p_WorkStack::_get_impl(_3640)->cof_base;
  int _3655 = mosek::fusion::p_WorkStack::_get_impl(_3640)->cconst_base;
  int _3656 = mosek::fusion::p_WorkStack::_get_impl(_3640)->codeptr_base;
  int _3657 = mosek::fusion::p_WorkStack::_get_impl(_3640)->code_base;
  int _3658 = p->getNumNonzero();
  int _3659 = _3641->alloci64(_3658);
  p->getSp(mosek::fusion::p_WorkStack::_get_impl(_3641)->i64,_3659);
  int _3660 = _3641->alloci32(p->getNumNonzero());
  std::shared_ptr< monty::ndarray< int,1 > > _3661 = mosek::fusion::p_WorkStack::_get_impl(_3641)->i32;
  _checked_ptr_1<int> _ptr__3661(_3661 ? _3661->raw() : nullptr,_3661 ? _3661->size(0) : 0);
  p->getAllIndexes(_3661,_3660);
  std::shared_ptr< monty::ndarray< long long,1 > > _3662 = mosek::fusion::p_WorkStack::_get_impl(_3641)->i64;
  _checked_ptr_1<long long> _ptr__3662(_3662 ? _3662->raw() : nullptr,_3662 ? _3662->size(0) : 0);
  int _3663 = (int)0;
  int _3664 = (int)1;
  int _3665 = (int)0;
  if (_3648)
  {
    {
      int _3666 = (int)0;
      int _3667 = (int)0;
      while ( ((_3666 < _3646) && (_3667 < _3658)) )
      {
        {
          if ((_ptr__3643[safe_add( _3652,_3666 )] < _ptr__3662[safe_add( _3659,_3667 )]))
          {
            {
              ++ _3666;
            }
          }
          else if((_ptr__3643[safe_add( _3652,_3666 )] > _ptr__3662[safe_add( _3659,_3667 )]))
          {
            {
              ++ _3667;
            }
          }
          else
          {
            {
              int _3668 = (_ptr__3642[safe_add( safe_add( _3649,_3666 ),(int)1 )] - _ptr__3642[safe_add( _3649,_3666 )]);
              _3663 += _3668;
              int _10331;
              bool _10332 = (_3650 > (int)0);
              if (_10332)
              {
                _10331 = safe_add( (_ptr__3642[safe_add( _3656,_ptr__3642[safe_add( safe_add( _3649,_3666 ),(int)1 )] )] - _ptr__3642[safe_add( _3656,_ptr__3642[safe_add( _3649,_3666 )] )]),safe_mul( (int)4,_3668 ) );
              }
              else
              {
                _10331 = safe_mul( (int)3,_3668 );
              }
              _3665 += _10331;
              ++ _3666;
              ++ _3667;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _10333 = (int)0;
      int _10334 = _3658;
      for (int _3669 = _10333; _3669 < _10334; ++_3669)
      {
        {
          _3663 += (_ptr__3642[safe_add( safe_add( _3649,_ptr__3662[safe_add( _3659,_3669 )] ),(int)1 )] - _ptr__3642[safe_add( _3649,_ptr__3662[safe_add( _3659,_3669 )] )]);
        }
      }
      if ((_3650 > (int)0))
      {
        {
          int _10335 = (int)0;
          int _10336 = _3658;
          for (int _3670 = _10335; _3670 < _10336; ++_3670)
          {
            {
              _3665 += safe_add( (_ptr__3642[safe_add( _3656,_ptr__3642[safe_add( safe_add( _3649,_ptr__3662[safe_add( _3659,_3670 )] ),(int)1 )] )] - _ptr__3642[safe_add( _3656,_ptr__3642[safe_add( _3649,_ptr__3662[safe_add( _3659,_3670 )] )] )]),safe_mul( (int)4,(_ptr__3642[safe_add( safe_add( _3649,_ptr__3662[safe_add( _3659,_3670 )] ),(int)1 )] - _ptr__3642[safe_add( _3649,_ptr__3662[safe_add( _3659,_3670 )] )]) ) );
            }
          }
        }
      }
      else
      {
        {
          int _10337 = (int)0;
          int _10338 = _3658;
          for (int _3671 = _10337; _3671 < _10338; ++_3671)
          {
            {
              _3665 += safe_mul( (int)3,(_ptr__3642[safe_add( safe_add( _3649,_ptr__3662[safe_add( _3659,_3671 )] ),(int)1 )] - _ptr__3642[safe_add( _3649,_ptr__3662[safe_add( _3659,_3671 )] )]) );
            }
          }
        }
      }
    }
  }
  long long _3672 = (int)1;
  int _10339 = (int)0;
  int _10340 = _3645;
  for (int _3673 = _10339; _3673 < _10340; ++_3673)
  {
    {
      _3672 *= _ptr__3642[safe_add( _3651,_3673 )];
    }
  }
  _3639->alloc_expr((int)0,_3664,_3663,false,_3665);
  int _3674 = mosek::fusion::p_WorkStack::_get_impl(_3639)->ptr_base;
  int _3675 = mosek::fusion::p_WorkStack::_get_impl(_3639)->nidxs_base;
  int _3676 = mosek::fusion::p_WorkStack::_get_impl(_3639)->cof_base;
  bool _3677 = mosek::fusion::p_WorkStack::_get_impl(_3639)->hassp;
  int _3678 = mosek::fusion::p_WorkStack::_get_impl(_3639)->shape_base;
  int _3679 = mosek::fusion::p_WorkStack::_get_impl(_3639)->codeptr_base;
  int _3680 = mosek::fusion::p_WorkStack::_get_impl(_3639)->code_base;
  int _3681 = mosek::fusion::p_WorkStack::_get_impl(_3639)->cconst_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3682 = mosek::fusion::p_WorkStack::_get_impl(_3639)->i64;
  _checked_ptr_1<long long> _ptr__3682(_3682 ? _3682->raw() : nullptr,_3682 ? _3682->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3683 = mosek::fusion::p_WorkStack::_get_impl(_3639)->f64;
  _checked_ptr_1<double> _ptr__3683(_3683 ? _3683->raw() : nullptr,_3683 ? _3683->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3684 = mosek::fusion::p_WorkStack::_get_impl(_3639)->i32;
  _checked_ptr_1<int> _ptr__3684(_3684 ? _3684->raw() : nullptr,_3684 ? _3684->size(0) : 0);
  _ptr__3684[_3674] = (int)0;
  _ptr__3684[safe_add( _3674,(int)1 )] = _3663;
  _ptr__3684[_3679] = (int)0;
  if (_3648)
  {
    {
      int _3685 = (int)0;
      int _3686 = (int)0;
      int _3687 = (int)0;
      int _3688 = (int)0;
      int _3689 = (int)0;
      while ( ((_3688 < _3646) && (_3689 < _3658)) )
      {
        {
          if ((_ptr__3643[safe_add( _3652,_3688 )] < _ptr__3662[safe_add( _3659,_3689 )]))
          {
            {
              ++ _3688;
            }
          }
          else if((_ptr__3643[safe_add( _3652,_3688 )] > _ptr__3662[safe_add( _3659,_3689 )]))
          {
            {
              ++ _3689;
            }
          }
          else
          {
            {
              int _10341 = _ptr__3642[safe_add( _3649,_3688 )];
              int _10342 = _ptr__3642[safe_add( safe_add( _3649,_3688 ),(int)1 )];
              for (int _3690 = _10341; _3690 < _10342; ++_3690)
              {
                {
                  _ptr__3682[safe_add( _3675,_3686 )] = _ptr__3643[safe_add( _3653,_3690 )];
                  _ptr__3683[safe_add( _3676,_3686 )] = 0.0;
                  _ptr__3684[safe_add( _3680,_3685 )] = 2;
                  _ptr__3683[safe_add( _3681,_3685 )] = _ptr__3644[safe_add( _3654,_3690 )];
                  ++ _3685;
                  if ((_3650 > (int)0))
                  {
                    {
                      int _10343 = _ptr__3642[safe_add( _3656,_3690 )];
                      int _10344 = _ptr__3642[safe_add( safe_add( _3656,_3690 ),(int)1 )];
                      for (int _3691 = _10343; _3691 < _10344; ++_3691)
                      {
                        {
                          _ptr__3684[safe_add( _3680,_3685 )] = _ptr__3642[safe_add( _3657,_3691 )];
                          _ptr__3683[safe_add( _3681,_3685 )] = _ptr__3644[safe_add( _3655,_3691 )];
                          ++ _3685;
                        }
                      }
                      _ptr__3684[safe_add( _3680,_3685 )] = 3;
                      ++ _3685;
                    }
                  }
                  {}
                  _ptr__3684[safe_add( _3680,_3685 )] = 1;
                  _ptr__3683[safe_add( _3681,_3685 )] = _ptr__3661[safe_add( _3660,_3689 )];
                  ++ _3685;
                  _ptr__3684[safe_add( _3680,_3685 )] = 5;
                  ++ _3685;
                  _ptr__3684[safe_add( safe_add( _3679,_3686 ),(int)1 )] = _3685;
                  ++ _3686;
                }
              }
              ++ _3688;
              ++ _3689;
            }
          }
        }
      }
      if ((_3687 != _3664))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: broken elmi"));
        }
      }
      {}
      if ((_3686 != _3663))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: broken nzi"));
        }
      }
      {}
      if ((_3685 != _3665))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: broken codei"));
        }
      }
      {}
    }
  }
  else
  {
    {
      int _3692 = (int)0;
      int _3693 = (int)0;
      int _10345 = (int)0;
      int _10346 = _3658;
      for (int _3694 = _10345; _3694 < _10346; ++_3694)
      {
        {
          int _3695 = _3694;
          long long _3696 = _ptr__3662[safe_add( _3659,_3694 )];
          int _10347 = _ptr__3642[safe_add( _3649,_3696 )];
          int _10348 = _ptr__3642[safe_add( safe_add( _3649,_3696 ),(int)1 )];
          for (int _3697 = _10347; _3697 < _10348; ++_3697)
          {
            {
              _ptr__3682[safe_add( _3675,_3693 )] = _ptr__3643[safe_add( _3653,_3697 )];
              _ptr__3683[safe_add( _3676,_3693 )] = 0.0;
              _ptr__3684[safe_add( _3680,_3692 )] = 2;
              _ptr__3683[safe_add( _3681,_3692 )] = _ptr__3644[safe_add( _3654,_3697 )];
              ++ _3692;
              if ((_3650 > (int)0))
              {
                {
                  int _10349 = _ptr__3642[safe_add( _3656,_3697 )];
                  int _10350 = _ptr__3642[safe_add( safe_add( _3656,_3697 ),(int)1 )];
                  for (int _3698 = _10349; _3698 < _10350; ++_3698)
                  {
                    {
                      _ptr__3684[safe_add( _3680,_3692 )] = _ptr__3642[safe_add( _3657,_3698 )];
                      _ptr__3683[safe_add( _3681,_3692 )] = _ptr__3644[safe_add( _3655,_3698 )];
                      ++ _3692;
                    }
                  }
                  _ptr__3684[safe_add( _3680,_3692 )] = 3;
                  ++ _3692;
                }
              }
              {}
              _ptr__3684[safe_add( _3680,_3692 )] = 1;
              _ptr__3683[safe_add( _3681,_3692 )] = _ptr__3661[safe_add( _3660,_3694 )];
              ++ _3692;
              _ptr__3684[safe_add( _3680,_3692 )] = 5;
              ++ _3692;
              _ptr__3684[safe_add( safe_add( _3679,_3693 ),(int)1 )] = _3692;
              ++ _3693;
            }
          }
        }
      }
      if ((_3693 != _3663))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: invalid nzi"));
        }
      }
      {}
      if ((_3692 != _3665))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: invalid codei"));
        }
      }
      {}
    }
  }
  _3641->clear();
}
std::string mosek::fusion::ExprDotParam :: toString() { return mosek::fusion::p_ExprDotParam::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDotParam::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDotParam("))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDotParam::destroy(){e.reset();p.reset();}void mosek::fusion::ExprDotParam::destroy() { mosek::fusion::p_ExprDotParam::_get_impl(this)->destroy(); }mosek::fusion::ExprMulParamElem::ExprMulParamElem(mosek::fusion::p_ExprMulParamElem *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulParamElem()" << this << std::endl; */ }mosek::fusion::ExprMulParamElem::~ExprMulParamElem() {  /* std::cout << "~ExprMulParamElem()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulParamElem::p_ExprMulParamElem  (::mosek::fusion::ExprMulParamElem * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulParamElem::t mosek::fusion::p_ExprMulParamElem::_new_ExprMulParamElem  (monty::rc_ptr< ::mosek::fusion::Parameter > _3699,    monty::rc_ptr< ::mosek::fusion::Expression > _3700){ return new mosek::fusion::ExprMulParamElem(_3699,_3700); }mosek::fusion::ExprMulParamElem::ExprMulParamElem  (monty::rc_ptr< ::mosek::fusion::Parameter > _3699,    monty::rc_ptr< ::mosek::fusion::Expression > _3700) :    ExprMulParamElem(new mosek::fusion::p_ExprMulParamElem(this)){ mosek::fusion::p_ExprMulParamElem::_get_impl(this)->_initialize(_3699,_3700); }void mosek::fusion::p_ExprMulParamElem::_initialize  (monty::rc_ptr< ::mosek::fusion::Parameter > _3699,    monty::rc_ptr< ::mosek::fusion::Expression > _3700){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_3700->getShape());
    mosek::fusion::p_ExprMulParamElem::_get_impl(::mosek::fusion::ExprMulParamElem::t(_pubthis))->p = _3699;
    mosek::fusion::p_ExprMulParamElem::_get_impl(::mosek::fusion::ExprMulParamElem::t(_pubthis))->e = _3700;
    if ((_3699->getND() != _3700->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    int _10351 = (int)0;
    int _10352 = _3699->getND();
    for (int _3701 = _10351; _3701 < _10352; ++_3701)
    {
      {
        if ((_3699->getDim(_3701) != _3700->getDim(_3701)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprMulParamElem :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3702,monty::rc_ptr< ::mosek::fusion::WorkStack > _3703,monty::rc_ptr< ::mosek::fusion::WorkStack > _3704) { mosek::fusion::p_ExprMulParamElem::_get_impl(this)->eval(_3702,_3703,_3704); }void mosek::fusion::p_ExprMulParamElem::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3702,monty::rc_ptr< ::mosek::fusion::WorkStack > _3703,monty::rc_ptr< ::mosek::fusion::WorkStack > _3704){
  e->eval(_3703,_3702,_3704);
  _3703->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3705 = mosek::fusion::p_WorkStack::_get_impl(_3703)->i32;
  _checked_ptr_1<int> _ptr__3705(_3705 ? _3705->raw() : nullptr,_3705 ? _3705->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3706 = mosek::fusion::p_WorkStack::_get_impl(_3703)->i64;
  _checked_ptr_1<long long> _ptr__3706(_3706 ? _3706->raw() : nullptr,_3706 ? _3706->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3707 = mosek::fusion::p_WorkStack::_get_impl(_3703)->f64;
  _checked_ptr_1<double> _ptr__3707(_3707 ? _3707->raw() : nullptr,_3707 ? _3707->size(0) : 0);
  int _3708 = mosek::fusion::p_WorkStack::_get_impl(_3703)->nd;
  int _3709 = mosek::fusion::p_WorkStack::_get_impl(_3703)->nelem;
  int _3710 = mosek::fusion::p_WorkStack::_get_impl(_3703)->nnz;
  bool _3711 = mosek::fusion::p_WorkStack::_get_impl(_3703)->hassp;
  int _3712 = mosek::fusion::p_WorkStack::_get_impl(_3703)->ptr_base;
  int _3713 = mosek::fusion::p_WorkStack::_get_impl(_3703)->ncodeatom;
  int _3714 = mosek::fusion::p_WorkStack::_get_impl(_3703)->shape_base;
  int _3715 = mosek::fusion::p_WorkStack::_get_impl(_3703)->sp_base;
  int _3716 = mosek::fusion::p_WorkStack::_get_impl(_3703)->nidxs_base;
  int _3717 = mosek::fusion::p_WorkStack::_get_impl(_3703)->cof_base;
  int _3718 = mosek::fusion::p_WorkStack::_get_impl(_3703)->cconst_base;
  int _3719 = mosek::fusion::p_WorkStack::_get_impl(_3703)->codeptr_base;
  int _3720 = mosek::fusion::p_WorkStack::_get_impl(_3703)->code_base;
  int _3721 = p->getNumNonzero();
  int _3722 = _3704->alloci64(_3721);
  p->getSp(mosek::fusion::p_WorkStack::_get_impl(_3704)->i64,_3722);
  int _3723 = _3704->alloci32(p->getNumNonzero());
  std::shared_ptr< monty::ndarray< int,1 > > _3724 = mosek::fusion::p_WorkStack::_get_impl(_3704)->i32;
  _checked_ptr_1<int> _ptr__3724(_3724 ? _3724->raw() : nullptr,_3724 ? _3724->size(0) : 0);
  p->getAllIndexes(_3724,_3723);
  std::shared_ptr< monty::ndarray< long long,1 > > _3725 = mosek::fusion::p_WorkStack::_get_impl(_3704)->i64;
  _checked_ptr_1<long long> _ptr__3725(_3725 ? _3725->raw() : nullptr,_3725 ? _3725->size(0) : 0);
  int _3726 = _3708;
  int _3727 = (int)0;
  int _3728 = (int)0;
  int _3729 = (int)0;
  if (_3711)
  {
    {
      int _3730 = (int)0;
      int _3731 = (int)0;
      while ( ((_3730 < _3709) && (_3731 < _3721)) )
      {
        {
          if ((_ptr__3706[safe_add( _3715,_3730 )] < _ptr__3725[safe_add( _3722,_3731 )]))
          {
            {
              ++ _3730;
            }
          }
          else if((_ptr__3706[safe_add( _3715,_3730 )] > _ptr__3725[safe_add( _3722,_3731 )]))
          {
            {
              ++ _3731;
            }
          }
          else
          {
            {
              int _3732 = (_ptr__3705[safe_add( safe_add( _3712,_3730 ),(int)1 )] - _ptr__3705[safe_add( _3712,_3730 )]);
              _3727 += _3732;
              int _10353;
              bool _10354 = (_3713 > (int)0);
              if (_10354)
              {
                _10353 = safe_add( (_ptr__3705[safe_add( _3719,_ptr__3705[safe_add( safe_add( _3712,_3730 ),(int)1 )] )] - _ptr__3705[safe_add( _3719,_ptr__3705[safe_add( _3712,_3730 )] )]),safe_mul( (int)4,_3732 ) );
              }
              else
              {
                _10353 = safe_mul( (int)3,_3732 );
              }
              _3729 += _10353;
              _3728 += (int)1;
              ++ _3730;
              ++ _3731;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _3728 = _3721;
      int _10355 = (int)0;
      int _10356 = _3721;
      for (int _3733 = _10355; _3733 < _10356; ++_3733)
      {
        {
          _3727 += (_ptr__3705[safe_add( safe_add( _3712,_ptr__3725[safe_add( _3722,_3733 )] ),(int)1 )] - _ptr__3705[safe_add( _3712,_ptr__3725[safe_add( _3722,_3733 )] )]);
        }
      }
      if ((_3713 > (int)0))
      {
        {
          int _10357 = (int)0;
          int _10358 = _3721;
          for (int _3734 = _10357; _3734 < _10358; ++_3734)
          {
            {
              _3729 += safe_add( (_ptr__3705[safe_add( _3719,_ptr__3705[safe_add( safe_add( _3712,_ptr__3725[safe_add( _3722,_3734 )] ),(int)1 )] )] - _ptr__3705[safe_add( _3719,_ptr__3705[safe_add( _3712,_ptr__3725[safe_add( _3722,_3734 )] )] )]),safe_mul( (int)3,(_ptr__3705[safe_add( safe_add( _3712,_ptr__3725[safe_add( _3722,_3734 )] ),(int)1 )] - _ptr__3705[safe_add( _3712,_ptr__3725[safe_add( _3722,_3734 )] )]) ) );
            }
          }
        }
      }
      else
      {
        {
          int _10359 = (int)0;
          int _10360 = _3721;
          for (int _3735 = _10359; _3735 < _10360; ++_3735)
          {
            {
              _3729 += safe_mul( (int)3,(_ptr__3705[safe_add( safe_add( _3712,_ptr__3725[safe_add( _3722,_3735 )] ),(int)1 )] - _ptr__3705[safe_add( _3712,_ptr__3725[safe_add( _3722,_3735 )] )]) );
            }
          }
        }
      }
    }
  }
  long long _3736 = (int)1;
  int _10361 = (int)0;
  int _10362 = _3708;
  for (int _3737 = _10361; _3737 < _10362; ++_3737)
  {
    {
      _3736 *= _ptr__3705[safe_add( _3714,_3737 )];
    }
  }
  bool _3738 = (_3728 < _3736);
  _3702->alloc_expr(_3726,_3728,_3727,_3738,_3729);
  int _3739 = mosek::fusion::p_WorkStack::_get_impl(_3702)->ptr_base;
  int _3740 = mosek::fusion::p_WorkStack::_get_impl(_3702)->nidxs_base;
  int _10363;
  bool _10364 = _3738;
  if (_10364)
  {
    _10363 = mosek::fusion::p_WorkStack::_get_impl(_3702)->sp_base;
  }
  else
  {
    _10363 = _3702->alloci64(_3728);
  }
  int _3741 = _10363;
  int _3742 = mosek::fusion::p_WorkStack::_get_impl(_3702)->cof_base;
  bool _3743 = mosek::fusion::p_WorkStack::_get_impl(_3702)->hassp;
  int _3744 = mosek::fusion::p_WorkStack::_get_impl(_3702)->shape_base;
  int _3745 = mosek::fusion::p_WorkStack::_get_impl(_3702)->codeptr_base;
  int _3746 = mosek::fusion::p_WorkStack::_get_impl(_3702)->code_base;
  int _3747 = mosek::fusion::p_WorkStack::_get_impl(_3702)->cconst_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _3748 = mosek::fusion::p_WorkStack::_get_impl(_3702)->i64;
  _checked_ptr_1<long long> _ptr__3748(_3748 ? _3748->raw() : nullptr,_3748 ? _3748->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3749 = mosek::fusion::p_WorkStack::_get_impl(_3702)->f64;
  _checked_ptr_1<double> _ptr__3749(_3749 ? _3749->raw() : nullptr,_3749 ? _3749->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3750 = mosek::fusion::p_WorkStack::_get_impl(_3702)->i32;
  _checked_ptr_1<int> _ptr__3750(_3750 ? _3750->raw() : nullptr,_3750 ? _3750->size(0) : 0);
  int _10365 = (int)0;
  int _10366 = _3708;
  for (int _3751 = _10365; _3751 < _10366; ++_3751)
  {
    {
      _ptr__3750[safe_add( _3744,_3751 )] = _ptr__3705[safe_add( _3714,_3751 )];
    }
  }
  _ptr__3750[_3739] = (int)0;
  _ptr__3750[_3745] = (int)0;
  if (_3711)
  {
    {
      int _3752 = (int)0;
      int _3753 = (int)0;
      int _3754 = (int)0;
      int _3755 = (int)0;
      int _3756 = (int)0;
      while ( ((_3755 < _3709) && (_3756 < _3721)) )
      {
        {
          if ((_ptr__3706[safe_add( _3715,_3755 )] < _ptr__3725[safe_add( _3722,_3756 )]))
          {
            {
              ++ _3755;
            }
          }
          else if((_ptr__3706[safe_add( _3715,_3755 )] > _ptr__3725[safe_add( _3722,_3756 )]))
          {
            {
              ++ _3756;
            }
          }
          else
          {
            {
              int _10367 = _ptr__3705[safe_add( _3712,_3755 )];
              int _10368 = _ptr__3705[safe_add( safe_add( _3712,_3755 ),(int)1 )];
              for (int _3757 = _10367; _3757 < _10368; ++_3757)
              {
                {
                  _ptr__3748[safe_add( _3740,_3753 )] = _ptr__3706[safe_add( _3716,_3757 )];
                  _ptr__3749[safe_add( _3742,_3753 )] = 0.0;
                  _ptr__3750[safe_add( _3746,_3752 )] = 2;
                  _ptr__3749[safe_add( _3747,_3752 )] = _ptr__3707[safe_add( _3717,_3757 )];
                  ++ _3752;
                  if ((_3713 > (int)0))
                  {
                    {
                      int _10369 = _ptr__3705[safe_add( _3719,_3757 )];
                      int _10370 = _ptr__3705[safe_add( safe_add( _3719,_3757 ),(int)1 )];
                      for (int _3758 = _10369; _3758 < _10370; ++_3758)
                      {
                        {
                          _ptr__3750[safe_add( _3746,_3752 )] = _ptr__3705[safe_add( _3720,_3758 )];
                          _ptr__3749[safe_add( _3747,_3752 )] = _ptr__3707[safe_add( _3718,_3758 )];
                          ++ _3752;
                        }
                      }
                      _ptr__3750[safe_add( _3746,_3752 )] = 3;
                      ++ _3752;
                    }
                  }
                  {}
                  _ptr__3750[safe_add( _3746,_3752 )] = 1;
                  _ptr__3749[safe_add( _3747,_3752 )] = _ptr__3724[safe_add( _3723,_3756 )];
                  ++ _3752;
                  _ptr__3750[safe_add( _3746,_3752 )] = 5;
                  ++ _3752;
                  _ptr__3750[safe_add( safe_add( _3745,_3753 ),(int)1 )] = _3752;
                  ++ _3753;
                }
              }
              _ptr__3748[safe_add( _3741,_3754 )] = _ptr__3706[safe_add( _3715,_3755 )];
              _ptr__3750[safe_add( safe_add( _3739,_3754 ),(int)1 )] = _3753;
              ++ _3754;
              ++ _3755;
              ++ _3756;
            }
          }
        }
      }
      if ((_3754 != _3728))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: broken elmi"));
        }
      }
      {}
      if ((_3753 != _3727))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: broken nzi"));
        }
      }
      {}
      if ((_3752 != _3729))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: broken codei"));
        }
      }
      {}
    }
  }
  else
  {
    {
      int _3759 = (int)0;
      int _3760 = (int)0;
      int _10371 = (int)0;
      int _10372 = _3721;
      for (int _3761 = _10371; _3761 < _10372; ++_3761)
      {
        {
          int _3762 = _3761;
          long long _3763 = _ptr__3725[safe_add( _3722,_3761 )];
          int _10373 = _ptr__3705[safe_add( _3712,_3763 )];
          int _10374 = _ptr__3705[safe_add( safe_add( _3712,_3763 ),(int)1 )];
          for (int _3764 = _10373; _3764 < _10374; ++_3764)
          {
            {
              _ptr__3748[safe_add( _3740,_3760 )] = _ptr__3706[safe_add( _3716,_3764 )];
              _ptr__3749[safe_add( _3742,_3760 )] = 0.0;
              _ptr__3750[safe_add( _3746,_3759 )] = 2;
              _ptr__3749[safe_add( _3747,_3759 )] = _ptr__3707[safe_add( _3717,_3764 )];
              ++ _3759;
              if ((_3713 > (int)0))
              {
                {
                  int _10375 = _ptr__3705[safe_add( _3719,_3764 )];
                  int _10376 = _ptr__3705[safe_add( safe_add( _3719,_3764 ),(int)1 )];
                  for (int _3765 = _10375; _3765 < _10376; ++_3765)
                  {
                    {
                      _ptr__3750[safe_add( _3746,_3759 )] = _ptr__3705[safe_add( _3720,_3765 )];
                      _ptr__3749[safe_add( _3747,_3759 )] = _ptr__3707[safe_add( _3718,_3765 )];
                      ++ _3759;
                    }
                  }
                  _ptr__3750[safe_add( _3746,_3759 )] = 3;
                  ++ _3759;
                }
              }
              {}
              _ptr__3750[safe_add( _3746,_3759 )] = 1;
              _ptr__3749[safe_add( _3747,_3759 )] = _ptr__3724[safe_add( _3723,_3761 )];
              ++ _3759;
              _ptr__3750[safe_add( _3746,_3759 )] = 5;
              ++ _3759;
              _ptr__3750[safe_add( safe_add( _3745,_3760 ),(int)1 )] = _3759;
              ++ _3760;
            }
          }
          _ptr__3748[safe_add( _3741,_3762 )] = _3763;
          _ptr__3750[safe_add( safe_add( _3739,_3762 ),(int)1 )] = _3760;
        }
      }
    }
  }
  if ((!_3743))
  {
    {
      _3702->popi64(_3728);
    }
  }
  {}
  _3704->clear();
}
std::string mosek::fusion::ExprMulParamElem :: toString() { return mosek::fusion::p_ExprMulParamElem::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulParamElem::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulParamElem("))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulParamElem::destroy(){e.reset();p.reset();}void mosek::fusion::ExprMulParamElem::destroy() { mosek::fusion::p_ExprMulParamElem::_get_impl(this)->destroy(); }mosek::fusion::ExprMulParamRight::ExprMulParamRight(mosek::fusion::p_ExprMulParamRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulParamRight()" << this << std::endl; */ }mosek::fusion::ExprMulParamRight::~ExprMulParamRight() {  /* std::cout << "~ExprMulParamRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulParamRight::p_ExprMulParamRight  (::mosek::fusion::ExprMulParamRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulParamRight::t mosek::fusion::p_ExprMulParamRight::_new_ExprMulParamRight  (monty::rc_ptr< ::mosek::fusion::Expression > _3766,    monty::rc_ptr< ::mosek::fusion::Parameter > _3767){ return new mosek::fusion::ExprMulParamRight(_3766,_3767); }mosek::fusion::ExprMulParamRight::ExprMulParamRight  (monty::rc_ptr< ::mosek::fusion::Expression > _3766,    monty::rc_ptr< ::mosek::fusion::Parameter > _3767) :    ExprMulParamRight(new mosek::fusion::p_ExprMulParamRight(this)){ mosek::fusion::p_ExprMulParamRight::_get_impl(this)->_initialize(_3766,_3767); }void mosek::fusion::p_ExprMulParamRight::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _3766,    monty::rc_ptr< ::mosek::fusion::Parameter > _3767){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3766->getDim((int)0)),(int)(_3767->getDim((int)1))}));
    mosek::fusion::p_ExprMulParamRight::_get_impl(::mosek::fusion::ExprMulParamRight::t(_pubthis))->p = _3767;
    mosek::fusion::p_ExprMulParamRight::_get_impl(::mosek::fusion::ExprMulParamRight::t(_pubthis))->e = _3766;
    if (((_3767->getND() != (int)2) || (_3766->getND() != (int)2)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
    if ((_3767->getDim((int)0) != _3766->getDim((int)1)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprMulParamRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3768,monty::rc_ptr< ::mosek::fusion::WorkStack > _3769,monty::rc_ptr< ::mosek::fusion::WorkStack > _3770) { mosek::fusion::p_ExprMulParamRight::_get_impl(this)->eval(_3768,_3769,_3770); }void mosek::fusion::p_ExprMulParamRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3768,monty::rc_ptr< ::mosek::fusion::WorkStack > _3769,monty::rc_ptr< ::mosek::fusion::WorkStack > _3770){
  e->eval(_3769,_3768,_3770);
  _3769->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3771 = mosek::fusion::p_WorkStack::_get_impl(_3769)->i32;
  _checked_ptr_1<int> _ptr__3771(_3771 ? _3771->raw() : nullptr,_3771 ? _3771->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3772 = mosek::fusion::p_WorkStack::_get_impl(_3769)->i64;
  _checked_ptr_1<long long> _ptr__3772(_3772 ? _3772->raw() : nullptr,_3772 ? _3772->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3773 = mosek::fusion::p_WorkStack::_get_impl(_3769)->f64;
  _checked_ptr_1<double> _ptr__3773(_3773 ? _3773->raw() : nullptr,_3773 ? _3773->size(0) : 0);
  int _3774 = mosek::fusion::p_WorkStack::_get_impl(_3769)->nd;
  int _3775 = mosek::fusion::p_WorkStack::_get_impl(_3769)->nelem;
  int _3776 = mosek::fusion::p_WorkStack::_get_impl(_3769)->nnz;
  bool _3777 = mosek::fusion::p_WorkStack::_get_impl(_3769)->hassp;
  int _3778 = mosek::fusion::p_WorkStack::_get_impl(_3769)->ptr_base;
  int _3779 = mosek::fusion::p_WorkStack::_get_impl(_3769)->ncodeatom;
  int _3780 = mosek::fusion::p_WorkStack::_get_impl(_3769)->shape_base;
  int _3781 = mosek::fusion::p_WorkStack::_get_impl(_3769)->sp_base;
  int _3782 = mosek::fusion::p_WorkStack::_get_impl(_3769)->nidxs_base;
  int _3783 = mosek::fusion::p_WorkStack::_get_impl(_3769)->cof_base;
  int _3784 = mosek::fusion::p_WorkStack::_get_impl(_3769)->cconst_base;
  int _3785 = mosek::fusion::p_WorkStack::_get_impl(_3769)->codeptr_base;
  int _3786 = mosek::fusion::p_WorkStack::_get_impl(_3769)->code_base;
  if (((_3774 != (int)2) || ((p->getDim((int)0) != _ptr__3771[safe_add( _3780,(int)1 )]) || (p->getDim((int)1) != _ptr__3771[_3780]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  int _3787 = _ptr__3771[_3780];
  int _3788 = _ptr__3771[safe_add( _3780,(int)1 )];
  int _3789 = p->getDim((int)0);
  int _3790 = p->getDim((int)1);
  int _3791 = p->getNumNonzero();
  int _3792 = _3770->alloci32(p->getNumNonzero());
  std::shared_ptr< monty::ndarray< int,1 > > _3793 = mosek::fusion::p_WorkStack::_get_impl(_3770)->i32;
  _checked_ptr_1<int> _ptr__3793(_3793 ? _3793->raw() : nullptr,_3793 ? _3793->size(0) : 0);
  p->getAllIndexes(_3793,_3792);
  int _3794 = _3770->alloci32(_3791);
  int _3795 = _3770->alloci64(_3791);
  p->getSp(mosek::fusion::p_WorkStack::_get_impl(_3770)->i64,_3795);
  {
    int _3796 = _3770->alloci32(safe_add( _3790,(int)1 ));
    std::shared_ptr< monty::ndarray< int,1 > > _3797 = mosek::fusion::p_WorkStack::_get_impl(_3770)->i32;
    _checked_ptr_1<int> _ptr__3797(_3797 ? _3797->raw() : nullptr,_3797 ? _3797->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _3798 = mosek::fusion::p_WorkStack::_get_impl(_3770)->i64;
    _checked_ptr_1<long long> _ptr__3798(_3798 ? _3798->raw() : nullptr,_3798 ? _3798->size(0) : 0);
    int _10377 = (int)0;
    int _10378 = safe_add( _3790,(int)1 );
    for (int _3799 = _10377; _3799 < _10378; ++_3799)
    {
      {
        _ptr__3797[safe_add( _3796,_3799 )] = (int)0;
      }
    }
    int _10379 = (int)0;
    int _10380 = _3791;
    for (int _3800 = _10379; _3800 < _10380; ++_3800)
    {
      {
        ++ _ptr__3797[safe_add( safe_add( _3796,(_ptr__3798[safe_add( _3795,_3800 )] % _3790) ),(int)1 )];
      }
    }
    int _10381 = (int)0;
    int _10382 = _3790;
    for (int _3801 = _10381; _3801 < _10382; ++_3801)
    {
      {
        _ptr__3797[safe_add( safe_add( _3796,_3801 ),(int)1 )] += _ptr__3797[safe_add( _3796,_3801 )];
      }
    }
    int _10383 = (int)0;
    int _10384 = _3791;
    for (int _3802 = _10383; _3802 < _10384; ++_3802)
    {
      {
        _ptr__3797[safe_add( _3794,_ptr__3797[safe_add( _3796,(_ptr__3798[safe_add( _3795,_3802 )] % _3790) )] )] = _3802;
        ++ _ptr__3797[safe_add( _3796,(_ptr__3798[safe_add( _3795,_3802 )] % _3790) )];
      }
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _3803 = mosek::fusion::p_WorkStack::_get_impl(_3770)->i32;
  _checked_ptr_1<int> _ptr__3803(_3803 ? _3803->raw() : nullptr,_3803 ? _3803->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3804 = mosek::fusion::p_WorkStack::_get_impl(_3770)->i64;
  _checked_ptr_1<long long> _ptr__3804(_3804 ? _3804->raw() : nullptr,_3804 ? _3804->size(0) : 0);
  int _3805 = (int)0;
  int _3806 = (int)0;
  int _3807 = (int)0;
  if (((!p->isSparse()) && (!_3777)))
  {
    {
      _3807 = safe_mul( _3776,_3790 );
      _3806 = safe_mul( _3787,_3790 );
      int _10385;
      bool _10386 = (_3779 > (int)0);
      if (_10386)
      {
        _10385 = safe_mul( safe_add( _3779,safe_mul( _3776,(int)4 ) ),_3790 );
      }
      else
      {
        _10385 = safe_mul( safe_mul( _3776,_3790 ),(int)3 );
      }
      _3805 = _10385;
    }
  }
  else if((!_3777))
  {
    {
      int _3808 = (int)0;
      while ( (_3808 < _3791) )
      {
        {
          long long _3809 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3808 )] )] % _3790);
          int _3810 = _3808;
          while ( ((_3808 < _3791) && ((_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3808 )] )] % _3790) == _3809)) )
          {
            {
              long long _3811 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3808 )] )] / _3790);
              int _10387 = (int)0;
              int _10388 = _3787;
              for (int _3812 = _10387; _3812 < _10388; ++_3812)
              {
                {
                  long long _3813 = safe_add( safe_mul( _3812,_3788 ),_3811 );
                  int _3814 = (_ptr__3771[safe_add( safe_add( _3778,_3813 ),(int)1 )] - _ptr__3771[safe_add( _3778,_3813 )]);
                  _3807 += _3814;
                  int _10389;
                  bool _10390 = (_3779 > (int)0);
                  if (_10390)
                  {
                    _10389 = safe_add( (_ptr__3771[safe_add( _3785,_ptr__3771[safe_add( safe_add( _3778,_3813 ),(int)1 )] )] - _ptr__3771[safe_add( _3785,_ptr__3771[safe_add( _3778,_3813 )] )]),safe_mul( _3814,(int)4 ) );
                  }
                  else
                  {
                    _10389 = safe_mul( _3814,(int)3 );
                  }
                  _3805 += _10389;
                }
              }
              ++ _3808;
            }
          }
          _3806 += _3787;
        }
      }
    }
  }
  else
  {
    {
      int _3815 = (int)0;
      while ( (_3815 < _3775) )
      {
        {
          long long _3816 = (_ptr__3772[safe_add( _3781,_3815 )] / _3788);
          int _3817 = _3815;
          long long _3818 = safe_mul( safe_add( _3816,(int)1 ),_3788 );
          while ( ((_3815 < _3775) && (_ptr__3772[safe_add( _3781,_3815 )] < _3818)) )
          {
            {
              ++ _3815;
            }
          }
          int _3819 = (int)0;
          while ( (_3819 < _3791) )
          {
            {
              long long _3820 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3819 )] )] % _3790);
              int _3821 = _3819;
              while ( ((_3819 < _3791) && (_3820 == (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3819 )] )] % _3790))) )
              {
                {
                  ++ _3819;
                }
              }
              int _3822 = (int)0;
              int _3823 = _3821;
              int _3824 = _3817;
              while ( ((_3824 < _3815) && (_3823 < _3819)) )
              {
                {
                  long long _3825 = (_ptr__3772[safe_add( _3781,_3824 )] % _3788);
                  long long _3826 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3823 )] )] / _3790);
                  if ((_3825 < _3826))
                  {
                    {
                      ++ _3824;
                    }
                  }
                  else if((_3825 > _3826))
                  {
                    {
                      ++ _3823;
                    }
                  }
                  else
                  {
                    {
                      int _3827 = (_ptr__3771[safe_add( safe_add( _3778,_3824 ),(int)1 )] - _ptr__3771[safe_add( _3778,_3824 )]);
                      _3807 += _3827;
                      int _10391;
                      bool _10392 = (_3779 > (int)0);
                      if (_10392)
                      {
                        _10391 = safe_add( (_ptr__3771[safe_add( _3785,_ptr__3771[safe_add( safe_add( _3778,_3824 ),(int)1 )] )] - _ptr__3771[safe_add( _3785,_ptr__3771[safe_add( _3778,_3824 )] )]),safe_mul( _3827,(int)4 ) );
                      }
                      else
                      {
                        _10391 = safe_mul( _3827,(int)3 );
                      }
                      _3805 += _10391;
                      ++ _3824;
                      ++ _3823;
                      ++ _3822;
                    }
                  }
                }
              }
              if ((_3822 > (int)0))
              {
                {
                  ++ _3806;
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  int _3828 = (int)2;
  bool _3829 = (_3806 < safe_mul( _3790,_3787 ));
  _3768->alloc_expr(_3828,_3806,_3807,_3829,_3805);
  std::shared_ptr< monty::ndarray< long long,1 > > _3830 = mosek::fusion::p_WorkStack::_get_impl(_3768)->i64;
  _checked_ptr_1<long long> _ptr__3830(_3830 ? _3830->raw() : nullptr,_3830 ? _3830->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3831 = mosek::fusion::p_WorkStack::_get_impl(_3768)->f64;
  _checked_ptr_1<double> _ptr__3831(_3831 ? _3831->raw() : nullptr,_3831 ? _3831->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _3832 = mosek::fusion::p_WorkStack::_get_impl(_3768)->i32;
  _checked_ptr_1<int> _ptr__3832(_3832 ? _3832->raw() : nullptr,_3832 ? _3832->size(0) : 0);
  int _3833 = mosek::fusion::p_WorkStack::_get_impl(_3768)->ptr_base;
  int _3834 = mosek::fusion::p_WorkStack::_get_impl(_3768)->nidxs_base;
  int _10393;
  bool _10394 = _3829;
  if (_10394)
  {
    _10393 = mosek::fusion::p_WorkStack::_get_impl(_3768)->sp_base;
  }
  else
  {
    _10393 = _3768->alloci64(_3806);
  }
  int _3835 = _10393;
  int _3836 = mosek::fusion::p_WorkStack::_get_impl(_3768)->cof_base;
  bool _3837 = mosek::fusion::p_WorkStack::_get_impl(_3768)->hassp;
  int _3838 = mosek::fusion::p_WorkStack::_get_impl(_3768)->shape_base;
  int _3839 = mosek::fusion::p_WorkStack::_get_impl(_3768)->codeptr_base;
  int _3840 = mosek::fusion::p_WorkStack::_get_impl(_3768)->code_base;
  int _3841 = mosek::fusion::p_WorkStack::_get_impl(_3768)->cconst_base;
  _ptr__3832[_3833] = (int)0;
  _ptr__3832[_3839] = (int)0;
  _ptr__3832[_3838] = _3787;
  _ptr__3832[safe_add( _3838,(int)1 )] = _3790;
  int _3842 = (int)0;
  int _3843 = (int)0;
  int _3844 = (int)0;
  if ((!_3777))
  {
    {
      int _10395 = (int)0;
      int _10396 = _3787;
      for (int _3845 = _10395; _3845 < _10396; ++_3845)
      {
        {
          int _3846 = (int)0;
          while ( (_3846 < _3791) )
          {
            {
              int _3847 = _3846;
              long long _3848 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3846 )] )] % _3790);
              while ( ((_3846 < _3791) && (_3848 == (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3846 )] )] % _3790))) )
              {
                {
                  ++ _3846;
                }
              }
              int _3849 = _3847;
              while ( (_3849 < _3846) )
              {
                {
                  long long _3850 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3849 )] )] / _3790);
                  long long _3851 = safe_add( safe_mul( _3845,_3788 ),_3850 );
                  int _3852 = _ptr__3803[safe_add( _3792,_ptr__3803[safe_add( _3794,_3849 )] )];
                  int _10397 = _ptr__3771[safe_add( _3778,_3851 )];
                  int _10398 = _ptr__3771[safe_add( safe_add( _3778,_3851 ),(int)1 )];
                  for (int _3853 = _10397; _3853 < _10398; ++_3853)
                  {
                    {
                      _ptr__3830[safe_add( _3834,_3844 )] = _ptr__3772[safe_add( _3782,_3853 )];
                      _ptr__3831[safe_add( _3836,_3844 )] = (int)0;
                      _ptr__3832[safe_add( _3840,_3842 )] = 2;
                      _ptr__3831[safe_add( _3841,_3842 )] = _ptr__3773[safe_add( _3783,_3853 )];
                      ++ _3842;
                      if ((_3779 > (int)0))
                      {
                        {
                          int _10399 = _ptr__3771[safe_add( _3785,_3853 )];
                          int _10400 = _ptr__3771[safe_add( safe_add( _3785,_3853 ),(int)1 )];
                          for (int _3854 = _10399; _3854 < _10400; ++_3854)
                          {
                            {
                              _ptr__3832[safe_add( _3840,_3842 )] = _ptr__3771[safe_add( _3786,_3854 )];
                              _ptr__3831[safe_add( _3841,_3842 )] = _ptr__3773[safe_add( _3784,_3854 )];
                              ++ _3842;
                            }
                          }
                          _ptr__3832[safe_add( _3840,_3842 )] = 3;
                          ++ _3842;
                        }
                      }
                      {}
                      _ptr__3832[safe_add( _3840,_3842 )] = 1;
                      _ptr__3831[safe_add( _3841,_3842 )] = _3852;
                      ++ _3842;
                      _ptr__3832[safe_add( _3840,_3842 )] = 5;
                      ++ _3842;
                      _ptr__3832[safe_add( safe_add( _3839,_3844 ),(int)1 )] = _3842;
                      ++ _3844;
                    }
                  }
                  ++ _3849;
                }
              }
              _ptr__3832[safe_add( safe_add( _3833,_3843 ),(int)1 )] = _3844;
              _ptr__3830[safe_add( _3835,_3843 )] = safe_add( safe_mul( _3845,_3790 ),_3848 );
              ++ _3843;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _3855 = (int)0;
      while ( (_3855 < _3775) )
      {
        {
          long long _3856 = (_ptr__3772[safe_add( _3781,_3855 )] / _3788);
          int _3857 = _3855;
          long long _3858 = safe_mul( safe_add( _3856,(int)1 ),_3788 );
          while ( ((_3855 < _3775) && (_ptr__3772[safe_add( _3781,_3855 )] < _3858)) )
          {
            {
              ++ _3855;
            }
          }
          int _3859 = (int)0;
          while ( (_3859 < _3791) )
          {
            {
              long long _3860 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3859 )] )] % _3790);
              int _3861 = _3859;
              while ( ((_3859 < _3791) && (_3860 == (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3859 )] )] % _3790))) )
              {
                {
                  ++ _3859;
                }
              }
              int _3862 = (int)0;
              int _3863 = _3861;
              int _3864 = _3857;
              while ( ((_3864 < _3855) && (_3863 < _3859)) )
              {
                {
                  long long _3865 = (_ptr__3772[safe_add( _3781,_3864 )] % _3788);
                  long long _3866 = (_ptr__3804[safe_add( _3795,_ptr__3803[safe_add( _3794,_3863 )] )] / _3790);
                  if ((_3865 < _3866))
                  {
                    {
                      ++ _3864;
                    }
                  }
                  else if((_3865 > _3866))
                  {
                    {
                      ++ _3863;
                    }
                  }
                  else
                  {
                    {
                      int _3867 = _ptr__3803[safe_add( _3792,_ptr__3803[safe_add( _3794,_3863 )] )];
                      int _10401 = _ptr__3771[safe_add( _3778,_3864 )];
                      int _10402 = _ptr__3771[safe_add( safe_add( _3778,_3864 ),(int)1 )];
                      for (int _3868 = _10401; _3868 < _10402; ++_3868)
                      {
                        {
                          _ptr__3830[safe_add( _3834,_3844 )] = _ptr__3772[safe_add( _3782,_3868 )];
                          _ptr__3831[safe_add( _3836,_3844 )] = (int)0;
                          _ptr__3832[safe_add( _3840,_3842 )] = 2;
                          _ptr__3831[safe_add( _3841,_3842 )] = _ptr__3773[safe_add( _3783,_3868 )];
                          ++ _3842;
                          if ((_3779 > (int)0))
                          {
                            {
                              int _10403 = _ptr__3771[safe_add( _3785,_3868 )];
                              int _10404 = _ptr__3771[safe_add( safe_add( _3785,_3868 ),(int)1 )];
                              for (int _3869 = _10403; _3869 < _10404; ++_3869)
                              {
                                {
                                  _ptr__3832[safe_add( _3840,_3842 )] = _ptr__3771[safe_add( _3786,_3869 )];
                                  _ptr__3831[safe_add( _3841,_3842 )] = _ptr__3773[safe_add( _3784,_3869 )];
                                  ++ _3842;
                                }
                              }
                              _ptr__3832[safe_add( _3840,_3842 )] = 3;
                              ++ _3842;
                            }
                          }
                          {}
                          _ptr__3832[safe_add( _3840,_3842 )] = 1;
                          _ptr__3831[safe_add( _3841,_3842 )] = _3867;
                          ++ _3842;
                          _ptr__3832[safe_add( _3840,_3842 )] = 5;
                          ++ _3842;
                          _ptr__3832[safe_add( safe_add( _3839,_3844 ),(int)1 )] = _3842;
                          ++ _3844;
                        }
                      }
                      ++ _3864;
                      ++ _3863;
                      ++ _3862;
                    }
                  }
                }
              }
              if ((_3862 > (int)0))
              {
                {
                  _ptr__3832[safe_add( safe_add( _3833,_3843 ),(int)1 )] = _3844;
                  _ptr__3830[safe_add( _3835,_3843 )] = safe_add( safe_mul( _3856,_3790 ),_3860 );
                  ++ _3843;
                }
              }
              {}
            }
          }
        }
      }
    }
  }
  if ((!_3837))
  {
    {
      _3768->popi64(_3806);
    }
  }
  {}
  if ((_3843 != _3806))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("broken elmi"));
    }
  }
  {}
  if ((_3844 != _3807))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("broken nzi"));
    }
  }
  {}
  if ((_3842 != _3805))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("broken codei"));
    }
  }
  {}
  _3770->clear();
}
std::string mosek::fusion::ExprMulParamRight :: toString() { return mosek::fusion::p_ExprMulParamRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulParamRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulParamRight("))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulParamRight::destroy(){e.reset();p.reset();}void mosek::fusion::ExprMulParamRight::destroy() { mosek::fusion::p_ExprMulParamRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulParamLeft::ExprMulParamLeft(mosek::fusion::p_ExprMulParamLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulParamLeft()" << this << std::endl; */ }mosek::fusion::ExprMulParamLeft::~ExprMulParamLeft() {  /* std::cout << "~ExprMulParamLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulParamLeft::p_ExprMulParamLeft  (::mosek::fusion::ExprMulParamLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulParamLeft::t mosek::fusion::p_ExprMulParamLeft::_new_ExprMulParamLeft  (monty::rc_ptr< ::mosek::fusion::Parameter > _3870,    monty::rc_ptr< ::mosek::fusion::Expression > _3871){ return new mosek::fusion::ExprMulParamLeft(_3870,_3871); }mosek::fusion::ExprMulParamLeft::ExprMulParamLeft  (monty::rc_ptr< ::mosek::fusion::Parameter > _3870,    monty::rc_ptr< ::mosek::fusion::Expression > _3871) :    ExprMulParamLeft(new mosek::fusion::p_ExprMulParamLeft(this)){ mosek::fusion::p_ExprMulParamLeft::_get_impl(this)->_initialize(_3870,_3871); }void mosek::fusion::p_ExprMulParamLeft::_initialize  (monty::rc_ptr< ::mosek::fusion::Parameter > _3870,    monty::rc_ptr< ::mosek::fusion::Expression > _3871){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_3870->getDim((int)0)),(int)(_3871->getDim((int)1))}));
    mosek::fusion::p_ExprMulParamLeft::_get_impl(::mosek::fusion::ExprMulParamLeft::t(_pubthis))->p = _3870;
    mosek::fusion::p_ExprMulParamLeft::_get_impl(::mosek::fusion::ExprMulParamLeft::t(_pubthis))->e = _3871;
    if (((_3870->getND() != (int)2) || (_3871->getND() != (int)2)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
      }
    }
    {}
    if ((_3870->getDim((int)1) != _3871->getDim((int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprMulParamLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3872,monty::rc_ptr< ::mosek::fusion::WorkStack > _3873,monty::rc_ptr< ::mosek::fusion::WorkStack > _3874) { mosek::fusion::p_ExprMulParamLeft::_get_impl(this)->eval(_3872,_3873,_3874); }void mosek::fusion::p_ExprMulParamLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3872,monty::rc_ptr< ::mosek::fusion::WorkStack > _3873,monty::rc_ptr< ::mosek::fusion::WorkStack > _3874){
  e->eval(_3873,_3872,_3874);
  _3873->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _3875 = mosek::fusion::p_WorkStack::_get_impl(_3873)->i32;
  _checked_ptr_1<int> _ptr__3875(_3875 ? _3875->raw() : nullptr,_3875 ? _3875->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _3876 = mosek::fusion::p_WorkStack::_get_impl(_3873)->i64;
  _checked_ptr_1<long long> _ptr__3876(_3876 ? _3876->raw() : nullptr,_3876 ? _3876->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _3877 = mosek::fusion::p_WorkStack::_get_impl(_3873)->f64;
  _checked_ptr_1<double> _ptr__3877(_3877 ? _3877->raw() : nullptr,_3877 ? _3877->size(0) : 0);
  int _3878 = mosek::fusion::p_WorkStack::_get_impl(_3873)->nd;
  int _3879 = mosek::fusion::p_WorkStack::_get_impl(_3873)->nelem;
  int _3880 = mosek::fusion::p_WorkStack::_get_impl(_3873)->nnz;
  bool _3881 = mosek::fusion::p_WorkStack::_get_impl(_3873)->hassp;
  int _3882 = mosek::fusion::p_WorkStack::_get_impl(_3873)->ncodeatom;
  int _3883 = mosek::fusion::p_WorkStack::_get_impl(_3873)->ptr_base;
  int _3884 = mosek::fusion::p_WorkStack::_get_impl(_3873)->code_base;
  int _3885 = mosek::fusion::p_WorkStack::_get_impl(_3873)->cconst_base;
  int _3886 = mosek::fusion::p_WorkStack::_get_impl(_3873)->codeptr_base;
  int _3887 = mosek::fusion::p_WorkStack::_get_impl(_3873)->shape_base;
  int _3888 = mosek::fusion::p_WorkStack::_get_impl(_3873)->sp_base;
  int _3889 = mosek::fusion::p_WorkStack::_get_impl(_3873)->nidxs_base;
  int _3890 = mosek::fusion::p_WorkStack::_get_impl(_3873)->cof_base;
  int _3891 = mosek::fusion::p_WorkStack::_get_impl(_3873)->cconst_base;
  if (((_3878 != (int)2) || (_ptr__3875[_3887] != p->getDim((int)1))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  int _3892 = p->getDim((int)0);
  int _3893 = p->getDim((int)1);
  int _3894 = _ptr__3875[_3887];
  int _3895 = _ptr__3875[safe_add( _3887,(int)1 )];
  int _3896 = p->getNumNonzero();
  int _3897 = _3874->alloci32(p->getNumNonzero());
  std::shared_ptr< monty::ndarray< int,1 > > _3898 = mosek::fusion::p_WorkStack::_get_impl(_3874)->i32;
  _checked_ptr_1<int> _ptr__3898(_3898 ? _3898->raw() : nullptr,_3898 ? _3898->size(0) : 0);
  p->getAllIndexes(_3898,_3897);
  if (((!_3881) && (!p->isSparse())))
  {
    {
      int _3899 = (int)2;
      int _3900 = safe_mul( _3895,p->getDim((int)0) );
      int _3901 = safe_mul( _3880,p->getDim((int)0) );
      int _10405;
      bool _10406 = (_3882 > (int)0);
      if (_10406)
      {
        _10405 = safe_add( safe_mul( p->getDim((int)0),_3882 ),safe_mul( (int)4,_3901 ) );
      }
      else
      {
        _10405 = safe_mul( (int)3,_3901 );
      }
      int _3902 = _10405;
      bool _3903 = false;
      _3872->alloc_expr(_3899,_3900,_3901,_3903,_3902);
      std::shared_ptr< monty::ndarray< long long,1 > > _3904 = mosek::fusion::p_WorkStack::_get_impl(_3872)->i64;
      _checked_ptr_1<long long> _ptr__3904(_3904 ? _3904->raw() : nullptr,_3904 ? _3904->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3905 = mosek::fusion::p_WorkStack::_get_impl(_3872)->f64;
      _checked_ptr_1<double> _ptr__3905(_3905 ? _3905->raw() : nullptr,_3905 ? _3905->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3906 = mosek::fusion::p_WorkStack::_get_impl(_3872)->i32;
      _checked_ptr_1<int> _ptr__3906(_3906 ? _3906->raw() : nullptr,_3906 ? _3906->size(0) : 0);
      int _3907 = mosek::fusion::p_WorkStack::_get_impl(_3872)->ptr_base;
      int _3908 = mosek::fusion::p_WorkStack::_get_impl(_3872)->nidxs_base;
      int _3909 = mosek::fusion::p_WorkStack::_get_impl(_3872)->cof_base;
      int _3910 = mosek::fusion::p_WorkStack::_get_impl(_3872)->code_base;
      int _3911 = mosek::fusion::p_WorkStack::_get_impl(_3872)->codeptr_base;
      int _3912 = mosek::fusion::p_WorkStack::_get_impl(_3872)->cconst_base;
      bool _3913 = mosek::fusion::p_WorkStack::_get_impl(_3872)->hassp;
      int _3914 = mosek::fusion::p_WorkStack::_get_impl(_3872)->shape_base;
      _ptr__3906[_3914] = _3892;
      _ptr__3906[safe_add( _3914,(int)1 )] = _3895;
      {
        _ptr__3906[_3907] = (int)0;
        _ptr__3906[_3911] = (int)0;
        int _3915 = (int)0;
        int _3916 = (int)0;
        int _3917 = (int)0;
        int _10407 = (int)0;
        int _10408 = p->getDim((int)0);
        for (int _3918 = _10407; _3918 < _10408; ++_3918)
        {
          {
            int _10409 = (int)0;
            int _10410 = e->getDim((int)1);
            for (int _3919 = _10409; _3919 < _10410; ++_3919)
            {
              {
                int _10411 = (int)0;
                int _10412 = p->getDim((int)1);
                for (int _3920 = _10411; _3920 < _10412; ++_3920)
                {
                  {
                    int _10413 = _ptr__3875[safe_add( safe_add( _3883,safe_mul( _3920,_3895 ) ),_3919 )];
                    int _10414 = _ptr__3875[safe_add( safe_add( safe_add( _3883,safe_mul( _3920,_3895 ) ),_3919 ),(int)1 )];
                    for (int _3921 = _10413; _3921 < _10414; ++_3921)
                    {
                      {
                        _ptr__3904[safe_add( _3908,_3915 )] = _ptr__3876[safe_add( _3889,_3921 )];
                        _ptr__3905[safe_add( _3909,_3915 )] = 0.0;
                        _ptr__3906[safe_add( _3910,_3917 )] = 2;
                        _ptr__3905[safe_add( _3912,_3917 )] = _ptr__3877[safe_add( _3890,_3921 )];
                        ++ _3917;
                        if ((_3882 > (int)0))
                        {
                          {
                            int _10415 = _ptr__3875[safe_add( _3886,_3921 )];
                            int _10416 = _ptr__3875[safe_add( safe_add( _3886,_3921 ),(int)1 )];
                            for (int _3922 = _10415; _3922 < _10416; ++_3922)
                            {
                              {
                                _ptr__3906[safe_add( _3910,_3917 )] = _ptr__3875[safe_add( _3884,_3922 )];
                                _ptr__3905[safe_add( _3912,_3917 )] = _ptr__3877[safe_add( _3885,_3922 )];
                                ++ _3917;
                              }
                            }
                            _ptr__3906[safe_add( _3910,_3917 )] = 3;
                            ++ _3917;
                          }
                        }
                        {}
                        _ptr__3906[safe_add( _3910,_3917 )] = 1;
                        _ptr__3905[safe_add( _3912,_3917 )] = _ptr__3898[safe_add( safe_add( _3897,safe_mul( _3918,_3893 ) ),_3920 )];
                        ++ _3917;
                        _ptr__3906[safe_add( _3910,_3917 )] = 5;
                        ++ _3917;
                        _ptr__3906[safe_add( safe_add( _3911,_3915 ),(int)1 )] = _3917;
                        ++ _3915;
                      }
                    }
                  }
                }
                _ptr__3906[safe_add( safe_add( _3907,_3916 ),(int)1 )] = _3915;
                ++ _3916;
              }
            }
          }
        }
        if ((_3917 != _3902))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect a-code length"));
          }
        }
        {}
        if ((_3915 != _3901))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect nnz length"));
          }
        }
        {}
        if ((_3916 != _3900))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect nelem length"));
          }
        }
        {}
        int _10417 = (int)0;
        int _10418 = _3900;
        for (int _3923 = _10417; _3923 < _10418; ++_3923)
        {
          {
            if ((_ptr__3906[safe_add( _3907,_3923 )] > _ptr__3906[safe_add( safe_add( _3907,_3923 ),(int)1 )]))
            {
              {
                throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect ptr indexes"));
              }
            }
            {}
          }
        }
      }
    }
  }
  else if((!_3881))
  {
    {
      int _3924 = _3879;
      int _3925 = _3896;
      int _3926 = _3874->alloci64(_3925);
      std::shared_ptr< monty::ndarray< long long,1 > > _3927 = mosek::fusion::p_WorkStack::_get_impl(_3874)->i64;
      _checked_ptr_1<long long> _ptr__3927(_3927 ? _3927->raw() : nullptr,_3927 ? _3927->size(0) : 0);
      p->getSp(_3927,_3926);
      int _3928 = (int)0;
      int _3929 = (int)0;
      int _3930 = (int)0;
      {
        int _3931 = (int)0;
        while ( (_3931 < _3896) )
        {
          {
            int _3932 = (int)(_ptr__3927[safe_add( _3926,_3931 )] / _3893);
            int _3933 = _3931;
            ++ _3931;
            while ( ((_3931 < _3896) && (_ptr__3927[safe_add( _3926,_3931 )] < safe_mul( safe_add( _3932,(int)1 ),_3893 ))) )
            {
              {
                ++ _3931;
              }
            }
            int _3934 = _3931;
            int _10419 = (int)0;
            int _10420 = _3895;
            for (int _3935 = _10419; _3935 < _10420; ++_3935)
            {
              {
                int _10421 = _3933;
                int _10422 = _3934;
                for (int _3936 = _10421; _3936 < _10422; ++_3936)
                {
                  {
                    long long _3937 = safe_add( safe_mul( (_ptr__3927[safe_add( _3926,_3936 )] % _3893),_3895 ),_3935 );
                    int _3938 = (_ptr__3875[safe_add( safe_add( _3883,_3937 ),(int)1 )] - _ptr__3875[safe_add( _3883,_3937 )]);
                    _3929 += _3938;
                    if ((_3882 > (int)0))
                    {
                      {
                        _3930 += safe_add( (_ptr__3875[safe_add( _3886,_ptr__3875[safe_add( safe_add( _3883,_3937 ),(int)1 )] )] - _ptr__3875[safe_add( _3886,_ptr__3875[safe_add( _3883,_3937 )] )]),safe_mul( (int)4,_3938 ) );
                      }
                    }
                    else
                    {
                      {
                        _3930 += safe_mul( (int)3,_3938 );
                      }
                    }
                  }
                }
                ++ _3928;
              }
            }
          }
        }
      }
      bool _3939 = (_3928 < safe_mul( _3892,_3895 ));
      int _3940 = (int)2;
      _3872->alloc_expr(_3940,_3928,_3929,_3939,_3930);
      std::shared_ptr< monty::ndarray< long long,1 > > _3941 = mosek::fusion::p_WorkStack::_get_impl(_3872)->i64;
      _checked_ptr_1<long long> _ptr__3941(_3941 ? _3941->raw() : nullptr,_3941 ? _3941->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _3942 = mosek::fusion::p_WorkStack::_get_impl(_3872)->f64;
      _checked_ptr_1<double> _ptr__3942(_3942 ? _3942->raw() : nullptr,_3942 ? _3942->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _3943 = mosek::fusion::p_WorkStack::_get_impl(_3872)->i32;
      _checked_ptr_1<int> _ptr__3943(_3943 ? _3943->raw() : nullptr,_3943 ? _3943->size(0) : 0);
      int _3944 = mosek::fusion::p_WorkStack::_get_impl(_3872)->ptr_base;
      int _3945 = mosek::fusion::p_WorkStack::_get_impl(_3872)->nidxs_base;
      int _10423;
      bool _10424 = _3939;
      if (_10424)
      {
        _10423 = mosek::fusion::p_WorkStack::_get_impl(_3872)->sp_base;
      }
      else
      {
        _10423 = _3872->alloci64(_3928);
      }
      int _3946 = _10423;
      int _3947 = mosek::fusion::p_WorkStack::_get_impl(_3872)->cof_base;
      bool _3948 = mosek::fusion::p_WorkStack::_get_impl(_3872)->hassp;
      int _3949 = mosek::fusion::p_WorkStack::_get_impl(_3872)->shape_base;
      int _3950 = mosek::fusion::p_WorkStack::_get_impl(_3872)->codeptr_base;
      int _3951 = mosek::fusion::p_WorkStack::_get_impl(_3872)->code_base;
      int _3952 = mosek::fusion::p_WorkStack::_get_impl(_3872)->cconst_base;
      _ptr__3943[_3949] = _3892;
      _ptr__3943[safe_add( _3949,(int)1 )] = _3895;
      {
        int _3953 = (int)0;
        int _3954 = (int)0;
        int _3955 = (int)0;
        _ptr__3943[_3950] = (int)0;
        _ptr__3943[_3944] = (int)0;
        int _10425 = (int)0;
        int _10426 = _3929;
        for (int _3956 = _10425; _3956 < _10426; ++_3956)
        {
          {
            _ptr__3942[safe_add( _3947,_3956 )] = 0.0;
          }
        }
        int _3957 = (int)0;
        while ( (_3957 < _3896) )
        {
          {
            int _3958 = (int)(_ptr__3927[safe_add( _3926,_3957 )] / _3893);
            int _3959 = _3957;
            ++ _3957;
            while ( ((_3957 < _3896) && (_ptr__3927[safe_add( _3926,_3957 )] < safe_mul( safe_add( _3958,(int)1 ),_3893 ))) )
            {
              {
                ++ _3957;
              }
            }
            int _3960 = _3957;
            int _10427 = (int)0;
            int _10428 = _3895;
            for (int _3961 = _10427; _3961 < _10428; ++_3961)
            {
              {
                int _10429 = _3959;
                int _10430 = _3960;
                for (int _3962 = _10429; _3962 < _10430; ++_3962)
                {
                  {
                    long long _3963 = safe_add( safe_mul( (_ptr__3927[safe_add( _3926,_3962 )] % _3893),_3895 ),_3961 );
                    int _10431 = _ptr__3875[safe_add( _3883,_3963 )];
                    int _10432 = _ptr__3875[safe_add( safe_add( _3883,_3963 ),(int)1 )];
                    for (int _3964 = _10431; _3964 < _10432; ++_3964)
                    {
                      {
                        _ptr__3941[safe_add( _3945,_3953 )] = _ptr__3876[safe_add( _3889,_3964 )];
                        _ptr__3943[safe_add( _3951,_3955 )] = 2;
                        _ptr__3942[safe_add( _3952,_3955 )] = _ptr__3877[safe_add( _3890,_3964 )];
                        ++ _3955;
                        if ((_3882 > (int)0))
                        {
                          {
                            int _10433 = _ptr__3875[safe_add( _3886,_3964 )];
                            int _10434 = _ptr__3875[safe_add( safe_add( _3886,_3964 ),(int)1 )];
                            for (int _3965 = _10433; _3965 < _10434; ++_3965)
                            {
                              {
                                _ptr__3943[safe_add( _3951,_3955 )] = _ptr__3875[safe_add( _3884,_3965 )];
                                _ptr__3942[safe_add( _3952,_3955 )] = _ptr__3877[safe_add( _3885,_3965 )];
                                ++ _3955;
                              }
                            }
                            _ptr__3943[safe_add( _3951,_3955 )] = 3;
                            ++ _3955;
                          }
                        }
                        {}
                        _ptr__3943[safe_add( _3951,_3955 )] = 1;
                        _ptr__3942[safe_add( _3952,_3955 )] = _ptr__3898[safe_add( _3897,_3962 )];
                        ++ _3955;
                        _ptr__3943[safe_add( _3951,_3955 )] = 5;
                        ++ _3955;
                        _ptr__3943[safe_add( safe_add( _3950,_3953 ),(int)1 )] = _3955;
                        ++ _3953;
                      }
                    }
                  }
                }
                _ptr__3943[safe_add( safe_add( _3944,_3954 ),(int)1 )] = _3953;
                ++ _3954;
              }
            }
          }
        }
        if ((_3955 != _3930))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect code list"));
          }
        }
        {}
        if ((_3953 != _3929))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect nnz length"));
          }
        }
        {}
        if ((_3954 != _3928))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect nelem length"));
          }
        }
        {}
        if ((_ptr__3943[safe_add( _3944,_3928 )] != _3929))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect ptr"));
          }
        }
        {}
      }
      if ((!_3948))
      {
        {
          _3872->popi64(_3928);
        }
      }
      {}
      _3874->clear();
    }
  }
  else
  {
    {
      int _3966 = _3879;
      int _3967 = _3874->alloci32(_3966);
      int _3968 = p->getNumNonzero();
      int _3969 = _3874->alloci64(_3968);
      int _3970 = _3874->alloci32(safe_add( _ptr__3875[safe_add( _3887,(int)1 )],(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _3971 = mosek::fusion::p_WorkStack::_get_impl(_3874)->i32;
      _checked_ptr_1<int> _ptr__3971(_3971 ? _3971->raw() : nullptr,_3971 ? _3971->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _3972 = mosek::fusion::p_WorkStack::_get_impl(_3874)->i64;
      _checked_ptr_1<long long> _ptr__3972(_3972 ? _3972->raw() : nullptr,_3972 ? _3972->size(0) : 0);
      p->getSp(_3972,_3969);
      {
        int _3973 = _ptr__3875[safe_add( _3887,(int)1 )];
        int _10435 = (int)0;
        int _10436 = safe_add( _ptr__3875[safe_add( _3887,(int)1 )],(int)1 );
        for (int _3974 = _10435; _3974 < _10436; ++_3974)
        {
          {
            _ptr__3971[safe_add( _3970,_3974 )] = (int)0;
          }
        }
        int _10437 = (int)0;
        int _10438 = _3879;
        for (int _3975 = _10437; _3975 < _10438; ++_3975)
        {
          {
            ++ _ptr__3971[safe_add( safe_add( _3970,(_ptr__3876[safe_add( _3888,_3975 )] % _3973) ),(int)1 )];
          }
        }
        int _10439 = (int)0;
        int _10440 = _3973;
        for (int _3976 = _10439; _3976 < _10440; ++_3976)
        {
          {
            _ptr__3971[safe_add( safe_add( _3970,_3976 ),(int)1 )] += _ptr__3971[safe_add( _3970,_3976 )];
          }
        }
        int _10441 = (int)0;
        int _10442 = _3879;
        for (int _3977 = _10441; _3977 < _10442; ++_3977)
        {
          {
            _ptr__3971[safe_add( _3967,_ptr__3971[safe_add( _3970,(_ptr__3876[safe_add( _3888,_3977 )] % _3973) )] )] = _3977;
            ++ _ptr__3971[safe_add( _3970,(_ptr__3876[safe_add( _3888,_3977 )] % _3973) )];
          }
        }
      }
      int _3978 = (int)0;
      int _3979 = (int)0;
      int _3980 = (int)0;
      int _3981 = _ptr__3875[safe_add( _3887,(int)1 )];
      int _3982 = _ptr__3875[_3887];
      int _3983 = p->getDim((int)1);
      int _3984 = p->getDim((int)0);
      {
        int _3985 = (int)0;
        while ( (_3985 < _3968) )
        {
          {
            int _3986 = _3985;
            long long _3987 = (_ptr__3972[safe_add( _3969,_3985 )] / _3983);
            while ( ((_3985 < _3968) && (_ptr__3972[safe_add( _3969,_3985 )] < safe_mul( safe_add( _3987,(int)1 ),_3983 ))) )
            {
              {
                ++ _3985;
              }
            }
            int _3988 = (int)0;
            while ( (_3988 < _3879) )
            {
              {
                int _3989 = _3988;
                long long _3990 = (_ptr__3876[safe_add( _3888,_ptr__3971[safe_add( _3967,_3988 )] )] % _3981);
                ++ _3988;
                while ( ((_3988 < _3879) && ((_ptr__3876[safe_add( _3888,_ptr__3971[safe_add( _3967,_3988 )] )] % _3981) == _3990)) )
                {
                  {
                    ++ _3988;
                  }
                }
                int _3991 = _3989;
                int _3992 = _3986;
                bool _3993 = false;
                int _3994 = (int)0;
                while ( ((_3992 < _3985) && (_3991 < _3988)) )
                {
                  {
                    int _3995 = _ptr__3971[safe_add( _3967,_3991 )];
                    if (((_ptr__3972[safe_add( _3969,_3992 )] % _3983) < (_ptr__3876[safe_add( _3888,_3995 )] / _3981)))
                    {
                      {
                        ++ _3992;
                      }
                    }
                    else if(((_ptr__3972[safe_add( _3969,_3992 )] % _3983) > (_ptr__3876[safe_add( _3888,_3995 )] / _3981)))
                    {
                      {
                        ++ _3991;
                      }
                    }
                    else
                    {
                      {
                        int _3996 = (_ptr__3875[safe_add( safe_add( _3883,_3995 ),(int)1 )] - _ptr__3875[safe_add( _3883,_3995 )]);
                        _3979 += _3996;
                        int _10443;
                        bool _10444 = (_3882 > (int)0);
                        if (_10444)
                        {
                          _10443 = safe_add( (_ptr__3875[safe_add( _3886,_ptr__3875[safe_add( safe_add( _3883,_3995 ),(int)1 )] )] - _ptr__3875[safe_add( _3886,_ptr__3875[safe_add( _3883,_3995 )] )]),safe_mul( (int)4,_3996 ) );
                        }
                        else
                        {
                          _10443 = safe_mul( (int)3,_3996 );
                        }
                        _3980 += _10443;
                        ++ _3991;
                        ++ _3992;
                        ++ _3994;
                      }
                    }
                  }
                }
                if ((_3994 > (int)0))
                {
                  {
                    ++ _3978;
                  }
                }
                {}
              }
            }
          }
        }
      }
      int _3997 = (int)2;
      bool _3998 = (_3978 < safe_mul( _3984,_3981 ));
      _3872->alloc_expr(_3997,_3978,_3979,_3998,_3980);
      std::shared_ptr< monty::ndarray< long long,1 > > _3999 = mosek::fusion::p_WorkStack::_get_impl(_3872)->i64;
      _checked_ptr_1<long long> _ptr__3999(_3999 ? _3999->raw() : nullptr,_3999 ? _3999->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4000 = mosek::fusion::p_WorkStack::_get_impl(_3872)->f64;
      _checked_ptr_1<double> _ptr__4000(_4000 ? _4000->raw() : nullptr,_4000 ? _4000->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4001 = mosek::fusion::p_WorkStack::_get_impl(_3872)->i32;
      _checked_ptr_1<int> _ptr__4001(_4001 ? _4001->raw() : nullptr,_4001 ? _4001->size(0) : 0);
      int _4002 = mosek::fusion::p_WorkStack::_get_impl(_3872)->ptr_base;
      int _4003 = mosek::fusion::p_WorkStack::_get_impl(_3872)->nidxs_base;
      int _10445;
      bool _10446 = _3998;
      if (_10446)
      {
        _10445 = mosek::fusion::p_WorkStack::_get_impl(_3872)->sp_base;
      }
      else
      {
        _10445 = _3872->alloci64(_3978);
      }
      int _4004 = _10445;
      int _4005 = mosek::fusion::p_WorkStack::_get_impl(_3872)->cof_base;
      int _4006 = mosek::fusion::p_WorkStack::_get_impl(_3872)->shape_base;
      int _4007 = mosek::fusion::p_WorkStack::_get_impl(_3872)->codeptr_base;
      int _4008 = mosek::fusion::p_WorkStack::_get_impl(_3872)->code_base;
      int _4009 = mosek::fusion::p_WorkStack::_get_impl(_3872)->cconst_base;
      int _10447 = (int)0;
      int _10448 = safe_add( _3978,(int)1 );
      for (int _4010 = _10447; _4010 < _10448; ++_4010)
      {
        {
          _ptr__4001[safe_add( _4002,_4010 )] = (-(int)9999);
        }
      }
      {
        _ptr__4001[_4002] = (int)0;
        _ptr__4001[_4007] = (int)0;
        _ptr__4001[_4006] = _3984;
        _ptr__4001[safe_add( _4006,(int)1 )] = _3981;
        int _4011 = (int)0;
        int _4012 = (int)0;
        int _4013 = (int)0;
        int _10449 = (int)0;
        int _10450 = _3979;
        for (int _4014 = _10449; _4014 < _10450; ++_4014)
        {
          {
            _ptr__4000[safe_add( _4005,_4014 )] = 0.0;
          }
        }
        int _4015 = (int)0;
        while ( (_4015 < _3968) )
        {
          {
            int _4016 = _4015;
            long long _4017 = (_ptr__3972[safe_add( _3969,_4015 )] / _3983);
            while ( ((_4015 < _3968) && (_ptr__3972[safe_add( _3969,_4015 )] < safe_mul( safe_add( _4017,(int)1 ),_3983 ))) )
            {
              {
                ++ _4015;
              }
            }
            int _4018 = (int)0;
            while ( (_4018 < _3879) )
            {
              {
                int _4019 = _4018;
                long long _4020 = (_ptr__3876[safe_add( _3888,_ptr__3971[safe_add( _3967,_4018 )] )] % _3981);
                ++ _4018;
                while ( ((_4018 < _3879) && ((_ptr__3876[safe_add( _3888,_ptr__3971[safe_add( _3967,_4018 )] )] % _3981) == _4020)) )
                {
                  {
                    ++ _4018;
                  }
                }
                int _4021 = _4019;
                int _4022 = _4016;
                int _4023 = (int)0;
                while ( ((_4022 < _4015) && (_4021 < _4018)) )
                {
                  {
                    int _4024 = _ptr__3971[safe_add( _3967,_4021 )];
                    if (((_ptr__3972[safe_add( _3969,_4022 )] % _3983) < (_ptr__3876[safe_add( _3888,_4024 )] / _3981)))
                    {
                      {
                        ++ _4022;
                      }
                    }
                    else if(((_ptr__3972[safe_add( _3969,_4022 )] % _3983) > (_ptr__3876[safe_add( _3888,_4024 )] / _3981)))
                    {
                      {
                        ++ _4021;
                      }
                    }
                    else
                    {
                      {
                        int _10451 = _ptr__3875[safe_add( _3883,_4024 )];
                        int _10452 = _ptr__3875[safe_add( safe_add( _3883,_4024 ),(int)1 )];
                        for (int _4025 = _10451; _4025 < _10452; ++_4025)
                        {
                          {
                            _ptr__3999[safe_add( _4003,_4011 )] = _ptr__3876[safe_add( _3889,_4025 )];
                            _ptr__4001[safe_add( _4008,_4013 )] = 2;
                            _ptr__4000[safe_add( _4009,_4013 )] = _ptr__3877[safe_add( _3890,_4025 )];
                            ++ _4013;
                            if ((_3882 > (int)0))
                            {
                              {
                                int _10453 = _ptr__3875[safe_add( _3886,_4025 )];
                                int _10454 = _ptr__3875[safe_add( safe_add( _3886,_4025 ),(int)1 )];
                                for (int _4026 = _10453; _4026 < _10454; ++_4026)
                                {
                                  {
                                    _ptr__4001[safe_add( _4008,_4013 )] = _ptr__3875[safe_add( _3884,_4026 )];
                                    _ptr__4000[safe_add( _4009,_4013 )] = _ptr__3877[safe_add( _3885,_4026 )];
                                    ++ _4013;
                                  }
                                }
                                _ptr__4001[safe_add( _4008,_4013 )] = 3;
                                ++ _4013;
                              }
                            }
                            {}
                            _ptr__4001[safe_add( _4008,_4013 )] = 1;
                            _ptr__4000[safe_add( _4009,_4013 )] = _ptr__3971[safe_add( _3897,_4022 )];
                            ++ _4013;
                            _ptr__4001[safe_add( _4008,_4013 )] = 5;
                            ++ _4013;
                            _ptr__4001[safe_add( safe_add( _4007,_4011 ),(int)1 )] = _4013;
                            ++ _4011;
                          }
                        }
                        ++ _4023;
                        ++ _4022;
                        ++ _4021;
                      }
                    }
                  }
                }
                if ((_4023 > (int)0))
                {
                  {
                    _ptr__3999[safe_add( _4004,_4012 )] = safe_add( safe_mul( _4017,_3981 ),_4020 );
                    _ptr__4001[safe_add( safe_add( _4002,_4012 ),(int)1 )] = _4011;
                    ++ _4012;
                  }
                }
                {}
              }
            }
          }
        }
        if ((_4013 != _3980))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect a-code length"));
          }
        }
        {}
        if ((_4011 != _3979))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect nnz length"));
          }
        }
        {}
        if ((_4012 != _3978))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect nelem length"));
          }
        }
        {}
        if ((_ptr__4001[safe_add( _4002,_4012 )] != _3979))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal! Incorrect ptr"));
          }
        }
        {}
      }
      if ((!_3998))
      {
        {
          _3872->popi64(_3978);
        }
      }
      {}
    }
  }
  _3874->clear();
}
std::string mosek::fusion::ExprMulParamLeft :: toString() { return mosek::fusion::p_ExprMulParamLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulParamLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulParamLeft("))->__mosek_2fusion_2Utils_2StringBuffer__a(p->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulParamLeft::destroy(){e.reset();p.reset();}void mosek::fusion::ExprMulParamLeft::destroy() { mosek::fusion::p_ExprMulParamLeft::_get_impl(this)->destroy(); }mosek::fusion::ParameterImpl::ParameterImpl(mosek::fusion::p_ParameterImpl *_impl) : _impl(_impl) { /*std::cout << "ParameterImpl() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::ParameterImpl::~ParameterImpl() { delete _impl; _impl = nullptr; }mosek::fusion::p_ParameterImpl::p_ParameterImpl  (::mosek::fusion::ParameterImpl * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::ParameterImpl::t mosek::fusion::p_ParameterImpl::_new_ParameterImpl  (monty::rc_ptr< ::mosek::fusion::ParameterImpl > _4027,    monty::rc_ptr< ::mosek::fusion::Model > _4028){ return new mosek::fusion::ParameterImpl(_4027,_4028); }mosek::fusion::ParameterImpl::ParameterImpl  (monty::rc_ptr< ::mosek::fusion::ParameterImpl > _4027,    monty::rc_ptr< ::mosek::fusion::Model > _4028) :    ParameterImpl(new mosek::fusion::p_ParameterImpl(this)){ mosek::fusion::p_ParameterImpl::_get_impl(this)->_initialize(_4027,_4028); }void mosek::fusion::p_ParameterImpl::_initialize  (monty::rc_ptr< ::mosek::fusion::ParameterImpl > _4027,    monty::rc_ptr< ::mosek::fusion::Model > _4028){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->model = _4028;
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->shape = mosek::fusion::p_ParameterImpl::_get_impl(_4027)->shape;
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->sp = mosek::fusion::p_ParameterImpl::_get_impl(_4027)->sp;
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->size = mosek::fusion::p_ParameterImpl::_get_impl(_4027)->size;
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->nidxs = mosek::fusion::p_ParameterImpl::_get_impl(_4027)->nidxs;
  }
}mosek::fusion::ParameterImpl::t mosek::fusion::p_ParameterImpl::_new_ParameterImpl  (monty::rc_ptr< ::mosek::fusion::Model > _4029,    std::shared_ptr< monty::ndarray< int,1 > > _4030,    std::shared_ptr< monty::ndarray< long long,1 > > _4031,    std::shared_ptr< monty::ndarray< int,1 > > _4032){ return new mosek::fusion::ParameterImpl(_4029,_4030,_4031,_4032); }mosek::fusion::ParameterImpl::ParameterImpl  (monty::rc_ptr< ::mosek::fusion::Model > _4029,    std::shared_ptr< monty::ndarray< int,1 > > _4030,    std::shared_ptr< monty::ndarray< long long,1 > > _4031,    std::shared_ptr< monty::ndarray< int,1 > > _4032) :    ParameterImpl(new mosek::fusion::p_ParameterImpl(this)){ mosek::fusion::p_ParameterImpl::_get_impl(this)->_initialize(_4029,_4030,_4031,_4032); }void mosek::fusion::p_ParameterImpl::_initialize  (monty::rc_ptr< ::mosek::fusion::Model > _4029,    std::shared_ptr< monty::ndarray< int,1 > > _4030,    std::shared_ptr< monty::ndarray< long long,1 > > _4031,    std::shared_ptr< monty::ndarray< int,1 > > _4032){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4030(_4030 ? _4030->raw() : nullptr, _4030 ? _4030->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4031(_4031 ? _4031->raw() : nullptr, _4031 ? _4031->size(0) : 0);
    _checked_ptr_1<int> _ptr__4032(_4032 ? _4032->raw() : nullptr, _4032 ? _4032->size(0) : 0);
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->model = _4029;
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->shape = ::mosek::fusion::Utils::Tools::arraycopy(_4030);
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->sp = _4031;
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->size = ::mosek::fusion::p_Set::size(_4030);
    mosek::fusion::p_ParameterImpl::_get_impl(::mosek::fusion::ParameterImpl::t(_pubthis))->nidxs = ::mosek::fusion::Utils::Tools::arraycopy(_4032);
  }
}monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__clone(monty::rc_ptr< ::mosek::fusion::Model > _4033) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__clone(_4033); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::clone(monty::rc_ptr< ::mosek::fusion::Model > _4033) { return __mosek_2fusion_2ParameterImpl__clone(_4033); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::__mosek_2fusion_2Parameter__clone(monty::rc_ptr< ::mosek::fusion::Model > _4033) { return __mosek_2fusion_2ParameterImpl__clone(_4033); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__clone(monty::rc_ptr< ::mosek::fusion::Model > _4033){
  return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(::mosek::fusion::ParameterImpl::t(_pubthis),_4033)).as<::mosek::fusion::Parameter>();
}
std::string mosek::fusion::ParameterImpl :: toString() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->toString(); }std::string mosek::fusion::p_ParameterImpl::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4034 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Parameter(("));
  if (((int)((shape)->size(0)) > (int)0))
  {
    {
      _4034->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)((int)0)));
      int _10455 = (int)1;
      int _10456 = (int)((shape)->size(0));
      for (int _4035 = _10455; _4035 < _10456; ++_4035)
      {
        {
          _4034->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*shape)(_4035)));
        }
      }
    }
  }
  {}
  _4034->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  if ((NULL != sp.get()))
  {
    {
      _4034->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",sparse"));
    }
  }
  {}
  _4034->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4034->toString();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__pick(std::shared_ptr< monty::ndarray< int,2 > > _4036) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__pick(_4036); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::pick(std::shared_ptr< monty::ndarray< int,2 > > _4036) { return __mosek_2fusion_2ParameterImpl__pick(_4036); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4036) { return __mosek_2fusion_2ParameterImpl__pick(_4036); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__pick(std::shared_ptr< monty::ndarray< int,2 > > _4036){
  throw ::mosek::fusion::UnimplementedError(std::string ("Not implemented"));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__pick(std::shared_ptr< monty::ndarray< int,1 > > _4037) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__pick(_4037); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::pick(std::shared_ptr< monty::ndarray< int,1 > > _4037) { return __mosek_2fusion_2ParameterImpl__pick(_4037); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4037) { return __mosek_2fusion_2ParameterImpl__pick(_4037); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__pick(std::shared_ptr< monty::ndarray< int,1 > > _4037){
  _checked_ptr_1<int> _ptr__4037(_4037 ? _4037->raw() : nullptr, _4037 ? _4037->size(0) : 0);
  throw ::mosek::fusion::UnimplementedError(std::string ("Not implemented"));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__index(std::shared_ptr< monty::ndarray< int,1 > > _4038) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__index(_4038); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::index(std::shared_ptr< monty::ndarray< int,1 > > _4038) { return __mosek_2fusion_2ParameterImpl__index(_4038); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4038) { return __mosek_2fusion_2ParameterImpl__index(_4038); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__index(std::shared_ptr< monty::ndarray< int,1 > > _4038){
  _checked_ptr_1<int> _ptr__4038(_4038 ? _4038->raw() : nullptr, _4038 ? _4038->size(0) : 0);
  if (((int)((shape)->size(0)) != (int)((_4038)->size(0))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Index has incorrect dimension"));
    }
  }
  else
  {
    {
      int _10457 = (int)0;
      int _10458 = (int)((_4038)->size(0));
      for (int _4039 = _10457; _4039 < _10458; ++_4039)
      {
        {
          if (((_ptr__4038[_4039] < (int)0) || (_ptr__4038[_4039] >= ((*shape)(_4039)))))
          {
            {
              throw ::mosek::fusion::IndexError(std::string ("Index out of bounds"));
            }
          }
          {}
        }
      }
    }
  }
  if ((NULL == sp.get()))
  {
    {
      int _4040 = (int)((_4038)->size(0));
      long long _4041 = _ptr__4038[(_4040 - (int)1)];
      int _10459 = (int)1;
      int _10460 = _4040;
      for (int _4042 = _10459; _4042 < _10460; ++_4042)
      {
        {
          _4041 = safe_add( safe_mul( _4041,((*shape)((_4040 - _4042))) ),_ptr__4038[((_4040 - _4042) - (int)1)] );
        }
      }
      return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nidxs)(_4041)))}))).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _4043 = (int)((_4038)->size(0));
      long long _4044 = _ptr__4038[(_4043 - (int)1)];
      int _10461 = (int)1;
      int _10462 = _4043;
      for (int _4045 = _10461; _4045 < _10462; ++_4045)
      {
        {
          _4044 = safe_add( safe_mul( _4044,((*shape)((_4043 - _4045))) ),_ptr__4038[((_4043 - _4045) - (int)1)] );
        }
      }
      int _4046 = (int)0;
      while ( ((_4046 < (int)((sp)->size(0))) && (((*sp)(_4046)) < _4044)) )
      {
        {
          ++ _4046;
        }
      }
      if (((_4046 < (int)((sp)->size(0))) && (((*sp)(_4046)) == _4044)))
      {
        {
          return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nidxs)(_4046)))}))).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__index(int _4047) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__index(_4047); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::index(int _4047) { return __mosek_2fusion_2ParameterImpl__index(_4047); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::__mosek_2fusion_2Expression__index(int _4047) { return __mosek_2fusion_2ParameterImpl__index(_4047); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__index(int _4047){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Index has incorrect dimension"));
    }
  }
  else if(((_4047 < (int)0) || (_4047 >= ((*shape)((int)0)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out of bounds"));
    }
  }
  {}
  if ((NULL == sp.get()))
  {
    {
      return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nidxs)(_4047)))}))).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _4048 = (int)0;
      while ( ((_4048 < (int)((sp)->size(0))) && (((*sp)(_4048)) < _4047)) )
      {
        {
          ++ _4048;
        }
      }
      if (((_4048 < (int)((sp)->size(0))) && (((*sp)(_4048)) == _4047)))
      {
        {
          return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((*nidxs)(_4048)))}))).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))))).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
void mosek::fusion::ParameterImpl :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4049,monty::rc_ptr< ::mosek::fusion::WorkStack > _4050,monty::rc_ptr< ::mosek::fusion::WorkStack > _4051) { mosek::fusion::p_ParameterImpl::_get_impl(this)->eval(_4049,_4050,_4051); }void mosek::fusion::p_ParameterImpl::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4049,monty::rc_ptr< ::mosek::fusion::WorkStack > _4050,monty::rc_ptr< ::mosek::fusion::WorkStack > _4051){
  int _4052 = (int)((shape)->size(0));
  int _4053 = (int)((nidxs)->size(0));
  bool _4054 = (NULL != sp.get());
  _4049->alloc_expr(_4052,_4053,(int)((nidxs)->size(0)),_4054,(int)((nidxs)->size(0)));
  std::shared_ptr< monty::ndarray< int,1 > > _4055 = mosek::fusion::p_WorkStack::_get_impl(_4049)->i32;
  _checked_ptr_1<int> _ptr__4055(_4055 ? _4055->raw() : nullptr,_4055 ? _4055->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4056 = mosek::fusion::p_WorkStack::_get_impl(_4049)->i64;
  _checked_ptr_1<long long> _ptr__4056(_4056 ? _4056->raw() : nullptr,_4056 ? _4056->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4057 = mosek::fusion::p_WorkStack::_get_impl(_4049)->f64;
  _checked_ptr_1<double> _ptr__4057(_4057 ? _4057->raw() : nullptr,_4057 ? _4057->size(0) : 0);
  int _4058 = mosek::fusion::p_WorkStack::_get_impl(_4049)->ptr_base;
  int _4059 = mosek::fusion::p_WorkStack::_get_impl(_4049)->nidxs_base;
  int _4060 = mosek::fusion::p_WorkStack::_get_impl(_4049)->cof_base;
  int _4061 = mosek::fusion::p_WorkStack::_get_impl(_4049)->shape_base;
  int _4062 = mosek::fusion::p_WorkStack::_get_impl(_4049)->codeptr_base;
  int _4063 = mosek::fusion::p_WorkStack::_get_impl(_4049)->code_base;
  int _4064 = mosek::fusion::p_WorkStack::_get_impl(_4049)->cconst_base;
  int _4065 = mosek::fusion::p_WorkStack::_get_impl(_4049)->sp_base;
  {
    _ptr__4055[_4058] = (int)0;
    int _10463 = (int)0;
    int _10464 = _4052;
    for (int _4066 = _10463; _4066 < _10464; ++_4066)
    {
      {
        _ptr__4055[safe_add( _4061,_4066 )] = ((*shape)(_4066));
      }
    }
    int _10465 = (int)0;
    int _10466 = _4053;
    for (int _4067 = _10465; _4067 < _10466; ++_4067)
    {
      {
        _ptr__4056[safe_add( _4059,_4067 )] = (int)0;
      }
    }
    int _10467 = (int)0;
    int _10468 = _4053;
    for (int _4068 = _10467; _4068 < _10468; ++_4068)
    {
      {
        _ptr__4057[safe_add( _4060,_4068 )] = 0.0;
      }
    }
    int _10469 = (int)0;
    int _10470 = safe_add( _4053,(int)1 );
    for (int _4069 = _10469; _4069 < _10470; ++_4069)
    {
      {
        _ptr__4055[safe_add( _4058,_4069 )] = _4069;
      }
    }
    int _10471 = (int)0;
    int _10472 = safe_add( _4053,(int)1 );
    for (int _4070 = _10471; _4070 < _10472; ++_4070)
    {
      {
        _ptr__4055[safe_add( _4062,_4070 )] = _4070;
      }
    }
    if (_4054)
    {
      {
        int _10473 = (int)0;
        int _10474 = _4053;
        for (int _4071 = _10473; _4071 < _10474; ++_4071)
        {
          {
            _ptr__4056[safe_add( _4065,_4071 )] = ((*sp)(_4071));
          }
        }
      }
    }
    {}
    int _10475 = (int)0;
    int _10476 = _4053;
    for (int _4072 = _10475; _4072 < _10476; ++_4072)
    {
      {
        _ptr__4055[safe_add( _4063,_4072 )] = (int)1;
        _ptr__4057[safe_add( _4064,_4072 )] = ((*nidxs)(_4072));
      }
    }
  }
}
void mosek::fusion::ParameterImpl :: getSp(std::shared_ptr< monty::ndarray< long long,1 > > _4073,int _4074) { mosek::fusion::p_ParameterImpl::_get_impl(this)->getSp(_4073,_4074); }void mosek::fusion::p_ParameterImpl::getSp(std::shared_ptr< monty::ndarray< long long,1 > > _4073,int _4074){
  _checked_ptr_1<long long> _ptr__4073(_4073 ? _4073->raw() : nullptr, _4073 ? _4073->size(0) : 0);
  if ((NULL != sp.get()))
  {
    {
      int _10477 = (int)0;
      int _10478 = (int)((sp)->size(0));
      for (int _4075 = _10477; _4075 < _10478; ++_4075)
      {
        {
          _ptr__4073[safe_add( _4075,_4074 )] = ((*sp)(_4075));
        }
      }
    }
  }
  else
  {
    {
      int _10479 = (int)0;
      int _10480 = (int)((nidxs)->size(0));
      for (int _4076 = _10479; _4076 < _10480; ++_4076)
      {
        {
          _ptr__4073[safe_add( _4076,_4074 )] = _4076;
        }
      }
    }
  }
}
bool mosek::fusion::ParameterImpl :: isSparse() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->isSparse(); }bool mosek::fusion::p_ParameterImpl::isSparse(){
  return (NULL != sp.get());
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__slice(std::shared_ptr< monty::ndarray< int,1 > > _4077,std::shared_ptr< monty::ndarray< int,1 > > _4078) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__slice(_4077,_4078); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::slice(std::shared_ptr< monty::ndarray< int,1 > > _4077,std::shared_ptr< monty::ndarray< int,1 > > _4078) { return __mosek_2fusion_2ParameterImpl__slice(_4077,_4078); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::__mosek_2fusion_2Parameter__slice(std::shared_ptr< monty::ndarray< int,1 > > _4077,std::shared_ptr< monty::ndarray< int,1 > > _4078) { return __mosek_2fusion_2ParameterImpl__slice(_4077,_4078); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__slice(std::shared_ptr< monty::ndarray< int,1 > > _4077,std::shared_ptr< monty::ndarray< int,1 > > _4078){
  _checked_ptr_1<int> _ptr__4077(_4077 ? _4077->raw() : nullptr, _4077 ? _4077->size(0) : 0);
  _checked_ptr_1<int> _ptr__4078(_4078 ? _4078->raw() : nullptr, _4078 ? _4078->size(0) : 0);
  if ((((int)((_4077)->size(0)) != (int)((_4078)->size(0))) || ((int)((_4077)->size(0)) != (int)((shape)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid index dimension"));
    }
  }
  {}
  int _4079 = (int)((_4077)->size(0));
  int _10481 = (int)0;
  int _10482 = _4079;
  for (int _4080 = _10481; _4080 < _10482; ++_4080)
  {
    {
      if (((_ptr__4077[_4080] < (int)0) || ((_ptr__4077[_4080] >= _ptr__4078[_4080]) || (_ptr__4078[_4080] > ((*shape)(_4080))))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _4081 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4079)));
  _checked_ptr_1<long long> _ptr__4081(_4081 ? _4081->raw() : nullptr,_4081 ? _4081->size(0) : 0);
  _ptr__4081[(_4079 - (int)1)] = (int)1;
  int _10483 = (int)1;
  int _10484 = _4079;
  for (int _4082 = _10483; _4082 < _10484; ++_4082)
  {
    {
      _ptr__4081[((_4079 - _4082) - (int)1)] = safe_mul( _ptr__4081[(_4079 - _4082)],((*shape)(_4082)) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4083 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4079)));
  _checked_ptr_1<int> _ptr__4083(_4083 ? _4083->raw() : nullptr,_4083 ? _4083->size(0) : 0);
  std::vector<int> _10485;
  for (int _4085 = (int)0, _10486 = _4079; _4085 < _10486 ; ++_4085)
  {
    _10485.push_back((_ptr__4078[_4085] - _ptr__4077[_4085]));
  }
  auto _10487 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10485.size()),_10485.begin(),_10485.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4084 = _10487;
  _checked_ptr_1<int> _ptr__4084(_4084 ? _4084->raw() : nullptr,_4084 ? _4084->size(0) : 0);
  if ((NULL == sp.get()))
  {
    {
      int _4086 = (int)1;
      int _10488 = (int)0;
      int _10489 = _4079;
      for (int _4087 = _10488; _4087 < _10489; ++_4087)
      {
        {
          _4086 *= _ptr__4084[_4087];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4088 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4086)));
      _checked_ptr_1<int> _ptr__4088(_4088 ? _4088->raw() : nullptr,_4088 ? _4088->size(0) : 0);
      int _4089 = (int)0;
      int _10490 = (int)0;
      int _10491 = (int)((nidxs)->size(0));
      for (int _4090 = _10490; _4090 < _10491; ++_4090)
      {
        {
          int _10492 = (int)0;
          int _10493 = _4079;
          for (int _4091 = _10492; _4091 < _10493; ++_4091)
          {
            {
              _ptr__4083[_4091] = (int)((_4090 / _ptr__4081[_4091]) % ((*shape)(_4091)));
            }
          }
          bool _4092 = true;
          int _10494 = (int)0;
          int _10495 = _4079;
          for (int _4093 = _10494; _4093 < _10495; ++_4093)
          {
            {
              _4092 = (_4092 && ((_ptr__4077[_4093] <= _ptr__4083[_4093]) && (_ptr__4083[_4093] < _ptr__4078[_4093])));
            }
          }
          if (_4092)
          {
            {
              _ptr__4088[_4089] = ((*nidxs)(_4090));
              ++ _4089;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,_4084,nullptr,_4088)).as<::mosek::fusion::Parameter>();
    }
  }
  else
  {
    {
      int _4094 = (int)0;
      int _10496 = (int)0;
      int _10497 = (int)((nidxs)->size(0));
      for (int _4095 = _10496; _4095 < _10497; ++_4095)
      {
        {
          int _10498 = (int)0;
          int _10499 = _4079;
          for (int _4096 = _10498; _4096 < _10499; ++_4096)
          {
            {
              _ptr__4083[_4096] = (int)((((*sp)(_4095)) / _ptr__4081[_4096]) % ((*shape)(_4096)));
            }
          }
          bool _4097 = true;
          int _10500 = (int)0;
          int _10501 = _4079;
          for (int _4098 = _10500; _4098 < _10501; ++_4098)
          {
            {
              _4097 = (_4097 && ((_ptr__4077[_4098] <= _ptr__4083[_4098]) && (_ptr__4083[_4098] < _ptr__4078[_4098])));
            }
          }
          if (_4097)
          {
            {
              ++ _4094;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4099 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4094)));
      _checked_ptr_1<int> _ptr__4099(_4099 ? _4099->raw() : nullptr,_4099 ? _4099->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4100 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4094)));
      _checked_ptr_1<long long> _ptr__4100(_4100 ? _4100->raw() : nullptr,_4100 ? _4100->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4101 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4079)));
      _checked_ptr_1<long long> _ptr__4101(_4101 ? _4101->raw() : nullptr,_4101 ? _4101->size(0) : 0);
      _ptr__4101[(_4079 - (int)1)] = (int)1;
      int _10502 = (int)1;
      int _10503 = _4079;
      for (int _4102 = _10502; _4102 < _10503; ++_4102)
      {
        {
          _ptr__4101[((_4079 - _4102) - (int)1)] = safe_mul( _ptr__4101[(_4079 - _4102)],_ptr__4084[_4102] );
        }
      }
      int _4103 = (int)0;
      int _10504 = (int)0;
      int _10505 = (int)((nidxs)->size(0));
      for (int _4104 = _10504; _4104 < _10505; ++_4104)
      {
        {
          int _10506 = (int)0;
          int _10507 = _4079;
          for (int _4105 = _10506; _4105 < _10507; ++_4105)
          {
            {
              _ptr__4083[_4104] = (int)((((*sp)(_4104)) / _ptr__4081[_4105]) % ((*shape)(_4105)));
            }
          }
          bool _4106 = true;
          int _10508 = (int)0;
          int _10509 = _4079;
          for (int _4107 = _10508; _4107 < _10509; ++_4107)
          {
            {
              _4106 = (_4106 && ((_ptr__4077[_4107] <= _ptr__4083[_4107]) && (_ptr__4083[_4107] < _ptr__4078[_4107])));
            }
          }
          if (_4106)
          {
            {
              long long _4108 = (long long)0;
              int _10510 = (int)0;
              int _10511 = _4079;
              for (int _4109 = _10510; _4109 < _10511; ++_4109)
              {
                {
                  _4108 += safe_mul( (_ptr__4083[_4109] - _ptr__4077[_4109]),_ptr__4101[_4109] );
                }
              }
              _ptr__4100[_4103] = _4108;
              _ptr__4099[_4103] = ((*nidxs)(_4104));
              ++ _4103;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,_4084,_4100,_4099)).as<::mosek::fusion::Parameter>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__slice(int _4110,int _4111) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__slice(_4110,_4111); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::slice(int _4110,int _4111) { return __mosek_2fusion_2ParameterImpl__slice(_4110,_4111); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::__mosek_2fusion_2Parameter__slice(int _4110,int _4111) { return __mosek_2fusion_2ParameterImpl__slice(_4110,_4111); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__slice(int _4110,int _4111){
  if (((int)((shape)->size(0)) != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid index dimension"));
    }
  }
  {}
  if (((_4110 < (int)0) || ((_4111 >= _4111) || (_4111 > size))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid index"));
    }
  }
  {}
  if ((NULL == sp.get()))
  {
    {
      std::vector<int> _10512;
      for (int _4112 = _4110, _10513 = _4111; _4112 < _10513 ; ++_4112)
      {
        _10512.push_back(((*nidxs)(_4112)));
      }
      auto _10514 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10512.size()),_10512.begin(),_10512.end()));
      return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((_4111 - _4110))}),nullptr,_10514)).as<::mosek::fusion::Parameter>();
    }
  }
  else
  {
    {
      int _4113 = (int)0;
      int _10515 = (int)0;
      int _10516 = (int)((sp)->size(0));
      for (int _4114 = _10515; _4114 < _10516; ++_4114)
      {
        {
          if (((_4110 <= ((*sp)(_4114))) && (((*sp)(_4114)) < _4111)))
          {
            {
              ++ _4113;
            }
          }
          {}
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4115 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4113)));
      _checked_ptr_1<int> _ptr__4115(_4115 ? _4115->raw() : nullptr,_4115 ? _4115->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4116 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4113)));
      _checked_ptr_1<long long> _ptr__4116(_4116 ? _4116->raw() : nullptr,_4116 ? _4116->size(0) : 0);
      int _4117 = (int)0;
      int _10517 = (int)0;
      int _10518 = (int)((sp)->size(0));
      for (int _4118 = _10517; _4118 < _10518; ++_4118)
      {
        {
          if (((_4110 <= ((*sp)(_4118))) && (((*sp)(_4118)) < _4111)))
          {
            {
              _ptr__4115[_4117] = ((*nidxs)(_4118));
              _ptr__4116[_4117] = (((*sp)(_4117)) - _4110);
              ++ _4117;
            }
          }
          {}
        }
      }
      return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)0),(int)((_4111 - _4110))}),_4116,_4115)).as<::mosek::fusion::Parameter>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__reshape(std::shared_ptr< monty::ndarray< int,1 > > _4119) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__reshape(_4119); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::reshape(std::shared_ptr< monty::ndarray< int,1 > > _4119) { return __mosek_2fusion_2ParameterImpl__reshape(_4119); }
monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::ParameterImpl::__mosek_2fusion_2Parameter__reshape(std::shared_ptr< monty::ndarray< int,1 > > _4119) { return __mosek_2fusion_2ParameterImpl__reshape(_4119); }monty::rc_ptr< ::mosek::fusion::Parameter > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__reshape(std::shared_ptr< monty::ndarray< int,1 > > _4119){
  _checked_ptr_1<int> _ptr__4119(_4119 ? _4119->raw() : nullptr, _4119 ? _4119->size(0) : 0);
  if ((::mosek::fusion::p_Set::size(_4119) != ::mosek::fusion::p_Set::size(shape)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incompatible shape for resize"));
    }
  }
  {}
  return (::mosek::fusion::p_ParameterImpl::_new_ParameterImpl(model,_4119,sp,nidxs)).as<::mosek::fusion::Parameter>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__asExpr() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::asExpr() { return __mosek_2fusion_2ParameterImpl__asExpr(); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::ParameterImpl::__mosek_2fusion_2Parameter__asExpr() { return __mosek_2fusion_2ParameterImpl__asExpr(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__asExpr(){
  return (::mosek::fusion::p_ExprParameter::_new_ExprParameter((::mosek::fusion::ParameterImpl::t(_pubthis)).as<::mosek::fusion::Parameter>())).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::ParameterImpl :: getSize() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->getSize(); }long long mosek::fusion::p_ParameterImpl::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::ParameterImpl :: getNumNonzero() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->getNumNonzero(); }int mosek::fusion::p_ParameterImpl::getNumNonzero(){
  return (int)((nidxs)->size(0));
}
int mosek::fusion::ParameterImpl :: getND() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->getND(); }int mosek::fusion::p_ParameterImpl::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::ParameterImpl :: getShape() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ParameterImpl::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
int mosek::fusion::ParameterImpl :: getDim(int _4120) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->getDim(_4120); }int mosek::fusion::p_ParameterImpl::getDim(int _4120){
  return ((*shape)(_4120));
}
void mosek::fusion::ParameterImpl :: getAllIndexes(std::shared_ptr< monty::ndarray< int,1 > > _4121,int _4122) { mosek::fusion::p_ParameterImpl::_get_impl(this)->getAllIndexes(_4121,_4122); }void mosek::fusion::p_ParameterImpl::getAllIndexes(std::shared_ptr< monty::ndarray< int,1 > > _4121,int _4122){
  _checked_ptr_1<int> _ptr__4121(_4121 ? _4121->raw() : nullptr, _4121 ? _4121->size(0) : 0);
  int _10519 = (int)0;
  int _10520 = (int)((nidxs)->size(0));
  for (int _4123 = _10519; _4123 < _10520; ++_4123)
  {
    {
      _ptr__4121[safe_add( _4122,_4123 )] = ((*nidxs)(_4123));
    }
  }
}
int mosek::fusion::ParameterImpl :: getIndex(int _4124) { return mosek::fusion::p_ParameterImpl::_get_impl(this)->getIndex(_4124); }int mosek::fusion::p_ParameterImpl::getIndex(int _4124){
  return ((*nidxs)(_4124));
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::ParameterImpl :: getValue() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->getValue(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_ParameterImpl::getValue(){
  return mosek::fusion::p_Model::_get_impl(model.get())->getParameterValue(nidxs);
}
void mosek::fusion::ParameterImpl :: setValue(std::shared_ptr< monty::ndarray< double,2 > > _4125) { mosek::fusion::p_ParameterImpl::_get_impl(this)->setValue(_4125); }void mosek::fusion::p_ParameterImpl::setValue(std::shared_ptr< monty::ndarray< double,2 > > _4125){
  if (((_pubthis->getND() != (int)2) || (((int)((_4125)->size(0)) != ((*shape)((int)0))) || ((int)((_4125)->size(1)) != ((*shape)((int)1))))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching value shape"));
    }
  }
  {}
  if ((NULL == sp.get()))
  {
    {
      std::vector<double> _10521;
      for (int _4127 = (int)0, _10522 = ((*shape)((int)0)); _4127 < _10522 ; ++_4127)
      {
        for (int _4128 = (int)0, _10523 = ((*shape)((int)1)); _4128 < _10523 ; ++_4128)
        {
          _10521.push_back(((*_4125)(_4127,_4128)));
        }
      }
      auto _10524 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10521.size()),_10521.begin(),_10521.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _4126 = _10524;
      _checked_ptr_1<double> _ptr__4126(_4126 ? _4126->raw() : nullptr,_4126 ? _4126->size(0) : 0);
      mosek::fusion::p_Model::_get_impl(model.get())->setParameterValue(nidxs,_4126);
    }
  }
  else
  {
    {
      std::vector<double> _10525;
      for (int _4130 = (int)0, _10526 = (int)((sp)->size(0)); _4130 < _10526 ; ++_4130)
      {
        _10525.push_back(((*_4125)((((*sp)(_4130)) / ((*shape)((int)1))),(((*sp)(_4130)) % ((*shape)((int)1))))));
      }
      auto _10527 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10525.size()),_10525.begin(),_10525.end()));
      std::shared_ptr< monty::ndarray< double,1 > > _4129 = _10527;
      _checked_ptr_1<double> _ptr__4129(_4129 ? _4129->raw() : nullptr,_4129 ? _4129->size(0) : 0);
      mosek::fusion::p_Model::_get_impl(model.get())->setParameterValue(nidxs,_4129);
    }
  }
}
void mosek::fusion::ParameterImpl :: setValue(std::shared_ptr< monty::ndarray< double,1 > > _4131) { mosek::fusion::p_ParameterImpl::_get_impl(this)->setValue(_4131); }void mosek::fusion::p_ParameterImpl::setValue(std::shared_ptr< monty::ndarray< double,1 > > _4131){
  _checked_ptr_1<double> _ptr__4131(_4131 ? _4131->raw() : nullptr, _4131 ? _4131->size(0) : 0);
  if ((NULL == sp.get()))
  {
    {
      if (((int)((_4131)->size(0)) != (int)((nidxs)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Length of value array is incorrect"));
        }
      }
      else
      {
        {
          mosek::fusion::p_Model::_get_impl(model.get())->setParameterValue(nidxs,_4131);
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_4131)->size(0)) != _pubthis->getSize()))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Length of value array is incorrect"));
        }
      }
      else
      {
        {
          std::vector<double> _10528;
          for (int _4133 = (int)0, _10529 = (int)((nidxs)->size(0)); _4133 < _10529 ; ++_4133)
          {
            _10528.push_back(_ptr__4131[((*sp)(_4133))]);
          }
          auto _10530 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10528.size()),_10528.begin(),_10528.end()));
          std::shared_ptr< monty::ndarray< double,1 > > _4132 = _10530;
          _checked_ptr_1<double> _ptr__4132(_4132 ? _4132->raw() : nullptr,_4132 ? _4132->size(0) : 0);
          mosek::fusion::p_Model::_get_impl(model.get())->setParameterValue(nidxs,_4132);
        }
      }
    }
  }
}
void mosek::fusion::ParameterImpl :: setValue(double _4134) { mosek::fusion::p_ParameterImpl::_get_impl(this)->setValue(_4134); }void mosek::fusion::p_ParameterImpl::setValue(double _4134){
  std::vector<double> _10531;
  for (long long _4135 = (int)0, _10532 = size; _4135 < _10532 ; ++_4135)
  {
    _10531.push_back(_4134);
  }
  auto _10533 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10531.size()),_10531.begin(),_10531.end()));
  mosek::fusion::p_Model::_get_impl(model.get())->setParameterValue(nidxs,_10533);
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::ParameterImpl :: __mosek_2fusion_2ParameterImpl__getModel() { return mosek::fusion::p_ParameterImpl::_get_impl(this)->__mosek_2fusion_2ParameterImpl__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::ParameterImpl::getModel() { return __mosek_2fusion_2ParameterImpl__getModel(); }
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::ParameterImpl::__mosek_2fusion_2Parameter__getModel() { return __mosek_2fusion_2ParameterImpl__getModel(); }monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_ParameterImpl::__mosek_2fusion_2ParameterImpl__getModel(){
  return model;
}
void mosek::fusion::p_ParameterImpl::destroy(){nidxs.reset();sp.reset();shape.reset();model.reset();}void mosek::fusion::ParameterImpl::destroy() { mosek::fusion::p_ParameterImpl::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Parameter > mosek::fusion::Parameter::clone(monty::rc_ptr< ::mosek::fusion::Model > _4136) { return __mosek_2fusion_2Parameter__clone(_4136); }
monty::rc_ptr< mosek::fusion::Model > mosek::fusion::Parameter::getModel() { return __mosek_2fusion_2Parameter__getModel(); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Parameter::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _4143,std::shared_ptr< monty::ndarray< int,1 > > _4144) { return __mosek_2fusion_2Parameter__slice(_4143,_4144); }
monty::rc_ptr< mosek::fusion::Parameter > mosek::fusion::Parameter::slice(std::shared_ptr< monty::ndarray< int,1 > > _4143,std::shared_ptr< monty::ndarray< int,1 > > _4144) { return __mosek_2fusion_2Parameter__slice(_4143,_4144); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Parameter::__mosek_2fusion_2Expression__slice(int _4145,int _4146) { return __mosek_2fusion_2Parameter__slice(_4145,_4146); }
monty::rc_ptr< mosek::fusion::Parameter > mosek::fusion::Parameter::slice(int _4145,int _4146) { return __mosek_2fusion_2Parameter__slice(_4145,_4146); }
monty::rc_ptr< mosek::fusion::Parameter > mosek::fusion::Parameter::reshape(std::shared_ptr< monty::ndarray< int,1 > > _4147) { return __mosek_2fusion_2Parameter__reshape(_4147); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Parameter::asExpr() { return __mosek_2fusion_2Parameter__asExpr(); }
mosek::fusion::ExprOptimizeCode::ExprOptimizeCode(mosek::fusion::p_ExprOptimizeCode *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprOptimizeCode()" << this << std::endl; */ }mosek::fusion::ExprOptimizeCode::~ExprOptimizeCode() {  /* std::cout << "~ExprOptimizeCode()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprOptimizeCode::p_ExprOptimizeCode  (::mosek::fusion::ExprOptimizeCode * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprOptimizeCode::t mosek::fusion::p_ExprOptimizeCode::_new_ExprOptimizeCode  (monty::rc_ptr< ::mosek::fusion::Expression > _4151){ return new mosek::fusion::ExprOptimizeCode(_4151); }mosek::fusion::ExprOptimizeCode::ExprOptimizeCode  (monty::rc_ptr< ::mosek::fusion::Expression > _4151) :    ExprOptimizeCode(new mosek::fusion::p_ExprOptimizeCode(this)){ mosek::fusion::p_ExprOptimizeCode::_get_impl(this)->_initialize(_4151); }void mosek::fusion::p_ExprOptimizeCode::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4151){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4151->getShape());
    mosek::fusion::p_ExprOptimizeCode::_get_impl(::mosek::fusion::ExprOptimizeCode::t(_pubthis))->expr = _4151;
  }
}void mosek::fusion::p_ExprOptimizeCode::compress_code(monty::rc_ptr< ::mosek::fusion::WorkStack > _4152,int _4153,std::shared_ptr< monty::ndarray< int,1 > > _4154,int _4155,std::shared_ptr< monty::ndarray< int,1 > > _4156,int _4157,std::shared_ptr< monty::ndarray< double,1 > > _4158,int _4159,std::shared_ptr< monty::ndarray< double,1 > > _4160,int _4161,int _4162,int _4163,int _4164){
  _checked_ptr_1<int> _ptr__4154(_4154 ? _4154->raw() : nullptr, _4154 ? _4154->size(0) : 0);
  _checked_ptr_1<int> _ptr__4156(_4156 ? _4156->raw() : nullptr, _4156 ? _4156->size(0) : 0);
  _checked_ptr_1<double> _ptr__4158(_4158 ? _4158->raw() : nullptr, _4158 ? _4158->size(0) : 0);
  _checked_ptr_1<double> _ptr__4160(_4160 ? _4160->raw() : nullptr, _4160 ? _4160->size(0) : 0);
  int _4165 = _ptr__4156[safe_add( _4157,_4153 )];
  int _4166 = _4152->alloci32(safe_add( _4165,(int)2 ));
  int _4167 = (int)0;
  int _4168 = _4152->alloci32(safe_add( _4165,(int)2 ));
  int _4169 = _4152->alloci32(safe_add( _4165,(int)3 ));
  int _4170 = _4152->allocf64(safe_add( _4165,(int)2 ));
  int _4171 = _4152->alloci32(safe_add( _4165,(int)2 ));
  int _4172 = (int)0;
  int _4173 = (-(int)1);
  std::shared_ptr< monty::ndarray< int,1 > > _4174 = mosek::fusion::p_WorkStack::_get_impl(_4152)->i32;
  _checked_ptr_1<int> _ptr__4174(_4174 ? _4174->raw() : nullptr,_4174 ? _4174->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4175 = mosek::fusion::p_WorkStack::_get_impl(_4152)->f64;
  _checked_ptr_1<double> _ptr__4175(_4175 ? _4175->raw() : nullptr,_4175 ? _4175->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4176 = _4174;
  _checked_ptr_1<int> _ptr__4176(_4176 ? _4176->raw() : nullptr,_4176 ? _4176->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4177 = _4175;
  _checked_ptr_1<double> _ptr__4177(_4177 ? _4177->raw() : nullptr,_4177 ? _4177->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _4178 = _4174;
  _checked_ptr_1<int> _ptr__4178(_4178 ? _4178->raw() : nullptr,_4178 ? _4178->size(0) : 0);
  int _4179 = mosek::fusion::p_WorkStack::_get_impl(_4152)->pi32;
  int _4180 = mosek::fusion::p_WorkStack::_get_impl(_4152)->pi64;
  int _4181 = mosek::fusion::p_WorkStack::_get_impl(_4152)->pf64;
  _ptr__4178[_4164] = (int)0;
  int _4182 = (int)0;
  int _10534 = (int)0;
  int _10535 = _4153;
  for (int _4183 = _10534; _4183 < _10535; ++_4183)
  {
    {
      int _4184 = _ptr__4156[safe_add( safe_add( _4157,_4183 ),(int)1 )];
      int _4185 = _ptr__4156[safe_add( _4157,_4183 )];
      if ((_4173 < (int)0))
      {
        {
          _4167 = (int)0;
          _4172 = (int)0;
          _ptr__4174[_4169] = (int)0;
          int _10536 = (int)0;
          int _10537 = (_4184 - _4185);
          for (int _4186 = _10536; _4186 < _10537; ++_4186)
          {
            {
              _ptr__4176[safe_add( _4171,_4186 )] = (-(int)9999);
            }
          }
          int _10538 = _4185;
          int _10539 = _4184;
          for (int _4187 = _10538; _4187 < _10539; ++_4187)
          {
            {
              int _4188 = _ptr__4154[safe_add( _4155,_4187 )];
              double _4189 = _ptr__4160[safe_add( _4161,_4187 )];
              if ((_4188 == 0))
              {
                {
                }
              }
              else if((_4188 == 2))
              {
                {
                  _ptr__4176[safe_add( _4171,_4172 )] = 2;
                  _ptr__4175[safe_add( _4170,_4172 )] = _4189;
                  _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                  _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                  ++ _4167;
                  ++ _4172;
                }
              }
              else if((_4188 == 1))
              {
                {
                  _ptr__4174[safe_add( _4171,_4172 )] = _4188;
                  _ptr__4175[safe_add( _4170,_4172 )] = _4189;
                  _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                  _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                  ++ _4167;
                  ++ _4172;
                }
              }
              else if((_4188 == 3))
              {
                {
                  if ((_4167 >= (int)2))
                  {
                    {
                      int _4190 = _ptr__4174[(safe_add( _4166,_4167 ) - (int)1)];
                      -- _4167;
                      int _4191 = _ptr__4174[(safe_add( _4166,_4167 ) - (int)1)];
                      -- _4167;
                      if (((_ptr__4174[safe_add( _4171,_4191 )] == 2) && (_ptr__4174[safe_add( _4171,_4190 )] == 2)))
                      {
                        {
                          _ptr__4174[safe_add( _4171,_4172 )] = 2;
                          _ptr__4175[safe_add( _4170,_4172 )] = (_ptr__4175[safe_add( _4170,_4191 )] + _ptr__4175[safe_add( _4170,_4190 )]);
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else if(((_ptr__4174[safe_add( _4171,_4191 )] == 2) && ((_ptr__4175[safe_add( _4170,_4191 )] <= 0.0) && (_ptr__4175[safe_add( _4170,_4191 )] >= 0.0))))
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4175[safe_add( _4170,_4172 )] = 0.0;
                          _ptr__4174[safe_add( _4166,_4167 )] = _4190;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else if(((_ptr__4174[safe_add( _4171,_4190 )] == 2) && ((_ptr__4175[safe_add( _4170,_4190 )] <= 0.0) && (_ptr__4175[safe_add( _4170,_4190 )] >= 0.0))))
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4174[safe_add( _4166,_4167 )] = _4191;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],(int)2 );
                          _ptr__4174[safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] )] = _4191;
                          _ptr__4174[safe_add( safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] ),(int)1 )] = _4190;
                          _ptr__4174[safe_add( _4171,_4172 )] = _4188;
                          _ptr__4175[safe_add( _4170,_4172 )] = _4189;
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                    }
                  }
                  else
                  {
                    {
                      _4173 = _4187;
                    }
                  }
                }
              }
              else if((_4188 == 5))
              {
                {
                  if ((_4167 >= (int)2))
                  {
                    {
                      int _4192 = _ptr__4174[(safe_add( _4166,_4167 ) - (int)1)];
                      -- _4167;
                      int _4193 = _ptr__4174[(safe_add( _4166,_4167 ) - (int)1)];
                      -- _4167;
                      if (((_ptr__4174[safe_add( _4171,_4193 )] == 2) && (_ptr__4174[safe_add( _4171,_4192 )] == 2)))
                      {
                        {
                          _ptr__4174[safe_add( _4171,_4172 )] = 2;
                          _ptr__4175[safe_add( _4170,_4172 )] = (_ptr__4175[safe_add( _4170,_4193 )] * _ptr__4175[safe_add( _4170,_4192 )]);
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else if(((_ptr__4174[safe_add( _4171,_4193 )] == 2) && ((_ptr__4175[safe_add( _4170,_4193 )] <= 0.0) && (_ptr__4175[safe_add( _4170,_4193 )] >= 0.0))))
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4174[safe_add( _4171,_4172 )] = 2;
                          _ptr__4175[safe_add( _4170,_4172 )] = 0.0;
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else if(((_ptr__4174[safe_add( _4171,_4192 )] == 2) && ((_ptr__4175[safe_add( _4170,_4192 )] <= 0.0) && (_ptr__4175[safe_add( _4170,_4192 )] >= 0.0))))
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4174[safe_add( _4171,_4172 )] = 2;
                          _ptr__4175[safe_add( _4170,_4172 )] = 0.0;
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else if(((_ptr__4174[safe_add( _4171,_4192 )] == 2) && ((_ptr__4175[safe_add( _4170,_4192 )] <= 1.0) && (_ptr__4175[safe_add( _4170,_4192 )] >= 1.0))))
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],(int)1 );
                          _ptr__4174[safe_add( _4166,_4167 )] = _4193;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else if(((_ptr__4174[safe_add( _4171,_4193 )] == 2) && ((_ptr__4175[safe_add( _4170,_4193 )] <= 1.0) && (_ptr__4175[safe_add( _4170,_4193 )] >= 1.0))))
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],(int)1 );
                          _ptr__4174[safe_add( _4166,_4167 )] = _4192;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],(int)2 );
                          _ptr__4174[safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] )] = _4193;
                          _ptr__4174[safe_add( safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] ),(int)1 )] = _4192;
                          _ptr__4174[safe_add( _4171,_4172 )] = 5;
                          _ptr__4175[safe_add( _4170,_4172 )] = _4189;
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                    }
                  }
                  else
                  {
                    {
                      _4173 = _4187;
                    }
                  }
                }
              }
              else if((_4188 == 4))
              {
                {
                  if ((_4167 >= (int)1))
                  {
                    {
                      int _4194 = _ptr__4174[(safe_add( _4166,_4167 ) - (int)1)];
                      -- _4167;
                      if ((_ptr__4174[safe_add( _4171,_4194 )] == 2))
                      {
                        {
                          _ptr__4174[safe_add( _4171,_4172 )] = 2;
                          _ptr__4175[safe_add( _4170,_4172 )] = (-_ptr__4175[safe_add( _4170,_4194 )]);
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4174[safe_add( _4171,_4172 )] = _ptr__4154[safe_add( _4155,_4187 )];
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],(int)1 );
                          _ptr__4174[safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] )] = _4194;
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                    }
                  }
                  else
                  {
                    {
                      _4173 = _4187;
                    }
                  }
                }
              }
              else if((_4188 == 6))
              {
                {
                  if ((_4167 >= (int)1))
                  {
                    {
                      int _4195 = _ptr__4174[(safe_add( _4166,_4167 ) - (int)1)];
                      -- _4167;
                      if ((_ptr__4174[safe_add( _4171,_4195 )] == 2))
                      {
                        {
                          _ptr__4174[safe_add( _4171,_4172 )] = 2;
                          _ptr__4175[safe_add( _4170,_4172 )] = (1.0 / _ptr__4175[safe_add( _4170,_4195 )]);
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4174[safe_add( _4171,_4172 )] = _ptr__4154[safe_add( _4155,_4187 )];
                          _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],(int)1 );
                          _ptr__4174[safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] )] = _4195;
                          _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                          ++ _4167;
                          ++ _4172;
                        }
                      }
                    }
                  }
                  else
                  {
                    {
                      _4173 = _4187;
                    }
                  }
                }
              }
              else if((_4188 == 8))
              {
                {
                  int _4196 = (int)_4189;
                  if ((_4196 < (int)0))
                  {
                    {
                      _4173 = _4187;
                    }
                  }
                  else if((_4196 > _4167))
                  {
                    {
                      _4173 = _4187;
                    }
                  }
                  else if((_4196 == (int)0))
                  {
                    {
                      _ptr__4174[safe_add( _4171,_4172 )] = 2;
                      _ptr__4175[safe_add( _4170,_4172 )] = 0.0;
                      _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                      _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                      ++ _4167;
                      ++ _4172;
                    }
                  }
                  else if((_4196 == (int)1))
                  {
                    {
                      _ptr__4174[safe_add( _4171,_4172 )] = (int)0;
                      _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                      _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                      ++ _4167;
                      ++ _4172;
                    }
                  }
                  else
                  {
                    {
                      std::vector<int> _10540;
                      for (int _4198 = (int)0, _10541 = _4196; _4198 < _10541 ; ++_4198)
                      {
                        _10540.push_back(_ptr__4174[((safe_add( _4166,_4167 ) - (int)1) - _4198)]);
                      }
                      auto _10542 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10540.size()),_10540.begin(),_10540.end()));
                      std::shared_ptr< monty::ndarray< int,1 > > _4197 = _10542;
                      _checked_ptr_1<int> _ptr__4197(_4197 ? _4197->raw() : nullptr,_4197 ? _4197->size(0) : 0);
                      _4167 -= _4196;
                      {
                        int _4199 = (_4196 - (int)1);
                        int _4200 = (int)0;
                        while ( (_4200 < _4199) )
                        {
                          {
                            while ( ((_4200 < _4199) && (_ptr__4174[safe_add( _4171,_ptr__4197[_4200] )] == 2)) )
                            {
                              {
                                ++ _4200;
                              }
                            }
                            while ( ((_4200 < _4199) && (_ptr__4174[safe_add( _4171,_ptr__4197[_4199] )] != 2)) )
                            {
                              {
                                -- _4199;
                              }
                            }
                            if ((_4200 < _4199))
                            {
                              {
                                int _4201 = _ptr__4197[_4200];
                                _ptr__4197[_4200] = _ptr__4197[_4199];
                                _ptr__4197[_4199] = _4201;
                                ++ _4200;
                                -- _4199;
                              }
                            }
                            {}
                          }
                        }
                        double _4202 = 0.0;
                        int _4203 = (int)0;
                        while ( ((_4203 < _4196) && (_ptr__4174[safe_add( _4171,_ptr__4197[_4203] )] == 2)) )
                        {
                          {
                            _4202 += _ptr__4175[safe_add( _4170,_ptr__4197[_4203] )];
                            ++ _4203;
                          }
                        }
                        int _10543;
                        bool _10544 = (_4203 > (int)0);
                        if (_10544)
                        {
                          _10543 = safe_add( (_4196 - _4203),(int)1 );
                        }
                        else
                        {
                          _10543 = _4196;
                        }
                        int _4204 = _10543;
                        int _4205 = (int)0;
                        if ((_4203 < (int)2))
                        {
                          {
                            int _10545 = (int)0;
                            int _10546 = _4196;
                            for (int _4206 = _10545; _4206 < _10546; ++_4206)
                            {
                              {
                                _ptr__4174[safe_add( safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] ),_4206 )] = _ptr__4197[_4206];
                              }
                            }
                            _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],_4196 );
                            _ptr__4174[safe_add( _4171,_4172 )] = 8;
                            _ptr__4175[safe_add( _4170,_4172 )] = _4196;
                            _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                            ++ _4167;
                            ++ _4172;
                          }
                        }
                        else
                        {
                          {
                            _ptr__4174[safe_add( _4171,_4172 )] = 2;
                            _ptr__4175[safe_add( _4170,_4172 )] = _4202;
                            _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = _ptr__4174[safe_add( _4169,_4172 )];
                            ++ _4172;
                            if ((_4203 == _4196))
                            {
                              {
                                _ptr__4174[safe_add( _4166,_4167 )] = (_4172 - (int)1);
                                ++ _4167;
                              }
                            }
                            else
                            {
                              {
                                _ptr__4174[safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] )] = (_4172 - (int)1);
                                int _10547 = _4203;
                                int _10548 = _4196;
                                for (int _4207 = _10547; _4207 < _10548; ++_4207)
                                {
                                  {
                                    _ptr__4174[safe_add( (safe_add( safe_add( _4168,_ptr__4174[safe_add( _4169,_4172 )] ),_4207 ) - _4203),(int)1 )] = _ptr__4197[_4207];
                                  }
                                }
                                _ptr__4174[safe_add( safe_add( _4169,_4172 ),(int)1 )] = safe_add( _ptr__4174[safe_add( _4169,_4172 )],_4204 );
                                _ptr__4174[safe_add( _4171,_4172 )] = 8;
                                _ptr__4175[safe_add( _4170,_4172 )] = _4204;
                                _ptr__4174[safe_add( _4166,_4167 )] = _4172;
                                ++ _4167;
                                ++ _4172;
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
              else
              {
                {
                  _4173 = _4187;
                }
              }
            }
          }
        }
      }
      {}
      if (((_4173 < (int)0) && (_4167 != (int)1)))
      {
        {
          _4173 = _4172;
        }
      }
      {}
      if ((_4173 < (int)0))
      {
        {
          int _4208 = _4182;
          int _4209 = _4208;
          if ((_ptr__4174[safe_add( _4171,_ptr__4174[(safe_add( _4166,_4167 ) - (int)1)] )] == 2))
          {
            {
              _ptr__4158[safe_add( _4159,_4183 )] += _ptr__4175[safe_add( _4170,_ptr__4174[(safe_add( _4166,_4167 ) - (int)1)] )];
              _ptr__4176[safe_add( _4162,_4209 )] = 10;
              _ptr__4177[safe_add( _4163,_4209 )] = 0.0;
              ++ _4209;
            }
          }
          else
          {
            {
              if (((_ptr__4158[safe_add( _4159,_4183 )] < (int)0) || ((int)0 < _ptr__4158[safe_add( _4159,_4183 )])))
              {
                {
                  _ptr__4176[safe_add( _4162,_4209 )] = 3;
                  ++ _4209;
                  _ptr__4176[safe_add( _4162,_4209 )] = 2;
                  _ptr__4177[safe_add( _4163,_4209 )] = _ptr__4158[safe_add( _4159,_4183 )];
                  ++ _4209;
                  _ptr__4158[safe_add( _4159,_4183 )] = (int)0;
                }
              }
              {}
              while ( (_4167 > (int)0) )
              {
                {
                  int _4210 = _ptr__4174[(safe_add( _4166,_4167 ) - (int)1)];
                  -- _4167;
                  int _4211 = _ptr__4174[safe_add( _4171,_4210 )];
                  double _4212 = _ptr__4175[safe_add( _4170,_4210 )];
                  _ptr__4176[safe_add( _4162,_4209 )] = _4211;
                  _ptr__4177[safe_add( _4163,_4209 )] = _4212;
                  ++ _4209;
                  int _10549 = _ptr__4174[safe_add( _4169,_4210 )];
                  int _10550 = _ptr__4174[safe_add( safe_add( _4169,_4210 ),(int)1 )];
                  for (int _4213 = _10549; _4213 < _10550; ++_4213)
                  {
                    {
                      _ptr__4174[safe_add( _4166,_4167 )] = _ptr__4174[safe_add( _4168,_4213 )];
                      ++ _4167;
                    }
                  }
                }
              }
              int _4214 = _4209;
              -- _4214;
              while ( (_4208 < _4214) )
              {
                {
                  int _4215 = _ptr__4176[safe_add( _4162,_4208 )];
                  double _4216 = _ptr__4177[safe_add( _4163,_4208 )];
                  _ptr__4176[safe_add( _4162,_4208 )] = _ptr__4176[safe_add( _4162,_4214 )];
                  _ptr__4177[safe_add( _4163,_4208 )] = _ptr__4177[safe_add( _4163,_4214 )];
                  _ptr__4176[safe_add( _4162,_4214 )] = _4215;
                  _ptr__4177[safe_add( _4163,_4214 )] = _4216;
                  ++ _4208;
                  -- _4214;
                }
              }
            }
          }
          _ptr__4178[safe_add( safe_add( _4164,_4183 ),(int)1 )] = _4209;
          _4182 = _4209;
        }
      }
      {}
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_4152)->pi32 = _4179;
  mosek::fusion::p_WorkStack::_get_impl(_4152)->pi64 = _4180;
  mosek::fusion::p_WorkStack::_get_impl(_4152)->pf64 = _4181;
  if ((_4173 >= (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal error: Invalid parameterization code list"));
    }
  }
  {}
}
void mosek::fusion::ExprOptimizeCode :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4217,monty::rc_ptr< ::mosek::fusion::WorkStack > _4218,monty::rc_ptr< ::mosek::fusion::WorkStack > _4219) { mosek::fusion::p_ExprOptimizeCode::_get_impl(this)->eval(_4217,_4218,_4219); }void mosek::fusion::p_ExprOptimizeCode::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4217,monty::rc_ptr< ::mosek::fusion::WorkStack > _4218,monty::rc_ptr< ::mosek::fusion::WorkStack > _4219){
  expr->eval(_4218,_4217,_4219);
  _4218->pop_expr();
  int _4220 = mosek::fusion::p_WorkStack::_get_impl(_4218)->nd;
  int _4221 = mosek::fusion::p_WorkStack::_get_impl(_4218)->shape_base;
  int _4222 = mosek::fusion::p_WorkStack::_get_impl(_4218)->nelem;
  int _4223 = mosek::fusion::p_WorkStack::_get_impl(_4218)->nnz;
  bool _4224 = mosek::fusion::p_WorkStack::_get_impl(_4218)->hassp;
  int _4225 = mosek::fusion::p_WorkStack::_get_impl(_4218)->ncodeatom;
  int _4226 = mosek::fusion::p_WorkStack::_get_impl(_4218)->ptr_base;
  int _4227 = mosek::fusion::p_WorkStack::_get_impl(_4218)->sp_base;
  int _4228 = mosek::fusion::p_WorkStack::_get_impl(_4218)->nidxs_base;
  int _4229 = mosek::fusion::p_WorkStack::_get_impl(_4218)->cof_base;
  int _4230 = mosek::fusion::p_WorkStack::_get_impl(_4218)->code_base;
  int _4231 = mosek::fusion::p_WorkStack::_get_impl(_4218)->codeptr_base;
  int _4232 = mosek::fusion::p_WorkStack::_get_impl(_4218)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4233 = mosek::fusion::p_WorkStack::_get_impl(_4218)->i32;
  _checked_ptr_1<int> _ptr__4233(_4233 ? _4233->raw() : nullptr,_4233 ? _4233->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4234 = mosek::fusion::p_WorkStack::_get_impl(_4218)->i64;
  _checked_ptr_1<long long> _ptr__4234(_4234 ? _4234->raw() : nullptr,_4234 ? _4234->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4235 = mosek::fusion::p_WorkStack::_get_impl(_4218)->f64;
  _checked_ptr_1<double> _ptr__4235(_4235 ? _4235->raw() : nullptr,_4235 ? _4235->size(0) : 0);
  if ((_4225 == (int)0))
  {
    {
      _4217->alloc_expr(_4220,_4222,_4223,_4224,(int)0);
      int _4236 = mosek::fusion::p_WorkStack::_get_impl(_4217)->ptr_base;
      int _4237 = mosek::fusion::p_WorkStack::_get_impl(_4217)->sp_base;
      int _4238 = mosek::fusion::p_WorkStack::_get_impl(_4217)->nidxs_base;
      int _4239 = mosek::fusion::p_WorkStack::_get_impl(_4217)->cof_base;
      int _4240 = mosek::fusion::p_WorkStack::_get_impl(_4217)->shape_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4241 = mosek::fusion::p_WorkStack::_get_impl(_4217)->i32;
      _checked_ptr_1<int> _ptr__4241(_4241 ? _4241->raw() : nullptr,_4241 ? _4241->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4242 = mosek::fusion::p_WorkStack::_get_impl(_4217)->i64;
      _checked_ptr_1<long long> _ptr__4242(_4242 ? _4242->raw() : nullptr,_4242 ? _4242->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4243 = mosek::fusion::p_WorkStack::_get_impl(_4217)->f64;
      _checked_ptr_1<double> _ptr__4243(_4243 ? _4243->raw() : nullptr,_4243 ? _4243->size(0) : 0);
      int _10551 = (int)0;
      int _10552 = safe_add( _4222,(int)1 );
      for (int _4244 = _10551; _4244 < _10552; ++_4244)
      {
        {
          _ptr__4241[safe_add( _4236,_4244 )] = _ptr__4233[safe_add( _4226,_4244 )];
        }
      }
      int _10553 = (int)0;
      int _10554 = _4220;
      for (int _4245 = _10553; _4245 < _10554; ++_4245)
      {
        {
          _ptr__4241[safe_add( _4240,_4245 )] = _ptr__4233[safe_add( _4221,_4245 )];
        }
      }
      int _10555 = (int)0;
      int _10556 = _4223;
      for (int _4246 = _10555; _4246 < _10556; ++_4246)
      {
        {
          _ptr__4242[safe_add( _4238,_4246 )] = _ptr__4234[safe_add( _4228,_4246 )];
        }
      }
      int _10557 = (int)0;
      int _10558 = _4223;
      for (int _4247 = _10557; _4247 < _10558; ++_4247)
      {
        {
          _ptr__4243[safe_add( _4239,_4247 )] = _ptr__4235[safe_add( _4229,_4247 )];
        }
      }
      if (_4224)
      {
        {
          int _10559 = (int)0;
          int _10560 = _4222;
          for (int _4248 = _10559; _4248 < _10560; ++_4248)
          {
            {
              _ptr__4242[safe_add( _4237,_4248 )] = _ptr__4234[safe_add( _4227,_4248 )];
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4249 = _4219->alloci32(_4225);
      int _4250 = _4219->alloci32(safe_add( _4223,(int)1 ));
      int _4251 = _4219->allocf64(_4225);
      ::mosek::fusion::p_ExprOptimizeCode::compress_code(_4219,_4223,_4233,_4230,_4233,_4231,_4235,_4229,_4235,_4232,_4249,_4251,_4250);
      std::shared_ptr< monty::ndarray< int,1 > > _4252 = mosek::fusion::p_WorkStack::_get_impl(_4219)->i32;
      _checked_ptr_1<int> _ptr__4252(_4252 ? _4252->raw() : nullptr,_4252 ? _4252->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4253 = mosek::fusion::p_WorkStack::_get_impl(_4219)->f64;
      _checked_ptr_1<double> _ptr__4253(_4253 ? _4253->raw() : nullptr,_4253 ? _4253->size(0) : 0);
      int _4254 = (int)0;
      int _4255 = (int)0;
      int _4256 = (int)0;
      int _10561 = (int)0;
      int _10562 = _4222;
      for (int _4257 = _10561; _4257 < _10562; ++_4257)
      {
        {
          int _4258 = (int)0;
          int _10563 = _ptr__4233[safe_add( _4226,_4257 )];
          int _10564 = _ptr__4233[safe_add( safe_add( _4226,_4257 ),(int)1 )];
          for (int _4259 = _10563; _4259 < _10564; ++_4259)
          {
            {
              if (((_ptr__4235[safe_add( _4229,_4259 )] < (int)0) || ((int)0 < _ptr__4235[safe_add( _4229,_4259 )])))
              {
                {
                  ++ _4255;
                  ++ _4258;
                  ++ _4254;
                }
              }
              else
              {
                {
                  if (((_ptr__4252[safe_add( safe_add( _4250,_4259 ),(int)1 )] - _ptr__4252[safe_add( _4250,_4259 )]) > (int)1))
                  {
                    {
                      ++ _4255;
                      ++ _4258;
                      _4254 += (_ptr__4252[safe_add( safe_add( _4250,_4259 ),(int)1 )] - _ptr__4252[safe_add( _4250,_4259 )]);
                    }
                  }
                  else
                  {
                    {
                      if ((_ptr__4252[safe_add( _4249,_ptr__4252[safe_add( _4250,_4259 )] )] != 10))
                      {
                        {
                          ++ _4255;
                          ++ _4258;
                          ++ _4254;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          if ((_4258 > (int)0))
          {
            {
              ++ _4256;
            }
          }
          {}
        }
      }
      bool _4260 = false;
      {
        long long _4261 = (long long)1;
        int _10565 = (int)0;
        int _10566 = _4220;
        for (int _4262 = _10565; _4262 < _10566; ++_4262)
        {
          {
            _4261 *= _ptr__4233[safe_add( _4221,_4262 )];
          }
        }
        _4260 = (_4261 > _4256);
      }
      _4217->alloc_expr(_4220,_4256,_4255,_4260,_4254);
      int _4263 = mosek::fusion::p_WorkStack::_get_impl(_4217)->ptr_base;
      int _4264 = mosek::fusion::p_WorkStack::_get_impl(_4217)->sp_base;
      int _4265 = mosek::fusion::p_WorkStack::_get_impl(_4217)->shape_base;
      int _4266 = mosek::fusion::p_WorkStack::_get_impl(_4217)->nidxs_base;
      int _4267 = mosek::fusion::p_WorkStack::_get_impl(_4217)->cof_base;
      int _4268 = mosek::fusion::p_WorkStack::_get_impl(_4217)->code_base;
      int _4269 = mosek::fusion::p_WorkStack::_get_impl(_4217)->codeptr_base;
      int _4270 = mosek::fusion::p_WorkStack::_get_impl(_4217)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4271 = mosek::fusion::p_WorkStack::_get_impl(_4217)->i32;
      _checked_ptr_1<int> _ptr__4271(_4271 ? _4271->raw() : nullptr,_4271 ? _4271->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4272 = mosek::fusion::p_WorkStack::_get_impl(_4217)->i64;
      _checked_ptr_1<long long> _ptr__4272(_4272 ? _4272->raw() : nullptr,_4272 ? _4272->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4273 = mosek::fusion::p_WorkStack::_get_impl(_4217)->f64;
      _checked_ptr_1<double> _ptr__4273(_4273 ? _4273->raw() : nullptr,_4273 ? _4273->size(0) : 0);
      int _10567 = (int)0;
      int _10568 = _4220;
      for (int _4274 = _10567; _4274 < _10568; ++_4274)
      {
        {
          _ptr__4271[safe_add( _4265,_4274 )] = _ptr__4233[safe_add( _4221,_4274 )];
        }
      }
      if ((_4254 == (int)0))
      {
        {
          int _10569 = (int)0;
          int _10570 = _4223;
          for (int _4275 = _10569; _4275 < _10570; ++_4275)
          {
            {
              _ptr__4272[safe_add( _4266,_4275 )] = _ptr__4234[safe_add( _4228,_4275 )];
            }
          }
          int _10571 = (int)0;
          int _10572 = _4223;
          for (int _4276 = _10571; _4276 < _10572; ++_4276)
          {
            {
              _ptr__4273[safe_add( _4267,_4276 )] = _ptr__4235[safe_add( _4229,_4276 )];
            }
          }
          int _10573 = (int)0;
          int _10574 = safe_add( _4222,(int)1 );
          for (int _4277 = _10573; _4277 < _10574; ++_4277)
          {
            {
              _ptr__4271[safe_add( _4263,_4277 )] = _ptr__4271[safe_add( _4226,_4277 )];
            }
          }
          if (_4224)
          {
            {
              int _10575 = (int)0;
              int _10576 = _4222;
              for (int _4278 = _10575; _4278 < _10576; ++_4278)
              {
                {
                  _ptr__4272[safe_add( _4264,_4278 )] = _ptr__4272[safe_add( _4227,_4278 )];
                }
              }
            }
          }
          {}
        }
      }
      else
      {
        {
          int _4279 = (int)0;
          int _4280 = (int)0;
          int _4281 = (int)0;
          _ptr__4271[_4263] = (int)0;
          if ((_4254 > (int)0))
          {
            {
              _ptr__4271[_4269] = (int)0;
            }
          }
          {}
          int _10577 = (int)0;
          int _10578 = _4222;
          for (int _4282 = _10577; _4282 < _10578; ++_4282)
          {
            {
              int _4283 = (int)0;
              int _10579 = _ptr__4233[safe_add( _4226,_4282 )];
              int _10580 = _ptr__4233[safe_add( safe_add( _4226,_4282 ),(int)1 )];
              for (int _4284 = _10579; _4284 < _10580; ++_4284)
              {
                {
                  if (((_ptr__4235[safe_add( _4229,_4284 )] < (int)0) || ((int)0 < _ptr__4235[safe_add( _4229,_4284 )])))
                  {
                    {
                      _ptr__4272[safe_add( _4266,_4281 )] = _ptr__4234[safe_add( _4228,_4284 )];
                      _ptr__4273[safe_add( _4267,_4281 )] = _ptr__4235[safe_add( _4229,_4284 )];
                      _ptr__4271[safe_add( _4268,_4279 )] = _ptr__4252[safe_add( _4249,_ptr__4252[safe_add( _4250,_4284 )] )];
                      _ptr__4273[safe_add( _4270,_4279 )] = _ptr__4253[safe_add( _4251,_ptr__4252[safe_add( _4250,_4284 )] )];
                      ++ _4279;
                      _ptr__4271[safe_add( safe_add( _4269,_4281 ),(int)1 )] = _4279;
                      ++ _4281;
                      ++ _4283;
                    }
                  }
                  else
                  {
                    {
                      if ((((_ptr__4252[safe_add( safe_add( _4250,_4284 ),(int)1 )] - _ptr__4252[safe_add( _4250,_4284 )]) > (int)1) || (_ptr__4252[safe_add( _4249,_ptr__4252[safe_add( _4250,_4284 )] )] != 10)))
                      {
                        {
                          _ptr__4272[safe_add( _4266,_4281 )] = _ptr__4234[safe_add( _4228,_4284 )];
                          _ptr__4273[safe_add( _4267,_4281 )] = 0.0;
                          int _10581 = _ptr__4252[safe_add( _4250,_4284 )];
                          int _10582 = _ptr__4252[safe_add( safe_add( _4250,_4284 ),(int)1 )];
                          for (int _4285 = _10581; _4285 < _10582; ++_4285)
                          {
                            {
                              _ptr__4271[safe_add( _4268,_4279 )] = _ptr__4252[safe_add( _4249,_4285 )];
                              _ptr__4273[safe_add( _4270,_4279 )] = _ptr__4253[safe_add( _4251,_4285 )];
                              ++ _4279;
                            }
                          }
                          _ptr__4271[safe_add( safe_add( _4269,_4281 ),(int)1 )] = _4279;
                          ++ _4281;
                          ++ _4283;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              if ((_4283 > (int)0))
              {
                {
                  _ptr__4271[safe_add( safe_add( _4263,_4280 ),(int)1 )] = _4281;
                  if (_4260)
                  {
                    {
                      _ptr__4272[safe_add( _4264,_4280 )] = _ptr__4234[safe_add( _4227,_4282 )];
                    }
                  }
                  {}
                  ++ _4280;
                }
              }
              {}
            }
          }
          if ((_4280 != _4256))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect result nelem"));
            }
          }
          {}
          if ((_4281 != _4255))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect result nnz"));
            }
          }
          {}
          if ((_4279 != _4254))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect result num code atoms"));
            }
          }
          {}
          if ((_4254 > (int)0))
          {
            {
              if ((_ptr__4271[safe_add( _4269,_4255 )] != _4254))
              {
                {
                  throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect codeptr"));
                }
              }
              {}
            }
          }
          {}
        }
      }
    }
  }
}
std::string mosek::fusion::ExprOptimizeCode :: toString() { return mosek::fusion::p_ExprOptimizeCode::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprOptimizeCode::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprOptimizeCode("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprOptimizeCode::destroy(){expr.reset();}void mosek::fusion::ExprOptimizeCode::destroy() { mosek::fusion::p_ExprOptimizeCode::_get_impl(this)->destroy(); }mosek::fusion::ExprCompress::ExprCompress(mosek::fusion::p_ExprCompress *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCompress()" << this << std::endl; */ }mosek::fusion::ExprCompress::~ExprCompress() {  /* std::cout << "~ExprCompress()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCompress::p_ExprCompress  (::mosek::fusion::ExprCompress * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4286){ return new mosek::fusion::ExprCompress(_4286); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4286) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4286); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4286){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4286->getShape());
    eps = 0.0;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4286;
  }
}mosek::fusion::ExprCompress::t mosek::fusion::p_ExprCompress::_new_ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4287,    double _4288){ return new mosek::fusion::ExprCompress(_4287,_4288); }mosek::fusion::ExprCompress::ExprCompress  (monty::rc_ptr< ::mosek::fusion::Expression > _4287,    double _4288) :    ExprCompress(new mosek::fusion::p_ExprCompress(this)){ mosek::fusion::p_ExprCompress::_get_impl(this)->_initialize(_4287,_4288); }void mosek::fusion::p_ExprCompress::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4287,    double _4288){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_4287->getShape());
    eps = _4288;
    mosek::fusion::p_ExprCompress::_get_impl(::mosek::fusion::ExprCompress::t(_pubthis))->expr = _4287;
  }
}void mosek::fusion::ExprCompress::arg_sort  ( monty::rc_ptr< ::mosek::fusion::WorkStack > _4289,    monty::rc_ptr< ::mosek::fusion::WorkStack > _4290,    int _4291,    int _4292,    int _4293,    int _4294,    int _4295) { mosek::fusion::p_ExprCompress::arg_sort(_4289,_4290,_4291,_4292,_4293,_4294,_4295); }void mosek::fusion::p_ExprCompress::arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4289,monty::rc_ptr< ::mosek::fusion::WorkStack > _4290,int _4291,int _4292,int _4293,int _4294,int _4295){
  int _4296 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _4297 = mosek::fusion::p_WorkStack::_get_impl(_4289)->i32;
  _checked_ptr_1<int> _ptr__4297(_4297 ? _4297->raw() : nullptr,_4297 ? _4297->size(0) : 0);
  int _10583 = (int)0;
  int _10584 = _4292;
  for (int _4298 = _10583; _4298 < _10584; ++_4298)
  {
    {
      if (((_ptr__4297[safe_add( safe_add( _4294,_4298 ),(int)1 )] - _ptr__4297[safe_add( _4294,_4298 )]) > _4296))
      {
        {
          _4296 = (_ptr__4297[safe_add( safe_add( _4294,_4298 ),(int)1 )] - _ptr__4297[safe_add( _4294,_4298 )]);
        }
      }
      {}
    }
  }
  int _10585;
  bool _10586 = (_4296 > (int)2);
  if (_10586)
  {
    _10585 = _4290->alloci32(safe_mul( _4296,(int)2 ));
  }
  else
  {
    _10585 = (int)99999;
  }
  int _4299 = _10585;
  std::shared_ptr< monty::ndarray< int,1 > > _4300 = mosek::fusion::p_WorkStack::_get_impl(_4290)->i32;
  _checked_ptr_1<int> _ptr__4300(_4300 ? _4300->raw() : nullptr,_4300 ? _4300->size(0) : 0);
  _4297 = mosek::fusion::p_WorkStack::_get_impl(_4289)->i32;
  _ptr__4297.update(_4297 ? _4297->raw() : nullptr, _4297 ? _4297->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4301 = mosek::fusion::p_WorkStack::_get_impl(_4289)->i64;
  _checked_ptr_1<long long> _ptr__4301(_4301 ? _4301->raw() : nullptr,_4301 ? _4301->size(0) : 0);
  int _10587 = (int)0;
  int _10588 = _4292;
  for (int _4302 = _10587; _4302 < _10588; ++_4302)
  {
    {
      int _4303 = _ptr__4297[safe_add( _4294,_4302 )];
      int _4304 = _ptr__4297[safe_add( safe_add( _4294,_4302 ),(int)1 )];
      int _4305 = (_4304 - _4303);
      if ((_4305 == (int)0))
      {
        {
        }
      }
      else if((_4305 == (int)1))
      {
        {
          _ptr__4300[safe_add( _4291,_4303 )] = _4303;
        }
      }
      else if((_4305 == (int)2))
      {
        {
          if ((_ptr__4301[safe_add( _4295,_4303 )] <= _ptr__4301[safe_add( safe_add( _4295,_4303 ),(int)1 )]))
          {
            {
              _ptr__4300[safe_add( _4291,_4303 )] = _4303;
              _ptr__4300[safe_add( safe_add( _4291,_4303 ),(int)1 )] = safe_add( _4303,(int)1 );
            }
          }
          else
          {
            {
              _ptr__4300[safe_add( _4291,_4303 )] = safe_add( _4303,(int)1 );
              _ptr__4300[safe_add( safe_add( _4291,_4303 ),(int)1 )] = _4303;
            }
          }
        }
      }
      else
      {
        {
          long long _4306 = _ptr__4301[safe_add( _4295,_4303 )];
          long long _4307 = _ptr__4301[safe_add( _4295,_4303 )];
          bool _4308 = false;
          int _10589 = safe_add( _4303,(int)1 );
          int _10590 = _4304;
          for (int _4309 = _10589; _4309 < _10590; ++_4309)
          {
            {
              _4308 = (_4308 && (_ptr__4301[(safe_add( _4295,_4309 ) - (int)1)] <= _ptr__4301[safe_add( _4295,_4309 )]));
              if ((_4306 > _ptr__4301[safe_add( _4295,_4309 )]))
              {
                {
                  _4306 = _ptr__4301[safe_add( _4295,_4309 )];
                }
              }
              {}
              if ((_4307 < _ptr__4301[safe_add( _4295,_4309 )]))
              {
                {
                  _4307 = _ptr__4301[safe_add( _4295,_4309 )];
                }
              }
              {}
            }
          }
          if (_4308)
          {
            {
              int _10591 = _4303;
              int _10592 = _4304;
              for (int _4310 = _10591; _4310 < _10592; ++_4310)
              {
                {
                  _ptr__4300[safe_add( _4291,_4310 )] = _4310;
                }
              }
            }
          }
          else if((safe_add( (_4307 - _4306),(int)1 ) <= _4305))
          {
            {
              long long _4311 = safe_add( (_4307 - _4306),(int)1 );
              int _10593 = (int)0;
              long long _10594 = safe_add( _4311,(int)1 );
              for (long long _4312 = _10593; _4312 < _10594; ++_4312)
              {
                {
                  _ptr__4300[safe_add( _4299,_4312 )] = (int)0;
                }
              }
              int _10595 = _4303;
              int _10596 = _4304;
              for (int _4313 = _10595; _4313 < _10596; ++_4313)
              {
                {
                  ++ _ptr__4300[safe_add( (safe_add( _4299,_ptr__4301[safe_add( _4295,_4313 )] ) - _4306),(int)1 )];
                }
              }
              int _10597 = (int)0;
              long long _10598 = _4311;
              for (long long _4314 = _10597; _4314 < _10598; ++_4314)
              {
                {
                  _ptr__4300[safe_add( safe_add( _4299,_4314 ),(int)1 )] += _ptr__4300[safe_add( _4299,_4314 )];
                }
              }
              int _10599 = _4303;
              int _10600 = _4304;
              for (int _4315 = _10599; _4315 < _10600; ++_4315)
              {
                {
                  _ptr__4300[safe_add( safe_add( _4291,_4303 ),_ptr__4300[(safe_add( _4299,_ptr__4301[safe_add( _4295,_4315 )] ) - _4306)] )] = _4315;
                  ++ _ptr__4300[(safe_add( _4299,_ptr__4301[safe_add( _4295,_4315 )] ) - _4306)];
                }
              }
            }
          }
          else
          {
            {
              int _4316 = (int)1;
              int _4317 = _4299;
              int _4318 = safe_add( _4299,_4305 );
              int _10601 = (int)0;
              int _10602 = _4305;
              for (int _4319 = _10601; _4319 < _10602; ++_4319)
              {
                {
                  _ptr__4300[safe_add( _4317,_4319 )] = _4319;
                }
              }
              while ( (_4316 < _4305) )
              {
                {
                  int _4320 = safe_mul( _4316,(int)2 );
                  int _4321 = (_4305 / _4320);
                  if ((safe_add( safe_mul( _4321,_4320 ),_4316 ) < _4305))
                  {
                    {
                      ++ _4321;
                    }
                  }
                  {}
                  int _4322 = (int)0;
                  int _10603 = (int)0;
                  int _10604 = _4321;
                  for (int _4323 = _10603; _4323 < _10604; ++_4323)
                  {
                    {
                      int _4324 = safe_mul( _4323,_4320 );
                      int _4325 = safe_add( _4324,_4316 );
                      int _4326 = _4325;
                      int _4327 = safe_add( _4326,_4316 );
                      if ((_4327 > _4305))
                      {
                        {
                          _4327 = _4305;
                        }
                      }
                      {}
                      while ( ((_4324 < _4325) && (_4326 < _4327)) )
                      {
                        {
                          if ((_ptr__4301[safe_add( safe_add( _4295,_ptr__4300[safe_add( _4317,_4324 )] ),_4303 )] <= _ptr__4301[safe_add( safe_add( _4295,_ptr__4300[safe_add( _4317,_4326 )] ),_4303 )]))
                          {
                            {
                              _ptr__4300[safe_add( _4318,_4322 )] = _ptr__4300[safe_add( _4317,_4324 )];
                              ++ _4322;
                              ++ _4324;
                            }
                          }
                          else
                          {
                            {
                              _ptr__4300[safe_add( _4318,_4322 )] = _ptr__4300[safe_add( _4317,_4326 )];
                              ++ _4322;
                              ++ _4326;
                            }
                          }
                        }
                      }
                      while ( (_4324 < _4325) )
                      {
                        {
                          _ptr__4300[safe_add( _4318,_4322 )] = _ptr__4300[safe_add( _4317,_4324 )];
                          ++ _4322;
                          ++ _4324;
                        }
                      }
                      while ( (_4326 < _4327) )
                      {
                        {
                          _ptr__4300[safe_add( _4318,_4322 )] = _ptr__4300[safe_add( _4317,_4326 )];
                          ++ _4322;
                          ++ _4326;
                        }
                      }
                    }
                  }
                  if ((safe_mul( _4321,_4320 ) < _4305))
                  {
                    {
                      int _4328 = safe_mul( _4321,_4320 );
                      while ( (_4328 < _4305) )
                      {
                        {
                          _ptr__4300[safe_add( _4318,_4322 )] = _ptr__4300[safe_add( _4317,_4328 )];
                          ++ _4328;
                          ++ _4322;
                        }
                      }
                    }
                  }
                  {}
                  int _4329 = _4317;
                  _4317 = _4318;
                  _4318 = _4329;
                  _4316 *= (int)2;
                }
              }
              int _10605 = (int)0;
              int _10606 = _4305;
              for (int _4330 = _10605; _4330 < _10606; ++_4330)
              {
                {
                  _ptr__4300[safe_add( safe_add( _4291,_4303 ),_4330 )] = safe_add( _ptr__4300[safe_add( _4317,_4330 )],_4303 );
                }
              }
            }
          }
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress::merge_sort  ( int _4331,    int _4332,    int _4333,    int _4334,    int _4335,    int _4336,    std::shared_ptr< monty::ndarray< int,1 > > _4337,    std::shared_ptr< monty::ndarray< long long,1 > > _4338) { mosek::fusion::p_ExprCompress::merge_sort(_4331,_4332,_4333,_4334,_4335,_4336,_4337,_4338); }void mosek::fusion::p_ExprCompress::merge_sort(int _4331,int _4332,int _4333,int _4334,int _4335,int _4336,std::shared_ptr< monty::ndarray< int,1 > > _4337,std::shared_ptr< monty::ndarray< long long,1 > > _4338){
  _checked_ptr_1<int> _ptr__4337(_4337 ? _4337->raw() : nullptr, _4337 ? _4337->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4338(_4338 ? _4338->raw() : nullptr, _4338 ? _4338->size(0) : 0);
  int _4339 = _4331;
  int _4340 = _4332;
  int _10607 = (int)0;
  int _10608 = _4334;
  for (int _4341 = _10607; _4341 < _10608; ++_4341)
  {
    {
      _ptr__4337[safe_add( _4339,_4341 )] = _4341;
    }
  }
  int _10609 = (int)0;
  int _10610 = _4333;
  for (int _4342 = _10609; _4342 < _10610; ++_4342)
  {
    {
      _4339 = _4331;
      _4340 = _4332;
      int _4343 = _ptr__4337[safe_add( safe_add( _4335,_4342 ),(int)1 )];
      int _4344 = _ptr__4337[safe_add( _4335,_4342 )];
      if ((safe_add( _4344,(int)1 ) < _4343))
      {
        {
          int _4345 = (_4343 - _4344);
          int _4346 = (int)0;
          while ( (_4345 > (int)1) )
          {
            {
              ++ _4346;
              _4345 /= (int)2;
            }
          }
          _4345 = (_4343 - _4344);
          int _4347 = (int)1;
          int _10611 = (int)0;
          int _10612 = safe_add( _4346,(int)1 );
          for (int _4348 = _10611; _4348 < _10612; ++_4348)
          {
            {
              int _4349 = ((safe_add( _4345,_4347 ) - (int)1) / _4347);
              int _4350 = (_4349 / (int)2);
              int _4351 = _4344;
              int _10613 = (int)0;
              int _10614 = _4350;
              for (int _4352 = _10613; _4352 < _10614; ++_4352)
              {
                {
                  int _4353 = safe_mul( safe_mul( _4352,_4347 ),(int)2 );
                  int _10615;
                  bool _10616 = (safe_add( safe_add( _4344,_4353 ),safe_mul( (int)2,_4347 ) ) < _4343);
                  if (_10616)
                  {
                    _10615 = safe_add( safe_add( _4344,_4353 ),safe_mul( (int)2,_4347 ) );
                  }
                  else
                  {
                    _10615 = _4343;
                  }
                  int _4354 = _10615;
                  int _4355 = safe_add( safe_add( _4344,_4353 ),_4347 );
                  int _4356 = safe_add( safe_add( _4344,_4353 ),_4347 );
                  int _4357 = safe_add( _4344,_4353 );
                  while ( ((_4357 < _4356) && (_4355 < _4354)) )
                  {
                    {
                      if ((_ptr__4338[safe_add( _4336,_ptr__4337[safe_add( _4339,_4357 )] )] <= _ptr__4338[safe_add( _4336,_ptr__4337[safe_add( _4339,_4355 )] )]))
                      {
                        {
                          _ptr__4337[safe_add( _4340,_4351 )] = _ptr__4337[safe_add( _4339,_4357 )];
                          ++ _4351;
                          ++ _4357;
                        }
                      }
                      else
                      {
                        {
                          _ptr__4337[safe_add( _4340,_4351 )] = _ptr__4337[safe_add( _4339,_4355 )];
                          ++ _4351;
                          ++ _4355;
                        }
                      }
                    }
                  }
                  while ( (_4357 < _4356) )
                  {
                    {
                      _ptr__4337[safe_add( _4340,_4351 )] = _ptr__4337[safe_add( _4339,_4357 )];
                      ++ _4351;
                      ++ _4357;
                    }
                  }
                  while ( (_4355 < _4354) )
                  {
                    {
                      _ptr__4337[safe_add( _4340,_4351 )] = _ptr__4337[safe_add( _4339,_4355 )];
                      ++ _4351;
                      ++ _4355;
                    }
                  }
                }
              }
              int _10617 = _4351;
              int _10618 = _4343;
              for (int _4358 = _10617; _4358 < _10618; ++_4358)
              {
                {
                  _ptr__4337[safe_add( _4340,_4358 )] = _ptr__4337[safe_add( _4339,_4358 )];
                }
              }
              int _4359 = _4339;
              _4339 = _4340;
              _4340 = _4359;
              _4347 *= (int)2;
            }
          }
        }
      }
      {}
      int _10619 = _4344;
      int _10620 = _4343;
      for (int _4360 = _10619; _4360 < _10620; ++_4360)
      {
        {
          _ptr__4337[safe_add( _4331,_4360 )] = _ptr__4337[safe_add( _4339,_4360 )];
        }
      }
    }
  }
}
void mosek::fusion::ExprCompress :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4361,monty::rc_ptr< ::mosek::fusion::WorkStack > _4362,monty::rc_ptr< ::mosek::fusion::WorkStack > _4363) { mosek::fusion::p_ExprCompress::_get_impl(this)->eval(_4361,_4362,_4363); }void mosek::fusion::p_ExprCompress::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4361,monty::rc_ptr< ::mosek::fusion::WorkStack > _4362,monty::rc_ptr< ::mosek::fusion::WorkStack > _4363){
  expr->eval(_4362,_4361,_4363);
  _4362->pop_expr();
  int _4364 = mosek::fusion::p_WorkStack::_get_impl(_4362)->nd;
  int _4365 = mosek::fusion::p_WorkStack::_get_impl(_4362)->shape_base;
  int _4366 = mosek::fusion::p_WorkStack::_get_impl(_4362)->nelem;
  int _4367 = mosek::fusion::p_WorkStack::_get_impl(_4362)->nnz;
  bool _4368 = mosek::fusion::p_WorkStack::_get_impl(_4362)->hassp;
  int _4369 = mosek::fusion::p_WorkStack::_get_impl(_4362)->ncodeatom;
  int _4370 = mosek::fusion::p_WorkStack::_get_impl(_4362)->ptr_base;
  int _4371 = mosek::fusion::p_WorkStack::_get_impl(_4362)->sp_base;
  int _4372 = mosek::fusion::p_WorkStack::_get_impl(_4362)->nidxs_base;
  int _4373 = mosek::fusion::p_WorkStack::_get_impl(_4362)->cof_base;
  int _4374 = mosek::fusion::p_WorkStack::_get_impl(_4362)->code_base;
  int _4375 = mosek::fusion::p_WorkStack::_get_impl(_4362)->codeptr_base;
  int _4376 = mosek::fusion::p_WorkStack::_get_impl(_4362)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4377 = mosek::fusion::p_WorkStack::_get_impl(_4362)->i32;
  _checked_ptr_1<int> _ptr__4377(_4377 ? _4377->raw() : nullptr,_4377 ? _4377->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4378 = mosek::fusion::p_WorkStack::_get_impl(_4362)->i64;
  _checked_ptr_1<long long> _ptr__4378(_4378 ? _4378->raw() : nullptr,_4378 ? _4378->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4379 = mosek::fusion::p_WorkStack::_get_impl(_4362)->f64;
  _checked_ptr_1<double> _ptr__4379(_4379 ? _4379->raw() : nullptr,_4379 ? _4379->size(0) : 0);
  bool _4380 = true;
  {
    std::shared_ptr< monty::ndarray< int,1 > > _4381 = mosek::fusion::p_WorkStack::_get_impl(_4363)->i32;
    _checked_ptr_1<int> _ptr__4381(_4381 ? _4381->raw() : nullptr,_4381 ? _4381->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _4382 = mosek::fusion::p_WorkStack::_get_impl(_4363)->i64;
    _checked_ptr_1<long long> _ptr__4382(_4382 ? _4382->raw() : nullptr,_4382 ? _4382->size(0) : 0);
    std::shared_ptr< monty::ndarray< double,1 > > _4383 = mosek::fusion::p_WorkStack::_get_impl(_4363)->f64;
    _checked_ptr_1<double> _ptr__4383(_4383 ? _4383->raw() : nullptr,_4383 ? _4383->size(0) : 0);
    int _10621 = (int)0;
    int _10622 = _4366;
    for (int _4384 = _10621; _4384 < _10622; ++_4384)
    {
      {
        int _10623 = _ptr__4377[safe_add( _4370,_4384 )];
        int _10624 = (_ptr__4377[safe_add( safe_add( _4370,_4384 ),(int)1 )] - (int)1);
        for (int _4385 = _10623; _4385 < _10624; ++_4385)
        {
          {
            _4380 = (_4380 && (_ptr__4378[safe_add( _4372,_4385 )] < _ptr__4378[safe_add( safe_add( _4372,_4385 ),(int)1 )]));
          }
        }
      }
    }
    if (_4380)
    {
      {
        if ((_4369 > (int)0))
        {
          {
            int _10625 = (int)0;
            int _10626 = _4367;
            for (int _4386 = _10625; _4386 < _10626; ++_4386)
            {
              {
                _4380 = (_4380 && ((_ptr__4379[safe_add( _4373,_4386 )] <= (0.0 - eps)) || (((0.0 + eps) <= _ptr__4379[safe_add( _4373,_4386 )]) || (((_ptr__4377[safe_add( safe_add( _4375,_4386 ),(int)1 )] - _ptr__4377[safe_add( _4375,_4386 )]) == (int)0) || (!(((_ptr__4377[safe_add( safe_add( _4375,_4386 ),(int)1 )] - _ptr__4377[safe_add( _4375,_4386 )]) == (int)1) && ((_ptr__4377[safe_add( _4374,_ptr__4377[safe_add( _4375,_4386 )] )] == 2) && ((_ptr__4379[safe_add( _4376,_ptr__4377[safe_add( _4375,_4386 )] )] <= 0.0) || (_ptr__4379[safe_add( _4376,_ptr__4381[safe_add( _4375,_4386 )] )] >= 0.0)))))))));
              }
            }
          }
        }
        else
        {
          {
            int _10627 = (int)0;
            int _10628 = _4367;
            for (int _4387 = _10627; _4387 < _10628; ++_4387)
            {
              {
                _4380 = (_4380 && ((_ptr__4379[safe_add( _4373,_4387 )] <= (0.0 - eps)) || ((0.0 + eps) <= _ptr__4379[safe_add( _4373,_4387 )])));
              }
            }
          }
        }
      }
    }
    {}
  }
  if (_4380)
  {
    {
      _4361->alloc_expr(_4364,_4366,_4367,_4368,_4369);
      int _4388 = mosek::fusion::p_WorkStack::_get_impl(_4361)->ptr_base;
      int _4389 = mosek::fusion::p_WorkStack::_get_impl(_4361)->nidxs_base;
      int _4390 = mosek::fusion::p_WorkStack::_get_impl(_4361)->sp_base;
      int _4391 = mosek::fusion::p_WorkStack::_get_impl(_4361)->cof_base;
      int _4392 = mosek::fusion::p_WorkStack::_get_impl(_4361)->shape_base;
      int _4393 = mosek::fusion::p_WorkStack::_get_impl(_4361)->code_base;
      int _4394 = mosek::fusion::p_WorkStack::_get_impl(_4361)->codeptr_base;
      int _4395 = mosek::fusion::p_WorkStack::_get_impl(_4361)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4396 = mosek::fusion::p_WorkStack::_get_impl(_4361)->i32;
      _checked_ptr_1<int> _ptr__4396(_4396 ? _4396->raw() : nullptr,_4396 ? _4396->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4397 = mosek::fusion::p_WorkStack::_get_impl(_4361)->i64;
      _checked_ptr_1<long long> _ptr__4397(_4397 ? _4397->raw() : nullptr,_4397 ? _4397->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4398 = mosek::fusion::p_WorkStack::_get_impl(_4361)->f64;
      _checked_ptr_1<double> _ptr__4398(_4398 ? _4398->raw() : nullptr,_4398 ? _4398->size(0) : 0);
      {
        int _10629 = (int)0;
        int _10630 = _4364;
        for (int _4399 = _10629; _4399 < _10630; ++_4399)
        {
          {
            _ptr__4396[safe_add( _4392,_4399 )] = _ptr__4377[safe_add( _4365,_4399 )];
          }
        }
        int _10631 = (int)0;
        int _10632 = safe_add( _4366,(int)1 );
        for (int _4400 = _10631; _4400 < _10632; ++_4400)
        {
          {
            _ptr__4396[safe_add( _4388,_4400 )] = _ptr__4377[safe_add( _4370,_4400 )];
          }
        }
        int _10633 = (int)0;
        int _10634 = _4367;
        for (int _4401 = _10633; _4401 < _10634; ++_4401)
        {
          {
            _ptr__4397[safe_add( _4389,_4401 )] = _ptr__4378[safe_add( _4372,_4401 )];
          }
        }
        int _10635 = (int)0;
        int _10636 = _4367;
        for (int _4402 = _10635; _4402 < _10636; ++_4402)
        {
          {
            _ptr__4398[safe_add( _4391,_4402 )] = _ptr__4379[safe_add( _4373,_4402 )];
          }
        }
        if (_4368)
        {
          {
            int _10637 = (int)0;
            int _10638 = _4366;
            for (int _4403 = _10637; _4403 < _10638; ++_4403)
            {
              {
                _ptr__4397[safe_add( _4390,_4403 )] = _ptr__4378[safe_add( _4371,_4403 )];
              }
            }
          }
        }
        {}
        if ((_4369 > (int)0))
        {
          {
            int _10639 = (int)0;
            int _10640 = _4369;
            for (int _4404 = _10639; _4404 < _10640; ++_4404)
            {
              {
                _ptr__4396[safe_add( _4393,_4404 )] = _ptr__4377[safe_add( _4374,_4404 )];
              }
            }
            int _10641 = (int)0;
            int _10642 = _4369;
            for (int _4405 = _10641; _4405 < _10642; ++_4405)
            {
              {
                _ptr__4398[safe_add( _4395,_4405 )] = _ptr__4379[safe_add( _4376,_4405 )];
              }
            }
            int _10643 = (int)0;
            int _10644 = safe_add( _4367,(int)1 );
            for (int _4406 = _10643; _4406 < _10644; ++_4406)
            {
              {
                _ptr__4396[safe_add( _4394,_4406 )] = _ptr__4377[safe_add( _4375,_4406 )];
              }
            }
          }
        }
        {}
      }
      if ((_4369 > (int)0))
      {
        {
          if ((_ptr__4396[safe_add( _4394,_4367 )] != _4369))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect codeptr"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      int _4407 = _4363->alloci32(_4367);
      ::mosek::fusion::p_ExprCompress::arg_sort(_4362,_4363,_4407,_4366,_4367,_4370,_4372);
      std::shared_ptr< monty::ndarray< int,1 > > _4408 = mosek::fusion::p_WorkStack::_get_impl(_4363)->i32;
      _checked_ptr_1<int> _ptr__4408(_4408 ? _4408->raw() : nullptr,_4408 ? _4408->size(0) : 0);
      int _4409 = (int)0;
      int _4410 = _4369;
      {
        std::shared_ptr< monty::ndarray< int,1 > > _4411 = mosek::fusion::p_WorkStack::_get_impl(_4361)->i32;
        _checked_ptr_1<int> _ptr__4411(_4411 ? _4411->raw() : nullptr,_4411 ? _4411->size(0) : 0);
        int _10645 = (int)0;
        int _10646 = _4366;
        for (int _4412 = _10645; _4412 < _10646; ++_4412)
        {
          {
            int _4413 = _ptr__4377[safe_add( safe_add( _4370,_4412 ),(int)1 )];
            int _4414 = _ptr__4377[safe_add( _4370,_4412 )];
            if ((_4414 < _4413))
            {
              {
                int _4415 = _4414;
                while ( (_4415 < _4413) )
                {
                  {
                    double _4416 = 0.0;
                    long long _4417 = _ptr__4378[safe_add( _4372,_ptr__4408[safe_add( _4407,_4415 )] )];
                    int _4418 = _4415;
                    while ( ((_4415 < _4413) && (_ptr__4378[safe_add( _4372,_ptr__4408[safe_add( _4407,_4415 )] )] == _4417)) )
                    {
                      {
                        _4416 += _ptr__4379[safe_add( _4373,_ptr__4408[safe_add( _4407,_4415 )] )];
                        ++ _4415;
                      }
                    }
                    if (((_4416 < 0.0) || ((0.0 < _4416) || (_4369 > (int)0))))
                    {
                      {
                        ++ _4409;
                        if (((safe_add( _4418,(int)1 ) < _4415) && (_4369 > (int)0)))
                        {
                          {
                            _4410 += (int)1;
                          }
                        }
                        {}
                      }
                    }
                    {}
                  }
                }
              }
            }
            {}
          }
        }
      }
      _4361->alloc_expr(_4364,_4366,_4409,_4368,_4410);
      int _4419 = mosek::fusion::p_WorkStack::_get_impl(_4361)->nidxs_base;
      int _4420 = mosek::fusion::p_WorkStack::_get_impl(_4361)->shape_base;
      int _4421 = mosek::fusion::p_WorkStack::_get_impl(_4361)->sp_base;
      int _4422 = mosek::fusion::p_WorkStack::_get_impl(_4361)->cof_base;
      int _4423 = mosek::fusion::p_WorkStack::_get_impl(_4361)->ptr_base;
      int _4424 = mosek::fusion::p_WorkStack::_get_impl(_4361)->code_base;
      int _4425 = mosek::fusion::p_WorkStack::_get_impl(_4361)->codeptr_base;
      int _4426 = mosek::fusion::p_WorkStack::_get_impl(_4361)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4427 = mosek::fusion::p_WorkStack::_get_impl(_4361)->i32;
      _checked_ptr_1<int> _ptr__4427(_4427 ? _4427->raw() : nullptr,_4427 ? _4427->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4428 = mosek::fusion::p_WorkStack::_get_impl(_4361)->i64;
      _checked_ptr_1<long long> _ptr__4428(_4428 ? _4428->raw() : nullptr,_4428 ? _4428->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4429 = mosek::fusion::p_WorkStack::_get_impl(_4361)->f64;
      _checked_ptr_1<double> _ptr__4429(_4429 ? _4429->raw() : nullptr,_4429 ? _4429->size(0) : 0);
      {
        int _10647 = (int)0;
        int _10648 = _4364;
        for (int _4430 = _10647; _4430 < _10648; ++_4430)
        {
          {
            _ptr__4427[safe_add( _4420,_4430 )] = _ptr__4377[safe_add( _4365,_4430 )];
          }
        }
        int _10649 = (int)0;
        int _10650 = _4366;
        for (int _4431 = _10649; _4431 < _10650; ++_4431)
        {
          {
            _ptr__4429[safe_add( _4422,_4431 )] = 0.0;
          }
        }
        if (_4368)
        {
          {
            int _10651 = (int)0;
            int _10652 = _4366;
            for (int _4432 = _10651; _4432 < _10652; ++_4432)
            {
              {
                _ptr__4428[safe_add( _4421,_4432 )] = _ptr__4378[safe_add( _4371,_4432 )];
              }
            }
          }
        }
        {}
        int _4433 = (int)0;
        int _4434 = (int)0;
        {
          _ptr__4427[_4423] = (int)0;
          if ((_4410 > (int)0))
          {
            {
              _ptr__4427[_4425] = (int)0;
            }
          }
          {}
          int _10653 = (int)0;
          int _10654 = _4366;
          for (int _4435 = _10653; _4435 < _10654; ++_4435)
          {
            {
              int _4436 = _ptr__4377[safe_add( safe_add( _4370,_4435 ),(int)1 )];
              int _4437 = _ptr__4377[safe_add( _4370,_4435 )];
              if ((_4437 < _4436))
              {
                {
                  int _4438 = _4437;
                  int _4439 = _4438;
                  while ( (_4438 < _4436) )
                  {
                    {
                      double _4440 = 0.0;
                      int _4441 = safe_add( _4438,(int)1 );
                      int _4442 = _4438;
                      long long _4443 = _ptr__4378[safe_add( _4372,_ptr__4408[safe_add( _4407,_4442 )] )];
                      while ( ((_4441 < _4436) && (_ptr__4378[safe_add( _4372,_ptr__4408[safe_add( _4407,_4441 )] )] == _4443)) )
                      {
                        {
                          ++ _4441;
                        }
                      }
                      if ((_4369 > (int)0))
                      {
                        {
                          while ( (_4438 < _4441) )
                          {
                            {
                              _4440 += _ptr__4379[safe_add( _4373,_ptr__4408[safe_add( _4407,_4438 )] )];
                              int _10655 = _ptr__4377[safe_add( _4375,_ptr__4408[safe_add( _4407,_4438 )] )];
                              int _10656 = _ptr__4377[safe_add( safe_add( _4375,_ptr__4408[safe_add( _4407,_4438 )] ),(int)1 )];
                              for (int _4444 = _10655; _4444 < _10656; ++_4444)
                              {
                                {
                                  _ptr__4427[safe_add( _4424,_4434 )] = _ptr__4377[safe_add( _4374,_4444 )];
                                  _ptr__4429[safe_add( _4426,_4434 )] = _ptr__4379[safe_add( _4376,_4444 )];
                                  ++ _4434;
                                }
                              }
                              ++ _4438;
                            }
                          }
                          if (((_4441 - _4442) > (int)1))
                          {
                            {
                              _ptr__4427[safe_add( _4424,_4434 )] = 8;
                              _ptr__4429[safe_add( _4426,_4434 )] = (_4441 - _4442);
                              ++ _4434;
                            }
                          }
                          {}
                          _ptr__4427[safe_add( safe_add( _4425,_4433 ),(int)1 )] = _4434;
                          _ptr__4428[safe_add( _4419,_4433 )] = _4443;
                          _ptr__4429[safe_add( _4422,_4433 )] = _4440;
                          ++ _4433;
                        }
                      }
                      else
                      {
                        {
                          while ( (_4438 < _4441) )
                          {
                            {
                              _4440 += _ptr__4379[safe_add( _4373,_ptr__4408[safe_add( _4407,_4438 )] )];
                              ++ _4438;
                            }
                          }
                          if (((_4440 < (int)0) || ((int)0 < _4440)))
                          {
                            {
                              _ptr__4428[safe_add( _4419,_4433 )] = _4443;
                              _ptr__4429[safe_add( _4422,_4433 )] = _4440;
                              ++ _4433;
                            }
                          }
                          {}
                        }
                      }
                    }
                  }
                }
              }
              {}
              _ptr__4427[safe_add( safe_add( _4423,_4435 ),(int)1 )] = _4433;
            }
          }
        }
        if ((_4410 != _4434))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid ncodeatom"));
          }
        }
        {}
        if ((_4433 != _4409))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid nnz"));
          }
        }
        {}
        if ((_4409 != _ptr__4427[safe_add( _4423,_4366 )]))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid ptr"));
          }
        }
        {}
      }
      if ((_4410 > (int)0))
      {
        {
          if ((_ptr__4427[safe_add( _4425,_4409 )] != _4410))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect codeptr"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  _4363->clear();
}
std::string mosek::fusion::ExprCompress :: toString() { return mosek::fusion::p_ExprCompress::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCompress::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCompress("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCompress::destroy(){expr.reset();}void mosek::fusion::ExprCompress::destroy() { mosek::fusion::p_ExprCompress::_get_impl(this)->destroy(); }mosek::fusion::ExprConst::ExprConst(mosek::fusion::p_ExprConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprConst()" << this << std::endl; */ }mosek::fusion::ExprConst::~ExprConst() {  /* std::cout << "~ExprConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprConst::p_ExprConst  (::mosek::fusion::ExprConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _4445,    std::shared_ptr< monty::ndarray< long long,1 > > _4446,    std::shared_ptr< monty::ndarray< double,1 > > _4447){ return new mosek::fusion::ExprConst(_4445,_4446,_4447); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _4445,    std::shared_ptr< monty::ndarray< long long,1 > > _4446,    std::shared_ptr< monty::ndarray< double,1 > > _4447) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_4445,_4446,_4447); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4445,    std::shared_ptr< monty::ndarray< long long,1 > > _4446,    std::shared_ptr< monty::ndarray< double,1 > > _4447){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4445(_4445 ? _4445->raw() : nullptr, _4445 ? _4445->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4446(_4446 ? _4446->raw() : nullptr, _4446 ? _4446->size(0) : 0);
    _checked_ptr_1<double> _ptr__4447(_4447 ? _4447->raw() : nullptr, _4447 ? _4447->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_4445);
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = ::mosek::fusion::Utils::Tools::arraycopy(_4447);
    std::shared_ptr< monty::ndarray< long long,1 > > _10657;
    bool _10658 = (NULL != _4446.get());
    if (_10658)
    {
      _10657 = ::mosek::fusion::Utils::Tools::arraycopy(_4446);
    }
    else
    {
      _10657 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _10657;
    ::mosek::fusion::p_ExprConst::validate(_4445,_4447,_4446);
  }
}mosek::fusion::ExprConst::t mosek::fusion::p_ExprConst::_new_ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _4448,    std::shared_ptr< monty::ndarray< long long,1 > > _4449,    double _4450){ return new mosek::fusion::ExprConst(_4448,_4449,_4450); }mosek::fusion::ExprConst::ExprConst  (std::shared_ptr< monty::ndarray< int,1 > > _4448,    std::shared_ptr< monty::ndarray< long long,1 > > _4449,    double _4450) :    ExprConst(new mosek::fusion::p_ExprConst(this)){ mosek::fusion::p_ExprConst::_get_impl(this)->_initialize(_4448,_4449,_4450); }void mosek::fusion::p_ExprConst::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4448,    std::shared_ptr< monty::ndarray< long long,1 > > _4449,    double _4450){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4448(_4448 ? _4448->raw() : nullptr, _4448 ? _4448->size(0) : 0);
    _checked_ptr_1<long long> _ptr__4449(_4449 ? _4449->raw() : nullptr, _4449 ? _4449->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_4448);
    long long _10659;
    bool _10660 = (NULL == _4449.get());
    if (_10660)
    {
      _10659 = ::mosek::fusion::p_Set::size(_4448);
    }
    else
    {
      _10659 = (int)((_4449)->size(0));
    }
    long long _4451 = _10659;
    std::vector<double> _10661;
    for (long long _4452 = (int)0, _10662 = _4451; _4452 < _10662 ; ++_4452)
    {
      _10661.push_back(_4450);
    }
    auto _10663 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_10661.size()),_10661.begin(),_10661.end()));
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix = _10663;
    std::shared_ptr< monty::ndarray< long long,1 > > _10664;
    bool _10665 = (NULL != _4449.get());
    if (_10665)
    {
      _10664 = ::mosek::fusion::Utils::Tools::arraycopy(_4449);
    }
    else
    {
      _10664 = nullptr;
    }
    mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->sparsity = _10664;
    ::mosek::fusion::p_ExprConst::validate(_4448,mosek::fusion::p_ExprConst::_get_impl(::mosek::fusion::ExprConst::t(_pubthis))->bfix,_4449);
  }
}void mosek::fusion::ExprConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4453,monty::rc_ptr< ::mosek::fusion::WorkStack > _4454,monty::rc_ptr< ::mosek::fusion::WorkStack > _4455) { mosek::fusion::p_ExprConst::_get_impl(this)->eval(_4453,_4454,_4455); }void mosek::fusion::p_ExprConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4453,monty::rc_ptr< ::mosek::fusion::WorkStack > _4454,monty::rc_ptr< ::mosek::fusion::WorkStack > _4455){
  std::shared_ptr< monty::ndarray< int,1 > > _4456 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__4456(_4456 ? _4456->raw() : nullptr,_4456 ? _4456->size(0) : 0);
  int _4457 = (int)((_4456)->size(0));
  int _4458 = (int)0;
  int _10666 = (int)0;
  int _10667 = (int)((bfix)->size(0));
  for (int _4459 = _10666; _4459 < _10667; ++_4459)
  {
    {
      if (((((*bfix)(_4459)) < (int)0) || (((*bfix)(_4459)) > (int)0)))
      {
        {
          ++ _4458;
        }
      }
      {}
    }
  }
  int _4460 = (int)((bfix)->size(0));
  bool _4461 = ((NULL != sparsity.get()) && ((int)((sparsity)->size(0)) < ::mosek::fusion::p_Set::size(_4456)));
  _4453->alloc_expr(_4457,_4460,_4458,_4461,(int)0);
  int _4462 = mosek::fusion::p_WorkStack::_get_impl(_4453)->shape_base;
  int _4463 = mosek::fusion::p_WorkStack::_get_impl(_4453)->ptr_base;
  int _4464 = mosek::fusion::p_WorkStack::_get_impl(_4453)->sp_base;
  int _4465 = mosek::fusion::p_WorkStack::_get_impl(_4453)->nidxs_base;
  int _4466 = mosek::fusion::p_WorkStack::_get_impl(_4453)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4467 = mosek::fusion::p_WorkStack::_get_impl(_4453)->i32;
  _checked_ptr_1<int> _ptr__4467(_4467 ? _4467->raw() : nullptr,_4467 ? _4467->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4468 = mosek::fusion::p_WorkStack::_get_impl(_4453)->i64;
  _checked_ptr_1<long long> _ptr__4468(_4468 ? _4468->raw() : nullptr,_4468 ? _4468->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4469 = mosek::fusion::p_WorkStack::_get_impl(_4453)->f64;
  _checked_ptr_1<double> _ptr__4469(_4469 ? _4469->raw() : nullptr,_4469 ? _4469->size(0) : 0);
  int _10668 = (int)0;
  int _10669 = _4457;
  for (int _4470 = _10668; _4470 < _10669; ++_4470)
  {
    {
      _ptr__4467[safe_add( _4462,_4470 )] = _ptr__4456[_4470];
    }
  }
  int _4471 = (int)0;
  _ptr__4467[_4463] = (int)0;
  if (_4461)
  {
    {
      int _10670 = (int)0;
      int _10671 = _4460;
      for (int _4472 = _10670; _4472 < _10671; ++_4472)
      {
        {
          _ptr__4468[safe_add( _4464,_4472 )] = ((*sparsity)(_4472));
        }
      }
    }
  }
  {}
  int _10672 = (int)0;
  int _10673 = _4460;
  for (int _4473 = _10672; _4473 < _10673; ++_4473)
  {
    {
      if (((((*bfix)(_4473)) < (int)0) || (((*bfix)(_4473)) > (int)0)))
      {
        {
          _ptr__4468[safe_add( _4465,_4471 )] = (int)0;
          _ptr__4469[safe_add( _4466,_4471 )] = ((*bfix)(_4473));
          ++ _4471;
        }
      }
      {}
      _ptr__4467[safe_add( safe_add( _4463,_4473 ),(int)1 )] = _4471;
    }
  }
}
void mosek::fusion::p_ExprConst::validate(std::shared_ptr< monty::ndarray< int,1 > > _4474,std::shared_ptr< monty::ndarray< double,1 > > _4475,std::shared_ptr< monty::ndarray< long long,1 > > _4476){
  _checked_ptr_1<int> _ptr__4474(_4474 ? _4474->raw() : nullptr, _4474 ? _4474->size(0) : 0);
  _checked_ptr_1<double> _ptr__4475(_4475 ? _4475->raw() : nullptr, _4475 ? _4475->size(0) : 0);
  _checked_ptr_1<long long> _ptr__4476(_4476 ? _4476->raw() : nullptr, _4476 ? _4476->size(0) : 0);
  long long _4477 = ::mosek::fusion::p_Set::size(_4474);
  if ((NULL != _4476.get()))
  {
    {
      if (((int)((_4476)->size(0)) != (int)((_4475)->size(0))))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data lengths"));
        }
      }
      {}
      bool _4478 = false;
      int _10674 = (int)0;
      int _10675 = (int)((_4476)->size(0));
      for (int _4479 = _10674; _4479 < _10675; ++_4479)
      {
        {
          if (((_ptr__4476[_4479] < (int)0) || (_ptr__4476[_4479] >= _4477)))
          {
            {
              _4478 = true;
            }
          }
          {}
        }
      }
      if (_4478)
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Invalid sparsity index"));
        }
      }
      {}
    }
  }
  else
  {
    {
      if (((int)((_4475)->size(0)) != _4477))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Mismatching data length"));
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprConst :: toString() { return mosek::fusion::p_ExprConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprConst::toString(){
  return std::string ("ExprConst()");
}
void mosek::fusion::p_ExprConst::destroy(){sparsity.reset();bfix.reset();}void mosek::fusion::ExprConst::destroy() { mosek::fusion::p_ExprConst::_get_impl(this)->destroy(); }mosek::fusion::ExprPick::ExprPick(mosek::fusion::p_ExprPick *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPick()" << this << std::endl; */ }mosek::fusion::ExprPick::~ExprPick() {  /* std::cout << "~ExprPick()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPick::p_ExprPick  (::mosek::fusion::ExprPick * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _4480,    std::shared_ptr< monty::ndarray< int,2 > > _4481){ return new mosek::fusion::ExprPick(_4480,_4481); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _4480,    std::shared_ptr< monty::ndarray< int,2 > > _4481) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_4480,_4481); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4480,    std::shared_ptr< monty::ndarray< int,2 > > _4481){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_4481)->size(0)))}));
    std::shared_ptr< monty::ndarray< int,1 > > _4482 = _4480->getShape();
    _checked_ptr_1<int> _ptr__4482(_4482 ? _4482->raw() : nullptr,_4482 ? _4482->size(0) : 0);
    int _4483 = (int)((_4482)->size(0));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _4480;
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_4481)->size(0)))));
    std::shared_ptr< monty::ndarray< long long,1 > > _4484 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
    _checked_ptr_1<long long> _ptr__4484(_4484 ? _4484->raw() : nullptr,_4484 ? _4484->size(0) : 0);
    if (((int)((_4481)->size(1)) != _4483))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching shape and index dimensions"));
      }
    }
    {}
    bool _4485 = false;
    int _10676 = (int)0;
    int _10677 = (int)((_4481)->size(0));
    for (int _4486 = _10676; _4486 < _10677; ++_4486)
    {
      {
        int _10678 = (int)0;
        int _10679 = _4483;
        for (int _4487 = _10678; _4487 < _10679; ++_4487)
        {
          {
            if (((((*_4481)(_4486,_4487)) < (int)0) || (((*_4481)(_4486,_4487)) >= _ptr__4482[_4487])))
            {
              {
                _4485 = true;
              }
            }
            {}
          }
        }
      }
    }
    if (_4485)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
      }
    }
    {}
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4488 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4483)));
      _checked_ptr_1<long long> _ptr__4488(_4488 ? _4488->raw() : nullptr,_4488 ? _4488->size(0) : 0);
      _ptr__4488[(_4483 - (int)1)] = (int)1;
      int _10680 = (int)1;
      int _10681 = _4483;
      for (int _4489 = _10680; _4489 < _10681; ++_4489)
      {
        {
          _ptr__4488[((_4483 - _4489) - (int)1)] = safe_mul( _ptr__4488[(_4483 - _4489)],_ptr__4482[(_4483 - _4489)] );
        }
      }
      int _10682 = (int)0;
      int _10683 = (int)((_4481)->size(0));
      for (int _4490 = _10682; _4490 < _10683; ++_4490)
      {
        {
          long long _4491 = (long long)0;
          int _10684 = (int)0;
          int _10685 = _4483;
          for (int _4492 = _10684; _4492 < _10685; ++_4492)
          {
            {
              _4491 += safe_mul( _ptr__4488[_4492],((*_4481)(_4490,_4492)) );
            }
          }
          _ptr__4484[_4490] = _4491;
        }
      }
    }
  }
}mosek::fusion::ExprPick::t mosek::fusion::p_ExprPick::_new_ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _4493,    std::shared_ptr< monty::ndarray< long long,1 > > _4494){ return new mosek::fusion::ExprPick(_4493,_4494); }mosek::fusion::ExprPick::ExprPick  (monty::rc_ptr< ::mosek::fusion::Expression > _4493,    std::shared_ptr< monty::ndarray< long long,1 > > _4494) :    ExprPick(new mosek::fusion::p_ExprPick(this)){ mosek::fusion::p_ExprPick::_get_impl(this)->_initialize(_4493,_4494); }void mosek::fusion::p_ExprPick::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4493,    std::shared_ptr< monty::ndarray< long long,1 > > _4494){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__4494(_4494 ? _4494->raw() : nullptr, _4494 ? _4494->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_4494)->size(0)))}));
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->expr = _4493;
    std::shared_ptr< monty::ndarray< int,1 > > _4495 = _4493->getShape();
    _checked_ptr_1<int> _ptr__4495(_4495 ? _4495->raw() : nullptr,_4495 ? _4495->size(0) : 0);
    long long _4496 = ::mosek::fusion::p_Set::size(_4495);
    bool _4497 = false;
    int _10686 = (int)0;
    int _10687 = (int)((_4494)->size(0));
    for (int _4498 = _10686; _4498 < _10687; ++_4498)
    {
      {
        if (((_ptr__4494[_4498] < (int)0) || (_ptr__4494[_4498] >= _4496)))
        {
          {
            _4497 = true;
          }
        }
        {}
      }
    }
    if (_4497)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Pick index out of bounds"));
      }
    }
    {}
    mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs = ::mosek::fusion::Utils::Tools::arraycopy(_4494);
  }
}void mosek::fusion::ExprPick :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501) { mosek::fusion::p_ExprPick::_get_impl(this)->eval(_4499,_4500,_4501); }void mosek::fusion::p_ExprPick::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501){
  expr->eval(_4500,_4499,_4501);
  _4500->pop_expr();
  int _4502 = mosek::fusion::p_WorkStack::_get_impl(_4500)->nd;
  int _4503 = mosek::fusion::p_WorkStack::_get_impl(_4500)->shape_base;
  int _4504 = mosek::fusion::p_WorkStack::_get_impl(_4500)->nelem;
  int _4505 = mosek::fusion::p_WorkStack::_get_impl(_4500)->nnz;
  int _4506 = mosek::fusion::p_WorkStack::_get_impl(_4500)->ncodeatom;
  bool _4507 = mosek::fusion::p_WorkStack::_get_impl(_4500)->hassp;
  int _4508 = mosek::fusion::p_WorkStack::_get_impl(_4500)->ptr_base;
  int _4509 = mosek::fusion::p_WorkStack::_get_impl(_4500)->sp_base;
  int _4510 = mosek::fusion::p_WorkStack::_get_impl(_4500)->nidxs_base;
  int _4511 = mosek::fusion::p_WorkStack::_get_impl(_4500)->cof_base;
  int _4512 = mosek::fusion::p_WorkStack::_get_impl(_4500)->code_base;
  int _4513 = mosek::fusion::p_WorkStack::_get_impl(_4500)->codeptr_base;
  int _4514 = mosek::fusion::p_WorkStack::_get_impl(_4500)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4515 = mosek::fusion::p_WorkStack::_get_impl(_4500)->i32;
  _checked_ptr_1<int> _ptr__4515(_4515 ? _4515->raw() : nullptr,_4515 ? _4515->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4516 = mosek::fusion::p_WorkStack::_get_impl(_4500)->i64;
  _checked_ptr_1<long long> _ptr__4516(_4516 ? _4516->raw() : nullptr,_4516 ? _4516->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4517 = mosek::fusion::p_WorkStack::_get_impl(_4500)->f64;
  _checked_ptr_1<double> _ptr__4517(_4517 ? _4517->raw() : nullptr,_4517 ? _4517->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4518 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
  _checked_ptr_1<long long> _ptr__4518(_4518 ? _4518->raw() : nullptr,_4518 ? _4518->size(0) : 0);
  if ((!_4507))
  {
    {
      int _4519 = (int)((_4518)->size(0));
      int _4520 = (int)1;
      int _4521 = (int)0;
      int _4522 = (int)0;
      int _10688 = (int)0;
      int _10689 = (int)((_4518)->size(0));
      for (int _4523 = _10688; _4523 < _10689; ++_4523)
      {
        {
          _4521 += (_ptr__4515[safe_add( safe_add( _4508,_ptr__4518[_4523] ),(int)1 )] - _ptr__4515[safe_add( _4508,_ptr__4518[_4523] )]);
          if ((_4506 > (int)0))
          {
            {
              _4522 += (_ptr__4515[safe_add( _4513,_ptr__4515[safe_add( safe_add( _4508,_ptr__4518[_4523] ),(int)1 )] )] - _ptr__4515[safe_add( _4513,_ptr__4515[safe_add( _4508,_ptr__4518[_4523] )] )]);
            }
          }
          {}
        }
      }
      _4499->alloc_expr(_4520,_4519,_4521,false,_4522);
      int _4524 = mosek::fusion::p_WorkStack::_get_impl(_4499)->cof_base;
      int _4525 = mosek::fusion::p_WorkStack::_get_impl(_4499)->nidxs_base;
      int _4526 = mosek::fusion::p_WorkStack::_get_impl(_4499)->ptr_base;
      int _4527 = mosek::fusion::p_WorkStack::_get_impl(_4499)->shape_base;
      int _4528 = mosek::fusion::p_WorkStack::_get_impl(_4499)->code_base;
      int _4529 = mosek::fusion::p_WorkStack::_get_impl(_4499)->codeptr_base;
      int _4530 = mosek::fusion::p_WorkStack::_get_impl(_4499)->cconst_base;
      {
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4531 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i32;
      _checked_ptr_1<int> _ptr__4531(_4531 ? _4531->raw() : nullptr,_4531 ? _4531->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4532 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i64;
      _checked_ptr_1<long long> _ptr__4532(_4532 ? _4532->raw() : nullptr,_4532 ? _4532->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4533 = mosek::fusion::p_WorkStack::_get_impl(_4499)->f64;
      _checked_ptr_1<double> _ptr__4533(_4533 ? _4533->raw() : nullptr,_4533 ? _4533->size(0) : 0);
      _ptr__4531[_4527] = (int)((_4518)->size(0));
      int _4534 = (int)0;
      int _4535 = (int)0;
      _ptr__4531[_4526] = (int)0;
      int _10690 = (int)0;
      int _10691 = (int)((_4518)->size(0));
      for (int _4536 = _10690; _4536 < _10691; ++_4536)
      {
        {
          int _10692 = _ptr__4515[safe_add( _4508,_ptr__4518[_4536] )];
          int _10693 = _ptr__4515[safe_add( safe_add( _4508,_ptr__4518[_4536] ),(int)1 )];
          for (int _4537 = _10692; _4537 < _10693; ++_4537)
          {
            {
              _ptr__4532[safe_add( _4525,_4535 )] = _ptr__4516[safe_add( _4510,_4537 )];
              _ptr__4533[safe_add( _4524,_4535 )] = _ptr__4517[safe_add( _4511,_4537 )];
              if ((_4506 > (int)0))
              {
                {
                  int _10694 = _ptr__4515[safe_add( _4513,_4537 )];
                  int _10695 = _ptr__4515[safe_add( safe_add( _4513,_4537 ),(int)1 )];
                  for (int _4538 = _10694; _4538 < _10695; ++_4538)
                  {
                    {
                      _ptr__4531[safe_add( _4528,_4534 )] = _ptr__4515[safe_add( _4512,_4538 )];
                      _ptr__4533[safe_add( _4530,_4534 )] = _ptr__4517[safe_add( _4514,_4538 )];
                      ++ _4534;
                    }
                  }
                  _ptr__4531[safe_add( safe_add( _4529,_4535 ),(int)1 )] = _4534;
                }
              }
              {}
              ++ _4535;
            }
          }
          _ptr__4531[safe_add( safe_add( _4526,_4536 ),(int)1 )] = _4535;
        }
      }
    }
  }
  else
  {
    {
      int _4539 = (int)1;
      int _4540 = (int)((_4518)->size(0));
      int _4541 = (int)0;
      int _4542 = (int)0;
      std::shared_ptr< monty::ndarray< long long,1 > > _4543 = mosek::fusion::p_ExprPick::_get_impl(::mosek::fusion::ExprPick::t(_pubthis))->idxs;
      _checked_ptr_1<long long> _ptr__4543(_4543 ? _4543->raw() : nullptr,_4543 ? _4543->size(0) : 0);
      int _4544 = _4501->alloci32((int)((_4543)->size(0)));
      std::shared_ptr< monty::ndarray< int,1 > > _4545 = mosek::fusion::p_WorkStack::_get_impl(_4501)->i32;
      _checked_ptr_1<int> _ptr__4545(_4545 ? _4545->raw() : nullptr,_4545 ? _4545->size(0) : 0);
      int _10696 = (int)0;
      int _10697 = (int)((_4543)->size(0));
      for (int _4546 = _10696; _4546 < _10697; ++_4546)
      {
        {
          int _4547 = _4504;
          int _4548 = (int)0;
          while ( (_4548 < (_4547 - (int)1)) )
          {
            {
              int _4549 = (safe_add( safe_add( _4547,_4548 ),(int)1 ) / (int)2);
              if ((_ptr__4516[safe_add( _4509,_4549 )] >= _ptr__4543[_4546]))
              {
                {
                  _4547 = _4549;
                }
              }
              else
              {
                {
                  _4548 = _4549;
                }
              }
            }
          }
          ++ _4548;
          if (((_4548 < _4504) && (_ptr__4516[safe_add( _4509,_4548 )] == _ptr__4543[_4546])))
          {
            {
              _ptr__4545[safe_add( _4544,_4546 )] = _4548;
              _4541 += (_ptr__4515[safe_add( safe_add( _4508,_4548 ),(int)1 )] - _ptr__4515[safe_add( _4508,_4548 )]);
              if ((_4506 > (int)0))
              {
                {
                  _4542 += (_ptr__4515[safe_add( _4513,_ptr__4515[safe_add( safe_add( _4508,_ptr__4543[_4546] ),(int)1 )] )] - _ptr__4515[safe_add( _4513,_ptr__4515[safe_add( _4508,_ptr__4543[_4546] )] )]);
                }
              }
              {}
            }
          }
          else
          {
            {
              _ptr__4545[safe_add( _4544,_4546 )] = (-(int)1);
            }
          }
        }
      }
      _4499->alloc_expr(_4539,_4540,_4541,false,_4542);
      int _4550 = mosek::fusion::p_WorkStack::_get_impl(_4499)->ptr_base;
      int _4551 = mosek::fusion::p_WorkStack::_get_impl(_4499)->nidxs_base;
      int _4552 = mosek::fusion::p_WorkStack::_get_impl(_4499)->cof_base;
      int _4553 = mosek::fusion::p_WorkStack::_get_impl(_4499)->shape_base;
      int _4554 = mosek::fusion::p_WorkStack::_get_impl(_4499)->code_base;
      int _4555 = mosek::fusion::p_WorkStack::_get_impl(_4499)->codeptr_base;
      int _4556 = mosek::fusion::p_WorkStack::_get_impl(_4499)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4557 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i32;
      _checked_ptr_1<int> _ptr__4557(_4557 ? _4557->raw() : nullptr,_4557 ? _4557->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4558 = mosek::fusion::p_WorkStack::_get_impl(_4499)->i64;
      _checked_ptr_1<long long> _ptr__4558(_4558 ? _4558->raw() : nullptr,_4558 ? _4558->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4559 = mosek::fusion::p_WorkStack::_get_impl(_4499)->f64;
      _checked_ptr_1<double> _ptr__4559(_4559 ? _4559->raw() : nullptr,_4559 ? _4559->size(0) : 0);
      _ptr__4557[_4553] = (int)((_4543)->size(0));
      _ptr__4557[_4550] = (int)0;
      int _4560 = (int)0;
      int _4561 = (int)0;
      int _10698 = (int)0;
      int _10699 = (int)((_4543)->size(0));
      for (int _4562 = _10698; _4562 < _10699; ++_4562)
      {
        {
          if ((_ptr__4545[safe_add( _4544,_4562 )] >= (int)0))
          {
            {
              int _4563 = _ptr__4545[safe_add( _4544,_4562 )];
              int _10700 = _ptr__4515[safe_add( _4508,_4563 )];
              int _10701 = _ptr__4515[safe_add( safe_add( _4508,_4563 ),(int)1 )];
              for (int _4564 = _10700; _4564 < _10701; ++_4564)
              {
                {
                  _ptr__4558[safe_add( _4551,_4561 )] = _ptr__4516[safe_add( _4510,_4564 )];
                  _ptr__4559[safe_add( _4552,_4561 )] = _ptr__4517[safe_add( _4511,_4564 )];
                  if ((_4506 > (int)0))
                  {
                    {
                      int _10702 = _ptr__4515[safe_add( _4513,_4564 )];
                      int _10703 = _ptr__4515[safe_add( safe_add( _4513,_4564 ),(int)1 )];
                      for (int _4565 = _10702; _4565 < _10703; ++_4565)
                      {
                        {
                          _ptr__4557[safe_add( _4554,_4560 )] = _ptr__4515[safe_add( _4512,_4565 )];
                          _ptr__4559[safe_add( _4556,_4560 )] = _ptr__4517[safe_add( _4514,_4565 )];
                          ++ _4560;
                        }
                      }
                      _ptr__4557[safe_add( safe_add( _4555,_4561 ),(int)1 )] = _4560;
                    }
                  }
                  {}
                  ++ _4561;
                }
              }
            }
          }
          {}
          _ptr__4557[safe_add( safe_add( _4550,_4562 ),(int)1 )] = _4561;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprPick :: toString() { return mosek::fusion::p_ExprPick::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprPick::toString(){
  return std::string ("ExprPick()");
}
void mosek::fusion::p_ExprPick::destroy(){idxs.reset();expr.reset();}void mosek::fusion::ExprPick::destroy() { mosek::fusion::p_ExprPick::_get_impl(this)->destroy(); }mosek::fusion::ExprSlice::ExprSlice(mosek::fusion::p_ExprSlice *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSlice()" << this << std::endl; */ }mosek::fusion::ExprSlice::~ExprSlice() {  /* std::cout << "~ExprSlice()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSlice::p_ExprSlice  (::mosek::fusion::ExprSlice * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSlice::t mosek::fusion::p_ExprSlice::_new_ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _4566,    std::shared_ptr< monty::ndarray< int,1 > > _4567,    std::shared_ptr< monty::ndarray< int,1 > > _4568){ return new mosek::fusion::ExprSlice(_4566,_4567,_4568); }mosek::fusion::ExprSlice::ExprSlice  (monty::rc_ptr< ::mosek::fusion::Expression > _4566,    std::shared_ptr< monty::ndarray< int,1 > > _4567,    std::shared_ptr< monty::ndarray< int,1 > > _4568) :    ExprSlice(new mosek::fusion::p_ExprSlice(this)){ mosek::fusion::p_ExprSlice::_get_impl(this)->_initialize(_4566,_4567,_4568); }void mosek::fusion::p_ExprSlice::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4566,    std::shared_ptr< monty::ndarray< int,1 > > _4567,    std::shared_ptr< monty::ndarray< int,1 > > _4568){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4567(_4567 ? _4567->raw() : nullptr, _4567 ? _4567->size(0) : 0);
    _checked_ptr_1<int> _ptr__4568(_4568 ? _4568->raw() : nullptr, _4568 ? _4568->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSlice::makeShape(_4566->getShape(),_4567,_4568));
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->expr = _4566;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->first = _4567;
    mosek::fusion::p_ExprSlice::_get_impl(::mosek::fusion::ExprSlice::t(_pubthis))->last = _4568;
  }
}void mosek::fusion::ExprSlice :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4569,monty::rc_ptr< ::mosek::fusion::WorkStack > _4570,monty::rc_ptr< ::mosek::fusion::WorkStack > _4571) { mosek::fusion::p_ExprSlice::_get_impl(this)->eval(_4569,_4570,_4571); }void mosek::fusion::p_ExprSlice::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4569,monty::rc_ptr< ::mosek::fusion::WorkStack > _4570,monty::rc_ptr< ::mosek::fusion::WorkStack > _4571){
  expr->eval(_4570,_4569,_4571);
  _4570->pop_expr();
  int _4572 = mosek::fusion::p_WorkStack::_get_impl(_4570)->nd;
  int _4573 = mosek::fusion::p_WorkStack::_get_impl(_4570)->nelem;
  int _4574 = mosek::fusion::p_WorkStack::_get_impl(_4570)->nnz;
  int _4575 = mosek::fusion::p_WorkStack::_get_impl(_4570)->ncodeatom;
  bool _4576 = mosek::fusion::p_WorkStack::_get_impl(_4570)->hassp;
  int _4577 = mosek::fusion::p_WorkStack::_get_impl(_4570)->shape_base;
  int _4578 = mosek::fusion::p_WorkStack::_get_impl(_4570)->ptr_base;
  int _4579 = mosek::fusion::p_WorkStack::_get_impl(_4570)->sp_base;
  int _4580 = mosek::fusion::p_WorkStack::_get_impl(_4570)->nidxs_base;
  int _4581 = mosek::fusion::p_WorkStack::_get_impl(_4570)->cof_base;
  int _4582 = mosek::fusion::p_WorkStack::_get_impl(_4570)->code_base;
  int _4583 = mosek::fusion::p_WorkStack::_get_impl(_4570)->codeptr_base;
  int _4584 = mosek::fusion::p_WorkStack::_get_impl(_4570)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4585 = mosek::fusion::p_WorkStack::_get_impl(_4570)->i32;
  _checked_ptr_1<int> _ptr__4585(_4585 ? _4585->raw() : nullptr,_4585 ? _4585->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4586 = mosek::fusion::p_WorkStack::_get_impl(_4570)->i64;
  _checked_ptr_1<long long> _ptr__4586(_4586 ? _4586->raw() : nullptr,_4586 ? _4586->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4587 = mosek::fusion::p_WorkStack::_get_impl(_4570)->f64;
  _checked_ptr_1<double> _ptr__4587(_4587 ? _4587->raw() : nullptr,_4587 ? _4587->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4588 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4572)));
  _checked_ptr_1<long long> _ptr__4588(_4588 ? _4588->raw() : nullptr,_4588 ? _4588->size(0) : 0);
  _ptr__4588[(_4572 - (int)1)] = (int)1;
  int _10704 = (int)1;
  int _10705 = _4572;
  for (int _4589 = _10704; _4589 < _10705; ++_4589)
  {
    {
      _ptr__4588[((_4572 - _4589) - (int)1)] = safe_mul( _ptr__4588[(_4572 - _4589)],_ptr__4585[(safe_add( _4577,_4572 ) - _4589)] );
    }
  }
  int _4590 = (int)0;
  int _4591 = (int)0;
  int _4592 = (int)0;
  if (_4576)
  {
    {
      int _10706 = (int)0;
      int _10707 = _4573;
      for (int _4593 = _10706; _4593 < _10707; ++_4593)
      {
        {
          bool _4594 = true;
          int _10708 = (int)0;
          int _10709 = _4572;
          for (int _4595 = _10708; _4595 < _10709; ++_4595)
          {
            {
              long long _4596 = ((_ptr__4586[safe_add( _4579,_4593 )] / _ptr__4588[_4595]) % _ptr__4585[safe_add( _4577,_4595 )]);
              _4594 = (_4594 && ((_4596 >= ((*first)(_4595))) && (_4596 < ((*last)(_4595)))));
            }
          }
          if (_4594)
          {
            {
              _4592 += (_ptr__4585[safe_add( safe_add( _4578,_4593 ),(int)1 )] - _ptr__4585[safe_add( _4578,_4593 )]);
              if ((_4575 > (int)0))
              {
                {
                  _4590 += (_ptr__4585[safe_add( _4583,_ptr__4585[safe_add( safe_add( _4578,_4593 ),(int)1 )] )] - _ptr__4585[safe_add( _4583,_ptr__4585[safe_add( _4578,_4593 )] )]);
                }
              }
              {}
              ++ _4591;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      _4591 = (int)1;
      int _10710 = (int)0;
      int _10711 = _4572;
      for (int _4597 = _10710; _4597 < _10711; ++_4597)
      {
        {
          _4591 *= (((*last)(_4597)) - ((*first)(_4597)));
        }
      }
      int _10712 = (int)0;
      int _10713 = _4573;
      for (int _4598 = _10712; _4598 < _10713; ++_4598)
      {
        {
          bool _4599 = true;
          int _10714 = (int)0;
          int _10715 = _4572;
          for (int _4600 = _10714; _4600 < _10715; ++_4600)
          {
            {
              long long _4601 = ((_4598 / _ptr__4588[_4600]) % _ptr__4585[safe_add( _4577,_4600 )]);
              _4599 = (_4599 && ((_4601 >= ((*first)(_4600))) && (_4601 < ((*last)(_4600)))));
            }
          }
          if (_4599)
          {
            {
              _4592 += (_ptr__4585[safe_add( safe_add( _4578,_4598 ),(int)1 )] - _ptr__4585[safe_add( _4578,_4598 )]);
              if ((_4575 > (int)0))
              {
                {
                  _4590 += (_ptr__4585[safe_add( _4583,_ptr__4585[safe_add( safe_add( _4578,_4598 ),(int)1 )] )] - _ptr__4585[safe_add( _4583,_ptr__4585[safe_add( _4578,_4598 )] )]);
                }
              }
              {}
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _10716;
  for (int _4603 = (int)0, _10717 = _4572; _4603 < _10717 ; ++_4603)
  {
    _10716.push_back((((*last)(_4603)) - ((*first)(_4603))));
  }
  auto _10718 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10716.size()),_10716.begin(),_10716.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _4602 = _10718;
  _checked_ptr_1<int> _ptr__4602(_4602 ? _4602->raw() : nullptr,_4602 ? _4602->size(0) : 0);
  bool _4604 = (_4591 < ::mosek::fusion::p_Set::size(_4602));
  _4569->alloc_expr(_4572,_4591,_4592,_4604,_4590);
  int _4605 = mosek::fusion::p_WorkStack::_get_impl(_4569)->shape_base;
  int _4606 = mosek::fusion::p_WorkStack::_get_impl(_4569)->cof_base;
  int _4607 = mosek::fusion::p_WorkStack::_get_impl(_4569)->nidxs_base;
  int _10719;
  bool _10720 = _4604;
  if (_10720)
  {
    _10719 = mosek::fusion::p_WorkStack::_get_impl(_4569)->sp_base;
  }
  else
  {
    _10719 = _4569->alloci64(_4591);
  }
  int _4608 = _10719;
  int _4609 = mosek::fusion::p_WorkStack::_get_impl(_4569)->ptr_base;
  int _4610 = mosek::fusion::p_WorkStack::_get_impl(_4569)->code_base;
  int _4611 = mosek::fusion::p_WorkStack::_get_impl(_4569)->codeptr_base;
  int _4612 = mosek::fusion::p_WorkStack::_get_impl(_4569)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4613 = mosek::fusion::p_WorkStack::_get_impl(_4569)->i32;
  _checked_ptr_1<int> _ptr__4613(_4613 ? _4613->raw() : nullptr,_4613 ? _4613->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4614 = mosek::fusion::p_WorkStack::_get_impl(_4569)->i64;
  _checked_ptr_1<long long> _ptr__4614(_4614 ? _4614->raw() : nullptr,_4614 ? _4614->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4615 = mosek::fusion::p_WorkStack::_get_impl(_4569)->f64;
  _checked_ptr_1<double> _ptr__4615(_4615 ? _4615->raw() : nullptr,_4615 ? _4615->size(0) : 0);
  int _10721 = (int)0;
  int _10722 = _4572;
  for (int _4616 = _10721; _4616 < _10722; ++_4616)
  {
    {
      _ptr__4613[safe_add( _4605,_4616 )] = _ptr__4602[_4616];
    }
  }
  _ptr__4613[_4609] = (int)0;
  if ((_4575 > (int)0))
  {
    {
      _ptr__4613[_4611] = (int)0;
    }
  }
  {}
  std::shared_ptr< monty::ndarray< long long,1 > > _4617 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4572)));
  _checked_ptr_1<long long> _ptr__4617(_4617 ? _4617->raw() : nullptr,_4617 ? _4617->size(0) : 0);
  _ptr__4617[(_4572 - (int)1)] = (int)1;
  int _10723 = (int)1;
  int _10724 = _4572;
  for (int _4618 = _10723; _4618 < _10724; ++_4618)
  {
    {
      _ptr__4617[((_4572 - _4618) - (int)1)] = safe_mul( _ptr__4617[(_4572 - _4618)],_ptr__4602[(_4572 - _4618)] );
    }
  }
  int _4619 = (int)0;
  int _4620 = (int)0;
  int _4621 = (int)0;
  if (_4576)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _4622 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4572)));
      _checked_ptr_1<int> _ptr__4622(_4622 ? _4622->raw() : nullptr,_4622 ? _4622->size(0) : 0);
      int _10725 = (int)0;
      int _10726 = _4573;
      for (int _4623 = _10725; _4623 < _10726; ++_4623)
      {
        {
          bool _4624 = true;
          int _10727 = (int)0;
          int _10728 = _4572;
          for (int _4625 = _10727; _4625 < _10728; ++_4625)
          {
            {
              _ptr__4622[_4625] = (int)((_ptr__4586[safe_add( _4579,_4623 )] / _ptr__4588[_4625]) % _ptr__4585[safe_add( _4577,_4625 )]);
              _4624 = (_4624 && ((_ptr__4622[_4625] >= ((*first)(_4625))) && (_ptr__4622[_4625] < ((*last)(_4625)))));
            }
          }
          if (_4624)
          {
            {
              int _10729 = _ptr__4585[safe_add( _4578,_4623 )];
              int _10730 = _ptr__4585[safe_add( safe_add( _4578,_4623 ),(int)1 )];
              for (int _4626 = _10729; _4626 < _10730; ++_4626)
              {
                {
                  _ptr__4614[safe_add( _4607,_4621 )] = _ptr__4586[safe_add( _4580,_4626 )];
                  _ptr__4615[safe_add( _4606,_4621 )] = _ptr__4587[safe_add( _4581,_4626 )];
                  if ((_4575 > (int)0))
                  {
                    {
                      int _10731 = _ptr__4585[safe_add( _4583,_4626 )];
                      int _10732 = _ptr__4585[safe_add( safe_add( _4583,_4626 ),(int)1 )];
                      for (int _4627 = _10731; _4627 < _10732; ++_4627)
                      {
                        {
                          _ptr__4613[safe_add( _4610,_4619 )] = _ptr__4585[safe_add( _4582,_4627 )];
                          _ptr__4615[safe_add( _4612,_4619 )] = _ptr__4587[safe_add( _4584,_4627 )];
                          ++ _4619;
                        }
                      }
                      _ptr__4613[safe_add( safe_add( _4611,_4621 ),(int)1 )] = _4619;
                    }
                  }
                  {}
                  ++ _4621;
                }
              }
              long long _4628 = (long long)0;
              int _10733 = (int)0;
              int _10734 = _4572;
              for (int _4629 = _10733; _4629 < _10734; ++_4629)
              {
                {
                  _4628 += safe_mul( _ptr__4617[_4629],(_ptr__4622[_4629] - ((*first)(_4629))) );
                }
              }
              _ptr__4614[safe_add( _4608,_4620 )] = _4628;
              _ptr__4613[safe_add( safe_add( _4609,_4620 ),(int)1 )] = _4621;
              ++ _4620;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _10735 = (int)0;
      int _10736 = _4573;
      for (int _4630 = _10735; _4630 < _10736; ++_4630)
      {
        {
          bool _4631 = true;
          int _10737 = (int)0;
          int _10738 = _4572;
          for (int _4632 = _10737; _4632 < _10738; ++_4632)
          {
            {
              long long _4633 = ((_4630 / _ptr__4588[_4632]) % _ptr__4585[safe_add( _4577,_4632 )]);
              _4631 = (_4631 && ((_4633 >= ((*first)(_4632))) && (_4633 < ((*last)(_4632)))));
            }
          }
          if (_4631)
          {
            {
              int _10739 = _ptr__4585[safe_add( _4578,_4630 )];
              int _10740 = _ptr__4585[safe_add( safe_add( _4578,_4630 ),(int)1 )];
              for (int _4634 = _10739; _4634 < _10740; ++_4634)
              {
                {
                  _ptr__4614[safe_add( _4607,_4621 )] = _ptr__4586[safe_add( _4580,_4634 )];
                  _ptr__4615[safe_add( _4606,_4621 )] = _ptr__4587[safe_add( _4581,_4634 )];
                  if ((_4575 > (int)0))
                  {
                    {
                      int _10741 = _ptr__4585[safe_add( _4583,_4634 )];
                      int _10742 = _ptr__4585[safe_add( safe_add( _4583,_4634 ),(int)1 )];
                      for (int _4635 = _10741; _4635 < _10742; ++_4635)
                      {
                        {
                          _ptr__4613[safe_add( _4610,_4619 )] = _ptr__4585[safe_add( _4582,_4635 )];
                          _ptr__4615[safe_add( _4612,_4619 )] = _ptr__4587[safe_add( _4584,_4635 )];
                          ++ _4619;
                        }
                      }
                      _ptr__4613[safe_add( safe_add( _4611,_4621 ),(int)1 )] = _4619;
                    }
                  }
                  {}
                  ++ _4621;
                }
              }
              _ptr__4613[safe_add( safe_add( _4609,_4620 ),(int)1 )] = _4621;
              ++ _4620;
            }
          }
          {}
        }
      }
    }
  }
  if ((!_4604))
  {
    {
      _4569->popi64(_4591);
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSlice::makeShape(std::shared_ptr< monty::ndarray< int,1 > > _4636,std::shared_ptr< monty::ndarray< int,1 > > _4637,std::shared_ptr< monty::ndarray< int,1 > > _4638){
  _checked_ptr_1<int> _ptr__4636(_4636 ? _4636->raw() : nullptr, _4636 ? _4636->size(0) : 0);
  _checked_ptr_1<int> _ptr__4637(_4637 ? _4637->raw() : nullptr, _4637 ? _4637->size(0) : 0);
  _checked_ptr_1<int> _ptr__4638(_4638 ? _4638->raw() : nullptr, _4638 ? _4638->size(0) : 0);
  if ((((int)((_4636)->size(0)) != (int)((_4637)->size(0))) || ((int)((_4636)->size(0)) != (int)((_4638)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid or mismatching index lengths"));
    }
  }
  {}
  int _10743 = (int)0;
  int _10744 = (int)((_4636)->size(0));
  for (int _4639 = _10743; _4639 < _10744; ++_4639)
  {
    {
      if (((_ptr__4637[_4639] < (int)0) || ((_ptr__4638[_4639] < _ptr__4637[_4639]) || (_ptr__4638[_4639] > _ptr__4636[_4639]))))
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("Slice is out of bounds"));
        }
      }
      {}
    }
  }
  std::vector<int> _10745;
  for (int _4640 = (int)0, _10746 = (int)((_4636)->size(0)); _4640 < _10746 ; ++_4640)
  {
    _10745.push_back((_ptr__4638[_4640] - _ptr__4637[_4640]));
  }
  auto _10747 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10745.size()),_10745.begin(),_10745.end()));
  return _10747;
}
std::string mosek::fusion::ExprSlice :: toString() { return mosek::fusion::p_ExprSlice::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSlice::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _4641 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSlice(["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)((int)0)));
  int _10748 = (int)1;
  int _10749 = (int)((first)->size(0));
  for (int _4642 = _10748; _4642 < _10749; ++_4642)
  {
    {
      _4641->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*first)(_4642)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (":"))->__mosek_2fusion_2Utils_2StringBuffer__a(((*last)(_4642)));
    }
  }
  _4641->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("],"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _4641->toString();
}
void mosek::fusion::p_ExprSlice::destroy(){last.reset();first.reset();expr.reset();}void mosek::fusion::ExprSlice::destroy() { mosek::fusion::p_ExprSlice::_get_impl(this)->destroy(); }mosek::fusion::ExprPermuteDims::ExprPermuteDims(mosek::fusion::p_ExprPermuteDims *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprPermuteDims()" << this << std::endl; */ }mosek::fusion::ExprPermuteDims::~ExprPermuteDims() {  /* std::cout << "~ExprPermuteDims()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprPermuteDims::p_ExprPermuteDims  (::mosek::fusion::ExprPermuteDims * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _4643,    monty::rc_ptr< ::mosek::fusion::Expression > _4644){ return new mosek::fusion::ExprPermuteDims(_4643,_4644); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _4643,    monty::rc_ptr< ::mosek::fusion::Expression > _4644) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_4643,_4644); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4643,    monty::rc_ptr< ::mosek::fusion::Expression > _4644){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4643(_4643 ? _4643->raw() : nullptr, _4643 ? _4643->size(0) : 0);
    mosek::fusion::p_ExprPermuteDims::_initialize(_4643,_4644,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _4645 = _4644->getShape();
    _checked_ptr_1<int> _ptr__4645(_4645 ? _4645->raw() : nullptr,_4645 ? _4645->size(0) : 0);
    if (((int)((_4643)->size(0)) != (int)((_4645)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
      }
    }
    {}
    std::vector<int> _10750;
    for (int _4647 = (int)0, _10751 = (int)((_4643)->size(0)); _4647 < _10751 ; ++_4647)
    {
      _10750.push_back((int)0);
    }
    auto _10752 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10750.size()),_10750.begin(),_10750.end()));
    std::shared_ptr< monty::ndarray< int,1 > > _4646 = _10752;
    _checked_ptr_1<int> _ptr__4646(_4646 ? _4646->raw() : nullptr,_4646 ? _4646->size(0) : 0);
    int _10753 = (int)0;
    int _10754 = (int)((_4646)->size(0));
    for (int _4648 = _10753; _4648 < _10754; ++_4648)
    {
      {
        if (((_ptr__4643[_4648] < (int)0) || (_ptr__4643[_4648] > (int)((_4645)->size(0)))))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
        ++ _ptr__4646[_ptr__4643[_4648]];
      }
    }
    int _10755 = (int)0;
    int _10756 = (int)((_4646)->size(0));
    for (int _4649 = _10755; _4649 < _10756; ++_4649)
    {
      {
        if (((_ptr__4646[_4649] < (int)1) || (_ptr__4646[_4649] > (int)1)))
        {
          {
            throw ::mosek::fusion::LengthError(std::string ("Invalid dimension permutation"));
          }
        }
        {}
      }
    }
  }
}mosek::fusion::ExprPermuteDims::t mosek::fusion::p_ExprPermuteDims::_new_ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _4650,    monty::rc_ptr< ::mosek::fusion::Expression > _4651,    int _4652){ return new mosek::fusion::ExprPermuteDims(_4650,_4651,_4652); }mosek::fusion::ExprPermuteDims::ExprPermuteDims  (std::shared_ptr< monty::ndarray< int,1 > > _4650,    monty::rc_ptr< ::mosek::fusion::Expression > _4651,    int _4652) :    ExprPermuteDims(new mosek::fusion::p_ExprPermuteDims(this)){ mosek::fusion::p_ExprPermuteDims::_get_impl(this)->_initialize(_4650,_4651,_4652); }void mosek::fusion::p_ExprPermuteDims::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _4650,    monty::rc_ptr< ::mosek::fusion::Expression > _4651,    int _4652){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__4650(_4650 ? _4650->raw() : nullptr, _4650 ? _4650->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprPermuteDims::computeshape(_4650,_4651->getShape()));
    mosek::fusion::p_ExprPermuteDims::_get_impl(::mosek::fusion::ExprPermuteDims::t(_pubthis))->expr = _4651;
    dperm = ::mosek::fusion::Utils::Tools::arraycopy(_4650);
  }
}void mosek::fusion::ExprPermuteDims :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4653,monty::rc_ptr< ::mosek::fusion::WorkStack > _4654,monty::rc_ptr< ::mosek::fusion::WorkStack > _4655) { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->eval(_4653,_4654,_4655); }void mosek::fusion::p_ExprPermuteDims::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4653,monty::rc_ptr< ::mosek::fusion::WorkStack > _4654,monty::rc_ptr< ::mosek::fusion::WorkStack > _4655){
  expr->eval(_4654,_4653,_4655);
  _4654->pop_expr();
  int _4656 = mosek::fusion::p_WorkStack::_get_impl(_4654)->nd;
  int _4657 = mosek::fusion::p_WorkStack::_get_impl(_4654)->nelem;
  int _4658 = mosek::fusion::p_WorkStack::_get_impl(_4654)->nnz;
  int _4659 = mosek::fusion::p_WorkStack::_get_impl(_4654)->ncodeatom;
  bool _4660 = mosek::fusion::p_WorkStack::_get_impl(_4654)->hassp;
  int _4661 = mosek::fusion::p_WorkStack::_get_impl(_4654)->shape_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _4662 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4656)));
  _checked_ptr_1<long long> _ptr__4662(_4662 ? _4662->raw() : nullptr,_4662 ? _4662->size(0) : 0);
  _ptr__4662[(_4656 - (int)1)] = (int)1;
  int _10757 = (int)1;
  int _10758 = _4656;
  for (int _4663 = _10757; _4663 < _10758; ++_4663)
  {
    {
      _ptr__4662[((_4656 - _4663) - (int)1)] = safe_mul( _ptr__4662[(_4656 - _4663)],((*mosek::fusion::p_WorkStack::_get_impl(_4654)->i32)((safe_add( _4661,_4656 ) - _4663))) );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _4664 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4656)));
  _checked_ptr_1<int> _ptr__4664(_4664 ? _4664->raw() : nullptr,_4664 ? _4664->size(0) : 0);
  _ptr__4664[(_4656 - (int)1)] = (int)1;
  int _10759 = (int)1;
  int _10760 = _4656;
  for (int _4665 = _10759; _4665 < _10760; ++_4665)
  {
    {
      _ptr__4664[((_4656 - _4665) - (int)1)] = safe_mul( _ptr__4664[(_4656 - _4665)],((*mosek::fusion::p_WorkStack::_get_impl(_4654)->i32)(safe_add( _4661,((*dperm)((_4656 - _4665))) ))) );
    }
  }
  int _4666 = mosek::fusion::p_WorkStack::_get_impl(_4654)->ptr_base;
  int _4667 = mosek::fusion::p_WorkStack::_get_impl(_4654)->sp_base;
  int _4668 = mosek::fusion::p_WorkStack::_get_impl(_4654)->nidxs_base;
  int _4669 = mosek::fusion::p_WorkStack::_get_impl(_4654)->cof_base;
  int _4670 = mosek::fusion::p_WorkStack::_get_impl(_4654)->code_base;
  int _4671 = mosek::fusion::p_WorkStack::_get_impl(_4654)->codeptr_base;
  int _4672 = mosek::fusion::p_WorkStack::_get_impl(_4654)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4673 = mosek::fusion::p_WorkStack::_get_impl(_4654)->i32;
  _checked_ptr_1<int> _ptr__4673(_4673 ? _4673->raw() : nullptr,_4673 ? _4673->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4674 = mosek::fusion::p_WorkStack::_get_impl(_4654)->i64;
  _checked_ptr_1<long long> _ptr__4674(_4674 ? _4674->raw() : nullptr,_4674 ? _4674->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4675 = mosek::fusion::p_WorkStack::_get_impl(_4654)->f64;
  _checked_ptr_1<double> _ptr__4675(_4675 ? _4675->raw() : nullptr,_4675 ? _4675->size(0) : 0);
  _4653->alloc_expr(_4656,_4657,_4658,_4660,_4659);
  int _4676 = mosek::fusion::p_WorkStack::_get_impl(_4653)->ptr_base;
  int _4677 = mosek::fusion::p_WorkStack::_get_impl(_4653)->shape_base;
  int _4678 = mosek::fusion::p_WorkStack::_get_impl(_4653)->nidxs_base;
  int _4679 = mosek::fusion::p_WorkStack::_get_impl(_4653)->sp_base;
  int _4680 = mosek::fusion::p_WorkStack::_get_impl(_4653)->cof_base;
  int _4681 = mosek::fusion::p_WorkStack::_get_impl(_4653)->code_base;
  int _4682 = mosek::fusion::p_WorkStack::_get_impl(_4653)->codeptr_base;
  int _4683 = mosek::fusion::p_WorkStack::_get_impl(_4653)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4684 = mosek::fusion::p_WorkStack::_get_impl(_4653)->i32;
  _checked_ptr_1<int> _ptr__4684(_4684 ? _4684->raw() : nullptr,_4684 ? _4684->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4685 = mosek::fusion::p_WorkStack::_get_impl(_4653)->i64;
  _checked_ptr_1<long long> _ptr__4685(_4685 ? _4685->raw() : nullptr,_4685 ? _4685->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4686 = mosek::fusion::p_WorkStack::_get_impl(_4653)->f64;
  _checked_ptr_1<double> _ptr__4686(_4686 ? _4686->raw() : nullptr,_4686 ? _4686->size(0) : 0);
  int _10761 = (int)0;
  int _10762 = _4656;
  for (int _4687 = _10761; _4687 < _10762; ++_4687)
  {
    {
      _ptr__4684[safe_add( _4677,_4687 )] = _ptr__4673[safe_add( _4661,((*dperm)(_4687)) )];
    }
  }
  if (_4660)
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _4688 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4657)));
      _checked_ptr_1<long long> _ptr__4688(_4688 ? _4688->raw() : nullptr,_4688 ? _4688->size(0) : 0);
      {
        int _10763 = (int)0;
        int _10764 = _4657;
        for (int _4689 = _10763; _4689 < _10764; ++_4689)
        {
          {
            long long _4690 = (long long)0;
            int _10765 = (int)0;
            int _10766 = _4656;
            for (int _4691 = _10765; _4691 < _10766; ++_4691)
            {
              {
                _4690 += safe_mul( ((_ptr__4674[safe_add( _4667,_4689 )] / _ptr__4662[_4691]) % _ptr__4673[safe_add( _4661,_4691 )]),_ptr__4664[((*dperm)(_4691))] );
              }
            }
            _ptr__4688[_4689] = _4690;
          }
        }
      }
      std::vector<long long> _10767;
      for (int _4693 = (int)0, _10768 = _4657; _4693 < _10768 ; ++_4693)
      {
        _10767.push_back(_4693);
      }
      auto _10769 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_10767.size()),_10767.begin(),_10767.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _4692 = _10769;
      _checked_ptr_1<long long> _ptr__4692(_4692 ? _4692->raw() : nullptr,_4692 ? _4692->size(0) : 0);
      ::mosek::fusion::p_CommonTools::argQsort(_4692,_4688,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)((int)0),(long long)(_4657));
      _ptr__4684[_4676] = (int)0;
      if ((_4659 > (int)0))
      {
        {
          _ptr__4684[_4682] = (int)0;
        }
      }
      {}
      int _4694 = (int)0;
      int _4695 = (int)0;
      int _4696 = (int)0;
      int _10770 = (int)0;
      int _10771 = _4657;
      for (int _4697 = _10770; _4697 < _10771; ++_4697)
      {
        {
          long long _4698 = _ptr__4692[_4697];
          int _10772 = _ptr__4673[safe_add( _4666,_4698 )];
          int _10773 = _ptr__4673[safe_add( safe_add( _4666,_4698 ),(int)1 )];
          for (int _4699 = _10772; _4699 < _10773; ++_4699)
          {
            {
              _ptr__4685[safe_add( _4678,_4696 )] = _ptr__4674[safe_add( _4668,_4699 )];
              _ptr__4686[safe_add( _4680,_4696 )] = _ptr__4675[safe_add( _4669,_4699 )];
              if ((_4659 > (int)0))
              {
                {
                  int _10774 = _ptr__4673[safe_add( _4671,_4699 )];
                  int _10775 = _ptr__4673[safe_add( safe_add( _4671,_4699 ),(int)1 )];
                  for (int _4700 = _10774; _4700 < _10775; ++_4700)
                  {
                    {
                      _ptr__4684[safe_add( _4681,_4694 )] = _ptr__4673[safe_add( _4670,_4700 )];
                      _ptr__4686[safe_add( _4683,_4694 )] = _ptr__4675[safe_add( _4672,_4700 )];
                      ++ _4694;
                    }
                  }
                  _ptr__4684[safe_add( safe_add( _4682,_4696 ),(int)1 )] = _4694;
                }
              }
              {}
              ++ _4696;
            }
          }
          _ptr__4685[safe_add( _4679,_4697 )] = _ptr__4688[_4698];
          ++ _4695;
          _ptr__4684[safe_add( safe_add( _4676,_4697 ),(int)1 )] = _4696;
        }
      }
    }
  }
  else
  {
    {
      _ptr__4684[_4676] = (int)0;
      if ((_4659 > (int)0))
      {
        {
          _ptr__4684[_4682] = (int)0;
        }
      }
      {}
      int _4701 = (int)0;
      int _4702 = (int)0;
      int _4703 = (int)0;
      int _10776 = (int)0;
      int _10777 = _4657;
      for (int _4704 = _10776; _4704 < _10777; ++_4704)
      {
        {
          long long _4705 = (long long)0;
          int _10778 = (int)0;
          int _10779 = _4656;
          for (int _4706 = _10778; _4706 < _10779; ++_4706)
          {
            {
              _4705 += safe_mul( ((_4704 / _ptr__4662[((*dperm)(_4706))]) % _ptr__4673[safe_add( _4661,((*dperm)(_4706)) )]),_ptr__4664[_4706] );
            }
          }
          int _10780 = _ptr__4673[safe_add( _4666,_4705 )];
          int _10781 = _ptr__4673[safe_add( safe_add( _4666,_4705 ),(int)1 )];
          for (int _4707 = _10780; _4707 < _10781; ++_4707)
          {
            {
              _ptr__4685[safe_add( _4678,_4703 )] = _ptr__4674[safe_add( _4668,_4707 )];
              _ptr__4686[safe_add( _4680,_4703 )] = _ptr__4675[safe_add( _4669,_4707 )];
              if ((_4659 > (int)0))
              {
                {
                  int _10782 = _ptr__4673[safe_add( _4671,_4707 )];
                  int _10783 = _ptr__4673[safe_add( safe_add( _4671,_4707 ),(int)1 )];
                  for (int _4708 = _10782; _4708 < _10783; ++_4708)
                  {
                    {
                      _ptr__4684[safe_add( _4681,_4701 )] = _ptr__4673[safe_add( _4670,_4708 )];
                      _ptr__4686[safe_add( _4683,_4701 )] = _ptr__4675[safe_add( _4672,_4708 )];
                      ++ _4701;
                    }
                  }
                  _ptr__4684[safe_add( safe_add( _4682,_4703 ),(int)1 )] = _4701;
                }
              }
              {}
              ++ _4703;
            }
          }
          ++ _4702;
          _ptr__4684[safe_add( _4676,_4702 )] = _4703;
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprPermuteDims::computeshape(std::shared_ptr< monty::ndarray< int,1 > > _4709,std::shared_ptr< monty::ndarray< int,1 > > _4710){
  _checked_ptr_1<int> _ptr__4709(_4709 ? _4709->raw() : nullptr, _4709 ? _4709->size(0) : 0);
  _checked_ptr_1<int> _ptr__4710(_4710 ? _4710->raw() : nullptr, _4710 ? _4710->size(0) : 0);
  std::vector<int> _10784;
  for (int _4711 = (int)0, _10785 = (int)((_4709)->size(0)); _4711 < _10785 ; ++_4711)
  {
    _10784.push_back(_ptr__4710[_ptr__4709[_4711]]);
  }
  auto _10786 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10784.size()),_10784.begin(),_10784.end()));
  return _10786;
}
void mosek::fusion::p_ExprPermuteDims::destroy(){dperm.reset();expr.reset();}void mosek::fusion::ExprPermuteDims::destroy() { mosek::fusion::p_ExprPermuteDims::_get_impl(this)->destroy(); }mosek::fusion::ExprTranspose::ExprTranspose(mosek::fusion::p_ExprTranspose *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprTranspose()" << this << std::endl; */ }mosek::fusion::ExprTranspose::~ExprTranspose() {  /* std::cout << "~ExprTranspose()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprTranspose::p_ExprTranspose  (::mosek::fusion::ExprTranspose * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprTranspose::t mosek::fusion::p_ExprTranspose::_new_ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _4712){ return new mosek::fusion::ExprTranspose(_4712); }mosek::fusion::ExprTranspose::ExprTranspose  (monty::rc_ptr< ::mosek::fusion::Expression > _4712) :    ExprTranspose(new mosek::fusion::p_ExprTranspose(this)){ mosek::fusion::p_ExprTranspose::_get_impl(this)->_initialize(_4712); }void mosek::fusion::p_ExprTranspose::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4712){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprTranspose::transposeShape(_4712->getShape()));
    mosek::fusion::p_ExprTranspose::_get_impl(::mosek::fusion::ExprTranspose::t(_pubthis))->expr = _4712;
  }
}void mosek::fusion::ExprTranspose :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4713,monty::rc_ptr< ::mosek::fusion::WorkStack > _4714,monty::rc_ptr< ::mosek::fusion::WorkStack > _4715) { mosek::fusion::p_ExprTranspose::_get_impl(this)->eval(_4713,_4714,_4715); }void mosek::fusion::p_ExprTranspose::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4713,monty::rc_ptr< ::mosek::fusion::WorkStack > _4714,monty::rc_ptr< ::mosek::fusion::WorkStack > _4715){
  expr->eval(_4714,_4713,_4715);
  _4714->pop_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_4714)->nd != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      int _4716 = mosek::fusion::p_WorkStack::_get_impl(_4714)->shape_base;
      int _4717 = mosek::fusion::p_WorkStack::_get_impl(_4714)->nelem;
      int _4718 = mosek::fusion::p_WorkStack::_get_impl(_4714)->nnz;
      bool _4719 = mosek::fusion::p_WorkStack::_get_impl(_4714)->hassp;
      int _4720 = mosek::fusion::p_WorkStack::_get_impl(_4714)->ncodeatom;
      int _4721 = mosek::fusion::p_WorkStack::_get_impl(_4714)->ptr_base;
      int _4722 = mosek::fusion::p_WorkStack::_get_impl(_4714)->sp_base;
      int _4723 = mosek::fusion::p_WorkStack::_get_impl(_4714)->nidxs_base;
      int _4724 = mosek::fusion::p_WorkStack::_get_impl(_4714)->cof_base;
      int _4725 = mosek::fusion::p_WorkStack::_get_impl(_4714)->code_base;
      int _4726 = mosek::fusion::p_WorkStack::_get_impl(_4714)->codeptr_base;
      int _4727 = mosek::fusion::p_WorkStack::_get_impl(_4714)->cconst_base;
      int _4728 = ((*mosek::fusion::p_WorkStack::_get_impl(_4714)->i32)(_4716));
      int _4729 = ((*mosek::fusion::p_WorkStack::_get_impl(_4714)->i32)(safe_add( _4716,(int)1 )));
      std::shared_ptr< monty::ndarray< int,1 > > _4730 = mosek::fusion::p_WorkStack::_get_impl(_4714)->i32;
      _checked_ptr_1<int> _ptr__4730(_4730 ? _4730->raw() : nullptr,_4730 ? _4730->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4731 = mosek::fusion::p_WorkStack::_get_impl(_4714)->i64;
      _checked_ptr_1<long long> _ptr__4731(_4731 ? _4731->raw() : nullptr,_4731 ? _4731->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4732 = mosek::fusion::p_WorkStack::_get_impl(_4714)->f64;
      _checked_ptr_1<double> _ptr__4732(_4732 ? _4732->raw() : nullptr,_4732 ? _4732->size(0) : 0);
      _4713->alloc_expr((int)2,_4717,_4718,_4719,_4720);
      int _4733 = mosek::fusion::p_WorkStack::_get_impl(_4713)->ptr_base;
      int _4734 = mosek::fusion::p_WorkStack::_get_impl(_4713)->nidxs_base;
      int _4735 = mosek::fusion::p_WorkStack::_get_impl(_4713)->sp_base;
      int _4736 = mosek::fusion::p_WorkStack::_get_impl(_4713)->cof_base;
      int _4737 = mosek::fusion::p_WorkStack::_get_impl(_4713)->shape_base;
      int _4738 = mosek::fusion::p_WorkStack::_get_impl(_4713)->code_base;
      int _4739 = mosek::fusion::p_WorkStack::_get_impl(_4713)->codeptr_base;
      int _4740 = mosek::fusion::p_WorkStack::_get_impl(_4713)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _4741 = mosek::fusion::p_WorkStack::_get_impl(_4713)->i32;
      _checked_ptr_1<int> _ptr__4741(_4741 ? _4741->raw() : nullptr,_4741 ? _4741->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4742 = mosek::fusion::p_WorkStack::_get_impl(_4713)->i64;
      _checked_ptr_1<long long> _ptr__4742(_4742 ? _4742->raw() : nullptr,_4742 ? _4742->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4743 = mosek::fusion::p_WorkStack::_get_impl(_4713)->f64;
      _checked_ptr_1<double> _ptr__4743(_4743 ? _4743->raw() : nullptr,_4743 ? _4743->size(0) : 0);
      _ptr__4741[_4737] = _4729;
      _ptr__4741[safe_add( _4737,(int)1 )] = _4728;
      _ptr__4741[_4733] = (int)0;
      if ((_4720 > (int)0))
      {
        {
          _ptr__4741[_4739] = (int)0;
        }
      }
      {}
      if (_4719)
      {
        {
          int _4744 = _4715->alloci32(_4717);
          int _4745 = _4715->alloci32(safe_add( _4729,(int)1 ));
          std::shared_ptr< monty::ndarray< int,1 > > _4746 = mosek::fusion::p_WorkStack::_get_impl(_4715)->i32;
          _checked_ptr_1<int> _ptr__4746(_4746 ? _4746->raw() : nullptr,_4746 ? _4746->size(0) : 0);
          {
            int _10787 = (int)0;
            int _10788 = safe_add( _4729,(int)1 );
            for (int _4747 = _10787; _4747 < _10788; ++_4747)
            {
              {
                _ptr__4746[safe_add( _4745,_4747 )] = (int)0;
              }
            }
            int _10789 = (int)0;
            int _10790 = _4717;
            for (int _4748 = _10789; _4748 < _10790; ++_4748)
            {
              {
                ++ _ptr__4746[safe_add( safe_add( _4745,(_ptr__4731[safe_add( _4722,_4748 )] % _4729) ),(int)1 )];
              }
            }
            int _10791 = (int)0;
            int _10792 = _4729;
            for (int _4749 = _10791; _4749 < _10792; ++_4749)
            {
              {
                _ptr__4746[safe_add( safe_add( _4745,_4749 ),(int)1 )] += _ptr__4746[safe_add( _4745,_4749 )];
              }
            }
            int _10793 = (int)0;
            int _10794 = _4717;
            for (int _4750 = _10793; _4750 < _10794; ++_4750)
            {
              {
                long long _4751 = (_ptr__4731[safe_add( _4722,_4750 )] % _4729);
                _ptr__4746[safe_add( _4744,_ptr__4746[safe_add( _4745,_4751 )] )] = _4750;
                ++ _ptr__4746[safe_add( _4745,_4751 )];
              }
            }
            _ptr__4741[_4733] = (int)0;
            int _4752 = (int)0;
            int _4753 = (int)0;
            int _10795 = (int)0;
            int _10796 = _4717;
            for (int _4754 = _10795; _4754 < _10796; ++_4754)
            {
              {
                int _4755 = _ptr__4746[safe_add( _4744,_4754 )];
                int _10797 = _ptr__4730[safe_add( _4721,_4755 )];
                int _10798 = _ptr__4730[safe_add( safe_add( _4721,_4755 ),(int)1 )];
                for (int _4756 = _10797; _4756 < _10798; ++_4756)
                {
                  {
                    _ptr__4742[safe_add( _4734,_4753 )] = _ptr__4731[safe_add( _4723,_4756 )];
                    _ptr__4743[safe_add( _4736,_4753 )] = _ptr__4732[safe_add( _4724,_4756 )];
                    if ((_4720 > (int)0))
                    {
                      {
                        int _10799 = _ptr__4730[safe_add( _4726,_4756 )];
                        int _10800 = _ptr__4730[safe_add( safe_add( _4726,_4756 ),(int)1 )];
                        for (int _4757 = _10799; _4757 < _10800; ++_4757)
                        {
                          {
                            _ptr__4741[safe_add( _4738,_4752 )] = _ptr__4730[safe_add( _4725,_4757 )];
                            _ptr__4743[safe_add( _4740,_4752 )] = _ptr__4732[safe_add( _4727,_4757 )];
                            ++ _4752;
                          }
                        }
                        _ptr__4741[safe_add( safe_add( _4739,_4753 ),(int)1 )] = _4752;
                      }
                    }
                    {}
                    ++ _4753;
                  }
                }
                long long _4758 = (_ptr__4731[safe_add( _4722,_4755 )] / _4729);
                long long _4759 = (_ptr__4731[safe_add( _4722,_4755 )] % _4729);
                _ptr__4741[safe_add( safe_add( _4733,_4754 ),(int)1 )] = _4753;
                _ptr__4742[safe_add( _4735,_4754 )] = safe_add( safe_mul( _4759,_4728 ),_4758 );
              }
            }
          }
        }
      }
      else
      {
        {
          _ptr__4741[_4733] = (int)0;
          int _4760 = (int)0;
          int _4761 = (int)0;
          int _4762 = (int)0;
          int _10801 = (int)0;
          int _10802 = _4729;
          for (int _4763 = _10801; _4763 < _10802; ++_4763)
          {
            {
              int _10803 = (int)0;
              int _10804 = _4728;
              for (int _4764 = _10803; _4764 < _10804; ++_4764)
              {
                {
                  int _4765 = safe_add( safe_mul( _4764,_4729 ),_4763 );
                  int _10805 = _ptr__4730[safe_add( _4721,_4765 )];
                  int _10806 = _ptr__4730[safe_add( safe_add( _4721,_4765 ),(int)1 )];
                  for (int _4766 = _10805; _4766 < _10806; ++_4766)
                  {
                    {
                      _ptr__4742[safe_add( _4734,_4761 )] = _ptr__4731[safe_add( _4723,_4766 )];
                      _ptr__4743[safe_add( _4736,_4761 )] = _ptr__4732[safe_add( _4724,_4766 )];
                      if ((_4720 > (int)0))
                      {
                        {
                          int _10807 = _ptr__4730[safe_add( _4726,_4766 )];
                          int _10808 = _ptr__4730[safe_add( safe_add( _4726,_4766 ),(int)1 )];
                          for (int _4767 = _10807; _4767 < _10808; ++_4767)
                          {
                            {
                              _ptr__4741[safe_add( _4738,_4760 )] = _ptr__4730[safe_add( _4725,_4767 )];
                              _ptr__4743[safe_add( _4740,_4760 )] = _ptr__4732[safe_add( _4727,_4767 )];
                              ++ _4760;
                            }
                          }
                          _ptr__4741[safe_add( safe_add( _4739,_4761 ),(int)1 )] = _4760;
                        }
                      }
                      {}
                      ++ _4761;
                    }
                  }
                  _ptr__4741[safe_add( safe_add( _4733,_4762 ),(int)1 )] = _4761;
                  ++ _4762;
                }
              }
            }
          }
        }
      }
      _4715->clear();
    }
  }
}
std::string mosek::fusion::ExprTranspose :: toString() { return mosek::fusion::p_ExprTranspose::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprTranspose::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprTranspose("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprTranspose::transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _4768){
  _checked_ptr_1<int> _ptr__4768(_4768 ? _4768->raw() : nullptr, _4768 ? _4768->size(0) : 0);
  if (((int)((_4768)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__4768[(int)1]),(int)(_ptr__4768[(int)0])});
    }
  }
}
void mosek::fusion::p_ExprTranspose::destroy(){expr.reset();}void mosek::fusion::ExprTranspose::destroy() { mosek::fusion::p_ExprTranspose::_get_impl(this)->destroy(); }mosek::fusion::ExprRepeat::ExprRepeat(mosek::fusion::p_ExprRepeat *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprRepeat()" << this << std::endl; */ }mosek::fusion::ExprRepeat::~ExprRepeat() {  /* std::cout << "~ExprRepeat()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprRepeat::p_ExprRepeat  (::mosek::fusion::ExprRepeat * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprRepeat::t mosek::fusion::p_ExprRepeat::_new_ExprRepeat  (monty::rc_ptr< ::mosek::fusion::Expression > _4769,    int _4770,    int _4771){ return new mosek::fusion::ExprRepeat(_4769,_4770,_4771); }mosek::fusion::ExprRepeat::ExprRepeat  (monty::rc_ptr< ::mosek::fusion::Expression > _4769,    int _4770,    int _4771) :    ExprRepeat(new mosek::fusion::p_ExprRepeat(this)){ mosek::fusion::p_ExprRepeat::_get_impl(this)->_initialize(_4769,_4770,_4771); }void mosek::fusion::p_ExprRepeat::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _4769,    int _4770,    int _4771){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprRepeat::getshape(_4769,_4770,_4771));
    mosek::fusion::p_ExprRepeat::_get_impl(::mosek::fusion::ExprRepeat::t(_pubthis))->expr = _4769;
    mosek::fusion::p_ExprRepeat::_get_impl(::mosek::fusion::ExprRepeat::t(_pubthis))->dim = _4770;
    mosek::fusion::p_ExprRepeat::_get_impl(::mosek::fusion::ExprRepeat::t(_pubthis))->n = _4771;
  }
}void mosek::fusion::ExprRepeat :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4772,monty::rc_ptr< ::mosek::fusion::WorkStack > _4773,monty::rc_ptr< ::mosek::fusion::WorkStack > _4774) { mosek::fusion::p_ExprRepeat::_get_impl(this)->eval(_4772,_4773,_4774); }void mosek::fusion::p_ExprRepeat::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4772,monty::rc_ptr< ::mosek::fusion::WorkStack > _4773,monty::rc_ptr< ::mosek::fusion::WorkStack > _4774){
  expr->eval(_4773,_4772,_4774);
  _4773->pop_expr();
  int _4775 = mosek::fusion::p_WorkStack::_get_impl(_4773)->nd;
  int _4776 = mosek::fusion::p_WorkStack::_get_impl(_4773)->shape_base;
  int _4777 = mosek::fusion::p_WorkStack::_get_impl(_4773)->nelem;
  int _4778 = mosek::fusion::p_WorkStack::_get_impl(_4773)->nnz;
  int _4779 = mosek::fusion::p_WorkStack::_get_impl(_4773)->ncodeatom;
  bool _4780 = mosek::fusion::p_WorkStack::_get_impl(_4773)->hassp;
  int _4781 = mosek::fusion::p_WorkStack::_get_impl(_4773)->ptr_base;
  int _4782 = mosek::fusion::p_WorkStack::_get_impl(_4773)->sp_base;
  int _4783 = mosek::fusion::p_WorkStack::_get_impl(_4773)->nidxs_base;
  int _4784 = mosek::fusion::p_WorkStack::_get_impl(_4773)->cof_base;
  int _4785 = mosek::fusion::p_WorkStack::_get_impl(_4773)->code_base;
  int _4786 = mosek::fusion::p_WorkStack::_get_impl(_4773)->codeptr_base;
  int _4787 = mosek::fusion::p_WorkStack::_get_impl(_4773)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _4788 = mosek::fusion::p_WorkStack::_get_impl(_4773)->i32;
  _checked_ptr_1<int> _ptr__4788(_4788 ? _4788->raw() : nullptr,_4788 ? _4788->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4789 = mosek::fusion::p_WorkStack::_get_impl(_4773)->i64;
  _checked_ptr_1<long long> _ptr__4789(_4789 ? _4789->raw() : nullptr,_4789 ? _4789->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4790 = mosek::fusion::p_WorkStack::_get_impl(_4773)->f64;
  _checked_ptr_1<double> _ptr__4790(_4790 ? _4790->raw() : nullptr,_4790 ? _4790->size(0) : 0);
  int _10809;
  bool _10810 = (dim < _4775);
  if (_10810)
  {
    _10809 = _4775;
  }
  else
  {
    _10809 = safe_add( _4775,(int)1 );
  }
  int _4791 = _10809;
  int _4792 = safe_mul( _4777,n );
  int _4793 = safe_mul( _4778,n );
  int _4794 = safe_mul( _4779,n );
  _4772->alloc_expr(_4791,_4792,_4793,_4780,_4794);
  std::shared_ptr< monty::ndarray< int,1 > > _4795 = mosek::fusion::p_WorkStack::_get_impl(_4772)->i32;
  _checked_ptr_1<int> _ptr__4795(_4795 ? _4795->raw() : nullptr,_4795 ? _4795->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _4796 = mosek::fusion::p_WorkStack::_get_impl(_4772)->i64;
  _checked_ptr_1<long long> _ptr__4796(_4796 ? _4796->raw() : nullptr,_4796 ? _4796->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _4797 = mosek::fusion::p_WorkStack::_get_impl(_4772)->f64;
  _checked_ptr_1<double> _ptr__4797(_4797 ? _4797->raw() : nullptr,_4797 ? _4797->size(0) : 0);
  int _4798 = mosek::fusion::p_WorkStack::_get_impl(_4772)->shape_base;
  int _4799 = mosek::fusion::p_WorkStack::_get_impl(_4772)->ptr_base;
  int _4800 = mosek::fusion::p_WorkStack::_get_impl(_4772)->sp_base;
  int _4801 = mosek::fusion::p_WorkStack::_get_impl(_4772)->nidxs_base;
  int _4802 = mosek::fusion::p_WorkStack::_get_impl(_4772)->cof_base;
  int _4803 = mosek::fusion::p_WorkStack::_get_impl(_4772)->code_base;
  int _4804 = mosek::fusion::p_WorkStack::_get_impl(_4772)->codeptr_base;
  int _4805 = mosek::fusion::p_WorkStack::_get_impl(_4772)->cconst_base;
  int _4806 = (int)1;
  int _10811 = (int)0;
  int _10812 = dim;
  for (int _4807 = _10811; _4807 < _10812; ++_4807)
  {
    {
      _4806 *= _ptr__4788[safe_add( _4776,_4807 )];
    }
  }
  int _10813;
  bool _10814 = (dim < _4775);
  if (_10814)
  {
    _10813 = _ptr__4788[safe_add( _4776,dim )];
  }
  else
  {
    _10813 = (int)1;
  }
  int _4808 = _10813;
  int _4809 = safe_mul( n,_4808 );
  int _4810 = (int)1;
  int _10815 = safe_add( dim,(int)1 );
  int _10816 = _4775;
  for (int _4811 = _10815; _4811 < _10816; ++_4811)
  {
    {
      _4810 *= _ptr__4788[safe_add( _4776,_4811 )];
    }
  }
  {
    int _10817 = (int)0;
    int _10818 = _4775;
    for (int _4812 = _10817; _4812 < _10818; ++_4812)
    {
      {
        _ptr__4795[safe_add( _4798,_4812 )] = _ptr__4788[safe_add( _4776,_4812 )];
      }
    }
    _ptr__4795[safe_add( _4798,dim )] = _4809;
    _ptr__4795[_4799] = (int)0;
    if ((_4794 != (int)0))
    {
      {
        _ptr__4795[_4804] = (int)0;
      }
    }
    {}
    if (_4780)
    {
      {
        int _4813 = (int)0;
        int _4814 = (int)0;
        int _4815 = (int)0;
        int _4816 = (int)0;
        int _4817 = (int)0;
        while ( (_4815 < _4777) )
        {
          {
            long long _4818 = _ptr__4789[safe_add( _4782,_4815 )];
            long long _4819 = safe_add( (_4818 - (_4818 % safe_mul( _4808,_4810 ))),safe_mul( _4808,_4810 ) );
            int _4820 = _4815;
            ++ _4815;
            while ( ((_4815 < _4777) && (_ptr__4789[safe_add( _4782,_4815 )] < _4819)) )
            {
              {
                ++ _4815;
              }
            }
            int _4821 = _4815;
            int _10819 = (int)0;
            int _10820 = n;
            for (int _4822 = _10819; _4822 < _10820; ++_4822)
            {
              {
                int _10821 = _4820;
                int _10822 = _4821;
                for (int _4823 = _10821; _4823 < _10822; ++_4823)
                {
                  {
                    long long _4824 = (_ptr__4789[safe_add( _4782,_4823 )] / safe_mul( _4808,_4810 ));
                    long long _4825 = ((_ptr__4789[safe_add( _4782,_4823 )] / _4810) % _4808);
                    long long _4826 = (_ptr__4789[safe_add( _4782,_4823 )] % _4810);
                    int _10823 = _ptr__4788[safe_add( _4781,_4823 )];
                    int _10824 = _ptr__4788[safe_add( safe_add( _4781,_4823 ),(int)1 )];
                    for (int _4827 = _10823; _4827 < _10824; ++_4827)
                    {
                      {
                        _ptr__4796[safe_add( _4801,_4817 )] = _ptr__4789[safe_add( _4783,_4827 )];
                        _ptr__4797[safe_add( _4802,_4817 )] = _ptr__4790[safe_add( _4784,_4827 )];
                        if ((_4779 > (int)0))
                        {
                          {
                            int _10825 = _ptr__4788[safe_add( _4786,_4827 )];
                            int _10826 = _ptr__4788[safe_add( safe_add( _4786,_4827 ),(int)1 )];
                            for (int _4828 = _10825; _4828 < _10826; ++_4828)
                            {
                              {
                                _ptr__4795[safe_add( _4803,_4813 )] = _ptr__4788[safe_add( _4785,_4828 )];
                                _ptr__4797[safe_add( _4805,_4813 )] = _ptr__4790[safe_add( _4787,_4828 )];
                                ++ _4813;
                              }
                            }
                            _ptr__4795[safe_add( safe_add( _4804,_4817 ),(int)1 )] = _4813;
                          }
                        }
                        {}
                        ++ _4817;
                      }
                    }
                    _ptr__4795[safe_add( safe_add( _4799,_4816 ),(int)1 )] = _4817;
                    _ptr__4796[safe_add( _4800,_4816 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _4824,_4809 ),safe_mul( _4822,_4808 ) ),_4825 ),_4810 ),_4826 );
                    ++ _4816;
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        int _4829 = (int)0;
        int _4830 = (int)0;
        int _4831 = (int)0;
        int _4832 = (int)0;
        int _10827 = (int)0;
        int _10828 = _4806;
        for (int _4833 = _10827; _4833 < _10828; ++_4833)
        {
          {
            int _10829 = (int)0;
            int _10830 = n;
            for (int _4834 = _10829; _4834 < _10830; ++_4834)
            {
              {
                int _4835 = safe_mul( safe_mul( _4833,_4808 ),_4810 );
                int _10831 = (int)0;
                int _10832 = safe_mul( _4808,_4810 );
                for (int _4836 = _10831; _4836 < _10832; ++_4836)
                {
                  {
                    int _10833 = _ptr__4788[safe_add( _4781,_4835 )];
                    int _10834 = _ptr__4788[safe_add( safe_add( _4781,_4835 ),(int)1 )];
                    for (int _4837 = _10833; _4837 < _10834; ++_4837)
                    {
                      {
                        _ptr__4796[safe_add( _4801,_4831 )] = _ptr__4789[safe_add( _4783,_4837 )];
                        _ptr__4797[safe_add( _4802,_4831 )] = _ptr__4790[safe_add( _4784,_4837 )];
                        if ((_4779 > (int)0))
                        {
                          {
                            int _10835 = _ptr__4788[safe_add( _4786,_4837 )];
                            int _10836 = _ptr__4788[safe_add( safe_add( _4786,_4837 ),(int)1 )];
                            for (int _4838 = _10835; _4838 < _10836; ++_4838)
                            {
                              {
                                _ptr__4795[safe_add( _4803,_4829 )] = _ptr__4788[safe_add( _4785,_4838 )];
                                _ptr__4797[safe_add( _4805,_4829 )] = _ptr__4790[safe_add( _4787,_4838 )];
                                ++ _4829;
                              }
                            }
                            _ptr__4795[safe_add( safe_add( _4804,_4831 ),(int)1 )] = _4829;
                          }
                        }
                        {}
                        ++ _4831;
                      }
                    }
                    _ptr__4795[safe_add( safe_add( _4799,_4830 ),(int)1 )] = _4831;
                    ++ _4830;
                    ++ _4835;
                  }
                }
              }
            }
          }
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprRepeat::getshape(monty::rc_ptr< ::mosek::fusion::Expression > _4839,int _4840,int _4841){
  std::shared_ptr< monty::ndarray< int,1 > > _4842 = _4839->getShape();
  _checked_ptr_1<int> _ptr__4842(_4842 ? _4842->raw() : nullptr,_4842 ? _4842->size(0) : 0);
  int _4843 = (int)((_4842)->size(0));
  if ((_4840 < _4843))
  {
    {
      _ptr__4842[_4840] *= _4841;
      return _4842;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _10837;
      bool _10838 = (_4840 == _4843);
      if (_10838)
      {
        _10837 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _4843,(int)1 ))));
      }
      else
      {
        _10837 = _4842;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4844 = _10837;
      _checked_ptr_1<int> _ptr__4844(_4844 ? _4844->raw() : nullptr,_4844 ? _4844->size(0) : 0);
      int _10839 = (int)0;
      int _10840 = _4843;
      for (int _4845 = _10839; _4845 < _10840; ++_4845)
      {
        {
          _ptr__4844[_4845] = _ptr__4842[_4845];
        }
      }
      _ptr__4844[_4840] = _4841;
      return _4844;
    }
  }
}
std::string mosek::fusion::ExprRepeat :: toString() { return mosek::fusion::p_ExprRepeat::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprRepeat::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprRepeat(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprRepeat::destroy(){expr.reset();}void mosek::fusion::ExprRepeat::destroy() { mosek::fusion::p_ExprRepeat::_get_impl(this)->destroy(); }mosek::fusion::ExprStack::ExprStack(mosek::fusion::p_ExprStack *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprStack()" << this << std::endl; */ }mosek::fusion::ExprStack::~ExprStack() {  /* std::cout << "~ExprStack()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprStack::p_ExprStack  (::mosek::fusion::ExprStack * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprStack::t mosek::fusion::p_ExprStack::_new_ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4846,    int _4847){ return new mosek::fusion::ExprStack(_4846,_4847); }mosek::fusion::ExprStack::ExprStack  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4846,    int _4847) :    ExprStack(new mosek::fusion::p_ExprStack(this)){ mosek::fusion::p_ExprStack::_get_impl(this)->_initialize(_4846,_4847); }void mosek::fusion::p_ExprStack::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4846,    int _4847){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprStack::getshape(_4846,_4847));
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _10841;
    for (int _4848 = (int)0, _10842 = (int)((_4846)->size(0)); _4848 < _10842 ; ++_4848)
    {
      _10841.push_back(((*_4846)(_4848)));
    }
    auto _10843 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_10841.size()),_10841.begin(),_10841.end()));
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->exprs = _10843;
    mosek::fusion::p_ExprStack::_get_impl(::mosek::fusion::ExprStack::t(_pubthis))->dim = _4847;
  }
}void mosek::fusion::ExprStack :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4849,monty::rc_ptr< ::mosek::fusion::WorkStack > _4850,monty::rc_ptr< ::mosek::fusion::WorkStack > _4851) { mosek::fusion::p_ExprStack::_get_impl(this)->eval(_4849,_4850,_4851); }void mosek::fusion::p_ExprStack::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4849,monty::rc_ptr< ::mosek::fusion::WorkStack > _4850,monty::rc_ptr< ::mosek::fusion::WorkStack > _4851){
  int _4852 = (int)((exprs)->size(0));
  if ((_4852 == (int)1))
  {
    {
      ((*exprs)((int)0))->eval(_4849,_4850,_4851);
    }
  }
  else
  {
    {
      int _10844 = (int)0;
      int _10845 = _4852;
      for (int _4853 = _10844; _4853 < _10845; ++_4853)
      {
        {
          ((*exprs)(((_4852 - _4853) - (int)1)))->eval(_4850,_4849,_4851);
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4854 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4854(_4854 ? _4854->raw() : nullptr,_4854 ? _4854->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4855 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4855(_4855 ? _4855->raw() : nullptr,_4855 ? _4855->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4856 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4856(_4856 ? _4856->raw() : nullptr,_4856 ? _4856->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4857 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4857(_4857 ? _4857->raw() : nullptr,_4857 ? _4857->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4858 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4858(_4858 ? _4858->raw() : nullptr,_4858 ? _4858->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4859 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4859(_4859 ? _4859->raw() : nullptr,_4859 ? _4859->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4860 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4860(_4860 ? _4860->raw() : nullptr,_4860 ? _4860->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4861 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4861(_4861 ? _4861->raw() : nullptr,_4861 ? _4861->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4862 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4862(_4862 ? _4862->raw() : nullptr,_4862 ? _4862->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4863 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4863(_4863 ? _4863->raw() : nullptr,_4863 ? _4863->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4864 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4864(_4864 ? _4864->raw() : nullptr,_4864 ? _4864->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4865 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4865(_4865 ? _4865->raw() : nullptr,_4865 ? _4865->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4866 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4866(_4866 ? _4866->raw() : nullptr,_4866 ? _4866->size(0) : 0);
      int _10846 = (int)0;
      int _10847 = _4852;
      for (int _4867 = _10846; _4867 < _10847; ++_4867)
      {
        {
          _4850->pop_expr();
          _ptr__4854[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->nd;
          _ptr__4855[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->shape_base;
          _ptr__4856[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->nelem;
          _ptr__4857[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->nnz;
          _ptr__4858[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->ncodeatom;
          int _10848;
          bool _10849 = mosek::fusion::p_WorkStack::_get_impl(_4850)->hassp;
          if (_10849)
          {
            _10848 = (int)1;
          }
          else
          {
            _10848 = (int)0;
          }
          _ptr__4859[_4867] = _10848;
          _ptr__4860[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->ptr_base;
          _ptr__4862[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->sp_base;
          _ptr__4861[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->nidxs_base;
          _ptr__4863[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->cof_base;
          _ptr__4864[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->code_base;
          _ptr__4865[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->codeptr_base;
          _ptr__4866[_4867] = mosek::fusion::p_WorkStack::_get_impl(_4850)->cconst_base;
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4868 = mosek::fusion::p_WorkStack::_get_impl(_4850)->i32;
      _checked_ptr_1<int> _ptr__4868(_4868 ? _4868->raw() : nullptr,_4868 ? _4868->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _4869 = mosek::fusion::p_WorkStack::_get_impl(_4850)->i64;
      _checked_ptr_1<long long> _ptr__4869(_4869 ? _4869->raw() : nullptr,_4869 ? _4869->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _4870 = mosek::fusion::p_WorkStack::_get_impl(_4850)->f64;
      _checked_ptr_1<double> _ptr__4870(_4870 ? _4870->raw() : nullptr,_4870 ? _4870->size(0) : 0);
      int _4871 = _ptr__4854[(int)0];
      int _4872 = _ptr__4855[(int)0];
      bool _4873 = (_ptr__4859[(int)0] == (int)0);
      bool _4874 = false;
      int _10850 = (int)1;
      int _10851 = _4852;
      for (int _4875 = _10850; _4875 < _10851; ++_4875)
      {
        {
          _4874 = (_4874 || ((dim != _4875) && (_ptr__4854[_4875] != _4871)));
          if ((!_4874))
          {
            {
              int _10852 = (int)0;
              int _10853 = dim;
              for (int _4876 = _10852; _4876 < _10853; ++_4876)
              {
                {
                  _4874 = (_4874 || (_ptr__4868[safe_add( _4872,_4876 )] != _ptr__4868[safe_add( _ptr__4855[_4875],_4876 )]));
                }
              }
            }
          }
          {}
          if ((!_4874))
          {
            {
              int _10854 = safe_add( dim,(int)1 );
              int _10855 = _4871;
              for (int _4877 = _10854; _4877 < _10855; ++_4877)
              {
                {
                  _4874 = (_4874 || (_ptr__4868[safe_add( _4872,_4877 )] != _ptr__4868[safe_add( _ptr__4855[_4875],_4877 )]));
                }
              }
            }
          }
          {}
          _4873 = (_4873 && ((int)0 == _ptr__4859[_4875]));
        }
      }
      if (_4874)
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
        }
      }
      {}
      int _4878 = (int)0;
      if ((dim < _4871))
      {
        {
          int _10856 = (int)0;
          int _10857 = _4852;
          for (int _4879 = _10856; _4879 < _10857; ++_4879)
          {
            {
              _4878 += _ptr__4868[safe_add( _ptr__4855[_4879],dim )];
            }
          }
        }
      }
      else
      {
        {
          _4878 = _4852;
        }
      }
      int _10858;
      bool _10859 = (dim < _4871);
      if (_10859)
      {
        _10858 = _4871;
      }
      else
      {
        _10858 = safe_add( _4871,(int)1 );
      }
      int _4880 = _10858;
      if ((_4880 != _pubthis->getND()))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Mismatching dimensions"));
        }
      }
      {}
      int _4881 = (int)0;
      int _4882 = (int)0;
      int _4883 = (int)0;
      bool _4884 = false;
      {
        int _10860 = (int)0;
        int _10861 = _4852;
        for (int _4885 = _10860; _4885 < _10861; ++_4885)
        {
          {
            _4884 = (_4884 || (_ptr__4858[_4885] > (int)0));
          }
        }
        int _10862 = (int)0;
        int _10863 = _4852;
        for (int _4886 = _10862; _4886 < _10863; ++_4886)
        {
          {
            _4883 += _ptr__4857[_4886];
          }
        }
        int _10864 = (int)0;
        int _10865 = _4852;
        for (int _4887 = _10864; _4887 < _10865; ++_4887)
        {
          {
            _4882 += _ptr__4856[_4887];
          }
        }
        if (_4884)
        {
          {
            int _10866 = (int)0;
            int _10867 = _4852;
            for (int _4888 = _10866; _4888 < _10867; ++_4888)
            {
              {
                int _10868;
                bool _10869 = (_ptr__4858[_4888] > (int)0);
                if (_10869)
                {
                  _10868 = _ptr__4858[_4888];
                }
                else
                {
                  _10868 = _ptr__4857[_4888];
                }
                _4881 += _10868;
              }
            }
          }
        }
        {}
      }
      int _4889 = (int)1;
      int _10870 = (int)0;
      int _10871 = dim;
      for (int _4890 = _10870; _4890 < _10871; ++_4890)
      {
        {
          _4889 *= _ptr__4868[safe_add( _4872,_4890 )];
        }
      }
      std::shared_ptr< monty::ndarray< int,1 > > _10872;
      bool _10873 = (dim < _4871);
      if (_10873)
      {
        std::vector<int> _10874;
        for (int _4892 = (int)0, _10875 = _4852; _4892 < _10875 ; ++_4892)
        {
          _10874.push_back(_ptr__4868[safe_add( _ptr__4855[_4892],dim )]);
        }
        auto _10876 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10874.size()),_10874.begin(),_10874.end()));
        _10872 = _10876;
      }
      else
      {
        std::vector<int> _10877;
        for (int _4893 = (int)0, _10878 = _4852; _4893 < _10878 ; ++_4893)
        {
          _10877.push_back((int)1);
        }
        auto _10879 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_10877.size()),_10877.begin(),_10877.end()));
        _10872 = _10879;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _4891 = _10872;
      _checked_ptr_1<int> _ptr__4891(_4891 ? _4891->raw() : nullptr,_4891 ? _4891->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _4894 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_4852)));
      _checked_ptr_1<int> _ptr__4894(_4894 ? _4894->raw() : nullptr,_4894 ? _4894->size(0) : 0);
      _ptr__4894[(int)0] = (int)0;
      int _10880 = (int)1;
      int _10881 = _4852;
      for (int _4895 = _10880; _4895 < _10881; ++_4895)
      {
        {
          _ptr__4894[_4895] = safe_add( _ptr__4894[(_4895 - (int)1)],_ptr__4891[(_4895 - (int)1)] );
        }
      }
      int _4896 = (int)0;
      int _10882 = (int)0;
      int _10883 = _4852;
      for (int _4897 = _10882; _4897 < _10883; ++_4897)
      {
        {
          _4896 += _ptr__4891[_4897];
        }
      }
      int _4898 = (int)1;
      int _10884 = safe_add( dim,(int)1 );
      int _10885 = _4871;
      for (int _4899 = _10884; _4899 < _10885; ++_4899)
      {
        {
          _4898 *= _ptr__4868[safe_add( _4872,_4899 )];
        }
      }
      if (_4873)
      {
        {
          _4849->alloc_expr(_4880,_4882,_4883,false,_4881);
          int _4900 = mosek::fusion::p_WorkStack::_get_impl(_4849)->ptr_base;
          int _4901 = mosek::fusion::p_WorkStack::_get_impl(_4849)->shape_base;
          int _4902 = mosek::fusion::p_WorkStack::_get_impl(_4849)->nidxs_base;
          int _4903 = mosek::fusion::p_WorkStack::_get_impl(_4849)->cof_base;
          int _4904 = mosek::fusion::p_WorkStack::_get_impl(_4849)->code_base;
          int _4905 = mosek::fusion::p_WorkStack::_get_impl(_4849)->codeptr_base;
          int _4906 = mosek::fusion::p_WorkStack::_get_impl(_4849)->cconst_base;
          std::shared_ptr< monty::ndarray< int,1 > > _4907 = mosek::fusion::p_WorkStack::_get_impl(_4849)->i32;
          _checked_ptr_1<int> _ptr__4907(_4907 ? _4907->raw() : nullptr,_4907 ? _4907->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _4908 = mosek::fusion::p_WorkStack::_get_impl(_4849)->i64;
          _checked_ptr_1<long long> _ptr__4908(_4908 ? _4908->raw() : nullptr,_4908 ? _4908->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4909 = mosek::fusion::p_WorkStack::_get_impl(_4849)->f64;
          _checked_ptr_1<double> _ptr__4909(_4909 ? _4909->raw() : nullptr,_4909 ? _4909->size(0) : 0);
          int _10886;
          bool _10887 = (_4881 > (int)0);
          if (_10887)
          {
            _10886 = _4851->alloci32(safe_add( _4882,(int)1 ));
          }
          else
          {
            _10886 = (-(int)9999);
          }
          int _4910 = _10886;
          std::shared_ptr< monty::ndarray< int,1 > > _4911 = mosek::fusion::p_WorkStack::_get_impl(_4851)->i32;
          _checked_ptr_1<int> _ptr__4911(_4911 ? _4911->raw() : nullptr,_4911 ? _4911->size(0) : 0);
          int _10888 = (int)0;
          int _10889 = _4871;
          for (int _4912 = _10888; _4912 < _10889; ++_4912)
          {
            {
              _ptr__4907[safe_add( _4901,_4912 )] = _ptr__4868[safe_add( _4872,_4912 )];
            }
          }
          _ptr__4907[safe_add( _4901,dim )] = _4878;
          {
            int _4913 = (int)0;
            int _4914 = (int)0;
            int _4915 = (int)0;
            _ptr__4907[_4900] = (int)0;
            if (_4884)
            {
              {
                _ptr__4907[_4905] = (int)0;
              }
            }
            {}
            int _10890 = (int)0;
            int _10891 = _4889;
            for (int _4916 = _10890; _4916 < _10891; ++_4916)
            {
              {
                int _10892 = (int)0;
                int _10893 = _4852;
                for (int _4917 = _10892; _4917 < _10893; ++_4917)
                {
                  {
                    int _10894 = (int)0;
                    int _10895 = _ptr__4891[_4917];
                    for (int _4918 = _10894; _4918 < _10895; ++_4918)
                    {
                      {
                        int _10896 = (int)0;
                        int _10897 = _4898;
                        for (int _4919 = _10896; _4919 < _10897; ++_4919)
                        {
                          {
                            int _4920 = safe_add( safe_add( safe_mul( safe_mul( _4916,_ptr__4891[_4917] ),_4898 ),safe_mul( _4918,_4898 ) ),_4919 );
                            int _10898 = _ptr__4868[safe_add( _ptr__4860[_4917],_4920 )];
                            int _10899 = _ptr__4868[safe_add( safe_add( _ptr__4860[_4917],_4920 ),(int)1 )];
                            for (int _4921 = _10898; _4921 < _10899; ++_4921)
                            {
                              {
                                _ptr__4908[safe_add( _4902,_4915 )] = _ptr__4869[safe_add( _ptr__4861[_4917],_4921 )];
                                _ptr__4909[safe_add( _4903,_4915 )] = _ptr__4870[safe_add( _ptr__4863[_4917],_4921 )];
                                if ((_ptr__4858[_4917] > (int)0))
                                {
                                  {
                                    int _10900 = _ptr__4868[safe_add( _ptr__4865[_4917],_4921 )];
                                    int _10901 = _ptr__4868[safe_add( safe_add( _ptr__4865[_4917],_4921 ),(int)1 )];
                                    for (int _4922 = _10900; _4922 < _10901; ++_4922)
                                    {
                                      {
                                        _ptr__4907[safe_add( _4904,_4913 )] = _ptr__4868[safe_add( _ptr__4864[_4917],_4922 )];
                                        _ptr__4909[safe_add( _4906,_4913 )] = _ptr__4870[safe_add( _ptr__4866[_4917],_4922 )];
                                        ++ _4913;
                                      }
                                    }
                                    _ptr__4907[safe_add( safe_add( _4905,_4915 ),(int)1 )] = _4913;
                                  }
                                }
                                else if(_4884)
                                {
                                  {
                                    _ptr__4907[safe_add( _4904,_4913 )] = 2;
                                    _ptr__4909[safe_add( _4906,_4913 )] = 0.0;
                                    ++ _4913;
                                    _ptr__4907[safe_add( safe_add( _4905,_4915 ),(int)1 )] = _4913;
                                  }
                                }
                                {}
                                ++ _4915;
                              }
                            }
                            _ptr__4907[safe_add( safe_add( _4900,_4914 ),(int)1 )] = _4915;
                            ++ _4914;
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _4923 = (int)1;
          int _10902 = (int)0;
          int _10903 = dim;
          for (int _4924 = _10902; _4924 < _10903; ++_4924)
          {
            {
              _4923 *= _ptr__4868[safe_add( _4872,_4924 )];
            }
          }
          _4923 *= _4878;
          int _10904 = safe_add( dim,(int)1 );
          int _10905 = _4871;
          for (int _4925 = _10904; _4925 < _10905; ++_4925)
          {
            {
              _4923 *= _ptr__4868[safe_add( _4872,_4925 )];
            }
          }
          bool _4926 = (_4882 < _4923);
          _4849->alloc_expr(_4880,_4882,_4883,_4926,_4881);
          int _4927 = mosek::fusion::p_WorkStack::_get_impl(_4849)->ptr_base;
          int _4928 = mosek::fusion::p_WorkStack::_get_impl(_4849)->nidxs_base;
          int _10906;
          bool _10907 = _4926;
          if (_10907)
          {
            _10906 = mosek::fusion::p_WorkStack::_get_impl(_4849)->sp_base;
          }
          else
          {
            _10906 = _4849->alloci64(_4882);
          }
          int _4929 = _10906;
          int _4930 = mosek::fusion::p_WorkStack::_get_impl(_4849)->cof_base;
          int _4931 = mosek::fusion::p_WorkStack::_get_impl(_4849)->code_base;
          int _4932 = mosek::fusion::p_WorkStack::_get_impl(_4849)->codeptr_base;
          int _4933 = mosek::fusion::p_WorkStack::_get_impl(_4849)->cconst_base;
          int _4934 = mosek::fusion::p_WorkStack::_get_impl(_4849)->shape_base;
          int _10908 = (int)0;
          int _10909 = _4871;
          for (int _4935 = _10908; _4935 < _10909; ++_4935)
          {
            {
              ((*mosek::fusion::p_WorkStack::_get_impl(_4849)->i32)(safe_add( _4934,_4935 ))) = _ptr__4868[safe_add( _4872,_4935 )];
            }
          }
          ((*mosek::fusion::p_WorkStack::_get_impl(_4849)->i32)(safe_add( _4934,dim ))) = _4878;
          std::shared_ptr< monty::ndarray< int,1 > > _4936 = mosek::fusion::p_WorkStack::_get_impl(_4849)->i32;
          _checked_ptr_1<int> _ptr__4936(_4936 ? _4936->raw() : nullptr,_4936 ? _4936->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _4937 = mosek::fusion::p_WorkStack::_get_impl(_4849)->i64;
          _checked_ptr_1<long long> _ptr__4937(_4937 ? _4937->raw() : nullptr,_4937 ? _4937->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _4938 = mosek::fusion::p_WorkStack::_get_impl(_4849)->f64;
          _checked_ptr_1<double> _ptr__4938(_4938 ? _4938->raw() : nullptr,_4938 ? _4938->size(0) : 0);
          if ((dim == (int)0))
          {
            {
              int _4939 = (int)0;
              int _4940 = (int)0;
              int _4941 = (int)0;
              long long _4942 = (long long)0;
              _ptr__4936[_4927] = (int)0;
              if ((_4881 > (int)0))
              {
                {
                  _ptr__4936[_4932] = (int)0;
                }
              }
              {}
              int _10910 = (int)0;
              int _10911 = _4852;
              for (int _4943 = _10910; _4943 < _10911; ++_4943)
              {
                {
                  int _10912 = (int)0;
                  int _10913 = _ptr__4856[_4943];
                  for (int _4944 = _10912; _4944 < _10913; ++_4944)
                  {
                    {
                      int _10914 = _ptr__4868[safe_add( _ptr__4860[_4943],_4944 )];
                      int _10915 = _ptr__4868[safe_add( safe_add( _ptr__4860[_4943],_4944 ),(int)1 )];
                      for (int _4945 = _10914; _4945 < _10915; ++_4945)
                      {
                        {
                          _ptr__4937[safe_add( _4928,_4940 )] = _ptr__4869[safe_add( _ptr__4861[_4943],_4945 )];
                          _ptr__4938[safe_add( _4930,_4940 )] = _ptr__4870[safe_add( _ptr__4863[_4943],_4945 )];
                          if ((_ptr__4858[_4943] > (int)0))
                          {
                            {
                              int _10916 = _ptr__4868[safe_add( _ptr__4865[_4943],_4945 )];
                              int _10917 = _ptr__4868[safe_add( safe_add( _ptr__4865[_4943],_4945 ),(int)1 )];
                              for (int _4946 = _10916; _4946 < _10917; ++_4946)
                              {
                                {
                                  _ptr__4936[safe_add( _4931,_4939 )] = _ptr__4868[safe_add( _ptr__4864[_4943],_4946 )];
                                  _ptr__4938[safe_add( _4933,_4939 )] = _ptr__4870[safe_add( _ptr__4866[_4943],_4946 )];
                                  ++ _4939;
                                }
                              }
                              _ptr__4936[safe_add( safe_add( _4932,_4940 ),(int)1 )] = _4939;
                            }
                          }
                          else if((_4881 > (int)0))
                          {
                            {
                              _ptr__4936[safe_add( _4931,_4939 )] = 2;
                              _ptr__4938[safe_add( _4933,_4939 )] = 0.0;
                              ++ _4939;
                              _ptr__4936[safe_add( safe_add( _4932,_4940 ),(int)1 )] = _4939;
                            }
                          }
                          {}
                          ++ _4940;
                        }
                      }
                      _ptr__4936[safe_add( safe_add( _4927,_4941 ),(int)1 )] = _4940;
                      if ((_ptr__4859[_4943] != (int)0))
                      {
                        {
                          _ptr__4937[safe_add( _4929,_4941 )] = safe_add( _4942,_ptr__4869[safe_add( _ptr__4862[_4943],_4944 )] );
                        }
                      }
                      else
                      {
                        {
                          _ptr__4937[safe_add( _4929,_4941 )] = safe_add( _4942,_4944 );
                        }
                      }
                      ++ _4941;
                    }
                  }
                  long long _4947 = (long long)1;
                  int _10918 = (int)0;
                  int _10919 = _4871;
                  for (int _4948 = _10918; _4948 < _10919; ++_4948)
                  {
                    {
                      _4947 *= _ptr__4868[safe_add( _ptr__4855[_4943],_4948 )];
                    }
                  }
                  _4942 += _4947;
                }
              }
            }
          }
          else
          {
            {
              int _4949 = (int)0;
              int _10920 = (int)0;
              int _10921 = _4880;
              for (int _4950 = _10920; _4950 < _10921; ++_4950)
              {
                {
                  if ((_4949 < _ptr__4936[safe_add( _4934,_4950 )]))
                  {
                    {
                      _4949 = _ptr__4936[safe_add( _4934,_4950 )];
                    }
                  }
                  {}
                }
              }
              int _4951 = _4851->alloci64(_4882);
              int _4952 = _4851->alloci32(_4882);
              int _4953 = _4851->alloci32(_4882);
              int _4954 = _4851->alloci32(_4882);
              int _4955 = _4851->alloci32(_4882);
              int _4956 = _4851->alloci32(safe_add( _4949,(int)1 ));
              std::shared_ptr< monty::ndarray< int,1 > > _4957 = mosek::fusion::p_WorkStack::_get_impl(_4851)->i32;
              _checked_ptr_1<int> _ptr__4957(_4957 ? _4957->raw() : nullptr,_4957 ? _4957->size(0) : 0);
              std::shared_ptr< monty::ndarray< long long,1 > > _4958 = mosek::fusion::p_WorkStack::_get_impl(_4851)->i64;
              _checked_ptr_1<long long> _ptr__4958(_4958 ? _4958->raw() : nullptr,_4958 ? _4958->size(0) : 0);
              {
                int _4959 = (int)0;
                int _10922 = (int)0;
                int _10923 = _4852;
                for (int _4960 = _10922; _4960 < _10923; ++_4960)
                {
                  {
                    int _4961 = _ptr__4891[_4960];
                    int _4962 = safe_mul( _4961,_4898 );
                    int _4963 = _4898;
                    if ((_ptr__4859[_4960] != (int)0))
                    {
                      {
                        int _10924 = (int)0;
                        int _10925 = _ptr__4856[_4960];
                        for (int _4964 = _10924; _4964 < _10925; ++_4964)
                        {
                          {
                            long long _4965 = (_ptr__4869[safe_add( _ptr__4862[_4960],_4964 )] / _4962);
                            long long _4966 = ((_ptr__4869[safe_add( _ptr__4862[_4960],_4964 )] / _4963) % _4961);
                            long long _4967 = (_ptr__4869[safe_add( _ptr__4862[_4960],_4964 )] % _4898);
                            _ptr__4958[safe_add( _4951,_4959 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _4965,_4878 ),_4966 ),_ptr__4894[_4960] ),_4898 ),_4967 );
                            _ptr__4957[safe_add( _4952,_4959 )] = _4960;
                            _ptr__4957[safe_add( _4953,_4959 )] = _4964;
                            ++ _4959;
                          }
                        }
                      }
                    }
                    else
                    {
                      {
                        int _10926 = (int)0;
                        int _10927 = _ptr__4856[_4960];
                        for (int _4968 = _10926; _4968 < _10927; ++_4968)
                        {
                          {
                            long long _4969 = ((long long)_4968 / _4962);
                            long long _4970 = (((long long)_4968 / _4963) % _4961);
                            long long _4971 = ((long long)_4968 % _4898);
                            _ptr__4958[safe_add( _4951,_4959 )] = safe_add( safe_mul( safe_add( safe_add( safe_mul( _4969,_4878 ),_4970 ),_ptr__4894[_4960] ),_4898 ),_4971 );
                            _ptr__4957[safe_add( _4952,_4959 )] = _4960;
                            _ptr__4957[safe_add( _4953,_4959 )] = _4968;
                            ++ _4959;
                          }
                        }
                      }
                    }
                  }
                }
              }
              {
                std::shared_ptr< monty::ndarray< long long,1 > > _4972 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_4880)));
                _checked_ptr_1<long long> _ptr__4972(_4972 ? _4972->raw() : nullptr,_4972 ? _4972->size(0) : 0);
                _ptr__4972[(_4880 - (int)1)] = (int)1;
                int _10928 = (int)1;
                int _10929 = _4880;
                for (int _4973 = _10928; _4973 < _10929; ++_4973)
                {
                  {
                    _ptr__4972[((_4880 - _4973) - (int)1)] = safe_mul( _ptr__4972[(_4880 - _4973)],_ptr__4936[(safe_add( _4934,_4880 ) - _4973)] );
                  }
                }
                int _10930 = (int)0;
                int _10931 = _4882;
                for (int _4974 = _10930; _4974 < _10931; ++_4974)
                {
                  {
                    _ptr__4957[safe_add( _4954,_4974 )] = _4974;
                  }
                }
                int _10932 = (int)0;
                int _10933 = _4880;
                for (int _4975 = _10932; _4975 < _10933; ++_4975)
                {
                  {
                    int _4976 = ((_4880 - _4975) - (int)1);
                    int _4977 = _ptr__4936[safe_add( _4934,_4976 )];
                    int _10934 = (int)0;
                    int _10935 = safe_add( _4977,(int)1 );
                    for (int _4978 = _10934; _4978 < _10935; ++_4978)
                    {
                      {
                        _ptr__4957[safe_add( _4956,_4978 )] = (int)0;
                      }
                    }
                    int _10936 = (int)0;
                    int _10937 = _4882;
                    for (int _4979 = _10936; _4979 < _10937; ++_4979)
                    {
                      {
                        int _4980 = _ptr__4957[safe_add( _4954,_4979 )];
                        long long _4981 = ((_ptr__4958[safe_add( _4951,_4980 )] / _ptr__4972[_4976]) % _4977);
                        ++ _ptr__4957[safe_add( safe_add( _4956,_4981 ),(int)1 )];
                      }
                    }
                    {
                      int _10938 = (int)0;
                      int _10939 = _4977;
                      for (int _4982 = _10938; _4982 < _10939; ++_4982)
                      {
                        {
                          _ptr__4957[safe_add( safe_add( _4956,_4982 ),(int)1 )] += _ptr__4957[safe_add( _4956,_4982 )];
                        }
                      }
                      int _10940 = (int)0;
                      int _10941 = _4882;
                      for (int _4983 = _10940; _4983 < _10941; ++_4983)
                      {
                        {
                          int _4984 = _ptr__4957[safe_add( _4954,_4983 )];
                          long long _4985 = ((_ptr__4958[safe_add( _4951,_4984 )] / _ptr__4972[_4976]) % _4977);
                          _ptr__4957[safe_add( _4955,_ptr__4957[safe_add( _4956,_4985 )] )] = _4984;
                          ++ _ptr__4957[safe_add( _4956,_4985 )];
                        }
                      }
                    }
                    int _4986 = _4954;
                    _4954 = _4955;
                    _4955 = _4986;
                  }
                }
              }
              {
                int _4987 = (int)0;
                int _4988 = (int)0;
                _ptr__4936[_4927] = (int)0;
                if ((_4881 > (int)0))
                {
                  {
                    _ptr__4936[_4932] = (int)0;
                  }
                }
                {}
                int _10942 = (int)0;
                int _10943 = _4882;
                for (int _4989 = _10942; _4989 < _10943; ++_4989)
                {
                  {
                    int _4990 = _ptr__4957[safe_add( _4954,_4989 )];
                    int _4991 = _ptr__4957[safe_add( _4952,_4990 )];
                    int _4992 = _ptr__4957[safe_add( _4953,_4990 )];
                    int _10944 = _ptr__4868[safe_add( _ptr__4860[_4991],_4992 )];
                    int _10945 = _ptr__4868[safe_add( safe_add( _ptr__4860[_4991],_4992 ),(int)1 )];
                    for (int _4993 = _10944; _4993 < _10945; ++_4993)
                    {
                      {
                        _ptr__4937[safe_add( _4928,_4988 )] = _ptr__4869[safe_add( _ptr__4861[_4991],_4993 )];
                        _ptr__4938[safe_add( _4930,_4988 )] = _ptr__4870[safe_add( _ptr__4863[_4991],_4993 )];
                        if ((_ptr__4858[_4991] > (int)0))
                        {
                          {
                            int _10946 = _ptr__4868[safe_add( _ptr__4865[_4991],_4993 )];
                            int _10947 = _ptr__4868[safe_add( safe_add( _ptr__4865[_4991],_4993 ),(int)1 )];
                            for (int _4994 = _10946; _4994 < _10947; ++_4994)
                            {
                              {
                                _ptr__4936[safe_add( _4931,_4987 )] = _ptr__4868[safe_add( _ptr__4864[_4991],_4994 )];
                                _ptr__4938[safe_add( _4933,_4987 )] = _ptr__4870[safe_add( _ptr__4866[_4991],_4994 )];
                                ++ _4987;
                              }
                            }
                            _ptr__4936[safe_add( safe_add( _4932,_4988 ),(int)1 )] = _4987;
                          }
                        }
                        else if(_4884)
                        {
                          {
                            _ptr__4936[safe_add( _4931,_4987 )] = 2;
                            _ptr__4938[safe_add( _4933,_4987 )] = 0.0;
                            ++ _4987;
                            _ptr__4936[safe_add( safe_add( _4932,_4988 ),(int)1 )] = _4987;
                          }
                        }
                        {}
                        ++ _4988;
                      }
                    }
                    _ptr__4936[safe_add( safe_add( _4927,_4989 ),(int)1 )] = _4988;
                    _ptr__4937[safe_add( _4929,_4989 )] = _ptr__4958[safe_add( _4951,_4990 )];
                  }
                }
              }
            }
          }
          if ((!_4926))
          {
            {
              _4849->popi64(_4882);
            }
          }
          {}
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprStack::getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4995,int _4996){
  if (((int)((_4995)->size(0)) == (int)0))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Cannot stack empty list"));
    }
  }
  else if(((int)((_4995)->size(0)) == (int)1))
  {
    {
      return ((*_4995)((int)0))->getShape();
    }
  }
  else
  {
    {
      std::vector<std::shared_ptr< monty::ndarray< int,1 > >> _10948;
      for (int _4998 = (int)0, _10949 = (int)((_4995)->size(0)); _4998 < _10949 ; ++_4998)
      {
        _10948.push_back(((*_4995)(_4998))->getShape());
      }
      auto _10950 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape(_10948.size()),_10948.begin(),_10948.end()));
      std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _4997 = _10950;
      std::shared_ptr< monty::ndarray< int,1 > > _4999 = ((*_4997)((int)0));
      _checked_ptr_1<int> _ptr__4999(_4999 ? _4999->raw() : nullptr,_4999 ? _4999->size(0) : 0);
      int _5000 = (int)((_4999)->size(0));
      int _10951 = (int)1;
      int _10952 = (int)((_4997)->size(0));
      for (int _5001 = _10951; _5001 < _10952; ++_5001)
      {
        {
          if ((_5000 != (int)((((*_4997)(_5001)))->size(0))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression dimensions"));
            }
          }
          {}
          int _10953 = (int)0;
          int _10954 = _4996;
          for (int _5002 = _10953; _5002 < _10954; ++_5002)
          {
            {
              if ((_ptr__4999[_5002] != ((*((*_4997)(_5001)))(_5002))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
          int _10955 = safe_add( _4996,(int)1 );
          int _10956 = _5000;
          for (int _5003 = _10955; _5003 < _10956; ++_5003)
          {
            {
              if ((_ptr__4999[_5003] != ((*((*_4997)(_5001)))(_5003))))
              {
                {
                  throw ::mosek::fusion::DimensionError(std::string ("mismatching expression dimensions"));
                }
              }
              {}
            }
          }
        }
      }
      if ((_4996 == _5000))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5004 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _5000,(int)1 ))));
          _checked_ptr_1<int> _ptr__5004(_5004 ? _5004->raw() : nullptr,_5004 ? _5004->size(0) : 0);
          int _10957 = (int)0;
          int _10958 = _5000;
          for (int _5005 = _10957; _5005 < _10958; ++_5005)
          {
            {
              _ptr__5004[_5005] = _ptr__4999[_5005];
            }
          }
          _ptr__5004[_5000] = (int)((_4997)->size(0));
          return _5004;
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _5006 = _4999;
          _checked_ptr_1<int> _ptr__5006(_5006 ? _5006->raw() : nullptr,_5006 ? _5006->size(0) : 0);
          int _10959 = (int)1;
          int _10960 = (int)((_4997)->size(0));
          for (int _5007 = _10959; _5007 < _10960; ++_5007)
          {
            {
              _ptr__5006[_4996] += ((*((*_4997)(_5007)))(_4996));
            }
          }
          return _5006;
        }
      }
    }
  }
}
std::string mosek::fusion::ExprStack :: toString() { return mosek::fusion::p_ExprStack::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprStack::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _5008 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprStack(dim="))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)((int)0))->toString());
  int _10961 = (int)1;
  int _10962 = (int)((exprs)->size(0));
  for (int _5009 = _10961; _5009 < _10962; ++_5009)
  {
    {
      _5008->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*exprs)(_5009))->toString());
    }
  }
  _5008->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _5008->toString();
}
void mosek::fusion::p_ExprStack::destroy(){exprs.reset();}void mosek::fusion::ExprStack::destroy() { mosek::fusion::p_ExprStack::_get_impl(this)->destroy(); }mosek::fusion::ExprInner::ExprInner(mosek::fusion::p_ExprInner *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprInner()" << this << std::endl; */ }mosek::fusion::ExprInner::~ExprInner() {  /* std::cout << "~ExprInner()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprInner::p_ExprInner  (::mosek::fusion::ExprInner * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _5010,    std::shared_ptr< monty::ndarray< long long,1 > > _5011,    std::shared_ptr< monty::ndarray< double,1 > > _5012){ return new mosek::fusion::ExprInner(_5010,_5011,_5012); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _5010,    std::shared_ptr< monty::ndarray< long long,1 > > _5011,    std::shared_ptr< monty::ndarray< double,1 > > _5012) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_5010,_5011,_5012); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _5010,    std::shared_ptr< monty::ndarray< long long,1 > > _5011,    std::shared_ptr< monty::ndarray< double,1 > > _5012){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__5011(_5011 ? _5011->raw() : nullptr, _5011 ? _5011->size(0) : 0);
    _checked_ptr_1<double> _ptr__5012(_5012 ? _5012->raw() : nullptr, _5012 ? _5012->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))));
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->expr = _5010;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vsub = _5011;
    mosek::fusion::p_ExprInner::_get_impl(::mosek::fusion::ExprInner::t(_pubthis))->vcof = _5012;
    if (((int)((_5011)->size(0)) != (int)((_5012)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching lengths of vcof and vsub"));
      }
    }
    {}
    std::shared_ptr< monty::ndarray< int,1 > > _5013 = _5010->getShape();
    _checked_ptr_1<int> _ptr__5013(_5013 ? _5013->raw() : nullptr,_5013 ? _5013->size(0) : 0);
    long long _5014 = ::mosek::fusion::p_Set::size(_5013);
    bool _5015 = false;
    bool _5016 = false;
    {
      int _10963 = (int)1;
      int _10964 = (int)((_5011)->size(0));
      for (int _5017 = _10963; _5017 < _10964; ++_5017)
      {
        {
          if ((_ptr__5011[_5017] <= _ptr__5011[(_5017 - (int)1)]))
          {
            {
              _5015 = true;
            }
          }
          {}
        }
      }
      if (((int)((_5011)->size(0)) > (int)0))
      {
        {
          if (((_ptr__5011[(int)0] < (int)0) || (_ptr__5011[((int)((_5011)->size(0)) - (int)1)] > _5014)))
          {
            {
              _5016 = true;
            }
          }
          {}
        }
      }
      {}
    }
    if (_5015)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Unordered coefficcient subscripts"));
      }
    }
    {}
    if (_5016)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Coefficient subscript out of bounds"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _5018,    std::shared_ptr< monty::ndarray< double,1 > > _5019){ return new mosek::fusion::ExprInner(_5018,_5019); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _5018,    std::shared_ptr< monty::ndarray< double,1 > > _5019) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_5018,_5019); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _5018,    std::shared_ptr< monty::ndarray< double,1 > > _5019){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5019(_5019 ? _5019->raw() : nullptr, _5019 ? _5019->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_5018,::mosek::fusion::p_ExprInner::range((int)((_5019)->size(0))),_5019);
    std::shared_ptr< monty::ndarray< int,1 > > _5020 = _5018->getShape();
    _checked_ptr_1<int> _ptr__5020(_5020 ? _5020->raw() : nullptr,_5020 ? _5020->size(0) : 0);
    if ((((int)((_5020)->size(0)) != (int)1) || (_ptr__5020[(int)0] != (int)((_5019)->size(0)))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
      }
    }
    {}
  }
}mosek::fusion::ExprInner::t mosek::fusion::p_ExprInner::_new_ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _5021,    std::shared_ptr< monty::ndarray< int,2 > > _5022,    std::shared_ptr< monty::ndarray< double,1 > > _5023){ return new mosek::fusion::ExprInner(_5021,_5022,_5023); }mosek::fusion::ExprInner::ExprInner  (monty::rc_ptr< ::mosek::fusion::Expression > _5021,    std::shared_ptr< monty::ndarray< int,2 > > _5022,    std::shared_ptr< monty::ndarray< double,1 > > _5023) :    ExprInner(new mosek::fusion::p_ExprInner(this)){ mosek::fusion::p_ExprInner::_get_impl(this)->_initialize(_5021,_5022,_5023); }void mosek::fusion::p_ExprInner::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _5021,    std::shared_ptr< monty::ndarray< int,2 > > _5022,    std::shared_ptr< monty::ndarray< double,1 > > _5023){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5023(_5023 ? _5023->raw() : nullptr, _5023 ? _5023->size(0) : 0);
    mosek::fusion::p_ExprInner::_initialize(_5021,::mosek::fusion::p_ExprInner::convert(_5021->getShape(),_5022),_5023);
  }
}void mosek::fusion::ExprInner :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5024,monty::rc_ptr< ::mosek::fusion::WorkStack > _5025,monty::rc_ptr< ::mosek::fusion::WorkStack > _5026) { mosek::fusion::p_ExprInner::_get_impl(this)->eval(_5024,_5025,_5026); }void mosek::fusion::p_ExprInner::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5024,monty::rc_ptr< ::mosek::fusion::WorkStack > _5025,monty::rc_ptr< ::mosek::fusion::WorkStack > _5026){
  expr->eval(_5025,_5024,_5026);
  _5025->pop_expr();
  int _5027 = mosek::fusion::p_WorkStack::_get_impl(_5025)->nd;
  int _5028 = mosek::fusion::p_WorkStack::_get_impl(_5025)->nelem;
  int _5029 = mosek::fusion::p_WorkStack::_get_impl(_5025)->nnz;
  int _5030 = mosek::fusion::p_WorkStack::_get_impl(_5025)->ncodeatom;
  bool _5031 = mosek::fusion::p_WorkStack::_get_impl(_5025)->hassp;
  int _5032 = mosek::fusion::p_WorkStack::_get_impl(_5025)->shape_base;
  int _5033 = mosek::fusion::p_WorkStack::_get_impl(_5025)->ptr_base;
  int _5034 = mosek::fusion::p_WorkStack::_get_impl(_5025)->nidxs_base;
  int _5035 = mosek::fusion::p_WorkStack::_get_impl(_5025)->sp_base;
  int _5036 = mosek::fusion::p_WorkStack::_get_impl(_5025)->cof_base;
  int _5037 = mosek::fusion::p_WorkStack::_get_impl(_5025)->code_base;
  int _5038 = mosek::fusion::p_WorkStack::_get_impl(_5025)->codeptr_base;
  int _5039 = mosek::fusion::p_WorkStack::_get_impl(_5025)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5040 = mosek::fusion::p_WorkStack::_get_impl(_5025)->i32;
  _checked_ptr_1<int> _ptr__5040(_5040 ? _5040->raw() : nullptr,_5040 ? _5040->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5041 = mosek::fusion::p_WorkStack::_get_impl(_5025)->i64;
  _checked_ptr_1<long long> _ptr__5041(_5041 ? _5041->raw() : nullptr,_5041 ? _5041->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5042 = mosek::fusion::p_WorkStack::_get_impl(_5025)->f64;
  _checked_ptr_1<double> _ptr__5042(_5042 ? _5042->raw() : nullptr,_5042 ? _5042->size(0) : 0);
  int _5043 = (int)0;
  if (_5031)
  {
    {
      int _5044 = (int)0;
      int _5045 = (int)0;
      while ( ((_5045 < (int)((vsub)->size(0))) && (_5044 < _5028)) )
      {
        {
          if ((_ptr__5041[safe_add( _5035,_5044 )] < ((*vsub)(_5045))))
          {
            {
              ++ _5044;
            }
          }
          else if((_ptr__5041[safe_add( _5035,_5044 )] > ((*vsub)(_5045))))
          {
            {
              ++ _5045;
            }
          }
          else
          {
            {
              _5043 += (_ptr__5040[safe_add( safe_add( _5033,_5044 ),(int)1 )] - _ptr__5040[safe_add( _5033,_5044 )]);
              ++ _5045;
              ++ _5044;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _10965 = (int)0;
      int _10966 = (int)((vsub)->size(0));
      for (int _5046 = _10965; _5046 < _10966; ++_5046)
      {
        {
          _5043 += (_ptr__5040[safe_add( safe_add( _5033,((*vsub)(_5046)) ),(int)1 )] - _ptr__5040[safe_add( _5033,((*vsub)(_5046)) )]);
        }
      }
    }
  }
  int _10967;
  bool _10968 = (_5030 > (int)0);
  if (_10968)
  {
    _10967 = safe_add( _5030,safe_mul( (int)2,_5029 ) );
  }
  else
  {
    _10967 = (int)0;
  }
  int _5047 = _10967;
  _5024->alloc_expr((int)0,(int)1,_5043,false,_5047);
  int _5048 = mosek::fusion::p_WorkStack::_get_impl(_5024)->ptr_base;
  int _5049 = mosek::fusion::p_WorkStack::_get_impl(_5024)->nidxs_base;
  int _5050 = mosek::fusion::p_WorkStack::_get_impl(_5024)->cof_base;
  int _5051 = mosek::fusion::p_WorkStack::_get_impl(_5024)->code_base;
  int _5052 = mosek::fusion::p_WorkStack::_get_impl(_5024)->codeptr_base;
  int _5053 = mosek::fusion::p_WorkStack::_get_impl(_5024)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5054 = mosek::fusion::p_WorkStack::_get_impl(_5024)->i32;
  _checked_ptr_1<int> _ptr__5054(_5054 ? _5054->raw() : nullptr,_5054 ? _5054->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5055 = mosek::fusion::p_WorkStack::_get_impl(_5024)->i64;
  _checked_ptr_1<long long> _ptr__5055(_5055 ? _5055->raw() : nullptr,_5055 ? _5055->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5056 = mosek::fusion::p_WorkStack::_get_impl(_5024)->f64;
  _checked_ptr_1<double> _ptr__5056(_5056 ? _5056->raw() : nullptr,_5056 ? _5056->size(0) : 0);
  _ptr__5054[_5048] = (int)0;
  _ptr__5054[safe_add( _5048,(int)1 )] = _5043;
  if ((_5047 > (int)0))
  {
    {
      _ptr__5054[_5052] = (int)0;
    }
  }
  {}
  int _5057 = (int)0;
  int _5058 = (int)0;
  if (_5031)
  {
    {
      int _5059 = (int)0;
      int _5060 = (int)0;
      while ( ((_5060 < (int)((vsub)->size(0))) && (_5059 < _5028)) )
      {
        {
          if ((_ptr__5041[safe_add( _5035,_5059 )] < ((*vsub)(_5060))))
          {
            {
              ++ _5059;
            }
          }
          else if((_ptr__5041[safe_add( _5035,_5059 )] > ((*vsub)(_5060))))
          {
            {
              ++ _5060;
            }
          }
          else
          {
            {
              int _5061 = _ptr__5040[safe_add( _5033,_5059 )];
              int _5062 = _ptr__5040[safe_add( safe_add( _5033,_5059 ),(int)1 )];
              int _10969 = _5061;
              int _10970 = _5062;
              for (int _5063 = _10969; _5063 < _10970; ++_5063)
              {
                {
                  _ptr__5055[safe_add( _5049,_5058 )] = _ptr__5041[safe_add( _5034,_5063 )];
                  _ptr__5056[safe_add( _5050,_5058 )] = (((*vcof)(_5060)) * _ptr__5042[safe_add( _5036,_5063 )]);
                  if ((_5047 > (int)0))
                  {
                    {
                      int _10971 = _ptr__5040[safe_add( _5038,_5063 )];
                      int _10972 = _ptr__5040[safe_add( safe_add( _5038,_5063 ),(int)1 )];
                      for (int _5064 = _10971; _5064 < _10972; ++_5064)
                      {
                        {
                          _ptr__5054[safe_add( _5051,_5057 )] = _ptr__5040[safe_add( _5037,_5064 )];
                          _ptr__5056[safe_add( _5053,_5057 )] = _ptr__5042[safe_add( _5039,_5064 )];
                          ++ _5057;
                        }
                      }
                      _ptr__5054[safe_add( _5051,_5057 )] = 2;
                      _ptr__5056[safe_add( _5053,_5057 )] = ((*vcof)(_5060));
                      ++ _5057;
                      _ptr__5054[safe_add( _5051,_5057 )] = 5;
                      ++ _5057;
                      _ptr__5054[safe_add( safe_add( _5052,_5058 ),(int)1 )] = _5057;
                    }
                  }
                  {}
                  ++ _5058;
                }
              }
              ++ _5060;
              ++ _5059;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _10973 = (int)0;
      int _10974 = (int)((vsub)->size(0));
      for (int _5065 = _10973; _5065 < _10974; ++_5065)
      {
        {
          int _5066 = _ptr__5040[safe_add( _5033,((*vsub)(_5065)) )];
          int _5067 = _ptr__5040[safe_add( safe_add( _5033,((*vsub)(_5065)) ),(int)1 )];
          int _10975 = _5066;
          int _10976 = _5067;
          for (int _5068 = _10975; _5068 < _10976; ++_5068)
          {
            {
              _ptr__5055[safe_add( _5049,_5058 )] = _ptr__5041[safe_add( _5034,_5068 )];
              _ptr__5056[safe_add( _5050,_5058 )] = (((*vcof)(_5065)) * _ptr__5042[safe_add( _5036,_5068 )]);
              if ((_5047 > (int)0))
              {
                {
                  int _10977 = _ptr__5040[safe_add( _5038,_5068 )];
                  int _10978 = _ptr__5040[safe_add( safe_add( _5038,_5068 ),(int)1 )];
                  for (int _5069 = _10977; _5069 < _10978; ++_5069)
                  {
                    {
                      _ptr__5054[safe_add( _5051,_5057 )] = _ptr__5040[safe_add( _5037,_5069 )];
                      _ptr__5056[safe_add( _5053,_5057 )] = _ptr__5040[safe_add( _5039,_5069 )];
                      ++ _5057;
                    }
                  }
                  _ptr__5054[safe_add( _5051,_5057 )] = 2;
                  _ptr__5056[safe_add( _5053,_5057 )] = ((*vcof)(_5065));
                  ++ _5057;
                  _ptr__5054[safe_add( _5051,_5057 )] = 5;
                  ++ _5057;
                  _ptr__5054[safe_add( safe_add( _5052,_5058 ),(int)1 )] = _5057;
                }
              }
              {}
              ++ _5058;
            }
          }
        }
      }
    }
  }
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::range(int _5070){
  std::vector<long long> _10979;
  for (int _5071 = (int)0, _10980 = _5070; _5071 < _10980 ; ++_5071)
  {
    _10979.push_back(_5071);
  }
  auto _10981 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_10979.size()),_10979.begin(),_10979.end()));
  return _10981;
}
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_ExprInner::convert(std::shared_ptr< monty::ndarray< int,1 > > _5072,std::shared_ptr< monty::ndarray< int,2 > > _5073){
  _checked_ptr_1<int> _ptr__5072(_5072 ? _5072->raw() : nullptr, _5072 ? _5072->size(0) : 0);
  int _5074 = (int)((_5072)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _5075 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_5074)));
  _checked_ptr_1<long long> _ptr__5075(_5075 ? _5075->raw() : nullptr,_5075 ? _5075->size(0) : 0);
  _ptr__5075[(_5074 - (int)1)] = (int)1;
  int _10982 = (int)1;
  int _10983 = _5074;
  for (int _5076 = _10982; _5076 < _10983; ++_5076)
  {
    {
      _ptr__5075[((_5074 - _5076) - (int)1)] = safe_mul( _ptr__5075[(_5074 - _5076)],_ptr__5072[(_5074 - _5076)] );
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _5077 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_5073)->size(0)))));
  _checked_ptr_1<long long> _ptr__5077(_5077 ? _5077->raw() : nullptr,_5077 ? _5077->size(0) : 0);
  int _10984 = (int)0;
  int _10985 = (int)((_5073)->size(0));
  for (int _5078 = _10984; _5078 < _10985; ++_5078)
  {
    {
      int _10986 = (int)0;
      int _10987 = _5074;
      for (int _5079 = _10986; _5079 < _10987; ++_5079)
      {
        {
          _ptr__5077[_5078] += safe_mul( _ptr__5075[_5079],((*_5073)(_5078,_5079)) );
        }
      }
    }
  }
  return _5077;
}
std::string mosek::fusion::ExprInner :: toString() { return mosek::fusion::p_ExprInner::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprInner::toString(){
  return std::string ("ExprInner()");
}
void mosek::fusion::p_ExprInner::destroy(){vcof.reset();vsub.reset();expr.reset();}void mosek::fusion::ExprInner::destroy() { mosek::fusion::p_ExprInner::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight(mosek::fusion::p_ExprMulDiagRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagRight()" << this << std::endl; */ }mosek::fusion::ExprMulDiagRight::~ExprMulDiagRight() {  /* std::cout << "~ExprMulDiagRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagRight::p_ExprMulDiagRight  (::mosek::fusion::ExprMulDiagRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _5080,    int _5081,    std::shared_ptr< monty::ndarray< int,1 > > _5082,    std::shared_ptr< monty::ndarray< int,1 > > _5083,    std::shared_ptr< monty::ndarray< double,1 > > _5084,    monty::rc_ptr< ::mosek::fusion::Expression > _5085,    int _5086){ return new mosek::fusion::ExprMulDiagRight(_5080,_5081,_5082,_5083,_5084,_5085,_5086); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _5080,    int _5081,    std::shared_ptr< monty::ndarray< int,1 > > _5082,    std::shared_ptr< monty::ndarray< int,1 > > _5083,    std::shared_ptr< monty::ndarray< double,1 > > _5084,    monty::rc_ptr< ::mosek::fusion::Expression > _5085,    int _5086) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_5080,_5081,_5082,_5083,_5084,_5085,_5086); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _5080,    int _5081,    std::shared_ptr< monty::ndarray< int,1 > > _5082,    std::shared_ptr< monty::ndarray< int,1 > > _5083,    std::shared_ptr< monty::ndarray< double,1 > > _5084,    monty::rc_ptr< ::mosek::fusion::Expression > _5085,    int _5086){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5082(_5082 ? _5082->raw() : nullptr, _5082 ? _5082->size(0) : 0);
    _checked_ptr_1<int> _ptr__5083(_5083 ? _5083->raw() : nullptr, _5083 ? _5083->size(0) : 0);
    _checked_ptr_1<double> _ptr__5084(_5084 ? _5084->raw() : nullptr, _5084 ? _5084->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5081)}));
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim0 = _5080;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mdim1 = _5081;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubi = _5082;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->msubj = _5083;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->mval = _5084;
    mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr = _5085;
  }
}mosek::fusion::ExprMulDiagRight::t mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight  (int _5087,    int _5088,    std::shared_ptr< monty::ndarray< int,1 > > _5089,    std::shared_ptr< monty::ndarray< int,1 > > _5090,    std::shared_ptr< monty::ndarray< double,1 > > _5091,    monty::rc_ptr< ::mosek::fusion::Expression > _5092){ return new mosek::fusion::ExprMulDiagRight(_5087,_5088,_5089,_5090,_5091,_5092); }mosek::fusion::ExprMulDiagRight::ExprMulDiagRight  (int _5087,    int _5088,    std::shared_ptr< monty::ndarray< int,1 > > _5089,    std::shared_ptr< monty::ndarray< int,1 > > _5090,    std::shared_ptr< monty::ndarray< double,1 > > _5091,    monty::rc_ptr< ::mosek::fusion::Expression > _5092) :    ExprMulDiagRight(new mosek::fusion::p_ExprMulDiagRight(this)){ mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->_initialize(_5087,_5088,_5089,_5090,_5091,_5092); }void mosek::fusion::p_ExprMulDiagRight::_initialize  (int _5087,    int _5088,    std::shared_ptr< monty::ndarray< int,1 > > _5089,    std::shared_ptr< monty::ndarray< int,1 > > _5090,    std::shared_ptr< monty::ndarray< double,1 > > _5091,    monty::rc_ptr< ::mosek::fusion::Expression > _5092){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5089(_5089 ? _5089->raw() : nullptr, _5089 ? _5089->size(0) : 0);
    _checked_ptr_1<int> _ptr__5090(_5090 ? _5090->raw() : nullptr, _5090 ? _5090->size(0) : 0);
    _checked_ptr_1<double> _ptr__5091(_5091 ? _5091->raw() : nullptr, _5091 ? _5091->size(0) : 0);
    mosek::fusion::p_ExprMulDiagRight::_initialize(_5087,_5088,_5089,_5090,_5091,_5092,::mosek::fusion::p_ExprMulDiagRight::validate(_5087,_5088,_5089,_5090,_5091,_5092));
  }
}void mosek::fusion::ExprMulDiagRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5093,monty::rc_ptr< ::mosek::fusion::WorkStack > _5094,monty::rc_ptr< ::mosek::fusion::WorkStack > _5095) { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->eval(_5093,_5094,_5095); }void mosek::fusion::p_ExprMulDiagRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5093,monty::rc_ptr< ::mosek::fusion::WorkStack > _5094,monty::rc_ptr< ::mosek::fusion::WorkStack > _5095){
  mosek::fusion::p_ExprMulDiagRight::_get_impl(::mosek::fusion::ExprMulDiagRight::t(_pubthis))->expr->eval(_5094,_5093,_5095);
  _5094->pop_expr();
  int _5096 = mosek::fusion::p_WorkStack::_get_impl(_5094)->nd;
  int _5097 = mosek::fusion::p_WorkStack::_get_impl(_5094)->nnz;
  int _5098 = mosek::fusion::p_WorkStack::_get_impl(_5094)->nelem;
  int _5099 = mosek::fusion::p_WorkStack::_get_impl(_5094)->ncodeatom;
  bool _5100 = mosek::fusion::p_WorkStack::_get_impl(_5094)->hassp;
  int _5101 = mosek::fusion::p_WorkStack::_get_impl(_5094)->shape_base;
  int _5102 = mosek::fusion::p_WorkStack::_get_impl(_5094)->ptr_base;
  int _5103 = mosek::fusion::p_WorkStack::_get_impl(_5094)->sp_base;
  int _5104 = mosek::fusion::p_WorkStack::_get_impl(_5094)->nidxs_base;
  int _5105 = mosek::fusion::p_WorkStack::_get_impl(_5094)->cof_base;
  int _5106 = mosek::fusion::p_WorkStack::_get_impl(_5094)->codeptr_base;
  int _5107 = mosek::fusion::p_WorkStack::_get_impl(_5094)->code_base;
  int _5108 = mosek::fusion::p_WorkStack::_get_impl(_5094)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5109 = mosek::fusion::p_WorkStack::_get_impl(_5094)->i32;
  _checked_ptr_1<int> _ptr__5109(_5109 ? _5109->raw() : nullptr,_5109 ? _5109->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5110 = mosek::fusion::p_WorkStack::_get_impl(_5094)->i64;
  _checked_ptr_1<long long> _ptr__5110(_5110 ? _5110->raw() : nullptr,_5110 ? _5110->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5111 = mosek::fusion::p_WorkStack::_get_impl(_5094)->f64;
  _checked_ptr_1<double> _ptr__5111(_5111 ? _5111->raw() : nullptr,_5111 ? _5111->size(0) : 0);
  int _5112 = _ptr__5109[_5101];
  int _5113 = _ptr__5109[safe_add( _5101,(int)1 )];
  int _5114 = (int)((mval)->size(0));
  int _5115 = _5095->alloci32(_5114);
  int _5116 = _5095->alloci32(safe_add( mdim1,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _5117 = mosek::fusion::p_WorkStack::_get_impl(_5095)->i32;
  _checked_ptr_1<int> _ptr__5117(_5117 ? _5117->raw() : nullptr,_5117 ? _5117->size(0) : 0);
  {
    int _10988 = (int)0;
    int _10989 = safe_add( mdim1,(int)1 );
    for (int _5118 = _10988; _5118 < _10989; ++_5118)
    {
      {
        _ptr__5117[safe_add( _5116,_5118 )] = (int)0;
      }
    }
    int _10990 = (int)0;
    int _10991 = _5114;
    for (int _5119 = _10990; _5119 < _10991; ++_5119)
    {
      {
        ++ _ptr__5117[safe_add( safe_add( _5116,((*msubj)(_5119)) ),(int)1 )];
      }
    }
    int _10992 = (int)0;
    int _10993 = mdim1;
    for (int _5120 = _10992; _5120 < _10993; ++_5120)
    {
      {
        _ptr__5117[safe_add( safe_add( _5116,_5120 ),(int)1 )] += _ptr__5117[safe_add( _5116,_5120 )];
      }
    }
    int _10994 = (int)0;
    int _10995 = _5114;
    for (int _5121 = _10994; _5121 < _10995; ++_5121)
    {
      {
        _ptr__5117[safe_add( _5115,_ptr__5117[safe_add( _5116,((*msubj)(_5121)) )] )] = _5121;
        ++ _ptr__5117[safe_add( _5116,((*msubj)(_5121)) )];
      }
    }
    int _10996 = (int)0;
    int _10997 = mdim1;
    for (int _5122 = _10996; _5122 < _10997; ++_5122)
    {
      {
        _ptr__5117[(safe_add( _5116,mdim1 ) - _5122)] = _ptr__5117[((safe_add( _5116,mdim1 ) - _5122) - (int)1)];
      }
    }
    _ptr__5117[_5116] = (int)0;
  }
  int _5123 = (int)0;
  int _5124 = (int)0;
  int _5125 = (int)0;
  if ((!_5100))
  {
    {
      int _5126 = (int)0;
      while ( (_5126 < _5114) )
      {
        {
          int _5127 = ((*msubj)(_ptr__5117[safe_add( _5115,_5126 )]));
          int _5128 = _5126;
          while ( ((_5126 < _5114) && (_5127 == ((*msubj)(_ptr__5117[safe_add( _5115,_5126 )])))) )
          {
            {
              ++ _5126;
            }
          }
          int _10998 = _5128;
          int _10999 = _5126;
          for (int _5129 = _10998; _5129 < _10999; ++_5129)
          {
            {
              int _5130 = safe_add( safe_mul( ((*msubj)(_ptr__5117[safe_add( _5115,_5129 )])),_5113 ),((*msubi)(_ptr__5117[safe_add( _5115,_5129 )])) );
              _5124 += (_ptr__5109[safe_add( safe_add( _5102,_5130 ),(int)1 )] - _ptr__5109[safe_add( _5102,_5130 )]);
              if ((_5099 > (int)0))
              {
                {
                  _5123 += safe_add( (_ptr__5109[safe_add( _5106,_ptr__5109[safe_add( safe_add( _5102,_5130 ),(int)1 )] )] - _ptr__5109[safe_add( _5106,_ptr__5109[safe_add( _5102,_5130 )] )]),safe_mul( (int)2,(_ptr__5109[safe_add( safe_add( _5102,_5130 ),(int)1 )] - _ptr__5109[safe_add( _5102,_5130 )]) ) );
                }
              }
              {}
            }
          }
          ++ _5125;
        }
      }
    }
  }
  else
  {
    {
      int _5131 = (int)0;
      int _5132 = (int)0;
      int _11000 = (int)0;
      int _11001 = mdim1;
      for (int _5133 = _11000; _5133 < _11001; ++_5133)
      {
        {
          int _5134 = _5131;
          int _5135 = _5132;
          while ( ((_5131 < _5114) && (_5133 == ((*msubj)(_ptr__5117[safe_add( _5115,_5131 )])))) )
          {
            {
              ++ _5131;
            }
          }
          while ( ((_5132 < _5098) && (_5133 == (_ptr__5110[safe_add( _5103,_5132 )] / _5113))) )
          {
            {
              ++ _5132;
            }
          }
          int _5136 = _5134;
          int _5137 = _5135;
          int _5138 = (int)0;
          while ( ((_5137 < _5132) && (_5136 < _5131)) )
          {
            {
              if (((_ptr__5110[safe_add( _5103,_5137 )] % _5113) < ((*msubi)(_ptr__5117[safe_add( _5115,_5136 )]))))
              {
                {
                  ++ _5137;
                }
              }
              else if(((_ptr__5110[safe_add( _5103,_5137 )] % _5113) > ((*msubi)(_ptr__5117[safe_add( _5115,_5136 )]))))
              {
                {
                  ++ _5136;
                }
              }
              else
              {
                {
                  _5124 += (_ptr__5109[safe_add( safe_add( _5102,_5137 ),(int)1 )] - _ptr__5109[safe_add( _5102,_5137 )]);
                  if ((_5099 > (int)0))
                  {
                    {
                      _5123 += safe_add( (_ptr__5109[safe_add( _5106,_ptr__5109[safe_add( safe_add( _5102,_5137 ),(int)1 )] )] - _ptr__5109[safe_add( _5106,_ptr__5109[safe_add( _5102,_5137 )] )]),safe_mul( (int)2,(_ptr__5109[safe_add( safe_add( _5102,_5137 ),(int)1 )] - _ptr__5109[safe_add( _5102,_5137 )]) ) );
                    }
                  }
                  {}
                  ++ _5138;
                  ++ _5137;
                  ++ _5136;
                }
              }
            }
          }
          if ((_5138 > (int)0))
          {
            {
              ++ _5125;
            }
          }
          {}
        }
      }
    }
  }
  bool _5139 = (_5125 < _5112);
  _5093->alloc_expr((int)1,_5125,_5124,_5139,_5123);
  int _5140 = mosek::fusion::p_WorkStack::_get_impl(_5093)->ptr_base;
  int _5141 = mosek::fusion::p_WorkStack::_get_impl(_5093)->nidxs_base;
  int _11002;
  bool _11003 = _5139;
  if (_11003)
  {
    _11002 = mosek::fusion::p_WorkStack::_get_impl(_5093)->sp_base;
  }
  else
  {
    _11002 = _5093->alloci64(_5125);
  }
  int _5142 = _11002;
  int _5143 = mosek::fusion::p_WorkStack::_get_impl(_5093)->cof_base;
  int _5144 = mosek::fusion::p_WorkStack::_get_impl(_5093)->shape_base;
  int _5145 = mosek::fusion::p_WorkStack::_get_impl(_5093)->code_base;
  int _5146 = mosek::fusion::p_WorkStack::_get_impl(_5093)->codeptr_base;
  int _5147 = mosek::fusion::p_WorkStack::_get_impl(_5093)->cconst_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _5148 = mosek::fusion::p_WorkStack::_get_impl(_5093)->i64;
  _checked_ptr_1<long long> _ptr__5148(_5148 ? _5148->raw() : nullptr,_5148 ? _5148->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5149 = mosek::fusion::p_WorkStack::_get_impl(_5093)->f64;
  _checked_ptr_1<double> _ptr__5149(_5149 ? _5149->raw() : nullptr,_5149 ? _5149->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5150 = mosek::fusion::p_WorkStack::_get_impl(_5093)->i32;
  _checked_ptr_1<int> _ptr__5150(_5150 ? _5150->raw() : nullptr,_5150 ? _5150->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5151 = mosek::fusion::p_WorkStack::_get_impl(_5095)->i32;
  _checked_ptr_1<int> _ptr__5151(_5151 ? _5151->raw() : nullptr,_5151 ? _5151->size(0) : 0);
  {
    int _5152 = (int)0;
    int _5153 = (int)0;
    int _5154 = (int)0;
    _ptr__5150[_5140] = (int)0;
    if ((_5123 > (int)0))
    {
      {
        _ptr__5150[_5146] = (int)0;
      }
    }
    {}
    _ptr__5150[_5144] = mdim1;
    if ((!_5100))
    {
      {
        int _5155 = (int)0;
        while ( (_5155 < _5114) )
        {
          {
            int _5156 = ((*msubj)(_ptr__5151[safe_add( _5115,_5155 )]));
            int _5157 = _5155;
            while ( ((_5155 < _5114) && (_5156 == ((*msubj)(_ptr__5151[safe_add( _5115,_5155 )])))) )
            {
              {
                ++ _5155;
              }
            }
            int _11004 = _5157;
            int _11005 = _5155;
            for (int _5158 = _11004; _5158 < _11005; ++_5158)
            {
              {
                int _5159 = _ptr__5151[safe_add( _5115,_5158 )];
                int _5160 = safe_add( safe_mul( ((*msubj)(_5159)),_5113 ),((*msubi)(_5159)) );
                int _11006 = _ptr__5109[safe_add( _5102,_5160 )];
                int _11007 = _ptr__5109[safe_add( safe_add( _5102,_5160 ),(int)1 )];
                for (int _5161 = _11006; _5161 < _11007; ++_5161)
                {
                  {
                    _ptr__5148[safe_add( _5141,_5153 )] = _ptr__5110[safe_add( _5104,_5161 )];
                    _ptr__5149[safe_add( _5143,_5153 )] = (_ptr__5111[safe_add( _5105,_5161 )] * ((*mval)(_5159)));
                    if ((_5099 > (int)0))
                    {
                      {
                        int _11008 = _ptr__5109[safe_add( _5106,_5161 )];
                        int _11009 = _ptr__5109[safe_add( safe_add( _5106,_5161 ),(int)1 )];
                        for (int _5162 = _11008; _5162 < _11009; ++_5162)
                        {
                          {
                            _ptr__5150[safe_add( _5145,_5152 )] = _ptr__5109[safe_add( _5107,_5162 )];
                            _ptr__5149[safe_add( _5147,_5152 )] = _ptr__5111[safe_add( _5108,_5162 )];
                            ++ _5152;
                          }
                        }
                        _ptr__5150[safe_add( _5145,_5152 )] = 2;
                        _ptr__5149[safe_add( _5147,_5152 )] = ((*mval)(_5159));
                        ++ _5152;
                        _ptr__5150[safe_add( _5145,_5152 )] = 5;
                        ++ _5152;
                        _ptr__5150[safe_add( safe_add( _5146,_5153 ),(int)1 )] = _5152;
                      }
                    }
                    {}
                    ++ _5153;
                  }
                }
              }
            }
            _ptr__5148[safe_add( _5142,_5154 )] = _5156;
            _ptr__5150[safe_add( safe_add( _5140,_5154 ),(int)1 )] = _5153;
            ++ _5154;
          }
        }
      }
    }
    else
    {
      {
        int _5163 = (int)0;
        int _5164 = (int)0;
        int _11010 = (int)0;
        int _11011 = mdim1;
        for (int _5165 = _11010; _5165 < _11011; ++_5165)
        {
          {
            int _5166 = _5163;
            int _5167 = _5164;
            while ( ((_5164 < _5098) && (_5165 == (_ptr__5110[safe_add( _5103,_5164 )] / _5113))) )
            {
              {
                ++ _5164;
              }
            }
            while ( ((_5163 < _5114) && (_5165 == ((*msubj)(_ptr__5151[safe_add( _5115,_5163 )])))) )
            {
              {
                ++ _5163;
              }
            }
            int _5168 = _5166;
            int _5169 = _5167;
            int _5170 = (int)0;
            while ( ((_5169 < _5164) && (_5168 < _5163)) )
            {
              {
                if (((_ptr__5110[safe_add( _5103,_5169 )] % _5113) < ((*msubi)(_ptr__5151[safe_add( _5115,_5168 )]))))
                {
                  {
                    ++ _5169;
                  }
                }
                else if(((_ptr__5110[safe_add( _5103,_5169 )] % _5113) > ((*msubi)(_ptr__5151[safe_add( _5115,_5168 )]))))
                {
                  {
                    ++ _5168;
                  }
                }
                else
                {
                  {
                    int _5171 = _ptr__5151[safe_add( _5115,_5168 )];
                    int _11012 = _ptr__5109[safe_add( _5102,_5169 )];
                    int _11013 = _ptr__5109[safe_add( safe_add( _5102,_5169 ),(int)1 )];
                    for (int _5172 = _11012; _5172 < _11013; ++_5172)
                    {
                      {
                        _ptr__5148[safe_add( _5141,_5153 )] = _ptr__5110[safe_add( _5104,_5172 )];
                        _ptr__5149[safe_add( _5143,_5153 )] = (_ptr__5111[safe_add( _5105,_5172 )] * ((*mval)(_5171)));
                        if ((_5099 > (int)0))
                        {
                          {
                            int _11014 = _ptr__5109[safe_add( _5106,_5172 )];
                            int _11015 = _ptr__5109[safe_add( safe_add( _5106,_5172 ),(int)1 )];
                            for (int _5173 = _11014; _5173 < _11015; ++_5173)
                            {
                              {
                                _ptr__5150[safe_add( _5145,_5152 )] = _ptr__5109[safe_add( _5107,_5173 )];
                                _ptr__5149[safe_add( _5147,_5152 )] = _ptr__5111[safe_add( _5108,_5173 )];
                                ++ _5152;
                              }
                            }
                            _ptr__5150[safe_add( _5145,_5152 )] = 2;
                            _ptr__5149[safe_add( _5147,_5152 )] = ((*mval)(_5171));
                            ++ _5152;
                            _ptr__5150[safe_add( _5145,_5152 )] = 5;
                            ++ _5152;
                            _ptr__5150[safe_add( safe_add( _5146,_5153 ),(int)1 )] = _5152;
                          }
                        }
                        {}
                        ++ _5153;
                      }
                    }
                    ++ _5170;
                    ++ _5169;
                    ++ _5168;
                  }
                }
              }
            }
            if ((_5170 > (int)0))
            {
              {
                _ptr__5150[safe_add( safe_add( _5140,_5154 ),(int)1 )] = _5153;
                _ptr__5148[safe_add( _5142,_5154 )] = _5165;
                ++ _5154;
              }
            }
            {}
          }
        }
      }
    }
    if ((!_5139))
    {
      {
        _5093->popi64(_5125);
      }
    }
    {}
    if ((!(_5124 == _5153)))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Incorrect number of non-zeros"));
      }
    }
    {}
    if ((!(_5125 == _5154)))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Incorrect number of elements"));
      }
    }
    {}
  }
  _5095->clear();
}
int mosek::fusion::p_ExprMulDiagRight::validate(int _5174,int _5175,std::shared_ptr< monty::ndarray< int,1 > > _5176,std::shared_ptr< monty::ndarray< int,1 > > _5177,std::shared_ptr< monty::ndarray< double,1 > > _5178,monty::rc_ptr< ::mosek::fusion::Expression > _5179){
  _checked_ptr_1<int> _ptr__5176(_5176 ? _5176->raw() : nullptr, _5176 ? _5176->size(0) : 0);
  _checked_ptr_1<int> _ptr__5177(_5177 ? _5177->raw() : nullptr, _5177 ? _5177->size(0) : 0);
  _checked_ptr_1<double> _ptr__5178(_5178 ? _5178->raw() : nullptr, _5178 ? _5178->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5180 = _5179->getShape();
  _checked_ptr_1<int> _ptr__5180(_5180 ? _5180->raw() : nullptr,_5180 ? _5180->size(0) : 0);
  if (((int)((_5180)->size(0)) > (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _5181 = _ptr__5180[(int)0];
  int _5182 = _ptr__5180[(int)1];
  if (((_5174 < (int)0) || ((_5175 < (int)0) || ((_5181 < (int)0) || (_5182 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_5174 != _5182) || (_5175 != _5181)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_5176)->size(0)) != (int)((_5177)->size(0))) || ((int)((_5176)->size(0)) != (int)((_5178)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _5183 = (int)((_5176)->size(0));
  bool _5184 = false;
  bool _5185 = false;
  {
    int _11016 = (int)0;
    int _11017 = _5183;
    for (int _5186 = _11016; _5186 < _11017; ++_5186)
    {
      {
        if (((_ptr__5176[_5186] < (int)0) || ((_ptr__5176[_5186] >= _5174) || ((_ptr__5177[_5186] < (int)0) || (_ptr__5177[_5186] >= _5175)))))
        {
          {
            _5184 = true;
          }
        }
        {}
      }
    }
    int _11018 = (int)0;
    int _11019 = (_5183 - (int)1);
    for (int _5187 = _11018; _5187 < _11019; ++_5187)
    {
      {
        if (((_ptr__5176[_5187] > _ptr__5176[safe_add( _5187,(int)1 )]) || ((_ptr__5176[_5187] == _ptr__5176[safe_add( _5187,(int)1 )]) && (_ptr__5177[_5187] >= _ptr__5177[safe_add( _5187,(int)1 )]))))
        {
          {
            _5185 = true;
          }
        }
        {}
      }
    }
  }
  if (_5184)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_5185)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagRight :: toString() { return mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulDiagRight("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",m)"))->toString();
}
void mosek::fusion::p_ExprMulDiagRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagRight::destroy() { mosek::fusion::p_ExprMulDiagRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft(mosek::fusion::p_ExprMulDiagLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulDiagLeft()" << this << std::endl; */ }mosek::fusion::ExprMulDiagLeft::~ExprMulDiagLeft() {  /* std::cout << "~ExprMulDiagLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulDiagLeft::p_ExprMulDiagLeft  (::mosek::fusion::ExprMulDiagLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _5188,    int _5189,    std::shared_ptr< monty::ndarray< int,1 > > _5190,    std::shared_ptr< monty::ndarray< int,1 > > _5191,    std::shared_ptr< monty::ndarray< double,1 > > _5192,    monty::rc_ptr< ::mosek::fusion::Expression > _5193,    int _5194){ return new mosek::fusion::ExprMulDiagLeft(_5188,_5189,_5190,_5191,_5192,_5193,_5194); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _5188,    int _5189,    std::shared_ptr< monty::ndarray< int,1 > > _5190,    std::shared_ptr< monty::ndarray< int,1 > > _5191,    std::shared_ptr< monty::ndarray< double,1 > > _5192,    monty::rc_ptr< ::mosek::fusion::Expression > _5193,    int _5194) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_5188,_5189,_5190,_5191,_5192,_5193,_5194); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _5188,    int _5189,    std::shared_ptr< monty::ndarray< int,1 > > _5190,    std::shared_ptr< monty::ndarray< int,1 > > _5191,    std::shared_ptr< monty::ndarray< double,1 > > _5192,    monty::rc_ptr< ::mosek::fusion::Expression > _5193,    int _5194){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5190(_5190 ? _5190->raw() : nullptr, _5190 ? _5190->size(0) : 0);
    _checked_ptr_1<int> _ptr__5191(_5191 ? _5191->raw() : nullptr, _5191 ? _5191->size(0) : 0);
    _checked_ptr_1<double> _ptr__5192(_5192 ? _5192->raw() : nullptr, _5192 ? _5192->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5188)}));
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim0 = _5188;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mdim1 = _5189;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubi = _5190;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->msubj = _5191;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->mval = _5192;
    mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr = _5193;
  }
}mosek::fusion::ExprMulDiagLeft::t mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft  (int _5195,    int _5196,    std::shared_ptr< monty::ndarray< int,1 > > _5197,    std::shared_ptr< monty::ndarray< int,1 > > _5198,    std::shared_ptr< monty::ndarray< double,1 > > _5199,    monty::rc_ptr< ::mosek::fusion::Expression > _5200){ return new mosek::fusion::ExprMulDiagLeft(_5195,_5196,_5197,_5198,_5199,_5200); }mosek::fusion::ExprMulDiagLeft::ExprMulDiagLeft  (int _5195,    int _5196,    std::shared_ptr< monty::ndarray< int,1 > > _5197,    std::shared_ptr< monty::ndarray< int,1 > > _5198,    std::shared_ptr< monty::ndarray< double,1 > > _5199,    monty::rc_ptr< ::mosek::fusion::Expression > _5200) :    ExprMulDiagLeft(new mosek::fusion::p_ExprMulDiagLeft(this)){ mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->_initialize(_5195,_5196,_5197,_5198,_5199,_5200); }void mosek::fusion::p_ExprMulDiagLeft::_initialize  (int _5195,    int _5196,    std::shared_ptr< monty::ndarray< int,1 > > _5197,    std::shared_ptr< monty::ndarray< int,1 > > _5198,    std::shared_ptr< monty::ndarray< double,1 > > _5199,    monty::rc_ptr< ::mosek::fusion::Expression > _5200){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5197(_5197 ? _5197->raw() : nullptr, _5197 ? _5197->size(0) : 0);
    _checked_ptr_1<int> _ptr__5198(_5198 ? _5198->raw() : nullptr, _5198 ? _5198->size(0) : 0);
    _checked_ptr_1<double> _ptr__5199(_5199 ? _5199->raw() : nullptr, _5199 ? _5199->size(0) : 0);
    mosek::fusion::p_ExprMulDiagLeft::_initialize(_5195,_5196,_5197,_5198,_5199,_5200,::mosek::fusion::p_ExprMulDiagLeft::validate(_5195,_5196,_5197,_5198,_5199,_5200));
  }
}void mosek::fusion::ExprMulDiagLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5201,monty::rc_ptr< ::mosek::fusion::WorkStack > _5202,monty::rc_ptr< ::mosek::fusion::WorkStack > _5203) { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->eval(_5201,_5202,_5203); }void mosek::fusion::p_ExprMulDiagLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5201,monty::rc_ptr< ::mosek::fusion::WorkStack > _5202,monty::rc_ptr< ::mosek::fusion::WorkStack > _5203){
  mosek::fusion::p_ExprMulDiagLeft::_get_impl(::mosek::fusion::ExprMulDiagLeft::t(_pubthis))->expr->eval(_5202,_5201,_5203);
  _5202->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _5204 = mosek::fusion::p_WorkStack::_get_impl(_5202)->i32;
  _checked_ptr_1<int> _ptr__5204(_5204 ? _5204->raw() : nullptr,_5204 ? _5204->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5205 = mosek::fusion::p_WorkStack::_get_impl(_5202)->i64;
  _checked_ptr_1<long long> _ptr__5205(_5205 ? _5205->raw() : nullptr,_5205 ? _5205->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5206 = mosek::fusion::p_WorkStack::_get_impl(_5202)->f64;
  _checked_ptr_1<double> _ptr__5206(_5206 ? _5206->raw() : nullptr,_5206 ? _5206->size(0) : 0);
  int _5207 = mosek::fusion::p_WorkStack::_get_impl(_5202)->nd;
  int _5208 = mosek::fusion::p_WorkStack::_get_impl(_5202)->nelem;
  int _5209 = mosek::fusion::p_WorkStack::_get_impl(_5202)->nnz;
  bool _5210 = mosek::fusion::p_WorkStack::_get_impl(_5202)->hassp;
  int _5211 = mosek::fusion::p_WorkStack::_get_impl(_5202)->ncodeatom;
  int _5212 = mosek::fusion::p_WorkStack::_get_impl(_5202)->ptr_base;
  int _5213 = mosek::fusion::p_WorkStack::_get_impl(_5202)->code_base;
  int _5214 = mosek::fusion::p_WorkStack::_get_impl(_5202)->cconst_base;
  int _5215 = mosek::fusion::p_WorkStack::_get_impl(_5202)->codeptr_base;
  int _5216 = mosek::fusion::p_WorkStack::_get_impl(_5202)->shape_base;
  int _5217 = mosek::fusion::p_WorkStack::_get_impl(_5202)->sp_base;
  int _5218 = mosek::fusion::p_WorkStack::_get_impl(_5202)->nidxs_base;
  int _5219 = mosek::fusion::p_WorkStack::_get_impl(_5202)->cof_base;
  int _5220 = mosek::fusion::p_WorkStack::_get_impl(_5202)->cconst_base;
  if ((_5207 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _5221 = _ptr__5204[_5216];
  int _5222 = _ptr__5204[safe_add( _5216,(int)1 )];
  int _5223 = (int)((msubi)->size(0));
  if ((!_5210))
  {
    {
      int _5224 = (int)0;
      int _5225 = (int)0;
      int _5226 = (int)0;
      int _5227 = (int)0;
      while ( (_5227 < (int)((msubi)->size(0))) )
      {
        {
          int _5228 = ((*msubi)(_5227));
          while ( ((_5227 < (int)((msubi)->size(0))) && (((*msubi)(_5227)) == _5228)) )
          {
            {
              int _5229 = safe_add( safe_mul( ((*msubj)(_5227)),_5222 ),((*msubi)(_5227)) );
              _5224 += (_ptr__5204[safe_add( safe_add( _5212,_5229 ),(int)1 )] - _ptr__5204[safe_add( _5212,_5229 )]);
              if ((_5211 > (int)0))
              {
                {
                  _5226 += safe_add( (_ptr__5204[safe_add( _5215,_ptr__5204[safe_add( safe_add( _5212,_5229 ),(int)1 )] )] - _ptr__5204[safe_add( _5215,_ptr__5204[safe_add( _5212,_5229 )] )]),safe_mul( (int)2,(_ptr__5204[safe_add( safe_add( _5212,_5229 ),(int)1 )] - _ptr__5204[safe_add( _5212,_5229 )]) ) );
                }
              }
              {}
              ++ _5227;
            }
          }
          ++ _5225;
        }
      }
      bool _5230 = (_5225 < mdim0);
      _5201->alloc_expr((int)1,_5225,_5224,_5230,_5226);
      int _5231 = mosek::fusion::p_WorkStack::_get_impl(_5201)->ptr_base;
      int _5232 = mosek::fusion::p_WorkStack::_get_impl(_5201)->nidxs_base;
      int _11020;
      bool _11021 = _5230;
      if (_11021)
      {
        _11020 = mosek::fusion::p_WorkStack::_get_impl(_5201)->sp_base;
      }
      else
      {
        _11020 = _5201->alloci64(_5225);
      }
      int _5233 = _11020;
      int _5234 = mosek::fusion::p_WorkStack::_get_impl(_5201)->cof_base;
      int _5235 = mosek::fusion::p_WorkStack::_get_impl(_5201)->shape_base;
      int _5236 = mosek::fusion::p_WorkStack::_get_impl(_5201)->code_base;
      int _5237 = mosek::fusion::p_WorkStack::_get_impl(_5201)->codeptr_base;
      int _5238 = mosek::fusion::p_WorkStack::_get_impl(_5201)->cconst_base;
      std::shared_ptr< monty::ndarray< long long,1 > > _5239 = mosek::fusion::p_WorkStack::_get_impl(_5201)->i64;
      _checked_ptr_1<long long> _ptr__5239(_5239 ? _5239->raw() : nullptr,_5239 ? _5239->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5240 = mosek::fusion::p_WorkStack::_get_impl(_5201)->f64;
      _checked_ptr_1<double> _ptr__5240(_5240 ? _5240->raw() : nullptr,_5240 ? _5240->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5241 = mosek::fusion::p_WorkStack::_get_impl(_5201)->i32;
      _checked_ptr_1<int> _ptr__5241(_5241 ? _5241->raw() : nullptr,_5241 ? _5241->size(0) : 0);
      {
        _ptr__5241[_5231] = (int)0;
        if ((_5211 > (int)0))
        {
          {
            _ptr__5241[_5237] = (int)0;
          }
        }
        {}
        _ptr__5241[_5235] = mdim0;
        int _5242 = (int)0;
        int _5243 = (int)0;
        int _5244 = (int)0;
        {
        }
        {
          int _5245 = (int)0;
          while ( (_5245 < (int)((msubi)->size(0))) )
          {
            {
              int _5246 = ((*msubi)(_5245));
              while ( ((_5245 < (int)((msubi)->size(0))) && (((*msubi)(_5245)) == _5246)) )
              {
                {
                  int _5247 = safe_add( safe_mul( ((*msubj)(_5245)),_5222 ),((*msubi)(_5245)) );
                  int _11022 = _ptr__5204[safe_add( _5212,_5247 )];
                  int _11023 = _ptr__5204[safe_add( safe_add( _5212,_5247 ),(int)1 )];
                  for (int _5248 = _11022; _5248 < _11023; ++_5248)
                  {
                    {
                      _ptr__5239[safe_add( _5232,_5242 )] = _ptr__5205[safe_add( _5218,_5248 )];
                      _ptr__5240[safe_add( _5234,_5242 )] = (_ptr__5206[safe_add( _5219,_5248 )] * ((*mval)(_5245)));
                      if ((_5226 > (int)0))
                      {
                        {
                          int _11024 = _ptr__5204[safe_add( _5215,_5248 )];
                          int _11025 = _ptr__5204[safe_add( safe_add( _5215,_5248 ),(int)1 )];
                          for (int _5249 = _11024; _5249 < _11025; ++_5249)
                          {
                            {
                              _ptr__5241[safe_add( _5236,_5244 )] = _ptr__5204[safe_add( _5213,_5249 )];
                              _ptr__5240[safe_add( _5238,_5244 )] = _ptr__5206[safe_add( _5214,_5249 )];
                              ++ _5244;
                            }
                          }
                          _ptr__5241[safe_add( _5236,_5244 )] = 2;
                          _ptr__5240[safe_add( _5238,_5244 )] = ((*mval)(_5245));
                          ++ _5244;
                          _ptr__5241[safe_add( _5236,_5244 )] = 5;
                          ++ _5244;
                          _ptr__5241[safe_add( safe_add( _5237,_5242 ),(int)1 )] = _5244;
                        }
                      }
                      {}
                      ++ _5242;
                    }
                  }
                  ++ _5245;
                }
              }
              _ptr__5241[safe_add( safe_add( _5231,_5243 ),(int)1 )] = _5242;
              _ptr__5239[safe_add( _5233,_5243 )] = _5246;
              ++ _5243;
            }
          }
        }
      }
      if ((!_5230))
      {
        {
          _5201->popi64(_5225);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _5250 = _5203->alloci32(safe_add( _5222,(int)1 ));
      int _5251 = _5203->alloci32(_5208);
      int _5252 = _5203->alloci32(safe_add( mdim0,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _5253 = mosek::fusion::p_WorkStack::_get_impl(_5203)->i32;
      _checked_ptr_1<int> _ptr__5253(_5253 ? _5253->raw() : nullptr,_5253 ? _5253->size(0) : 0);
      int _5254 = (int)0;
      int _5255 = (int)0;
      int _5256 = (int)0;
      {
        int _11026 = (int)0;
        int _11027 = safe_add( _5222,(int)1 );
        for (int _5257 = _11026; _5257 < _11027; ++_5257)
        {
          {
            _ptr__5253[safe_add( _5250,_5257 )] = (int)0;
          }
        }
        int _11028 = (int)0;
        int _11029 = _5208;
        for (int _5258 = _11028; _5258 < _11029; ++_5258)
        {
          {
            ++ _ptr__5253[safe_add( safe_add( _5250,(_ptr__5205[safe_add( _5217,_5258 )] % _5222) ),(int)1 )];
          }
        }
        int _11030 = (int)0;
        int _11031 = _5222;
        for (int _5259 = _11030; _5259 < _11031; ++_5259)
        {
          {
            _ptr__5253[safe_add( safe_add( _5250,_5259 ),(int)1 )] += _ptr__5253[safe_add( _5250,_5259 )];
          }
        }
        int _11032 = (int)0;
        int _11033 = _5208;
        for (int _5260 = _11032; _5260 < _11033; ++_5260)
        {
          {
            long long _5261 = (_ptr__5205[safe_add( _5217,_5260 )] % _5222);
            _ptr__5253[safe_add( _5251,_ptr__5253[safe_add( _5250,_5261 )] )] = _5260;
            ++ _ptr__5253[safe_add( _5250,_5261 )];
          }
        }
        int _11034 = (int)0;
        int _11035 = _5222;
        for (int _5262 = _11034; _5262 < _11035; ++_5262)
        {
          {
            _ptr__5253[(safe_add( _5250,_5222 ) - _5262)] = _ptr__5253[((safe_add( _5250,_5222 ) - _5262) - (int)1)];
          }
        }
        _ptr__5253[_5250] = (int)0;
        int _5263 = (int)0;
        int _5264 = (int)0;
        while ( ((_5264 < (int)((msubi)->size(0))) && (_5263 < _5208)) )
        {
          {
            if ((((*msubi)(_5264)) < (_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5263 )] )] % _5222)))
            {
              {
                ++ _5264;
              }
            }
            else if((((*msubi)(_5264)) > (_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5263 )] )] % _5222)))
            {
              {
                ++ _5263;
              }
            }
            else
            {
              {
                int _5265 = (int)0;
                long long _5266 = (_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5263 )] )] % _5222);
                int _5267 = _5264;
                while ( ((_5264 < (int)((msubi)->size(0))) && (((*msubi)(_5264)) == ((*msubi)(_5267)))) )
                {
                  {
                    ++ _5264;
                  }
                }
                int _5268 = _5263;
                while ( ((_5263 < _5208) && ((_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5263 )] )] % _5222) == _5266)) )
                {
                  {
                    ++ _5263;
                  }
                }
                int _5269 = _5268;
                int _5270 = _5267;
                int _5271 = (int)0;
                while ( ((_5270 < _5264) && (_5269 < _5263)) )
                {
                  {
                    int _5272 = _ptr__5253[safe_add( _5251,_5269 )];
                    if ((((*msubj)(_5270)) < (_ptr__5205[safe_add( _5217,_5272 )] / _5222)))
                    {
                      {
                        ++ _5270;
                      }
                    }
                    else if((((*msubj)(_5270)) > (_ptr__5205[safe_add( _5217,_5272 )] / _5222)))
                    {
                      {
                        ++ _5269;
                      }
                    }
                    else
                    {
                      {
                        _5255 += (_ptr__5204[safe_add( safe_add( _5212,_5272 ),(int)1 )] - _ptr__5204[safe_add( _5212,_5272 )]);
                        if ((_5211 > (int)0))
                        {
                          {
                            _5254 += safe_add( (_ptr__5204[safe_add( _5215,_ptr__5204[safe_add( safe_add( _5212,_5272 ),(int)1 )] )] - _ptr__5204[safe_add( _5215,_ptr__5204[safe_add( _5212,_5272 )] )]),safe_mul( (int)2,(_ptr__5204[safe_add( safe_add( _5212,_5272 ),(int)1 )] - _ptr__5204[safe_add( _5212,_5272 )]) ) );
                          }
                        }
                        {}
                        ++ _5271;
                        ++ _5270;
                        ++ _5269;
                      }
                    }
                  }
                }
                if ((_5271 > (int)0))
                {
                  {
                    ++ _5256;
                  }
                }
                {}
              }
            }
          }
        }
      }
      bool _5273 = (_5256 < mdim0);
      _5201->alloc_expr((int)1,_5256,_5255,_5273,_5254);
      int _5274 = mosek::fusion::p_WorkStack::_get_impl(_5201)->ptr_base;
      int _5275 = mosek::fusion::p_WorkStack::_get_impl(_5201)->nidxs_base;
      int _11036;
      bool _11037 = _5273;
      if (_11037)
      {
        _11036 = mosek::fusion::p_WorkStack::_get_impl(_5201)->sp_base;
      }
      else
      {
        _11036 = _5201->alloci64(_5256);
      }
      int _5276 = _11036;
      int _5277 = mosek::fusion::p_WorkStack::_get_impl(_5201)->cof_base;
      int _5278 = mosek::fusion::p_WorkStack::_get_impl(_5201)->shape_base;
      int _5279 = mosek::fusion::p_WorkStack::_get_impl(_5201)->code_base;
      int _5280 = mosek::fusion::p_WorkStack::_get_impl(_5201)->codeptr_base;
      int _5281 = mosek::fusion::p_WorkStack::_get_impl(_5201)->cconst_base;
      std::shared_ptr< monty::ndarray< long long,1 > > _5282 = mosek::fusion::p_WorkStack::_get_impl(_5201)->i64;
      _checked_ptr_1<long long> _ptr__5282(_5282 ? _5282->raw() : nullptr,_5282 ? _5282->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5283 = mosek::fusion::p_WorkStack::_get_impl(_5201)->f64;
      _checked_ptr_1<double> _ptr__5283(_5283 ? _5283->raw() : nullptr,_5283 ? _5283->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _5284 = mosek::fusion::p_WorkStack::_get_impl(_5201)->i32;
      _checked_ptr_1<int> _ptr__5284(_5284 ? _5284->raw() : nullptr,_5284 ? _5284->size(0) : 0);
      {
        int _5285 = (int)0;
        int _5286 = (int)0;
        int _5287 = (int)0;
        int _5288 = (int)0;
        int _5289 = (int)0;
        _ptr__5284[_5274] = (int)0;
        if ((_5211 > (int)0))
        {
          {
            _ptr__5284[_5280] = (int)0;
          }
        }
        {}
        _ptr__5284[_5278] = mdim0;
        while ( ((_5289 < (int)((msubi)->size(0))) && (_5288 < _5208)) )
        {
          {
            if ((((*msubi)(_5289)) < (_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5288 )] )] % _5222)))
            {
              {
                ++ _5289;
              }
            }
            else if((((*msubi)(_5289)) > (_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5288 )] )] % _5222)))
            {
              {
                ++ _5288;
              }
            }
            else
            {
              {
                int _5290 = (int)0;
                long long _5291 = (_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5288 )] )] % _5222);
                int _5292 = _5289;
                while ( ((_5289 < (int)((msubi)->size(0))) && (((*msubi)(_5289)) == ((*msubi)(_5292)))) )
                {
                  {
                    ++ _5289;
                  }
                }
                int _5293 = _5288;
                while ( ((_5288 < _5208) && ((_ptr__5205[safe_add( _5217,_ptr__5253[safe_add( _5251,_5288 )] )] % _5222) == _5291)) )
                {
                  {
                    ++ _5288;
                  }
                }
                int _5294 = _5293;
                int _5295 = _5292;
                int _5296 = (int)0;
                int _5297 = ((*msubi)(_5292));
                while ( ((_5295 < _5289) && (_5294 < _5288)) )
                {
                  {
                    int _5298 = _ptr__5253[safe_add( _5251,_5294 )];
                    if ((((*msubj)(_5295)) < (_ptr__5205[safe_add( _5217,_5298 )] / _5222)))
                    {
                      {
                        ++ _5295;
                      }
                    }
                    else if((((*msubj)(_5295)) > (_ptr__5205[safe_add( _5217,_5298 )] / _5222)))
                    {
                      {
                        ++ _5294;
                      }
                    }
                    else
                    {
                      {
                        int _11038 = _ptr__5204[safe_add( _5212,_5298 )];
                        int _11039 = _ptr__5204[safe_add( safe_add( _5212,_5298 ),(int)1 )];
                        for (int _5299 = _11038; _5299 < _11039; ++_5299)
                        {
                          {
                            _ptr__5282[safe_add( _5275,_5286 )] = _ptr__5205[safe_add( _5218,_5299 )];
                            _ptr__5283[safe_add( _5277,_5286 )] = (_ptr__5206[safe_add( _5219,_5299 )] * ((*mval)(_5295)));
                            if ((_5211 > (int)0))
                            {
                              {
                                int _11040 = _ptr__5204[safe_add( _5215,_5299 )];
                                int _11041 = _ptr__5204[safe_add( safe_add( _5215,_5299 ),(int)1 )];
                                for (int _5300 = _11040; _5300 < _11041; ++_5300)
                                {
                                  {
                                    _ptr__5284[safe_add( _5279,_5287 )] = _ptr__5204[safe_add( _5213,_5300 )];
                                    _ptr__5283[safe_add( _5281,_5287 )] = _ptr__5206[safe_add( _5214,_5300 )];
                                    ++ _5287;
                                  }
                                }
                                _ptr__5284[safe_add( _5279,_5287 )] = 2;
                                _ptr__5283[safe_add( _5281,_5287 )] = ((*mval)(_5295));
                                ++ _5287;
                                _ptr__5284[safe_add( _5279,_5287 )] = 5;
                                ++ _5287;
                                _ptr__5284[safe_add( safe_add( _5280,_5286 ),(int)1 )] = _5287;
                              }
                            }
                            {}
                            ++ _5286;
                            ++ _5296;
                          }
                        }
                        ++ _5295;
                        ++ _5294;
                      }
                    }
                  }
                }
                if ((_5296 > (int)0))
                {
                  {
                    _ptr__5284[safe_add( safe_add( _5274,_5285 ),(int)1 )] = _5286;
                    _ptr__5282[safe_add( _5276,_5285 )] = _5297;
                    ++ _5285;
                  }
                }
                {}
              }
            }
          }
        }
        if ((_5286 != _5255))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of non-zeros"));
          }
        }
        {}
        if ((_5285 != _5256))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of elements"));
          }
        }
        {}
      }
      if ((!_5273))
      {
        {
          _5201->popi64(_5256);
        }
      }
      {}
    }
  }
  _5203->clear();
}
int mosek::fusion::p_ExprMulDiagLeft::validate(int _5301,int _5302,std::shared_ptr< monty::ndarray< int,1 > > _5303,std::shared_ptr< monty::ndarray< int,1 > > _5304,std::shared_ptr< monty::ndarray< double,1 > > _5305,monty::rc_ptr< ::mosek::fusion::Expression > _5306){
  _checked_ptr_1<int> _ptr__5303(_5303 ? _5303->raw() : nullptr, _5303 ? _5303->size(0) : 0);
  _checked_ptr_1<int> _ptr__5304(_5304 ? _5304->raw() : nullptr, _5304 ? _5304->size(0) : 0);
  _checked_ptr_1<double> _ptr__5305(_5305 ? _5305->raw() : nullptr, _5305 ? _5305->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5307 = _5306->getShape();
  _checked_ptr_1<int> _ptr__5307(_5307 ? _5307->raw() : nullptr,_5307 ? _5307->size(0) : 0);
  if (((int)((_5307)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _5308 = _ptr__5307[(int)0];
  int _5309 = _ptr__5307[(int)1];
  if (((_5301 < (int)0) || (_5302 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_5302 != _5308) || (_5301 != _5309)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_5303)->size(0)) != (int)((_5304)->size(0))) || ((int)((_5303)->size(0)) != (int)((_5305)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _5310 = (int)((_5303)->size(0));
  bool _5311 = false;
  bool _5312 = false;
  {
    int _11042 = (int)0;
    int _11043 = _5310;
    for (int _5313 = _11042; _5313 < _11043; ++_5313)
    {
      {
        if (((_ptr__5303[_5313] < (int)0) || ((_ptr__5303[_5313] >= _5301) || ((_ptr__5304[_5313] < (int)0) || (_ptr__5304[_5313] >= _5302)))))
        {
          {
            _5311 = true;
          }
        }
        {}
      }
    }
    int _11044 = (int)0;
    int _11045 = (_5310 - (int)1);
    for (int _5314 = _11044; _5314 < _11045; ++_5314)
    {
      {
        if (((_ptr__5303[_5314] > _ptr__5303[safe_add( _5314,(int)1 )]) || ((_ptr__5303[_5314] == _ptr__5303[safe_add( _5314,(int)1 )]) && (_ptr__5304[_5314] >= _ptr__5304[safe_add( _5314,(int)1 )]))))
        {
          {
            _5312 = true;
          }
        }
        {}
      }
    }
  }
  if (_5311)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_5312)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulDiagLeft :: toString() { return mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulDiagLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulDiagLeft(m,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulDiagLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulDiagLeft::destroy() { mosek::fusion::p_ExprMulDiagLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulElement::ExprMulElement(mosek::fusion::p_ExprMulElement *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulElement()" << this << std::endl; */ }mosek::fusion::ExprMulElement::~ExprMulElement() {  /* std::cout << "~ExprMulElement()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulElement::p_ExprMulElement  (::mosek::fusion::ExprMulElement * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _5315,    std::shared_ptr< monty::ndarray< long long,1 > > _5316,    monty::rc_ptr< ::mosek::fusion::Expression > _5317){ return new mosek::fusion::ExprMulElement(_5315,_5316,_5317); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _5315,    std::shared_ptr< monty::ndarray< long long,1 > > _5316,    monty::rc_ptr< ::mosek::fusion::Expression > _5317) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_5315,_5316,_5317); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5315,    std::shared_ptr< monty::ndarray< long long,1 > > _5316,    monty::rc_ptr< ::mosek::fusion::Expression > _5317){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5315(_5315 ? _5315->raw() : nullptr, _5315 ? _5315->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5316(_5316 ? _5316->raw() : nullptr, _5316 ? _5316->size(0) : 0);
    mosek::fusion::p_ExprMulElement::_initialize(_5315,_5316,_5317,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _5318 = _5317->getShape();
    _checked_ptr_1<int> _ptr__5318(_5318 ? _5318->raw() : nullptr,_5318 ? _5318->size(0) : 0);
    if (((int)((_5315)->size(0)) != (int)((_5316)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix specification"));
      }
    }
    {}
    long long _5319 = ::mosek::fusion::p_Set::size(_5318);
    bool _5320 = false;
    bool _5321 = false;
    {
      int _11046 = (int)0;
      int _11047 = (int)((_5316)->size(0));
      for (int _5322 = _11046; _5322 < _11047; ++_5322)
      {
        {
          if (((_ptr__5316[_5322] < (int)0) || (_ptr__5316[_5322] >= _5319)))
          {
            {
              _5320 = true;
            }
          }
          {}
        }
      }
      int _11048 = (int)0;
      int _11049 = ((int)((_5316)->size(0)) - (int)1);
      for (int _5323 = _11048; _5323 < _11049; ++_5323)
      {
        {
          if ((_ptr__5316[_5323] >= _ptr__5316[safe_add( _5323,(int)1 )]))
          {
            {
              _5321 = true;
            }
          }
          {}
        }
      }
    }
    if (_5320)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
      }
    }
    {}
    if (_5321)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Matrix data not sorted"));
      }
    }
    {}
  }
}mosek::fusion::ExprMulElement::t mosek::fusion::p_ExprMulElement::_new_ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _5324,    std::shared_ptr< monty::ndarray< long long,1 > > _5325,    monty::rc_ptr< ::mosek::fusion::Expression > _5326,    int _5327){ return new mosek::fusion::ExprMulElement(_5324,_5325,_5326,_5327); }mosek::fusion::ExprMulElement::ExprMulElement  (std::shared_ptr< monty::ndarray< double,1 > > _5324,    std::shared_ptr< monty::ndarray< long long,1 > > _5325,    monty::rc_ptr< ::mosek::fusion::Expression > _5326,    int _5327) :    ExprMulElement(new mosek::fusion::p_ExprMulElement(this)){ mosek::fusion::p_ExprMulElement::_get_impl(this)->_initialize(_5324,_5325,_5326,_5327); }void mosek::fusion::p_ExprMulElement::_initialize  (std::shared_ptr< monty::ndarray< double,1 > > _5324,    std::shared_ptr< monty::ndarray< long long,1 > > _5325,    monty::rc_ptr< ::mosek::fusion::Expression > _5326,    int _5327){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__5324(_5324 ? _5324->raw() : nullptr, _5324 ? _5324->size(0) : 0);
    _checked_ptr_1<long long> _ptr__5325(_5325 ? _5325->raw() : nullptr, _5325 ? _5325->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_5326->getShape());
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->expr = _5326;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->mcof = _5324;
    mosek::fusion::p_ExprMulElement::_get_impl(::mosek::fusion::ExprMulElement::t(_pubthis))->msp = _5325;
  }
}void mosek::fusion::ExprMulElement :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5328,monty::rc_ptr< ::mosek::fusion::WorkStack > _5329,monty::rc_ptr< ::mosek::fusion::WorkStack > _5330) { mosek::fusion::p_ExprMulElement::_get_impl(this)->eval(_5328,_5329,_5330); }void mosek::fusion::p_ExprMulElement::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5328,monty::rc_ptr< ::mosek::fusion::WorkStack > _5329,monty::rc_ptr< ::mosek::fusion::WorkStack > _5330){
  expr->eval(_5329,_5328,_5330);
  _5329->pop_expr();
  int _5331 = mosek::fusion::p_WorkStack::_get_impl(_5329)->nd;
  int _5332 = mosek::fusion::p_WorkStack::_get_impl(_5329)->nelem;
  int _5333 = mosek::fusion::p_WorkStack::_get_impl(_5329)->nnz;
  int _5334 = mosek::fusion::p_WorkStack::_get_impl(_5329)->ncodeatom;
  bool _5335 = mosek::fusion::p_WorkStack::_get_impl(_5329)->hassp;
  int _5336 = mosek::fusion::p_WorkStack::_get_impl(_5329)->shape_base;
  int _5337 = mosek::fusion::p_WorkStack::_get_impl(_5329)->ptr_base;
  int _5338 = mosek::fusion::p_WorkStack::_get_impl(_5329)->nidxs_base;
  int _5339 = mosek::fusion::p_WorkStack::_get_impl(_5329)->sp_base;
  int _5340 = mosek::fusion::p_WorkStack::_get_impl(_5329)->cof_base;
  int _5341 = mosek::fusion::p_WorkStack::_get_impl(_5329)->code_base;
  int _5342 = mosek::fusion::p_WorkStack::_get_impl(_5329)->codeptr_base;
  int _5343 = mosek::fusion::p_WorkStack::_get_impl(_5329)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5344 = mosek::fusion::p_WorkStack::_get_impl(_5329)->i32;
  _checked_ptr_1<int> _ptr__5344(_5344 ? _5344->raw() : nullptr,_5344 ? _5344->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5345 = mosek::fusion::p_WorkStack::_get_impl(_5329)->i64;
  _checked_ptr_1<long long> _ptr__5345(_5345 ? _5345->raw() : nullptr,_5345 ? _5345->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5346 = mosek::fusion::p_WorkStack::_get_impl(_5329)->f64;
  _checked_ptr_1<double> _ptr__5346(_5346 ? _5346->raw() : nullptr,_5346 ? _5346->size(0) : 0);
  int _5347 = (int)0;
  int _5348 = (int)0;
  int _5349 = (int)0;
  if ((!_5335))
  {
    {
      _5349 = (int)((msp)->size(0));
      int _11050 = (int)0;
      int _11051 = (int)((msp)->size(0));
      for (int _5350 = _11050; _5350 < _11051; ++_5350)
      {
        {
          _5348 += (_ptr__5344[safe_add( safe_add( _5337,((*msp)(_5350)) ),(int)1 )] - _ptr__5344[safe_add( _5337,((*msp)(_5350)) )]);
        }
      }
      if ((_5334 > (int)0))
      {
        {
          int _11052 = (int)0;
          int _11053 = (int)((msp)->size(0));
          for (int _5351 = _11052; _5351 < _11053; ++_5351)
          {
            {
              _5347 += safe_add( (_ptr__5344[safe_add( _5342,_ptr__5344[safe_add( safe_add( _5337,((*msp)(_5351)) ),(int)1 )] )] - _ptr__5344[safe_add( _5342,_ptr__5344[safe_add( _5337,((*msp)(_5351)) )] )]),safe_mul( (int)2,(_ptr__5344[safe_add( safe_add( _5337,((*msp)(_5351)) ),(int)1 )] - _ptr__5344[safe_add( _5337,((*msp)(_5351)) )]) ) );
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      int _5352 = (int)((msp)->size(0));
      int _5353 = (int)0;
      int _5354 = _5332;
      int _5355 = (int)0;
      while ( ((_5353 < _5352) && (_5355 < _5354)) )
      {
        {
          if ((((*msp)(_5353)) < _ptr__5345[safe_add( _5339,_5355 )]))
          {
            {
              ++ _5353;
            }
          }
          else if((((*msp)(_5353)) > _ptr__5345[safe_add( _5339,_5355 )]))
          {
            {
              ++ _5355;
            }
          }
          else
          {
            {
              _5348 += (_ptr__5344[safe_add( safe_add( _5337,_5355 ),(int)1 )] - _ptr__5344[safe_add( _5337,_5355 )]);
              if ((_5334 > (int)0))
              {
                {
                  _5347 += safe_add( (_ptr__5344[safe_add( _5342,_ptr__5344[safe_add( safe_add( _5337,_5355 ),(int)1 )] )] - _ptr__5344[safe_add( _5342,_ptr__5344[safe_add( _5337,_5355 )] )]),safe_mul( (int)2,(_ptr__5344[safe_add( safe_add( _5337,_5355 ),(int)1 )] - _ptr__5344[safe_add( _5337,_5355 )]) ) );
                }
              }
              {}
              ++ _5353;
              ++ _5355;
              ++ _5349;
            }
          }
        }
      }
    }
  }
  long long _5356 = (long long)1;
  int _11054 = (int)0;
  int _11055 = _5331;
  for (int _5357 = _11054; _5357 < _11055; ++_5357)
  {
    {
      _5356 *= _ptr__5344[safe_add( _5336,_5357 )];
    }
  }
  bool _5358 = (_5349 < _5356);
  int _5359 = _5331;
  _5328->alloc_expr(_5359,_5349,_5348,_5358,_5347);
  int _5360 = mosek::fusion::p_WorkStack::_get_impl(_5328)->ptr_base;
  int _5361 = mosek::fusion::p_WorkStack::_get_impl(_5328)->shape_base;
  int _5362 = mosek::fusion::p_WorkStack::_get_impl(_5328)->nidxs_base;
  int _11056;
  bool _11057 = _5358;
  if (_11057)
  {
    _11056 = mosek::fusion::p_WorkStack::_get_impl(_5328)->sp_base;
  }
  else
  {
    _11056 = _5328->alloci64(_5349);
  }
  int _5363 = _11056;
  int _5364 = mosek::fusion::p_WorkStack::_get_impl(_5328)->cof_base;
  int _5365 = mosek::fusion::p_WorkStack::_get_impl(_5328)->code_base;
  int _5366 = mosek::fusion::p_WorkStack::_get_impl(_5328)->codeptr_base;
  int _5367 = mosek::fusion::p_WorkStack::_get_impl(_5328)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5368 = mosek::fusion::p_WorkStack::_get_impl(_5328)->i32;
  _checked_ptr_1<int> _ptr__5368(_5368 ? _5368->raw() : nullptr,_5368 ? _5368->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5369 = mosek::fusion::p_WorkStack::_get_impl(_5328)->i64;
  _checked_ptr_1<long long> _ptr__5369(_5369 ? _5369->raw() : nullptr,_5369 ? _5369->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5370 = mosek::fusion::p_WorkStack::_get_impl(_5328)->f64;
  _checked_ptr_1<double> _ptr__5370(_5370 ? _5370->raw() : nullptr,_5370 ? _5370->size(0) : 0);
  {
    int _5371 = (int)0;
    int _5372 = (int)0;
    int _5373 = (int)0;
    _ptr__5368[_5360] = (int)0;
    if ((_5347 > (int)0))
    {
      {
        _ptr__5368[_5366] = (int)0;
      }
    }
    {}
    int _11058 = (int)0;
    int _11059 = _5359;
    for (int _5374 = _11058; _5374 < _11059; ++_5374)
    {
      {
        _ptr__5368[safe_add( _5361,_5374 )] = _ptr__5344[safe_add( _5336,_5374 )];
      }
    }
    if ((!_5335))
    {
      {
        int _11060 = (int)0;
        int _11061 = (int)((msp)->size(0));
        for (int _5375 = _11060; _5375 < _11061; ++_5375)
        {
          {
            int _5376 = _ptr__5344[safe_add( _5337,((*msp)(_5375)) )];
            int _5377 = _ptr__5344[safe_add( safe_add( _5337,((*msp)(_5375)) ),(int)1 )];
            int _11062 = _5376;
            int _11063 = _5377;
            for (int _5378 = _11062; _5378 < _11063; ++_5378)
            {
              {
                _ptr__5369[safe_add( _5362,_5373 )] = _ptr__5345[safe_add( _5338,_5378 )];
                _ptr__5370[safe_add( _5364,_5373 )] = (_ptr__5346[safe_add( _5340,_5378 )] * ((*mcof)(_5375)));
                if ((_5334 > (int)0))
                {
                  {
                    int _11064 = _ptr__5344[safe_add( _5342,_5378 )];
                    int _11065 = _ptr__5344[safe_add( safe_add( _5342,_5378 ),(int)1 )];
                    for (int _5379 = _11064; _5379 < _11065; ++_5379)
                    {
                      {
                        _ptr__5368[safe_add( _5365,_5371 )] = _ptr__5344[safe_add( _5341,_5379 )];
                        _ptr__5370[safe_add( _5367,_5371 )] = _ptr__5346[safe_add( _5343,_5379 )];
                        ++ _5371;
                      }
                    }
                    _ptr__5368[safe_add( _5365,_5371 )] = 2;
                    _ptr__5370[safe_add( _5367,_5371 )] = ((*mcof)(_5375));
                    ++ _5371;
                    _ptr__5368[safe_add( _5365,_5371 )] = 5;
                    ++ _5371;
                    _ptr__5368[safe_add( safe_add( _5366,_5373 ),(int)1 )] = _5371;
                  }
                }
                {}
                ++ _5373;
              }
            }
            _ptr__5368[safe_add( safe_add( _5360,_5375 ),(int)1 )] = _5373;
            _ptr__5369[safe_add( _5363,_5375 )] = ((*msp)(_5375));
          }
        }
      }
    }
    else
    {
      {
        int _5380 = (int)((msp)->size(0));
        int _5381 = (int)0;
        int _5382 = _5332;
        int _5383 = (int)0;
        while ( ((_5381 < _5380) && (_5383 < _5382)) )
        {
          {
            if ((((*msp)(_5381)) < _ptr__5345[safe_add( _5339,_5383 )]))
            {
              {
                ++ _5381;
              }
            }
            else if((((*msp)(_5381)) > _ptr__5345[safe_add( _5339,_5383 )]))
            {
              {
                ++ _5383;
              }
            }
            else
            {
              {
                int _5384 = _ptr__5344[safe_add( _5337,_5383 )];
                int _5385 = _ptr__5344[safe_add( safe_add( _5337,_5383 ),(int)1 )];
                int _11066 = _5384;
                int _11067 = _5385;
                for (int _5386 = _11066; _5386 < _11067; ++_5386)
                {
                  {
                    _ptr__5369[safe_add( _5362,_5373 )] = _ptr__5345[safe_add( _5338,_5386 )];
                    _ptr__5370[safe_add( _5364,_5373 )] = (_ptr__5346[safe_add( _5338,_5386 )] * ((*mcof)(_5381)));
                    if ((_5334 > (int)0))
                    {
                      {
                        int _11068 = _ptr__5344[safe_add( _5342,_5386 )];
                        int _11069 = _ptr__5344[safe_add( safe_add( _5342,_5386 ),(int)1 )];
                        for (int _5387 = _11068; _5387 < _11069; ++_5387)
                        {
                          {
                            _ptr__5368[safe_add( _5365,_5371 )] = _ptr__5344[safe_add( _5341,_5387 )];
                            _ptr__5370[safe_add( _5367,_5371 )] = _ptr__5346[safe_add( _5343,_5387 )];
                            ++ _5371;
                          }
                        }
                        _ptr__5368[safe_add( _5365,_5371 )] = 2;
                        _ptr__5370[safe_add( _5367,_5371 )] = ((*mcof)(_5381));
                        ++ _5371;
                        _ptr__5368[safe_add( _5365,_5371 )] = 5;
                        ++ _5371;
                        _ptr__5368[safe_add( safe_add( _5366,_5373 ),(int)1 )] = _5371;
                      }
                    }
                    {}
                    ++ _5373;
                  }
                }
                _ptr__5368[safe_add( safe_add( _5360,_5372 ),(int)1 )] = _5373;
                _ptr__5369[safe_add( _5363,_5372 )] = ((*msp)(_5381));
                ++ _5372;
                ++ _5381;
                ++ _5383;
              }
            }
          }
        }
      }
    }
  }
  if ((!_5358))
  {
    {
      _5328->popi64(_5349);
    }
  }
  {}
}
std::string mosek::fusion::ExprMulElement :: toString() { return mosek::fusion::p_ExprMulElement::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulElement::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulElement(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulElement::destroy(){expr.reset();msp.reset();mcof.reset();}void mosek::fusion::ExprMulElement::destroy() { mosek::fusion::p_ExprMulElement::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst(mosek::fusion::p_ExprMulScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulScalarConst::~ExprMulScalarConst() {  /* std::cout << "~ExprMulScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarConst::p_ExprMulScalarConst  (::mosek::fusion::ExprMulScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarConst::t mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst  (double _5388,    monty::rc_ptr< ::mosek::fusion::Expression > _5389){ return new mosek::fusion::ExprMulScalarConst(_5388,_5389); }mosek::fusion::ExprMulScalarConst::ExprMulScalarConst  (double _5388,    monty::rc_ptr< ::mosek::fusion::Expression > _5389) :    ExprMulScalarConst(new mosek::fusion::p_ExprMulScalarConst(this)){ mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->_initialize(_5388,_5389); }void mosek::fusion::p_ExprMulScalarConst::_initialize  (double _5388,    monty::rc_ptr< ::mosek::fusion::Expression > _5389){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_5389->getShape());
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->c = _5388;
    mosek::fusion::p_ExprMulScalarConst::_get_impl(::mosek::fusion::ExprMulScalarConst::t(_pubthis))->expr = _5389;
  }
}void mosek::fusion::ExprMulScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5390,monty::rc_ptr< ::mosek::fusion::WorkStack > _5391,monty::rc_ptr< ::mosek::fusion::WorkStack > _5392) { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->eval(_5390,_5391,_5392); }void mosek::fusion::p_ExprMulScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5390,monty::rc_ptr< ::mosek::fusion::WorkStack > _5391,monty::rc_ptr< ::mosek::fusion::WorkStack > _5392){
  expr->eval(_5391,_5390,_5392);
  _5391->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _5393 = mosek::fusion::p_WorkStack::_get_impl(_5391)->i32;
  _checked_ptr_1<int> _ptr__5393(_5393 ? _5393->raw() : nullptr,_5393 ? _5393->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5394 = mosek::fusion::p_WorkStack::_get_impl(_5391)->i64;
  _checked_ptr_1<long long> _ptr__5394(_5394 ? _5394->raw() : nullptr,_5394 ? _5394->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5395 = mosek::fusion::p_WorkStack::_get_impl(_5391)->f64;
  _checked_ptr_1<double> _ptr__5395(_5395 ? _5395->raw() : nullptr,_5395 ? _5395->size(0) : 0);
  int _5396 = mosek::fusion::p_WorkStack::_get_impl(_5391)->nd;
  int _5397 = mosek::fusion::p_WorkStack::_get_impl(_5391)->nelem;
  int _5398 = mosek::fusion::p_WorkStack::_get_impl(_5391)->nnz;
  bool _5399 = mosek::fusion::p_WorkStack::_get_impl(_5391)->hassp;
  int _5400 = mosek::fusion::p_WorkStack::_get_impl(_5391)->ncodeatom;
  int _5401 = mosek::fusion::p_WorkStack::_get_impl(_5391)->ptr_base;
  int _5402 = mosek::fusion::p_WorkStack::_get_impl(_5391)->code_base;
  int _5403 = mosek::fusion::p_WorkStack::_get_impl(_5391)->cconst_base;
  int _5404 = mosek::fusion::p_WorkStack::_get_impl(_5391)->codeptr_base;
  int _5405 = mosek::fusion::p_WorkStack::_get_impl(_5391)->shape_base;
  int _5406 = mosek::fusion::p_WorkStack::_get_impl(_5391)->sp_base;
  int _5407 = mosek::fusion::p_WorkStack::_get_impl(_5391)->nidxs_base;
  int _5408 = mosek::fusion::p_WorkStack::_get_impl(_5391)->cof_base;
  int _5409 = mosek::fusion::p_WorkStack::_get_impl(_5391)->cconst_base;
  int _11070;
  bool _11071 = (_5400 == (int)0);
  if (_11071)
  {
    _11070 = (int)0;
  }
  else
  {
    _11070 = safe_add( _5400,safe_mul( (int)2,_5398 ) );
  }
  int _5410 = _11070;
  _5390->alloc_expr(_5396,_5397,_5398,_5399,_5410);
  std::shared_ptr< monty::ndarray< long long,1 > > _5411 = mosek::fusion::p_WorkStack::_get_impl(_5390)->i64;
  _checked_ptr_1<long long> _ptr__5411(_5411 ? _5411->raw() : nullptr,_5411 ? _5411->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5412 = mosek::fusion::p_WorkStack::_get_impl(_5390)->f64;
  _checked_ptr_1<double> _ptr__5412(_5412 ? _5412->raw() : nullptr,_5412 ? _5412->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5413 = mosek::fusion::p_WorkStack::_get_impl(_5390)->i32;
  _checked_ptr_1<int> _ptr__5413(_5413 ? _5413->raw() : nullptr,_5413 ? _5413->size(0) : 0);
  int _5414 = mosek::fusion::p_WorkStack::_get_impl(_5390)->ptr_base;
  int _5415 = mosek::fusion::p_WorkStack::_get_impl(_5390)->nidxs_base;
  int _5416 = mosek::fusion::p_WorkStack::_get_impl(_5390)->cof_base;
  int _5417 = mosek::fusion::p_WorkStack::_get_impl(_5390)->code_base;
  int _5418 = mosek::fusion::p_WorkStack::_get_impl(_5390)->codeptr_base;
  int _5419 = mosek::fusion::p_WorkStack::_get_impl(_5390)->cconst_base;
  bool _5420 = mosek::fusion::p_WorkStack::_get_impl(_5390)->hassp;
  int _5421 = mosek::fusion::p_WorkStack::_get_impl(_5390)->shape_base;
  {
    int _11072 = (int)0;
    int _11073 = safe_add( _5397,(int)1 );
    for (int _5422 = _11072; _5422 < _11073; ++_5422)
    {
      {
        _ptr__5413[safe_add( _5414,_5422 )] = _ptr__5393[safe_add( _5401,_5422 )];
      }
    }
    int _11074 = (int)0;
    int _11075 = _5398;
    for (int _5423 = _11074; _5423 < _11075; ++_5423)
    {
      {
        _ptr__5411[safe_add( _5415,_5423 )] = _ptr__5394[safe_add( _5407,_5423 )];
        _ptr__5412[safe_add( _5416,_5423 )] = (_ptr__5395[safe_add( _5408,_5423 )] * c);
      }
    }
    if (_5399)
    {
      {
        int _11076 = (int)0;
        int _11077 = _5397;
        for (int _5424 = _11076; _5424 < _11077; ++_5424)
        {
          {
            _ptr__5411[safe_add( _5406,_5424 )] = _ptr__5394[safe_add( _5406,_5424 )];
          }
        }
      }
    }
    {}
    int _11078 = (int)0;
    int _11079 = _5396;
    for (int _5425 = _11078; _5425 < _11079; ++_5425)
    {
      {
        _ptr__5413[safe_add( _5421,_5425 )] = _ptr__5393[safe_add( _5405,_5425 )];
      }
    }
    if ((_5400 > (int)0))
    {
      {
        _ptr__5413[_5418] = (int)0;
        int _5426 = (int)0;
        int _11080 = (int)0;
        int _11081 = _5398;
        for (int _5427 = _11080; _5427 < _11081; ++_5427)
        {
          {
            int _11082 = _ptr__5393[safe_add( _5404,_5427 )];
            int _11083 = _ptr__5393[safe_add( safe_add( _5404,_5427 ),(int)1 )];
            for (int _5428 = _11082; _5428 < _11083; ++_5428)
            {
              {
                _ptr__5413[safe_add( _5417,_5426 )] = _ptr__5393[safe_add( _5402,_5428 )];
                _ptr__5412[safe_add( _5419,_5426 )] = _ptr__5395[safe_add( _5403,_5428 )];
                ++ _5426;
              }
            }
            _ptr__5413[safe_add( _5417,_5426 )] = 2;
            _ptr__5412[safe_add( _5419,_5426 )] = c;
            ++ _5426;
            _ptr__5413[safe_add( _5417,_5426 )] = 5;
            ++ _5426;
            _ptr__5413[safe_add( safe_add( _5418,_5427 ),(int)1 )] = _5426;
          }
        }
      }
    }
    {}
  }
}
std::string mosek::fusion::ExprMulScalarConst :: toString() { return mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarConst::toString(){
  return std::string ("ExprMulScalarConst()");
}
void mosek::fusion::p_ExprMulScalarConst::destroy(){expr.reset();}void mosek::fusion::ExprMulScalarConst::destroy() { mosek::fusion::p_ExprMulScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprScalarMul::ExprScalarMul(mosek::fusion::p_ExprScalarMul *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprScalarMul()" << this << std::endl; */ }mosek::fusion::ExprScalarMul::~ExprScalarMul() {  /* std::cout << "~ExprScalarMul()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprScalarMul::p_ExprScalarMul  (::mosek::fusion::ExprScalarMul * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _5429,    int _5430,    std::shared_ptr< monty::ndarray< int,1 > > _5431,    std::shared_ptr< monty::ndarray< int,1 > > _5432,    std::shared_ptr< monty::ndarray< double,1 > > _5433,    monty::rc_ptr< ::mosek::fusion::Expression > _5434,    int _5435){ return new mosek::fusion::ExprScalarMul(_5429,_5430,_5431,_5432,_5433,_5434,_5435); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _5429,    int _5430,    std::shared_ptr< monty::ndarray< int,1 > > _5431,    std::shared_ptr< monty::ndarray< int,1 > > _5432,    std::shared_ptr< monty::ndarray< double,1 > > _5433,    monty::rc_ptr< ::mosek::fusion::Expression > _5434,    int _5435) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_5429,_5430,_5431,_5432,_5433,_5434,_5435); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _5429,    int _5430,    std::shared_ptr< monty::ndarray< int,1 > > _5431,    std::shared_ptr< monty::ndarray< int,1 > > _5432,    std::shared_ptr< monty::ndarray< double,1 > > _5433,    monty::rc_ptr< ::mosek::fusion::Expression > _5434,    int _5435){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5431(_5431 ? _5431->raw() : nullptr, _5431 ? _5431->size(0) : 0);
    _checked_ptr_1<int> _ptr__5432(_5432 ? _5432->raw() : nullptr, _5432 ? _5432->size(0) : 0);
    _checked_ptr_1<double> _ptr__5433(_5433 ? _5433->raw() : nullptr, _5433 ? _5433->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5429),(int)(_5430)}));
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim0 = _5429;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mdim1 = _5430;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubi = _5431;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->msubj = _5432;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->mval = _5433;
    mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr = _5434;
  }
}mosek::fusion::ExprScalarMul::t mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul  (int _5436,    int _5437,    std::shared_ptr< monty::ndarray< int,1 > > _5438,    std::shared_ptr< monty::ndarray< int,1 > > _5439,    std::shared_ptr< monty::ndarray< double,1 > > _5440,    monty::rc_ptr< ::mosek::fusion::Expression > _5441){ return new mosek::fusion::ExprScalarMul(_5436,_5437,_5438,_5439,_5440,_5441); }mosek::fusion::ExprScalarMul::ExprScalarMul  (int _5436,    int _5437,    std::shared_ptr< monty::ndarray< int,1 > > _5438,    std::shared_ptr< monty::ndarray< int,1 > > _5439,    std::shared_ptr< monty::ndarray< double,1 > > _5440,    monty::rc_ptr< ::mosek::fusion::Expression > _5441) :    ExprScalarMul(new mosek::fusion::p_ExprScalarMul(this)){ mosek::fusion::p_ExprScalarMul::_get_impl(this)->_initialize(_5436,_5437,_5438,_5439,_5440,_5441); }void mosek::fusion::p_ExprScalarMul::_initialize  (int _5436,    int _5437,    std::shared_ptr< monty::ndarray< int,1 > > _5438,    std::shared_ptr< monty::ndarray< int,1 > > _5439,    std::shared_ptr< monty::ndarray< double,1 > > _5440,    monty::rc_ptr< ::mosek::fusion::Expression > _5441){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5438(_5438 ? _5438->raw() : nullptr, _5438 ? _5438->size(0) : 0);
    _checked_ptr_1<int> _ptr__5439(_5439 ? _5439->raw() : nullptr, _5439 ? _5439->size(0) : 0);
    _checked_ptr_1<double> _ptr__5440(_5440 ? _5440->raw() : nullptr, _5440 ? _5440->size(0) : 0);
    mosek::fusion::p_ExprScalarMul::_initialize(_5436,_5437,_5438,_5439,_5440,_5441,::mosek::fusion::p_ExprScalarMul::validate(_5436,_5437,_5438,_5439,_5440,_5441));
  }
}void mosek::fusion::ExprScalarMul :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5442,monty::rc_ptr< ::mosek::fusion::WorkStack > _5443,monty::rc_ptr< ::mosek::fusion::WorkStack > _5444) { mosek::fusion::p_ExprScalarMul::_get_impl(this)->eval(_5442,_5443,_5444); }void mosek::fusion::p_ExprScalarMul::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5442,monty::rc_ptr< ::mosek::fusion::WorkStack > _5443,monty::rc_ptr< ::mosek::fusion::WorkStack > _5444){
  mosek::fusion::p_ExprScalarMul::_get_impl(::mosek::fusion::ExprScalarMul::t(_pubthis))->expr->eval(_5443,_5442,_5444);
  _5443->pop_expr();
  int _5445 = mosek::fusion::p_WorkStack::_get_impl(_5443)->nd;
  int _5446 = mosek::fusion::p_WorkStack::_get_impl(_5443)->nelem;
  int _5447 = mosek::fusion::p_WorkStack::_get_impl(_5443)->nnz;
  bool _5448 = mosek::fusion::p_WorkStack::_get_impl(_5443)->hassp;
  int _5449 = mosek::fusion::p_WorkStack::_get_impl(_5443)->ncodeatom;
  int _5450 = mosek::fusion::p_WorkStack::_get_impl(_5443)->ptr_base;
  int _5451 = mosek::fusion::p_WorkStack::_get_impl(_5443)->sp_base;
  int _5452 = mosek::fusion::p_WorkStack::_get_impl(_5443)->nidxs_base;
  int _5453 = mosek::fusion::p_WorkStack::_get_impl(_5443)->cof_base;
  int _5454 = mosek::fusion::p_WorkStack::_get_impl(_5443)->code_base;
  int _5455 = mosek::fusion::p_WorkStack::_get_impl(_5443)->codeptr_base;
  int _5456 = mosek::fusion::p_WorkStack::_get_impl(_5443)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5457 = mosek::fusion::p_WorkStack::_get_impl(_5443)->i32;
  _checked_ptr_1<int> _ptr__5457(_5457 ? _5457->raw() : nullptr,_5457 ? _5457->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5458 = mosek::fusion::p_WorkStack::_get_impl(_5443)->i64;
  _checked_ptr_1<long long> _ptr__5458(_5458 ? _5458->raw() : nullptr,_5458 ? _5458->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5459 = mosek::fusion::p_WorkStack::_get_impl(_5443)->f64;
  _checked_ptr_1<double> _ptr__5459(_5459 ? _5459->raw() : nullptr,_5459 ? _5459->size(0) : 0);
  int _5460 = (int)((mval)->size(0));
  if ((_5445 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid expression shape"));
    }
  }
  {}
  if ((_5446 == (int)0))
  {
    {
      _5442->alloc_expr((int)2,(int)0,(int)0,true);
      ((*mosek::fusion::p_WorkStack::_get_impl(_5442)->i32)(mosek::fusion::p_WorkStack::_get_impl(_5442)->shape_base)) = mdim0;
      ((*mosek::fusion::p_WorkStack::_get_impl(_5442)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_5442)->shape_base,(int)1 ))) = mdim1;
    }
  }
  else
  {
    {
      int _11084;
      bool _11085 = (_5449 > (int)0);
      if (_11085)
      {
        _11084 = safe_mul( (int)2,_5447 );
      }
      else
      {
        _11084 = (int)0;
      }
      int _5461 = safe_add( _5449,_11084 );
      _5442->alloc_expr((int)2,_5460,safe_mul( _5460,_5447 ),true,_5461);
      int _5462 = mosek::fusion::p_WorkStack::_get_impl(_5442)->ptr_base;
      int _5463 = mosek::fusion::p_WorkStack::_get_impl(_5442)->nidxs_base;
      int _5464 = mosek::fusion::p_WorkStack::_get_impl(_5442)->sp_base;
      int _5465 = mosek::fusion::p_WorkStack::_get_impl(_5442)->cof_base;
      int _5466 = mosek::fusion::p_WorkStack::_get_impl(_5442)->shape_base;
      int _5467 = mosek::fusion::p_WorkStack::_get_impl(_5442)->code_base;
      int _5468 = mosek::fusion::p_WorkStack::_get_impl(_5442)->codeptr_base;
      int _5469 = mosek::fusion::p_WorkStack::_get_impl(_5442)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _5470 = mosek::fusion::p_WorkStack::_get_impl(_5442)->i32;
      _checked_ptr_1<int> _ptr__5470(_5470 ? _5470->raw() : nullptr,_5470 ? _5470->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _5471 = mosek::fusion::p_WorkStack::_get_impl(_5442)->i64;
      _checked_ptr_1<long long> _ptr__5471(_5471 ? _5471->raw() : nullptr,_5471 ? _5471->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5472 = mosek::fusion::p_WorkStack::_get_impl(_5442)->f64;
      _checked_ptr_1<double> _ptr__5472(_5472 ? _5472->raw() : nullptr,_5472 ? _5472->size(0) : 0);
      _ptr__5470[_5466] = mdim0;
      _ptr__5470[safe_add( _5466,(int)1 )] = mdim1;
      int _5473 = (int)0;
      int _5474 = (int)0;
      _ptr__5470[_5462] = (int)0;
      if ((_5449 > (int)0))
      {
        {
          _ptr__5470[_5468] = (int)0;
          int _11086 = (int)0;
          int _11087 = _5460;
          for (int _5475 = _11086; _5475 < _11087; ++_5475)
          {
            {
              int _11088 = (int)0;
              int _11089 = _5447;
              for (int _5476 = _11088; _5476 < _11089; ++_5476)
              {
                {
                  _ptr__5471[safe_add( _5463,_5474 )] = _ptr__5458[safe_add( _5452,_5476 )];
                  _ptr__5472[safe_add( _5465,_5474 )] = (_ptr__5459[safe_add( _5453,_5476 )] * ((*mval)(_5475)));
                  int _11090 = _ptr__5457[safe_add( _5455,_5476 )];
                  int _11091 = _ptr__5457[safe_add( safe_add( _5455,_5476 ),(int)1 )];
                  for (int _5477 = _11090; _5477 < _11091; ++_5477)
                  {
                    {
                      _ptr__5470[safe_add( _5467,_5473 )] = _ptr__5457[safe_add( _5454,_5477 )];
                      _ptr__5472[safe_add( _5469,_5473 )] = _ptr__5459[safe_add( _5456,_5477 )];
                      ++ _5473;
                    }
                  }
                  _ptr__5470[safe_add( _5467,_5473 )] = 2;
                  _ptr__5472[safe_add( _5469,_5473 )] = ((*mval)(_5475));
                  ++ _5473;
                  _ptr__5470[safe_add( _5467,_5473 )] = 5;
                  ++ _5473;
                  _ptr__5470[safe_add( safe_add( _5468,_5474 ),(int)1 )] = _5473;
                  ++ _5474;
                }
              }
              _ptr__5471[safe_add( _5464,_5475 )] = safe_add( safe_mul( ((*msubi)(_5475)),mdim1 ),((*msubj)(_5475)) );
              _ptr__5470[safe_add( safe_add( _5462,_5475 ),(int)1 )] = _5474;
            }
          }
        }
      }
      else
      {
        {
          int _11092 = (int)0;
          int _11093 = _5460;
          for (int _5478 = _11092; _5478 < _11093; ++_5478)
          {
            {
              int _11094 = (int)0;
              int _11095 = _5447;
              for (int _5479 = _11094; _5479 < _11095; ++_5479)
              {
                {
                  _ptr__5471[safe_add( _5463,_5474 )] = _ptr__5458[safe_add( _5452,_5479 )];
                  _ptr__5472[safe_add( _5465,_5474 )] = (_ptr__5459[safe_add( _5453,_5479 )] * ((*mval)(_5478)));
                  ++ _5474;
                }
              }
              _ptr__5471[safe_add( _5464,_5478 )] = safe_add( safe_mul( ((*msubi)(_5478)),mdim1 ),((*msubj)(_5478)) );
              _ptr__5470[safe_add( safe_add( _5462,_5478 ),(int)1 )] = _5474;
            }
          }
        }
      }
    }
  }
}
int mosek::fusion::p_ExprScalarMul::validate(int _5480,int _5481,std::shared_ptr< monty::ndarray< int,1 > > _5482,std::shared_ptr< monty::ndarray< int,1 > > _5483,std::shared_ptr< monty::ndarray< double,1 > > _5484,monty::rc_ptr< ::mosek::fusion::Expression > _5485){
  _checked_ptr_1<int> _ptr__5482(_5482 ? _5482->raw() : nullptr, _5482 ? _5482->size(0) : 0);
  _checked_ptr_1<int> _ptr__5483(_5483 ? _5483->raw() : nullptr, _5483 ? _5483->size(0) : 0);
  _checked_ptr_1<double> _ptr__5484(_5484 ? _5484->raw() : nullptr, _5484 ? _5484->size(0) : 0);
  int _5486 = _5485->getND();
  if ((_5486 != (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if (((_5480 < (int)0) || (_5481 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((((int)((_5482)->size(0)) != (int)((_5483)->size(0))) || ((int)((_5482)->size(0)) != (int)((_5484)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _5487 = (int)((_5482)->size(0));
  bool _5488 = false;
  bool _5489 = false;
  {
    int _11096 = (int)0;
    int _11097 = _5487;
    for (int _5490 = _11096; _5490 < _11097; ++_5490)
    {
      {
        if (((_ptr__5482[_5490] < (int)0) || ((_ptr__5482[_5490] >= _5480) || ((_ptr__5483[_5490] < (int)0) || (_ptr__5483[_5490] >= _5481)))))
        {
          {
            _5488 = true;
          }
        }
        {}
      }
    }
    int _11098 = (int)0;
    int _11099 = (_5487 - (int)1);
    for (int _5491 = _11098; _5491 < _11099; ++_5491)
    {
      {
        if (((_ptr__5482[_5491] > _ptr__5482[safe_add( _5491,(int)1 )]) || ((_ptr__5482[_5491] == _ptr__5482[safe_add( _5491,(int)1 )]) && (_ptr__5483[_5491] >= _ptr__5483[safe_add( _5491,(int)1 )]))))
        {
          {
            _5489 = true;
          }
        }
        {}
      }
    }
  }
  if (_5488)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_5489)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprScalarMul :: toString() { return mosek::fusion::p_ExprScalarMul::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprScalarMul::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprScalarMul(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprScalarMul::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprScalarMul::destroy() { mosek::fusion::p_ExprScalarMul::_get_impl(this)->destroy(); }mosek::fusion::ExprMulRight::ExprMulRight(mosek::fusion::p_ExprMulRight *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulRight()" << this << std::endl; */ }mosek::fusion::ExprMulRight::~ExprMulRight() {  /* std::cout << "~ExprMulRight()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulRight::p_ExprMulRight  (::mosek::fusion::ExprMulRight * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _5492,    int _5493,    std::shared_ptr< monty::ndarray< int,1 > > _5494,    std::shared_ptr< monty::ndarray< int,1 > > _5495,    std::shared_ptr< monty::ndarray< double,1 > > _5496,    monty::rc_ptr< ::mosek::fusion::Expression > _5497,    int _5498){ return new mosek::fusion::ExprMulRight(_5492,_5493,_5494,_5495,_5496,_5497,_5498); }mosek::fusion::ExprMulRight::ExprMulRight  (int _5492,    int _5493,    std::shared_ptr< monty::ndarray< int,1 > > _5494,    std::shared_ptr< monty::ndarray< int,1 > > _5495,    std::shared_ptr< monty::ndarray< double,1 > > _5496,    monty::rc_ptr< ::mosek::fusion::Expression > _5497,    int _5498) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_5492,_5493,_5494,_5495,_5496,_5497,_5498); }void mosek::fusion::p_ExprMulRight::_initialize  (int _5492,    int _5493,    std::shared_ptr< monty::ndarray< int,1 > > _5494,    std::shared_ptr< monty::ndarray< int,1 > > _5495,    std::shared_ptr< monty::ndarray< double,1 > > _5496,    monty::rc_ptr< ::mosek::fusion::Expression > _5497,    int _5498){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5494(_5494 ? _5494->raw() : nullptr, _5494 ? _5494->size(0) : 0);
    _checked_ptr_1<int> _ptr__5495(_5495 ? _5495->raw() : nullptr, _5495 ? _5495->size(0) : 0);
    _checked_ptr_1<double> _ptr__5496(_5496 ? _5496->raw() : nullptr, _5496 ? _5496->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulRight::computeshape(_5493,_5497->getShape()));
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim0 = _5492;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mdim1 = _5493;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubi = _5494;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->msubj = _5495;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->mval = _5496;
    mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr = _5497;
  }
}mosek::fusion::ExprMulRight::t mosek::fusion::p_ExprMulRight::_new_ExprMulRight  (int _5499,    int _5500,    std::shared_ptr< monty::ndarray< int,1 > > _5501,    std::shared_ptr< monty::ndarray< int,1 > > _5502,    std::shared_ptr< monty::ndarray< double,1 > > _5503,    monty::rc_ptr< ::mosek::fusion::Expression > _5504){ return new mosek::fusion::ExprMulRight(_5499,_5500,_5501,_5502,_5503,_5504); }mosek::fusion::ExprMulRight::ExprMulRight  (int _5499,    int _5500,    std::shared_ptr< monty::ndarray< int,1 > > _5501,    std::shared_ptr< monty::ndarray< int,1 > > _5502,    std::shared_ptr< monty::ndarray< double,1 > > _5503,    monty::rc_ptr< ::mosek::fusion::Expression > _5504) :    ExprMulRight(new mosek::fusion::p_ExprMulRight(this)){ mosek::fusion::p_ExprMulRight::_get_impl(this)->_initialize(_5499,_5500,_5501,_5502,_5503,_5504); }void mosek::fusion::p_ExprMulRight::_initialize  (int _5499,    int _5500,    std::shared_ptr< monty::ndarray< int,1 > > _5501,    std::shared_ptr< monty::ndarray< int,1 > > _5502,    std::shared_ptr< monty::ndarray< double,1 > > _5503,    monty::rc_ptr< ::mosek::fusion::Expression > _5504){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5501(_5501 ? _5501->raw() : nullptr, _5501 ? _5501->size(0) : 0);
    _checked_ptr_1<int> _ptr__5502(_5502 ? _5502->raw() : nullptr, _5502 ? _5502->size(0) : 0);
    _checked_ptr_1<double> _ptr__5503(_5503 ? _5503->raw() : nullptr, _5503 ? _5503->size(0) : 0);
    mosek::fusion::p_ExprMulRight::_initialize(_5499,_5500,_5501,_5502,_5503,_5504,::mosek::fusion::p_ExprMulRight::validate(_5499,_5500,_5501,_5502,_5503,_5504));
  }
}void mosek::fusion::ExprMulRight :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5505,monty::rc_ptr< ::mosek::fusion::WorkStack > _5506,monty::rc_ptr< ::mosek::fusion::WorkStack > _5507) { mosek::fusion::p_ExprMulRight::_get_impl(this)->eval(_5505,_5506,_5507); }void mosek::fusion::p_ExprMulRight::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5505,monty::rc_ptr< ::mosek::fusion::WorkStack > _5506,monty::rc_ptr< ::mosek::fusion::WorkStack > _5507){
  mosek::fusion::p_ExprMulRight::_get_impl(::mosek::fusion::ExprMulRight::t(_pubthis))->expr->eval(_5506,_5505,_5507);
  _5506->pop_expr();
  std::shared_ptr< monty::ndarray< int,1 > > _5508 = mosek::fusion::p_WorkStack::_get_impl(_5506)->i32;
  _checked_ptr_1<int> _ptr__5508(_5508 ? _5508->raw() : nullptr,_5508 ? _5508->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5509 = mosek::fusion::p_WorkStack::_get_impl(_5506)->i64;
  _checked_ptr_1<long long> _ptr__5509(_5509 ? _5509->raw() : nullptr,_5509 ? _5509->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5510 = mosek::fusion::p_WorkStack::_get_impl(_5506)->f64;
  _checked_ptr_1<double> _ptr__5510(_5510 ? _5510->raw() : nullptr,_5510 ? _5510->size(0) : 0);
  int _5511 = mosek::fusion::p_WorkStack::_get_impl(_5506)->nd;
  if ((_5511 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _5512 = mosek::fusion::p_WorkStack::_get_impl(_5506)->nelem;
  int _5513 = mosek::fusion::p_WorkStack::_get_impl(_5506)->nnz;
  int _5514 = mosek::fusion::p_WorkStack::_get_impl(_5506)->ncodeatom;
  bool _5515 = mosek::fusion::p_WorkStack::_get_impl(_5506)->hassp;
  int _5516 = mosek::fusion::p_WorkStack::_get_impl(_5506)->ptr_base;
  int _5517 = mosek::fusion::p_WorkStack::_get_impl(_5506)->shape_base;
  int _5518 = mosek::fusion::p_WorkStack::_get_impl(_5506)->sp_base;
  int _5519 = mosek::fusion::p_WorkStack::_get_impl(_5506)->nidxs_base;
  int _5520 = mosek::fusion::p_WorkStack::_get_impl(_5506)->cof_base;
  int _5521 = mosek::fusion::p_WorkStack::_get_impl(_5506)->codeptr_base;
  int _5522 = mosek::fusion::p_WorkStack::_get_impl(_5506)->code_base;
  int _5523 = mosek::fusion::p_WorkStack::_get_impl(_5506)->cconst_base;
  int _5524 = _ptr__5508[_5517];
  int _5525 = _ptr__5508[safe_add( _5517,(int)1 )];
  int _5526 = (int)((mval)->size(0));
  bool _5527 = (_5526 < safe_mul( (long long)mdim0,(long long)mdim1 ));
  if (_5527)
  {
    {
      int _5528 = _5507->alloci32(safe_add( mdim1,(int)1 ));
      int _5529 = _5507->alloci32(_5526);
      int _5530 = _5507->alloci32(safe_add( _5524,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _5531 = mosek::fusion::p_WorkStack::_get_impl(_5507)->i32;
      _checked_ptr_1<int> _ptr__5531(_5531 ? _5531->raw() : nullptr,_5531 ? _5531->size(0) : 0);
      {
        int _11100 = (int)0;
        int _11101 = safe_add( mdim1,(int)1 );
        for (int _5532 = _11100; _5532 < _11101; ++_5532)
        {
          {
            _ptr__5531[safe_add( _5528,_5532 )] = (int)0;
          }
        }
        int _11102 = (int)0;
        int _11103 = _5526;
        for (int _5533 = _11102; _5533 < _11103; ++_5533)
        {
          {
            ++ _ptr__5531[safe_add( safe_add( _5528,((*msubj)(_5533)) ),(int)1 )];
          }
        }
        int _11104 = (int)0;
        int _11105 = mdim1;
        for (int _5534 = _11104; _5534 < _11105; ++_5534)
        {
          {
            _ptr__5531[safe_add( safe_add( _5528,_5534 ),(int)1 )] += _ptr__5531[safe_add( _5528,_5534 )];
          }
        }
        int _11106 = (int)0;
        int _11107 = _5526;
        for (int _5535 = _11106; _5535 < _11107; ++_5535)
        {
          {
            _ptr__5531[safe_add( _5529,_5535 )] = _ptr__5531[safe_add( _5528,((*msubj)(_5535)) )];
            ++ _ptr__5531[safe_add( _5528,((*msubj)(_5535)) )];
          }
        }
        int _11108 = (int)0;
        int _11109 = mdim1;
        for (int _5536 = _11108; _5536 < _11109; ++_5536)
        {
          {
            _ptr__5531[(safe_add( _5528,mdim1 ) - _5536)] = _ptr__5531[((safe_add( _5528,mdim1 ) - _5536) - (int)1)];
          }
        }
        _ptr__5531[_5528] = (int)0;
        int _11110 = (int)0;
        int _11111 = safe_add( _5524,(int)1 );
        for (int _5537 = _11110; _5537 < _11111; ++_5537)
        {
          {
            _ptr__5531[safe_add( _5530,_5537 )] = (int)0;
          }
        }
      }
      if (_5515)
      {
        {
          int _5538 = (int)0;
          int _5539 = (int)0;
          long long _5540 = (long long)0;
          {
            int _5541 = (int)0;
            while ( (_5541 < _5512) )
            {
              {
                long long _5542 = (_ptr__5509[safe_add( _5518,_5541 )] / _5525);
                int _5543 = _5541;
                ++ _5541;
                while ( ((_5541 > _5512) && ((_ptr__5509[safe_add( _5518,_5541 )] / _5525) == _5542)) )
                {
                  {
                    ++ _5541;
                  }
                }
                int _5544 = _5541;
                int _5545 = (int)0;
                while ( (_5545 < _5526) )
                {
                  {
                    int _5546 = ((*msubj)(_ptr__5531[safe_add( _5529,_5545 )]));
                    int _5547 = _5545;
                    ++ _5545;
                    while ( ((_5545 < _5526) && (((*msubj)(_ptr__5531[safe_add( _5529,_5545 )])) == _5546)) )
                    {
                      {
                        ++ _5545;
                      }
                    }
                    int _5548 = _5545;
                    bool _5549 = false;
                    int _5550 = _5547;
                    int _5551 = _5543;
                    while ( ((_5551 < _5544) && (_5550 < _5548)) )
                    {
                      {
                        int _5552 = _ptr__5531[safe_add( _5529,_5550 )];
                        if (((_ptr__5509[safe_add( _5518,_5551 )] % _5525) < ((*msubi)(_5552))))
                        {
                          {
                            ++ _5551;
                          }
                        }
                        else if(((_ptr__5509[safe_add( _5518,_5551 )] % _5525) > ((*msubi)(_5552))))
                        {
                          {
                            ++ _5550;
                          }
                        }
                        else
                        {
                          {
                            if (((((*mval)(_5552)) > (int)0) || ((int)0 < ((*mval)(_5552)))))
                            {
                              {
                                _5540 += (_ptr__5508[safe_add( safe_add( _5516,_5551 ),(int)1 )] - _ptr__5508[safe_add( _5516,_5551 )]);
                                if ((_5514 > (int)0))
                                {
                                  {
                                    _5538 += safe_add( (_ptr__5508[safe_add( _5521,_ptr__5508[safe_add( safe_add( _5516,_5551 ),(int)1 )] )] - _ptr__5508[safe_add( _5521,_ptr__5508[safe_add( _5516,_5551 )] )]),safe_mul( (int)2,(_ptr__5508[safe_add( safe_add( _5516,_5551 ),(int)1 )] - _ptr__5508[safe_add( _5516,_5551 )]) ) );
                                  }
                                }
                                {}
                                ++ _5551;
                                ++ _5550;
                                _5549 = true;
                              }
                            }
                            {}
                          }
                        }
                      }
                    }
                    if (_5549)
                    {
                      {
                        ++ _5539;
                      }
                    }
                    {}
                  }
                }
              }
            }
          }
          bool _5553 = (_5539 < safe_mul( _5524,mdim1 ));
          _5505->alloc_expr((int)2,_5539,(int)_5540,_5553,_5538);
          int _5554 = mosek::fusion::p_WorkStack::_get_impl(_5505)->ptr_base;
          int _5555 = mosek::fusion::p_WorkStack::_get_impl(_5505)->nidxs_base;
          int _11112;
          bool _11113 = _5553;
          if (_11113)
          {
            _11112 = mosek::fusion::p_WorkStack::_get_impl(_5505)->sp_base;
          }
          else
          {
            _11112 = _5505->alloci64(_5539);
          }
          int _5556 = _11112;
          int _5557 = mosek::fusion::p_WorkStack::_get_impl(_5505)->cof_base;
          int _5558 = mosek::fusion::p_WorkStack::_get_impl(_5505)->shape_base;
          int _5559 = mosek::fusion::p_WorkStack::_get_impl(_5505)->codeptr_base;
          int _5560 = mosek::fusion::p_WorkStack::_get_impl(_5505)->code_base;
          int _5561 = mosek::fusion::p_WorkStack::_get_impl(_5505)->cconst_base;
          std::shared_ptr< monty::ndarray< int,1 > > _5562 = mosek::fusion::p_WorkStack::_get_impl(_5505)->i32;
          _checked_ptr_1<int> _ptr__5562(_5562 ? _5562->raw() : nullptr,_5562 ? _5562->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _5563 = mosek::fusion::p_WorkStack::_get_impl(_5505)->i64;
          _checked_ptr_1<long long> _ptr__5563(_5563 ? _5563->raw() : nullptr,_5563 ? _5563->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _5564 = mosek::fusion::p_WorkStack::_get_impl(_5505)->f64;
          _checked_ptr_1<double> _ptr__5564(_5564 ? _5564->raw() : nullptr,_5564 ? _5564->size(0) : 0);
          _ptr__5562[_5558] = _5524;
          _ptr__5562[safe_add( _5558,(int)1 )] = mdim1;
          _ptr__5562[_5554] = (int)0;
          if ((_5538 > (int)0))
          {
            {
              _ptr__5562[_5559] = (int)0;
            }
          }
          {}
          {
            int _5565 = (int)0;
            int _5566 = (int)0;
            int _5567 = (int)0;
            int _5568 = (int)0;
            while ( (_5565 < _5512) )
            {
              {
                long long _5569 = (_ptr__5509[safe_add( _5518,_5565 )] / _5525);
                int _5570 = _5565;
                ++ _5565;
                while ( ((_5565 > _5512) && ((_ptr__5509[safe_add( _5518,_5565 )] / _5525) == _5569)) )
                {
                  {
                    ++ _5565;
                  }
                }
                int _5571 = _5565;
                int _5572 = (int)0;
                while ( (_5572 < _5526) )
                {
                  {
                    int _5573 = ((*msubj)(_ptr__5531[safe_add( _5529,_5572 )]));
                    int _5574 = _5572;
                    ++ _5572;
                    while ( ((_5572 < _5526) && (((*msubj)(_ptr__5531[safe_add( _5529,_5572 )])) == _5573)) )
                    {
                      {
                        ++ _5572;
                      }
                    }
                    int _5575 = _5572;
                    int _5576 = _5574;
                    int _5577 = _5570;
                    bool _5578 = false;
                    while ( ((_5577 < _5571) && (_5576 < _5575)) )
                    {
                      {
                        int _5579 = _ptr__5531[safe_add( _5529,_5576 )];
                        if (((_ptr__5509[safe_add( _5518,_5577 )] % _5525) < ((*msubi)(_5579))))
                        {
                          {
                            ++ _5577;
                          }
                        }
                        else if(((_ptr__5509[safe_add( _5518,_5577 )] % _5525) > ((*msubi)(_5579))))
                        {
                          {
                            ++ _5576;
                          }
                        }
                        else
                        {
                          {
                            if (((((*mval)(_5579)) > (int)0) || ((int)0 < ((*mval)(_5579)))))
                            {
                              {
                                int _11114 = _ptr__5508[safe_add( _5516,_5577 )];
                                int _11115 = _ptr__5508[safe_add( safe_add( _5516,_5577 ),(int)1 )];
                                for (int _5580 = _11114; _5580 < _11115; ++_5580)
                                {
                                  {
                                    _ptr__5563[safe_add( _5555,_5568 )] = _ptr__5509[safe_add( _5519,_5580 )];
                                    _ptr__5564[safe_add( _5557,_5568 )] = (_ptr__5510[safe_add( _5520,_5580 )] * ((*mval)(_5579)));
                                    if ((_5514 > (int)0))
                                    {
                                      {
                                        int _11116 = _ptr__5508[safe_add( _5521,_5580 )];
                                        int _11117 = _ptr__5508[safe_add( safe_add( _5521,_5580 ),(int)1 )];
                                        for (int _5581 = _11116; _5581 < _11117; ++_5581)
                                        {
                                          {
                                            _ptr__5562[safe_add( _5560,_5566 )] = _ptr__5508[safe_add( _5522,_5581 )];
                                            _ptr__5564[safe_add( _5561,_5566 )] = _ptr__5510[safe_add( _5523,_5581 )];
                                            ++ _5566;
                                          }
                                        }
                                        _ptr__5562[safe_add( _5560,_5566 )] = 2;
                                        _ptr__5564[safe_add( _5561,_5566 )] = ((*mval)(_5576));
                                        ++ _5566;
                                        _ptr__5562[safe_add( _5560,_5566 )] = 5;
                                        ++ _5566;
                                        _ptr__5562[safe_add( safe_add( _5559,_5568 ),(int)1 )] = _5566;
                                      }
                                    }
                                    {}
                                    ++ _5568;
                                  }
                                }
                                ++ _5577;
                                ++ _5576;
                                _5578 = true;
                              }
                            }
                            {}
                          }
                        }
                      }
                    }
                    if (_5578)
                    {
                      {
                        _ptr__5562[safe_add( safe_add( _5554,_5567 ),(int)1 )] = _5568;
                        _ptr__5563[safe_add( _5556,_5567 )] = safe_add( safe_mul( _5569,mdim1 ),_5573 );
                        ++ _5567;
                      }
                    }
                    {}
                  }
                }
              }
            }
            if ((_5568 != _5540))
            {
              {
                throw ::mosek::fusion::UnexpectedError(std::string ("Internal: invalid nnz"));
              }
            }
            {}
            if ((_5567 != _5539))
            {
              {
                throw ::mosek::fusion::UnexpectedError(std::string ("Internal: invalid nnz"));
              }
            }
            {}
            if ((_ptr__5562[safe_add( _5554,_5539 )] != _5540))
            {
              {
                throw ::mosek::fusion::UnexpectedError(std::string ("Internal: invalid nnz"));
              }
            }
            {}
          }
          if ((!_5553))
          {
            {
              _5505->popi64(_5539);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _5582 = (int)0;
          int _5583 = safe_mul( _5524,mdim1 );
          int _5584 = (int)0;
          int _11118 = (int)0;
          int _11119 = _5524;
          for (int _5585 = _11118; _5585 < _11119; ++_5585)
          {
            {
              int _11120 = (int)0;
              int _11121 = mdim1;
              for (int _5586 = _11120; _5586 < _11121; ++_5586)
              {
                {
                  int _11122 = _ptr__5531[safe_add( _5528,_5586 )];
                  int _11123 = _ptr__5531[safe_add( safe_add( _5528,_5586 ),(int)1 )];
                  for (int _5587 = _11122; _5587 < _11123; ++_5587)
                  {
                    {
                      int _5588 = _ptr__5531[safe_add( _5529,_5587 )];
                      int _5589 = safe_add( safe_mul( _5585,_5525 ),((*msubi)(_5588)) );
                      _5584 += (_ptr__5508[safe_add( safe_add( _5516,_5589 ),(int)1 )] - _ptr__5508[safe_add( _5516,_5589 )]);
                      if ((_5514 > (int)0))
                      {
                        {
                          _5582 += safe_add( (_ptr__5508[safe_add( _5521,_ptr__5508[safe_add( safe_add( _5516,_5589 ),(int)1 )] )] - _ptr__5508[safe_add( _5521,_ptr__5508[safe_add( _5516,_5589 )] )]),safe_mul( (int)2,(_ptr__5508[safe_add( safe_add( _5516,_5589 ),(int)1 )] - _ptr__5508[safe_add( _5516,_5589 )]) ) );
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          bool _5590 = (_5583 < safe_mul( _5524,mdim1 ));
          if ((!(_5584 <= (int)0x7fffffff)))
          {
            {
              throw ::mosek::fusion::LengthError(std::string ("Maximum number of nonzeros exceeded in multiplication"));
            }
          }
          {}
          _5505->alloc_expr((int)2,_5583,(int)_5584,_5590,_5582);
          int _5591 = mosek::fusion::p_WorkStack::_get_impl(_5505)->shape_base;
          int _5592 = mosek::fusion::p_WorkStack::_get_impl(_5505)->ptr_base;
          int _5593 = mosek::fusion::p_WorkStack::_get_impl(_5505)->nidxs_base;
          int _11124;
          bool _11125 = _5590;
          if (_11125)
          {
            _11124 = mosek::fusion::p_WorkStack::_get_impl(_5505)->sp_base;
          }
          else
          {
            _11124 = _5505->alloci64(_5583);
          }
          int _5594 = _11124;
          int _5595 = mosek::fusion::p_WorkStack::_get_impl(_5505)->cof_base;
          int _5596 = mosek::fusion::p_WorkStack::_get_impl(_5505)->code_base;
          int _5597 = mosek::fusion::p_WorkStack::_get_impl(_5505)->codeptr_base;
          int _5598 = mosek::fusion::p_WorkStack::_get_impl(_5505)->cconst_base;
          std::shared_ptr< monty::ndarray< int,1 > > _5599 = mosek::fusion::p_WorkStack::_get_impl(_5505)->i32;
          _checked_ptr_1<int> _ptr__5599(_5599 ? _5599->raw() : nullptr,_5599 ? _5599->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _5600 = mosek::fusion::p_WorkStack::_get_impl(_5505)->i64;
          _checked_ptr_1<long long> _ptr__5600(_5600 ? _5600->raw() : nullptr,_5600 ? _5600->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _5601 = mosek::fusion::p_WorkStack::_get_impl(_5505)->f64;
          _checked_ptr_1<double> _ptr__5601(_5601 ? _5601->raw() : nullptr,_5601 ? _5601->size(0) : 0);
          _ptr__5599[_5591] = _5524;
          _ptr__5599[safe_add( _5591,(int)1 )] = mdim1;
          int _5602 = (int)0;
          int _5603 = (int)0;
          int _5604 = (int)0;
          _ptr__5599[_5592] = (int)0;
          if ((_5582 > (int)0))
          {
            {
              _ptr__5599[_5597] = (int)0;
            }
          }
          {}
          int _11126 = (int)0;
          int _11127 = _5524;
          for (int _5605 = _11126; _5605 < _11127; ++_5605)
          {
            {
              int _11128 = (int)0;
              int _11129 = mdim1;
              for (int _5606 = _11128; _5606 < _11129; ++_5606)
              {
                {
                  int _5607 = safe_mul( _5605,_5525 );
                  int _11130 = _ptr__5531[safe_add( _5528,_5606 )];
                  int _11131 = _ptr__5531[safe_add( safe_add( _5528,_5606 ),(int)1 )];
                  for (int _5608 = _11130; _5608 < _11131; ++_5608)
                  {
                    {
                      int _5609 = _ptr__5531[safe_add( _5529,_5608 )];
                      int _5610 = safe_add( _5607,((*msubi)(_5609)) );
                      if ((_5582 == (int)0))
                      {
                        {
                          int _11132 = _ptr__5508[safe_add( _5516,_5610 )];
                          int _11133 = _ptr__5508[safe_add( safe_add( _5516,_5610 ),(int)1 )];
                          for (int _5611 = _11132; _5611 < _11133; ++_5611)
                          {
                            {
                              _ptr__5600[safe_add( _5593,_5604 )] = _ptr__5509[safe_add( _5519,_5611 )];
                              _ptr__5601[safe_add( _5595,_5604 )] = (_ptr__5510[safe_add( _5520,_5611 )] * ((*mval)(_5609)));
                              ++ _5604;
                            }
                          }
                        }
                      }
                      else
                      {
                        {
                          int _11134 = _ptr__5508[safe_add( _5516,_5610 )];
                          int _11135 = _ptr__5508[safe_add( safe_add( _5516,_5610 ),(int)1 )];
                          for (int _5612 = _11134; _5612 < _11135; ++_5612)
                          {
                            {
                              _ptr__5600[safe_add( _5593,_5604 )] = _ptr__5509[safe_add( _5519,_5612 )];
                              _ptr__5601[safe_add( _5595,_5604 )] = (_ptr__5510[safe_add( _5520,_5612 )] * ((*mval)(_5609)));
                              int _11136 = _ptr__5508[safe_add( _5521,_5612 )];
                              int _11137 = _ptr__5508[safe_add( safe_add( _5521,_5612 ),(int)1 )];
                              for (int _5613 = _11136; _5613 < _11137; ++_5613)
                              {
                                {
                                  _ptr__5599[safe_add( _5596,_5602 )] = _ptr__5508[safe_add( _5522,_5613 )];
                                  _ptr__5601[safe_add( _5598,_5602 )] = _ptr__5510[safe_add( _5523,_5613 )];
                                  ++ _5602;
                                }
                              }
                              _ptr__5599[safe_add( _5596,_5602 )] = 2;
                              _ptr__5601[safe_add( _5598,_5602 )] = ((*mval)(_5609));
                              ++ _5602;
                              _ptr__5599[safe_add( _5596,_5602 )] = 5;
                              ++ _5602;
                              _ptr__5599[safe_add( safe_add( _5597,_5604 ),(int)1 )] = _5602;
                              ++ _5604;
                            }
                          }
                        }
                      }
                    }
                  }
                  _ptr__5599[safe_add( safe_add( _5592,_5603 ),(int)1 )] = _5604;
                  _ptr__5600[safe_add( _5594,_5603 )] = safe_add( safe_mul( _5605,mdim1 ),_5606 );
                  ++ _5603;
                }
              }
            }
          }
          if ((!_5590))
          {
            {
              _5505->popi64(_5583);
            }
          }
          {}
        }
      }
      _5507->clear();
    }
  }
  else
  {
    {
      int _5614 = _5507->alloci32(safe_add( _5524,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _5615 = mosek::fusion::p_WorkStack::_get_impl(_5507)->i32;
      _checked_ptr_1<int> _ptr__5615(_5615 ? _5615->raw() : nullptr,_5615 ? _5615->size(0) : 0);
      int _11138 = (int)0;
      int _11139 = safe_add( _5524,(int)1 );
      for (int _5616 = _11138; _5616 < _11139; ++_5616)
      {
        {
          _ptr__5615[safe_add( _5614,_5616 )] = (int)0;
        }
      }
      long long _5617 = safe_mul( (long long)_5513,mdim1 );
      int _5618 = safe_mul( _5524,mdim1 );
      int _11140;
      bool _11141 = (_5514 == (int)0);
      if (_11141)
      {
        _11140 = (int)0;
      }
      else
      {
        _11140 = safe_mul( (int)_5617,(int)2 );
      }
      int _5619 = safe_add( safe_mul( _5514,mdim1 ),_11140 );
      bool _5620 = false;
      int _5621 = (int)2;
      if ((!(_5617 <= (int)0x7fffffff)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Maximum number of nonzeros exceeded in multiplication"));
        }
      }
      {}
      _5505->alloc_expr(_5621,_5618,(int)_5617,_5620,_5619);
      std::shared_ptr< monty::ndarray< int,1 > > _5622 = mosek::fusion::p_WorkStack::_get_impl(_5505)->i32;
      _checked_ptr_1<int> _ptr__5622(_5622 ? _5622->raw() : nullptr,_5622 ? _5622->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _5623 = mosek::fusion::p_WorkStack::_get_impl(_5505)->i64;
      _checked_ptr_1<long long> _ptr__5623(_5623 ? _5623->raw() : nullptr,_5623 ? _5623->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5624 = mosek::fusion::p_WorkStack::_get_impl(_5505)->f64;
      _checked_ptr_1<double> _ptr__5624(_5624 ? _5624->raw() : nullptr,_5624 ? _5624->size(0) : 0);
      int _5625 = mosek::fusion::p_WorkStack::_get_impl(_5505)->shape_base;
      int _5626 = mosek::fusion::p_WorkStack::_get_impl(_5505)->ptr_base;
      int _5627 = mosek::fusion::p_WorkStack::_get_impl(_5505)->nidxs_base;
      int _5628 = mosek::fusion::p_WorkStack::_get_impl(_5505)->sp_base;
      int _5629 = mosek::fusion::p_WorkStack::_get_impl(_5505)->cof_base;
      int _5630 = mosek::fusion::p_WorkStack::_get_impl(_5505)->code_base;
      int _5631 = mosek::fusion::p_WorkStack::_get_impl(_5505)->codeptr_base;
      int _5632 = mosek::fusion::p_WorkStack::_get_impl(_5505)->cconst_base;
      _ptr__5622[_5625] = _5524;
      _ptr__5622[safe_add( _5625,(int)1 )] = mdim1;
      int _5633 = (int)0;
      int _5634 = (int)0;
      int _5635 = (int)0;
      _ptr__5622[_5626] = (int)0;
      if ((_5619 > (int)0))
      {
        {
          _ptr__5622[_5631] = (int)0;
        }
      }
      {}
      if (_5515)
      {
        {
          {
            int _11142 = (int)0;
            int _11143 = _5512;
            for (int _5636 = _11142; _5636 < _11143; ++_5636)
            {
              {
                ++ _ptr__5615[safe_add( safe_add( _5614,(_ptr__5509[safe_add( _5518,_5636 )] / _5525) ),(int)1 )];
              }
            }
            int _11144 = (int)0;
            int _11145 = _5524;
            for (int _5637 = _11144; _5637 < _11145; ++_5637)
            {
              {
                _ptr__5615[safe_add( safe_add( _5614,_5637 ),(int)1 )] += _ptr__5615[safe_add( _5614,_5637 )];
              }
            }
            int _11146 = (int)0;
            int _11147 = _5524;
            for (int _5638 = _11146; _5638 < _11147; ++_5638)
            {
              {
                int _11148 = (int)0;
                int _11149 = mdim1;
                for (int _5639 = _11148; _5639 < _11149; ++_5639)
                {
                  {
                    int _11150 = _ptr__5615[safe_add( _5614,_5638 )];
                    int _11151 = _ptr__5615[safe_add( safe_add( _5614,_5638 ),(int)1 )];
                    for (int _5640 = _11150; _5640 < _11151; ++_5640)
                    {
                      {
                        long long _5641 = safe_add( _5639,safe_mul( (_ptr__5509[safe_add( _5518,_5640 )] % _5525),mdim1 ) );
                        int _11152 = _ptr__5508[safe_add( _5516,_5640 )];
                        int _11153 = _ptr__5508[safe_add( safe_add( _5516,_5640 ),(int)1 )];
                        for (int _5642 = _11152; _5642 < _11153; ++_5642)
                        {
                          {
                            _ptr__5623[safe_add( _5627,_5634 )] = _ptr__5509[safe_add( _5519,_5642 )];
                            _ptr__5624[safe_add( _5629,_5634 )] = (_ptr__5510[safe_add( _5520,_5642 )] * ((*mval)(_5641)));
                            if ((_5514 > (int)0))
                            {
                              {
                                int _11154 = _ptr__5508[safe_add( _5521,_5642 )];
                                int _11155 = _ptr__5508[safe_add( safe_add( _5521,_5642 ),(int)1 )];
                                for (int _5643 = _11154; _5643 < _11155; ++_5643)
                                {
                                  {
                                    _ptr__5622[safe_add( _5630,_5633 )] = _ptr__5508[safe_add( _5522,_5643 )];
                                    _ptr__5624[safe_add( _5632,_5633 )] = _ptr__5510[safe_add( _5523,_5643 )];
                                    ++ _5633;
                                  }
                                }
                                _ptr__5622[safe_add( _5630,_5633 )] = 2;
                                _ptr__5624[safe_add( _5632,_5633 )] = ((*mval)(_5641));
                                ++ _5633;
                                _ptr__5622[safe_add( _5630,_5633 )] = 5;
                                ++ _5633;
                                _ptr__5622[safe_add( safe_add( _5631,_5634 ),(int)1 )] = _5633;
                              }
                            }
                            {}
                            ++ _5634;
                          }
                        }
                      }
                    }
                    _ptr__5622[safe_add( safe_add( _5626,_5635 ),(int)1 )] = _5634;
                    ++ _5635;
                  }
                }
              }
            }
          }
          if ((_5634 != _5617))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid num nonzeros"));
            }
          }
          {}
          if ((_5635 != _5618))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid num elements"));
            }
          }
          {}
          if ((_5633 != _5619))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid num code atoms"));
            }
          }
          {}
        }
      }
      else
      {
        {
          int _11156 = (int)0;
          int _11157 = _5524;
          for (int _5644 = _11156; _5644 < _11157; ++_5644)
          {
            {
              int _11158 = (int)0;
              int _11159 = mdim1;
              for (int _5645 = _11158; _5645 < _11159; ++_5645)
              {
                {
                  int _11160 = (int)0;
                  int _11161 = _5525;
                  for (int _5646 = _11160; _5646 < _11161; ++_5646)
                  {
                    {
                      int _5647 = safe_add( safe_mul( _5644,_5525 ),_5646 );
                      int _5648 = safe_add( _5645,safe_mul( _5646,mdim1 ) );
                      int _11162 = _ptr__5508[safe_add( _5516,_5647 )];
                      int _11163 = _ptr__5508[safe_add( safe_add( _5516,_5647 ),(int)1 )];
                      for (int _5649 = _11162; _5649 < _11163; ++_5649)
                      {
                        {
                          _ptr__5623[safe_add( _5627,_5634 )] = _ptr__5509[safe_add( _5519,_5649 )];
                          _ptr__5624[safe_add( _5629,_5634 )] = (_ptr__5510[safe_add( _5520,_5649 )] * ((*mval)(_5648)));
                          if ((_5514 > (int)0))
                          {
                            {
                              int _11164 = _ptr__5508[safe_add( _5521,_5649 )];
                              int _11165 = _ptr__5508[safe_add( safe_add( _5521,_5649 ),(int)1 )];
                              for (int _5650 = _11164; _5650 < _11165; ++_5650)
                              {
                                {
                                  _ptr__5622[safe_add( _5630,_5633 )] = _ptr__5508[safe_add( _5522,_5650 )];
                                  _ptr__5624[safe_add( _5632,_5633 )] = _ptr__5510[safe_add( _5523,_5650 )];
                                  ++ _5633;
                                }
                              }
                              _ptr__5622[safe_add( _5630,_5633 )] = 2;
                              _ptr__5624[safe_add( _5632,_5633 )] = ((*mval)(_5648));
                              ++ _5633;
                              _ptr__5622[safe_add( _5630,_5633 )] = 5;
                              ++ _5633;
                              _ptr__5622[safe_add( safe_add( _5631,_5634 ),(int)1 )] = _5633;
                            }
                          }
                          {}
                          ++ _5634;
                        }
                      }
                    }
                  }
                  _ptr__5622[safe_add( safe_add( _5626,_5635 ),(int)1 )] = _5634;
                  ++ _5635;
                }
              }
            }
          }
        }
      }
      _5507->clear();
    }
  }
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulRight::computeshape(int _5651,std::shared_ptr< monty::ndarray< int,1 > > _5652){
  _checked_ptr_1<int> _ptr__5652(_5652 ? _5652->raw() : nullptr, _5652 ? _5652->size(0) : 0);
  if (((int)((_5652)->size(0)) == (int)1))
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_5651)});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__5652[(int)0]),(int)(_5651)});
    }
  }
}
int mosek::fusion::p_ExprMulRight::validate(int _5653,int _5654,std::shared_ptr< monty::ndarray< int,1 > > _5655,std::shared_ptr< monty::ndarray< int,1 > > _5656,std::shared_ptr< monty::ndarray< double,1 > > _5657,monty::rc_ptr< ::mosek::fusion::Expression > _5658){
  _checked_ptr_1<int> _ptr__5655(_5655 ? _5655->raw() : nullptr, _5655 ? _5655->size(0) : 0);
  _checked_ptr_1<int> _ptr__5656(_5656 ? _5656->raw() : nullptr, _5656 ? _5656->size(0) : 0);
  _checked_ptr_1<double> _ptr__5657(_5657 ? _5657->raw() : nullptr, _5657 ? _5657->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5659 = _5658->getShape();
  _checked_ptr_1<int> _ptr__5659(_5659 ? _5659->raw() : nullptr,_5659 ? _5659->size(0) : 0);
  if (((int)((_5659)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _5660 = _ptr__5659[(int)0];
  int _5661 = _ptr__5659[(int)1];
  if (((_5653 < (int)0) || ((_5654 < (int)0) || ((_5660 < (int)0) || (_5661 < (int)0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_5653 != _5661))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_5655)->size(0)) != (int)((_5656)->size(0))) || ((int)((_5655)->size(0)) != (int)((_5657)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _5662 = (int)((_5655)->size(0));
  {
    bool _5663 = false;
    int _11166 = (int)0;
    int _11167 = _5662;
    for (int _5664 = _11166; _5664 < _11167; ++_5664)
    {
      {
        _5663 = (_5663 || ((_ptr__5655[_5664] < (int)0) || ((_ptr__5655[_5664] >= _5653) || ((_ptr__5656[_5664] < (int)0) || (_ptr__5656[_5664] >= _5654)))));
      }
    }
    if (_5663)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
      }
    }
    {}
  }
  {
    bool _5665 = false;
    int _11168 = (int)0;
    int _11169 = (_5662 - (int)1);
    for (int _5666 = _11168; _5666 < _11169; ++_5666)
    {
      {
        _5665 = (_5665 || ((_ptr__5655[_5666] > _ptr__5655[safe_add( _5666,(int)1 )]) || ((_ptr__5655[_5666] == _ptr__5655[safe_add( _5666,(int)1 )]) && (_ptr__5656[_5666] >= _ptr__5656[safe_add( _5666,(int)1 )]))));
      }
    }
    if (_5665)
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
      }
    }
    {}
  }
  return (int)1;
}
std::string mosek::fusion::ExprMulRight :: toString() { return mosek::fusion::p_ExprMulRight::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulRight::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulRight(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulRight::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulRight::destroy() { mosek::fusion::p_ExprMulRight::_get_impl(this)->destroy(); }mosek::fusion::ExprMulLeft::ExprMulLeft(mosek::fusion::p_ExprMulLeft *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulLeft()" << this << std::endl; */ }mosek::fusion::ExprMulLeft::~ExprMulLeft() {  /* std::cout << "~ExprMulLeft()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulLeft::p_ExprMulLeft  (::mosek::fusion::ExprMulLeft * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _5667,    int _5668,    std::shared_ptr< monty::ndarray< int,1 > > _5669,    std::shared_ptr< monty::ndarray< int,1 > > _5670,    std::shared_ptr< monty::ndarray< double,1 > > _5671,    monty::rc_ptr< ::mosek::fusion::Expression > _5672,    int _5673){ return new mosek::fusion::ExprMulLeft(_5667,_5668,_5669,_5670,_5671,_5672,_5673); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _5667,    int _5668,    std::shared_ptr< monty::ndarray< int,1 > > _5669,    std::shared_ptr< monty::ndarray< int,1 > > _5670,    std::shared_ptr< monty::ndarray< double,1 > > _5671,    monty::rc_ptr< ::mosek::fusion::Expression > _5672,    int _5673) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_5667,_5668,_5669,_5670,_5671,_5672,_5673); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _5667,    int _5668,    std::shared_ptr< monty::ndarray< int,1 > > _5669,    std::shared_ptr< monty::ndarray< int,1 > > _5670,    std::shared_ptr< monty::ndarray< double,1 > > _5671,    monty::rc_ptr< ::mosek::fusion::Expression > _5672,    int _5673){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5669(_5669 ? _5669->raw() : nullptr, _5669 ? _5669->size(0) : 0);
    _checked_ptr_1<int> _ptr__5670(_5670 ? _5670->raw() : nullptr, _5670 ? _5670->size(0) : 0);
    _checked_ptr_1<double> _ptr__5671(_5671 ? _5671->raw() : nullptr, _5671 ? _5671->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulLeft::computeshape(_5667,_5668,_5672->getShape()));
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim0 = _5667;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mdim1 = _5668;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubi = _5669;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->msubj = _5670;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->mval = _5671;
    mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr = _5672;
  }
}mosek::fusion::ExprMulLeft::t mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft  (int _5674,    int _5675,    std::shared_ptr< monty::ndarray< int,1 > > _5676,    std::shared_ptr< monty::ndarray< int,1 > > _5677,    std::shared_ptr< monty::ndarray< double,1 > > _5678,    monty::rc_ptr< ::mosek::fusion::Expression > _5679){ return new mosek::fusion::ExprMulLeft(_5674,_5675,_5676,_5677,_5678,_5679); }mosek::fusion::ExprMulLeft::ExprMulLeft  (int _5674,    int _5675,    std::shared_ptr< monty::ndarray< int,1 > > _5676,    std::shared_ptr< monty::ndarray< int,1 > > _5677,    std::shared_ptr< monty::ndarray< double,1 > > _5678,    monty::rc_ptr< ::mosek::fusion::Expression > _5679) :    ExprMulLeft(new mosek::fusion::p_ExprMulLeft(this)){ mosek::fusion::p_ExprMulLeft::_get_impl(this)->_initialize(_5674,_5675,_5676,_5677,_5678,_5679); }void mosek::fusion::p_ExprMulLeft::_initialize  (int _5674,    int _5675,    std::shared_ptr< monty::ndarray< int,1 > > _5676,    std::shared_ptr< monty::ndarray< int,1 > > _5677,    std::shared_ptr< monty::ndarray< double,1 > > _5678,    monty::rc_ptr< ::mosek::fusion::Expression > _5679){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5676(_5676 ? _5676->raw() : nullptr, _5676 ? _5676->size(0) : 0);
    _checked_ptr_1<int> _ptr__5677(_5677 ? _5677->raw() : nullptr, _5677 ? _5677->size(0) : 0);
    _checked_ptr_1<double> _ptr__5678(_5678 ? _5678->raw() : nullptr, _5678 ? _5678->size(0) : 0);
    mosek::fusion::p_ExprMulLeft::_initialize(_5674,_5675,_5676,_5677,_5678,_5679,::mosek::fusion::p_ExprMulLeft::validate(_5674,_5675,_5676,_5677,_5678,_5679));
  }
}void mosek::fusion::ExprMulLeft :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5680,monty::rc_ptr< ::mosek::fusion::WorkStack > _5681,monty::rc_ptr< ::mosek::fusion::WorkStack > _5682) { mosek::fusion::p_ExprMulLeft::_get_impl(this)->eval(_5680,_5681,_5682); }void mosek::fusion::p_ExprMulLeft::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5680,monty::rc_ptr< ::mosek::fusion::WorkStack > _5681,monty::rc_ptr< ::mosek::fusion::WorkStack > _5682){
  mosek::fusion::p_ExprMulLeft::_get_impl(::mosek::fusion::ExprMulLeft::t(_pubthis))->expr->eval(_5681,_5680,_5682);
  _5681->pop_expr();
  int _5683 = mosek::fusion::p_WorkStack::_get_impl(_5681)->nd;
  int _5684 = mosek::fusion::p_WorkStack::_get_impl(_5681)->nnz;
  int _5685 = mosek::fusion::p_WorkStack::_get_impl(_5681)->nelem;
  int _5686 = mosek::fusion::p_WorkStack::_get_impl(_5681)->ncodeatom;
  bool _5687 = mosek::fusion::p_WorkStack::_get_impl(_5681)->hassp;
  int _5688 = mosek::fusion::p_WorkStack::_get_impl(_5681)->shape_base;
  int _5689 = mosek::fusion::p_WorkStack::_get_impl(_5681)->ptr_base;
  int _5690 = mosek::fusion::p_WorkStack::_get_impl(_5681)->sp_base;
  int _5691 = mosek::fusion::p_WorkStack::_get_impl(_5681)->nidxs_base;
  int _5692 = mosek::fusion::p_WorkStack::_get_impl(_5681)->cof_base;
  int _5693 = mosek::fusion::p_WorkStack::_get_impl(_5681)->codeptr_base;
  int _5694 = mosek::fusion::p_WorkStack::_get_impl(_5681)->code_base;
  int _5695 = mosek::fusion::p_WorkStack::_get_impl(_5681)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5696 = mosek::fusion::p_WorkStack::_get_impl(_5681)->i32;
  _checked_ptr_1<int> _ptr__5696(_5696 ? _5696->raw() : nullptr,_5696 ? _5696->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5697 = mosek::fusion::p_WorkStack::_get_impl(_5681)->i64;
  _checked_ptr_1<long long> _ptr__5697(_5697 ? _5697->raw() : nullptr,_5697 ? _5697->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5698 = mosek::fusion::p_WorkStack::_get_impl(_5681)->f64;
  _checked_ptr_1<double> _ptr__5698(_5698 ? _5698->raw() : nullptr,_5698 ? _5698->size(0) : 0);
  if ((_5683 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operator shape for multiplication"));
    }
  }
  {}
  int _5699 = (int)9999;
  int _5700 = (int)9999;
  int _5701 = (int)9999;
  int _5702 = _ptr__5696[_5688];
  int _5703 = _ptr__5696[safe_add( _5688,(int)1 )];
  int _5704 = (int)((msubi)->size(0));
  bool _5705 = (_5704 < safe_mul( (long long)mdim0,(long long)mdim1 ));
  bool _5706 = false;
  int _5707 = (int)0;
  int _5708 = (int)0;
  long long _5709 = (long long)0;
  if (_5687)
  {
    {
      _5699 = _5682->alloci32(_5685);
      _5700 = _5682->alloci32(_5685);
      _5701 = _5682->alloci32(safe_add( _5703,(int)1 ));
      std::shared_ptr< monty::ndarray< int,1 > > _5710 = mosek::fusion::p_WorkStack::_get_impl(_5682)->i32;
      _checked_ptr_1<int> _ptr__5710(_5710 ? _5710->raw() : nullptr,_5710 ? _5710->size(0) : 0);
      {
        int _11170 = (int)0;
        int _11171 = safe_add( _5703,(int)1 );
        for (int _5711 = _11170; _5711 < _11171; ++_5711)
        {
          {
            _ptr__5710[safe_add( _5701,_5711 )] = (int)0;
          }
        }
        int _11172 = (int)0;
        int _11173 = _5685;
        for (int _5712 = _11172; _5712 < _11173; ++_5712)
        {
          {
            ++ _ptr__5710[safe_add( safe_add( _5701,(_ptr__5697[safe_add( _5690,_5712 )] % _5703) ),(int)1 )];
          }
        }
        int _11174 = (int)0;
        int _11175 = _5703;
        for (int _5713 = _11174; _5713 < _11175; ++_5713)
        {
          {
            _ptr__5710[safe_add( safe_add( _5701,_5713 ),(int)1 )] += _ptr__5710[safe_add( _5701,_5713 )];
          }
        }
        int _11176 = (int)0;
        int _11177 = _5685;
        for (int _5714 = _11176; _5714 < _11177; ++_5714)
        {
          {
            long long _5715 = (_ptr__5697[safe_add( _5690,_5714 )] % _5703);
            _ptr__5710[safe_add( _5699,_ptr__5710[safe_add( _5701,_5715 )] )] = _5714;
            ++ _ptr__5710[safe_add( _5701,_5715 )];
          }
        }
        int _11178 = (int)0;
        int _11179 = _5703;
        for (int _5716 = _11178; _5716 < _11179; ++_5716)
        {
          {
            _ptr__5710[(safe_add( _5701,_5703 ) - _5716)] = _ptr__5710[((safe_add( _5701,_5703 ) - _5716) - (int)1)];
          }
        }
        _ptr__5710[_5701] = (int)0;
      }
      if (_5705)
      {
        {
          int _5717 = (int)0;
          while ( (_5717 < _5704) )
          {
            {
              int _5718 = ((*msubi)(_5717));
              int _5719 = safe_add( _5717,(int)1 );
              while ( ((_5719 < _5704) && (((*msubi)(_5719)) == ((*msubi)(_5717)))) )
              {
                {
                  ++ _5719;
                }
              }
              int _11180 = (int)0;
              int _11181 = _5703;
              for (int _5720 = _11180; _5720 < _11181; ++_5720)
              {
                {
                  bool _5721 = false;
                  int _5722 = _5719;
                  int _5723 = _5717;
                  int _5724 = _ptr__5710[safe_add( safe_add( _5701,_5720 ),(int)1 )];
                  int _5725 = _ptr__5710[safe_add( _5701,_5720 )];
                  while ( ((_5723 < _5722) && (_5725 < _5724)) )
                  {
                    {
                      int _5726 = _ptr__5710[safe_add( _5699,_5725 )];
                      if ((((*msubj)(_5723)) < (_ptr__5697[safe_add( _5690,_5726 )] / _5703)))
                      {
                        {
                          ++ _5723;
                        }
                      }
                      else if((((*msubj)(_5723)) > (_ptr__5697[safe_add( _5690,_5726 )] / _5703)))
                      {
                        {
                          ++ _5725;
                        }
                      }
                      else
                      {
                        {
                          _5721 = true;
                          _5709 += (_ptr__5696[safe_add( safe_add( _5689,_5726 ),(int)1 )] - _ptr__5696[safe_add( _5689,_5726 )]);
                          if ((_5686 > (int)0))
                          {
                            {
                              _5707 += safe_add( (_ptr__5696[safe_add( _5693,_ptr__5696[safe_add( safe_add( _5689,_5726 ),(int)1 )] )] - _ptr__5696[safe_add( _5693,_ptr__5696[safe_add( _5689,_5726 )] )]),safe_mul( (int)2,(_ptr__5696[safe_add( safe_add( _5689,_5726 ),(int)1 )] - _ptr__5696[safe_add( _5689,_5726 )]) ) );
                            }
                          }
                          {}
                          ++ _5725;
                          ++ _5723;
                        }
                      }
                    }
                  }
                  if (_5721)
                  {
                    {
                      ++ _5708;
                    }
                  }
                  {}
                }
              }
              _5717 = _5719;
            }
          }
        }
      }
      else
      {
        {
          _5708 = safe_mul( mdim0,_5703 );
          _5709 = safe_mul( (long long)_5684,mdim0 );
          if ((_5686 > (int)0))
          {
            {
              _5707 = (int)safe_add( safe_mul( _5686,mdim0 ),safe_mul( (int)2,_5709 ) );
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      if (_5705)
      {
        {
          int _5727 = (int)0;
          while ( (_5727 < _5704) )
          {
            {
              int _5728 = safe_add( _5727,(int)1 );
              while ( ((_5728 < _5704) && (((*msubi)(_5727)) == ((*msubi)(_5728)))) )
              {
                {
                  ++ _5728;
                }
              }
              int _5729 = ((*msubi)(_5727));
              int _11182 = (int)0;
              int _11183 = _5703;
              for (int _5730 = _11182; _5730 < _11183; ++_5730)
              {
                {
                  bool _5731 = false;
                  int _11184 = _5727;
                  int _11185 = _5728;
                  for (int _5732 = _11184; _5732 < _11185; ++_5732)
                  {
                    {
                      int _5733 = safe_add( safe_mul( ((*msubj)(_5732)),_5703 ),_5730 );
                      _5709 += (_ptr__5696[safe_add( safe_add( _5689,_5733 ),(int)1 )] - _ptr__5696[safe_add( _5689,_5733 )]);
                      if ((_5686 > (int)0))
                      {
                        {
                          _5707 += safe_add( (_ptr__5696[safe_add( _5693,_ptr__5696[safe_add( safe_add( _5689,_5733 ),(int)1 )] )] - _ptr__5696[safe_add( _5693,_ptr__5696[safe_add( _5689,_5733 )] )]),safe_mul( (int)2,(_ptr__5696[safe_add( safe_add( _5689,_5733 ),(int)1 )] - _ptr__5696[safe_add( _5689,_5733 )]) ) );
                        }
                      }
                      {}
                      _5731 = true;
                    }
                  }
                  if (_5731)
                  {
                    {
                      ++ _5708;
                    }
                  }
                  {}
                }
              }
              _5727 = _5728;
            }
          }
        }
      }
      else
      {
        {
          _5709 = safe_mul( (long long)_5684,mdim0 );
          if ((_5686 > (int)0))
          {
            {
              _5707 = (int)safe_add( safe_mul( _5686,mdim0 ),safe_mul( (int)2,_5709 ) );
            }
          }
          {}
          _5708 = safe_mul( mdim0,_5703 );
        }
      }
    }
  }
  if ((!(_5709 <= (int)0x7fffffff)))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Maximum number of nonzeros exceeded in multiplication"));
    }
  }
  {}
  _5706 = (_5708 < safe_mul( mdim0,_5703 ));
  int _5734 = (int)2;
  _5680->alloc_expr(_5734,_5708,(int)_5709,_5706,_5707);
  int _5735 = mosek::fusion::p_WorkStack::_get_impl(_5680)->ptr_base;
  int _5736 = mosek::fusion::p_WorkStack::_get_impl(_5680)->nidxs_base;
  int _11186;
  bool _11187 = _5706;
  if (_11187)
  {
    _11186 = mosek::fusion::p_WorkStack::_get_impl(_5680)->sp_base;
  }
  else
  {
    _11186 = _5680->alloci64(_5708);
  }
  int _5737 = _11186;
  int _5738 = mosek::fusion::p_WorkStack::_get_impl(_5680)->cof_base;
  int _5739 = mosek::fusion::p_WorkStack::_get_impl(_5680)->shape_base;
  int _5740 = mosek::fusion::p_WorkStack::_get_impl(_5680)->code_base;
  int _5741 = mosek::fusion::p_WorkStack::_get_impl(_5680)->codeptr_base;
  int _5742 = mosek::fusion::p_WorkStack::_get_impl(_5680)->cconst_base;
  std::shared_ptr< monty::ndarray< long long,1 > > _5743 = mosek::fusion::p_WorkStack::_get_impl(_5680)->i64;
  _checked_ptr_1<long long> _ptr__5743(_5743 ? _5743->raw() : nullptr,_5743 ? _5743->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5744 = mosek::fusion::p_WorkStack::_get_impl(_5680)->f64;
  _checked_ptr_1<double> _ptr__5744(_5744 ? _5744->raw() : nullptr,_5744 ? _5744->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5745 = mosek::fusion::p_WorkStack::_get_impl(_5680)->i32;
  _checked_ptr_1<int> _ptr__5745(_5745 ? _5745->raw() : nullptr,_5745 ? _5745->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5746 = mosek::fusion::p_WorkStack::_get_impl(_5682)->i32;
  _checked_ptr_1<int> _ptr__5746(_5746 ? _5746->raw() : nullptr,_5746 ? _5746->size(0) : 0);
  _ptr__5745[_5739] = mdim0;
  _ptr__5745[safe_add( _5739,(int)1 )] = _5703;
  _ptr__5745[_5735] = (int)0;
  if ((_5707 > (int)0))
  {
    {
      _ptr__5745[_5741] = (int)0;
    }
  }
  {}
  if (_5687)
  {
    {
      if (_5705)
      {
        {
          int _5747 = (int)0;
          int _5748 = (int)0;
          int _5749 = (int)0;
          int _5750 = (int)0;
          while ( (_5750 < _5704) )
          {
            {
              int _5751 = ((*msubi)(_5750));
              int _5752 = safe_add( _5750,(int)1 );
              while ( ((_5752 < _5704) && (((*msubi)(_5752)) == ((*msubi)(_5750)))) )
              {
                {
                  ++ _5752;
                }
              }
              int _11188 = (int)0;
              int _11189 = _5703;
              for (int _5753 = _11188; _5753 < _11189; ++_5753)
              {
                {
                  bool _5754 = false;
                  int _5755 = _5752;
                  int _5756 = _5750;
                  int _5757 = _ptr__5746[safe_add( safe_add( _5701,_5753 ),(int)1 )];
                  int _5758 = _ptr__5746[safe_add( _5701,_5753 )];
                  while ( ((_5756 < _5755) && (_5758 < _5757)) )
                  {
                    {
                      int _5759 = _ptr__5746[safe_add( _5699,_5758 )];
                      if ((((*msubj)(_5756)) < (_ptr__5697[safe_add( _5690,_5759 )] / _5703)))
                      {
                        {
                          ++ _5756;
                        }
                      }
                      else if((((*msubj)(_5756)) > (_ptr__5697[safe_add( _5690,_5759 )] / _5703)))
                      {
                        {
                          ++ _5758;
                        }
                      }
                      else
                      {
                        {
                          _5754 = true;
                          int _11190 = _ptr__5696[safe_add( _5689,_5759 )];
                          int _11191 = _ptr__5696[safe_add( safe_add( _5689,_5759 ),(int)1 )];
                          for (int _5760 = _11190; _5760 < _11191; ++_5760)
                          {
                            {
                              _ptr__5743[safe_add( _5736,_5749 )] = _ptr__5697[safe_add( _5691,_5760 )];
                              _ptr__5744[safe_add( _5738,_5749 )] = (_ptr__5698[safe_add( _5692,_5760 )] * ((*mval)(_5756)));
                              if ((_5707 > (int)0))
                              {
                                {
                                  int _11192 = _ptr__5696[safe_add( _5693,_5760 )];
                                  int _11193 = _ptr__5696[safe_add( safe_add( _5693,_5760 ),(int)1 )];
                                  for (int _5761 = _11192; _5761 < _11193; ++_5761)
                                  {
                                    {
                                      _ptr__5745[safe_add( _5740,_5747 )] = _ptr__5696[safe_add( _5694,_5761 )];
                                      _ptr__5744[safe_add( _5742,_5747 )] = _ptr__5744[safe_add( _5695,_5761 )];
                                      ++ _5747;
                                    }
                                  }
                                  _ptr__5745[safe_add( _5740,_5747 )] = 2;
                                  _ptr__5744[safe_add( _5742,_5747 )] = ((*mval)(_5756));
                                  ++ _5747;
                                  _ptr__5745[safe_add( _5740,_5747 )] = 5;
                                  _ptr__5745[safe_add( safe_add( _5741,_5749 ),(int)1 )] = _5747;
                                }
                              }
                              {}
                              ++ _5749;
                            }
                          }
                          ++ _5756;
                          ++ _5758;
                        }
                      }
                    }
                  }
                  if (_5754)
                  {
                    {
                      _ptr__5745[safe_add( safe_add( _5735,_5748 ),(int)1 )] = _5749;
                      _ptr__5743[safe_add( _5737,_5748 )] = safe_add( safe_mul( _5751,_5703 ),_5753 );
                      ++ _5748;
                    }
                  }
                  {}
                }
              }
              _5750 = _5752;
            }
          }
        }
      }
      else
      {
        {
          int _5762 = (int)0;
          int _5763 = (int)0;
          int _5764 = (int)0;
          int _11194 = (int)0;
          int _11195 = mdim0;
          for (int _5765 = _11194; _5765 < _11195; ++_5765)
          {
            {
              int _11196 = (int)0;
              int _11197 = _5703;
              for (int _5766 = _11196; _5766 < _11197; ++_5766)
              {
                {
                  int _11198 = _ptr__5746[safe_add( _5701,_5766 )];
                  int _11199 = _ptr__5746[safe_add( safe_add( _5701,_5766 ),(int)1 )];
                  for (int _5767 = _11198; _5767 < _11199; ++_5767)
                  {
                    {
                      int _5768 = _ptr__5746[safe_add( _5699,_5767 )];
                      long long _5769 = safe_add( safe_mul( _5765,mdim1 ),(_ptr__5697[safe_add( _5690,_5768 )] / _5703) );
                      int _11200 = _ptr__5696[safe_add( _5689,_5768 )];
                      int _11201 = _ptr__5696[safe_add( safe_add( _5689,_5768 ),(int)1 )];
                      for (int _5770 = _11200; _5770 < _11201; ++_5770)
                      {
                        {
                          _ptr__5743[safe_add( _5736,_5764 )] = _ptr__5697[safe_add( _5691,_5770 )];
                          _ptr__5744[safe_add( _5738,_5764 )] = (_ptr__5698[safe_add( _5692,_5770 )] * ((*mval)(_5769)));
                          if ((_5707 > (int)0))
                          {
                            {
                              int _11202 = _ptr__5696[safe_add( _5693,_5770 )];
                              int _11203 = _ptr__5696[safe_add( safe_add( _5693,_5770 ),(int)1 )];
                              for (int _5771 = _11202; _5771 < _11203; ++_5771)
                              {
                                {
                                  _ptr__5745[safe_add( _5740,_5762 )] = _ptr__5696[safe_add( _5694,_5771 )];
                                  _ptr__5744[safe_add( _5742,_5762 )] = _ptr__5698[safe_add( _5695,_5771 )];
                                  ++ _5762;
                                }
                              }
                              _ptr__5745[safe_add( _5740,_5762 )] = 2;
                              _ptr__5744[safe_add( _5742,_5762 )] = ((*mval)(_5769));
                              ++ _5762;
                              _ptr__5745[safe_add( _5740,_5762 )] = 5;
                              ++ _5762;
                              _ptr__5745[safe_add( safe_add( _5741,_5764 ),(int)1 )] = _5762;
                            }
                          }
                          {}
                          ++ _5764;
                        }
                      }
                    }
                  }
                  _ptr__5745[safe_add( safe_add( _5735,_5763 ),(int)1 )] = _5764;
                  ++ _5763;
                }
              }
            }
          }
          if ((_5763 != _5708))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of elements"));
            }
          }
          {}
          if ((_5764 != _5709))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of non-zeros"));
            }
          }
          {}
          if ((_5762 != _5707))
          {
            {
              throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of code atoms"));
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      int _5772 = (int)0;
      int _5773 = (int)0;
      int _5774 = (int)0;
      int _5775 = (int)0;
      while ( (_5773 < _5704) )
      {
        {
          int _5776 = safe_add( _5773,(int)1 );
          while ( ((_5776 < _5704) && (((*msubi)(_5773)) == ((*msubi)(_5776)))) )
          {
            {
              ++ _5776;
            }
          }
          int _5777 = ((*msubi)(_5773));
          int _11204 = (int)0;
          int _11205 = _5703;
          for (int _5778 = _11204; _5778 < _11205; ++_5778)
          {
            {
              bool _5779 = false;
              int _11206 = _5773;
              int _11207 = _5776;
              for (int _5780 = _11206; _5780 < _11207; ++_5780)
              {
                {
                  int _5781 = safe_add( safe_mul( ((*msubj)(_5780)),_5703 ),_5778 );
                  int _11208 = _ptr__5696[safe_add( _5689,_5781 )];
                  int _11209 = _ptr__5696[safe_add( safe_add( _5689,_5781 ),(int)1 )];
                  for (int _5782 = _11208; _5782 < _11209; ++_5782)
                  {
                    {
                      _ptr__5743[safe_add( _5736,_5775 )] = _ptr__5697[safe_add( _5691,_5782 )];
                      _ptr__5744[safe_add( _5738,_5775 )] = (_ptr__5698[safe_add( _5692,_5782 )] * ((*mval)(_5780)));
                      if ((_5707 > (int)0))
                      {
                        {
                          int _11210 = _ptr__5696[safe_add( _5693,_5782 )];
                          int _11211 = _ptr__5696[safe_add( safe_add( _5693,_5782 ),(int)1 )];
                          for (int _5783 = _11210; _5783 < _11211; ++_5783)
                          {
                            {
                              _ptr__5745[safe_add( _5740,_5772 )] = _ptr__5696[safe_add( _5694,_5783 )];
                              _ptr__5744[safe_add( _5742,_5772 )] = _ptr__5698[safe_add( _5695,_5783 )];
                              ++ _5772;
                            }
                          }
                          _ptr__5745[safe_add( _5740,_5772 )] = 2;
                          _ptr__5744[safe_add( _5742,_5772 )] = ((*mval)(_5780));
                          ++ _5772;
                          _ptr__5745[safe_add( _5740,_5772 )] = 5;
                          ++ _5772;
                          _ptr__5745[safe_add( safe_add( _5741,_5775 ),(int)1 )] = _5772;
                        }
                      }
                      {}
                      ++ _5775;
                    }
                  }
                  _5779 = true;
                }
              }
              if (_5779)
              {
                {
                  _ptr__5743[safe_add( _5737,_5774 )] = safe_add( safe_mul( _5777,_5703 ),_5778 );
                  _ptr__5745[safe_add( safe_add( _5735,_5774 ),(int)1 )] = _5775;
                  ++ _5774;
                }
              }
              {}
            }
          }
          _5773 = _5776;
        }
      }
      if ((_5774 != _5708))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of elements"));
        }
      }
      {}
      if ((_5775 != _5709))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of non-zeros"));
        }
      }
      {}
      if ((_5772 != _5707))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Incorrect number of code atoms"));
        }
      }
      {}
    }
  }
  if ((!_5706))
  {
    {
      _5680->popi64(_5708);
    }
  }
  {}
  _5682->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulLeft::computeshape(int _5784,int _5785,std::shared_ptr< monty::ndarray< int,1 > > _5786){
  _checked_ptr_1<int> _ptr__5786(_5786 ? _5786->raw() : nullptr, _5786 ? _5786->size(0) : 0);
  if (((int)((_5786)->size(0)) != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  else if((_5785 != _ptr__5786[(int)0]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_5784),(int)(_ptr__5786[(int)1])});
}
int mosek::fusion::p_ExprMulLeft::validate(int _5787,int _5788,std::shared_ptr< monty::ndarray< int,1 > > _5789,std::shared_ptr< monty::ndarray< int,1 > > _5790,std::shared_ptr< monty::ndarray< double,1 > > _5791,monty::rc_ptr< ::mosek::fusion::Expression > _5792){
  _checked_ptr_1<int> _ptr__5789(_5789 ? _5789->raw() : nullptr, _5789 ? _5789->size(0) : 0);
  _checked_ptr_1<int> _ptr__5790(_5790 ? _5790->raw() : nullptr, _5790 ? _5790->size(0) : 0);
  _checked_ptr_1<double> _ptr__5791(_5791 ? _5791->raw() : nullptr, _5791 ? _5791->size(0) : 0);
  if ((_5792->getND() != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  int _5793 = _5792->getDim((int)0);
  int _5794 = _5792->getDim((int)0);
  if (((_5787 < (int)0) || (_5788 < (int)0)))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  {}
  if ((_5788 != _5793))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
    }
  }
  {}
  if ((((int)((_5789)->size(0)) != (int)((_5790)->size(0))) || ((int)((_5789)->size(0)) != (int)((_5791)->size(0)))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  int _5795 = (int)((_5789)->size(0));
  bool _5796 = false;
  bool _5797 = false;
  {
    int _11212 = (int)0;
    int _11213 = _5795;
    for (int _5798 = _11212; _5798 < _11213; ++_5798)
    {
      {
        _5796 = (_5796 || ((_ptr__5789[_5798] < (int)0) || ((_ptr__5789[_5798] >= _5787) || ((_ptr__5790[_5798] < (int)0) || (_ptr__5790[_5798] >= _5788)))));
      }
    }
    if ((!_5796))
    {
      {
        int _11214 = (int)0;
        int _11215 = (_5795 - (int)1);
        for (int _5799 = _11214; _5799 < _11215; ++_5799)
        {
          {
            _5797 = (_5797 || ((_ptr__5789[_5799] > _ptr__5789[safe_add( _5799,(int)1 )]) || ((_ptr__5789[_5799] == _ptr__5789[safe_add( _5799,(int)1 )]) && (_ptr__5790[_5799] >= _ptr__5790[safe_add( _5799,(int)1 )]))));
          }
        }
      }
    }
    {}
  }
  if (_5796)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Invalid matrix data"));
    }
  }
  {}
  if (_5797)
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Unsorted matrix data"));
    }
  }
  {}
  return (int)1;
}
std::string mosek::fusion::ExprMulLeft :: toString() { return mosek::fusion::p_ExprMulLeft::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulLeft::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulLeft(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulLeft::destroy(){expr.reset();mval.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulLeft::destroy() { mosek::fusion::p_ExprMulLeft::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVar::ExprMulVar(mosek::fusion::p_ExprMulVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVar()" << this << std::endl; */ }mosek::fusion::ExprMulVar::~ExprMulVar() {  /* std::cout << "~ExprMulVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVar::p_ExprMulVar  (::mosek::fusion::ExprMulVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _5800,    int _5801,    int _5802,    std::shared_ptr< monty::ndarray< int,1 > > _5803,    std::shared_ptr< monty::ndarray< int,1 > > _5804,    std::shared_ptr< monty::ndarray< double,1 > > _5805,    monty::rc_ptr< ::mosek::fusion::Variable > _5806){ return new mosek::fusion::ExprMulVar(_5800,_5801,_5802,_5803,_5804,_5805,_5806); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _5800,    int _5801,    int _5802,    std::shared_ptr< monty::ndarray< int,1 > > _5803,    std::shared_ptr< monty::ndarray< int,1 > > _5804,    std::shared_ptr< monty::ndarray< double,1 > > _5805,    monty::rc_ptr< ::mosek::fusion::Variable > _5806) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_5800,_5801,_5802,_5803,_5804,_5805,_5806); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _5800,    int _5801,    int _5802,    std::shared_ptr< monty::ndarray< int,1 > > _5803,    std::shared_ptr< monty::ndarray< int,1 > > _5804,    std::shared_ptr< monty::ndarray< double,1 > > _5805,    monty::rc_ptr< ::mosek::fusion::Variable > _5806){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5803(_5803 ? _5803->raw() : nullptr, _5803 ? _5803->size(0) : 0);
    _checked_ptr_1<int> _ptr__5804(_5804 ? _5804->raw() : nullptr, _5804 ? _5804->size(0) : 0);
    _checked_ptr_1<double> _ptr__5805(_5805 ? _5805->raw() : nullptr, _5805 ? _5805->size(0) : 0);
    mosek::fusion::p_ExprMulVar::_initialize(_5800,_5801,_5802,_5803,_5804,_5805,_5806,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _5807 = _5806->getShape();
    _checked_ptr_1<int> _ptr__5807(_5807 ? _5807->raw() : nullptr,_5807 ? _5807->size(0) : 0);
    int _5808 = (int)((_5807)->size(0));
    if ((_5808 != (int)2))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if((_5800 && (_ptr__5807[(int)0] != _5802)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    else if(((!_5800) && (_ptr__5807[(int)1] != _5801)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
      }
    }
    {}
    if ((((int)((_5803)->size(0)) != (int)((_5804)->size(0))) || ((int)((_5803)->size(0)) != (int)((_5805)->size(0)))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching matrix data lengths"));
      }
    }
    {}
    validate(_5801,_5802,_5803,_5804,_5805);
  }
}mosek::fusion::ExprMulVar::t mosek::fusion::p_ExprMulVar::_new_ExprMulVar  (bool _5809,    int _5810,    int _5811,    std::shared_ptr< monty::ndarray< int,1 > > _5812,    std::shared_ptr< monty::ndarray< int,1 > > _5813,    std::shared_ptr< monty::ndarray< double,1 > > _5814,    monty::rc_ptr< ::mosek::fusion::Variable > _5815,    int _5816){ return new mosek::fusion::ExprMulVar(_5809,_5810,_5811,_5812,_5813,_5814,_5815,_5816); }mosek::fusion::ExprMulVar::ExprMulVar  (bool _5809,    int _5810,    int _5811,    std::shared_ptr< monty::ndarray< int,1 > > _5812,    std::shared_ptr< monty::ndarray< int,1 > > _5813,    std::shared_ptr< monty::ndarray< double,1 > > _5814,    monty::rc_ptr< ::mosek::fusion::Variable > _5815,    int _5816) :    ExprMulVar(new mosek::fusion::p_ExprMulVar(this)){ mosek::fusion::p_ExprMulVar::_get_impl(this)->_initialize(_5809,_5810,_5811,_5812,_5813,_5814,_5815,_5816); }void mosek::fusion::p_ExprMulVar::_initialize  (bool _5809,    int _5810,    int _5811,    std::shared_ptr< monty::ndarray< int,1 > > _5812,    std::shared_ptr< monty::ndarray< int,1 > > _5813,    std::shared_ptr< monty::ndarray< double,1 > > _5814,    monty::rc_ptr< ::mosek::fusion::Variable > _5815,    int _5816){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__5812(_5812 ? _5812->raw() : nullptr, _5812 ? _5812->size(0) : 0);
    _checked_ptr_1<int> _ptr__5813(_5813 ? _5813->raw() : nullptr, _5813 ? _5813->size(0) : 0);
    _checked_ptr_1<double> _ptr__5814(_5814 ? _5814->raw() : nullptr, _5814 ? _5814->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprMulVar::resshape(_5810,_5811,_5815->getShape(),_5809));
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->left = _5809;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->x = _5815;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi = _5810;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj = _5811;
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi = ::mosek::fusion::Utils::Tools::arraycopy(_5812);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj = ::mosek::fusion::Utils::Tools::arraycopy(_5813);
    mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof = ::mosek::fusion::Utils::Tools::arraycopy(_5814);
  }
}void mosek::fusion::ExprMulVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5817,monty::rc_ptr< ::mosek::fusion::WorkStack > _5818,monty::rc_ptr< ::mosek::fusion::WorkStack > _5819) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval(_5817,_5818,_5819); }void mosek::fusion::p_ExprMulVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5817,monty::rc_ptr< ::mosek::fusion::WorkStack > _5818,monty::rc_ptr< ::mosek::fusion::WorkStack > _5819){
  if (left)
  {
    {
      _pubthis->eval_left(_5817,_5818,_5819);
    }
  }
  else
  {
    {
      _pubthis->eval_right(_5817,_5818,_5819);
    }
  }
}
void mosek::fusion::ExprMulVar :: eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _5820,monty::rc_ptr< ::mosek::fusion::WorkStack > _5821,monty::rc_ptr< ::mosek::fusion::WorkStack > _5822) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_right(_5820,_5821,_5822); }void mosek::fusion::p_ExprMulVar::eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _5820,monty::rc_ptr< ::mosek::fusion::WorkStack > _5821,monty::rc_ptr< ::mosek::fusion::WorkStack > _5822){
  int _5823 = mosek::fusion::p_WorkStack::_get_impl(_5821)->pi32;
  int _5824 = mosek::fusion::p_WorkStack::_get_impl(_5821)->pi64;
  int _5825 = x->numInst();
  int _5826 = _5821->alloci64(_5825);
  int _5827 = _5821->alloci64(_5825);
  int _5828 = _5821->alloci32(_5825);
  int _5829 = _5821->alloci32(_5825);
  std::shared_ptr< monty::ndarray< int,1 > > _5830 = x->getShape();
  _checked_ptr_1<int> _ptr__5830(_5830 ? _5830->raw() : nullptr,_5830 ? _5830->size(0) : 0);
  int _5831 = (int)((_5830)->size(0));
  long long _5832 = safe_mul( _ptr__5830[(int)0],_ptr__5830[(int)1] );
  int _5833 = _ptr__5830[(int)1];
  int _5834 = _ptr__5830[(int)0];
  int _5835 = _5821->alloci32(safe_add( _5834,(int)1 ));
  int _5836 = (int)((mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi)->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _5837 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__5837(_5837 ? _5837->raw() : nullptr,_5837 ? _5837->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5838 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__5838(_5838 ? _5838->raw() : nullptr,_5838 ? _5838->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5839 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__5839(_5839 ? _5839->raw() : nullptr,_5839 ? _5839->size(0) : 0);
  int _5840 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _5841 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  bool _5842 = ((_5836 / _5840) == _5841);
  int _5843 = _5821->alloci32(_5836);
  int _5844 = _5821->alloci32(safe_add( mdimj,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _5845 = mosek::fusion::p_WorkStack::_get_impl(_5821)->i32;
  _checked_ptr_1<int> _ptr__5845(_5845 ? _5845->raw() : nullptr,_5845 ? _5845->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5846 = mosek::fusion::p_WorkStack::_get_impl(_5821)->i64;
  _checked_ptr_1<long long> _ptr__5846(_5846 ? _5846->raw() : nullptr,_5846 ? _5846->size(0) : 0);
  int _5847 = (int)0;
  int _5848 = (int)0;
  x->inst(_5827,_5846,_5826,_5846);
  if (_5842)
  {
    {
      int _5849 = (int)0;
      if ((_5825 > (int)0))
      {
        {
          _5849 = (int)1;
          if ((_5834 > (int)1))
          {
            {
              if ((_5833 == (int)1))
              {
                {
                  int _11216 = (int)1;
                  int _11217 = _5825;
                  for (int _5850 = _11216; _5850 < _11217; ++_5850)
                  {
                    {
                      if ((_ptr__5846[safe_add( _5827,_5850 )] > _ptr__5846[(safe_add( _5827,_5850 ) - (int)1)]))
                      {
                        {
                          ++ _5849;
                        }
                      }
                      {}
                    }
                  }
                }
              }
              else
              {
                {
                  int _11218 = (int)1;
                  int _11219 = _5825;
                  for (int _5851 = _11218; _5851 < _11219; ++_5851)
                  {
                    {
                      if (((_ptr__5846[safe_add( _5827,_5851 )] / _5833) > (_ptr__5846[(safe_add( _5827,_5851 ) - (int)1)] / _5833)))
                      {
                        {
                          ++ _5849;
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
          {}
        }
      }
      {}
      _5848 = safe_mul( _5849,_5841 );
      _5847 = safe_mul( _5825,_5841 );
      bool _5852 = (_5849 < _5834);
      _5820->alloc_expr((int)2,_5848,_5847,_5852);
      int _5853 = mosek::fusion::p_WorkStack::_get_impl(_5820)->ptr_base;
      int _5854 = mosek::fusion::p_WorkStack::_get_impl(_5820)->shape_base;
      int _5855 = mosek::fusion::p_WorkStack::_get_impl(_5820)->nidxs_base;
      int _11220;
      bool _11221 = _5852;
      if (_11221)
      {
        _11220 = mosek::fusion::p_WorkStack::_get_impl(_5820)->sp_base;
      }
      else
      {
        _11220 = _5820->alloci64(_5848);
      }
      int _5856 = _11220;
      int _5857 = mosek::fusion::p_WorkStack::_get_impl(_5820)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _5858 = mosek::fusion::p_WorkStack::_get_impl(_5820)->i32;
      _checked_ptr_1<int> _ptr__5858(_5858 ? _5858->raw() : nullptr,_5858 ? _5858->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _5859 = mosek::fusion::p_WorkStack::_get_impl(_5820)->i64;
      _checked_ptr_1<long long> _ptr__5859(_5859 ? _5859->raw() : nullptr,_5859 ? _5859->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _5860 = mosek::fusion::p_WorkStack::_get_impl(_5820)->f64;
      _checked_ptr_1<double> _ptr__5860(_5860 ? _5860->raw() : nullptr,_5860 ? _5860->size(0) : 0);
      _ptr__5858[_5854] = _5834;
      _ptr__5858[safe_add( _5854,(int)1 )] = _5841;
      {
        int _5861 = (int)0;
        int _5862 = (int)0;
        int _5863 = (int)0;
        _ptr__5858[_5853] = (int)0;
        while ( (_5861 < _5825) )
        {
          {
            int _5864 = _5861;
            ++ _5861;
            while ( ((_5861 < _5825) && ((_ptr__5846[safe_add( _5827,_5861 )] / _5833) == (_ptr__5846[safe_add( _5827,_5864 )] / _5833))) )
            {
              {
                ++ _5861;
              }
            }
            long long _5865 = (_ptr__5846[safe_add( _5827,_5864 )] / _5833);
            int _11222 = (int)0;
            int _11223 = _5841;
            for (int _5866 = _11222; _5866 < _11223; ++_5866)
            {
              {
                int _11224 = _5864;
                int _11225 = _5861;
                for (int _5867 = _11224; _5867 < _11225; ++_5867)
                {
                  {
                    long long _5868 = (_ptr__5846[safe_add( _5827,_5867 )] % _5833);
                    _ptr__5859[safe_add( _5855,_5863 )] = _ptr__5846[safe_add( _5826,_5867 )];
                    _ptr__5860[safe_add( _5857,_5863 )] = _ptr__5839[safe_add( safe_mul( _5868,_5841 ),_5866 )];
                    ++ _5863;
                  }
                }
                _ptr__5858[safe_add( safe_add( _5853,_5862 ),(int)1 )] = _5863;
                _ptr__5859[safe_add( _5856,_5862 )] = safe_add( safe_mul( _5865,_5841 ),_5866 );
                ++ _5862;
              }
            }
          }
        }
      }
      if ((!_5852))
      {
        {
          _5820->popi64(_5848);
        }
      }
      {}
    }
  }
  else
  {
    {
      {
        if ((_5841 == (int)1))
        {
          {
            int _11226 = (int)0;
            int _11227 = _5836;
            for (int _5869 = _11226; _5869 < _11227; ++_5869)
            {
              {
                _ptr__5845[safe_add( _5843,_5869 )] = _5869;
              }
            }
            _ptr__5845[_5844] = (int)0;
            _ptr__5845[safe_add( _5844,(int)1 )] = _5836;
          }
        }
        else
        {
          {
            _ptr__5845[_5844] = (int)0;
            int _11228 = (int)0;
            int _11229 = safe_add( _5841,(int)1 );
            for (int _5870 = _11228; _5870 < _11229; ++_5870)
            {
              {
                _ptr__5845[safe_add( _5844,_5870 )] = (int)0;
              }
            }
            int _11230 = (int)0;
            int _11231 = _5836;
            for (int _5871 = _11230; _5871 < _11231; ++_5871)
            {
              {
                ++ _ptr__5845[safe_add( safe_add( _5844,_ptr__5838[_5871] ),(int)1 )];
              }
            }
            int _11232 = (int)0;
            int _11233 = mdimj;
            for (int _5872 = _11232; _5872 < _11233; ++_5872)
            {
              {
                _ptr__5845[safe_add( safe_add( _5844,_5872 ),(int)1 )] += _ptr__5845[safe_add( _5844,_5872 )];
              }
            }
            int _11234 = (int)0;
            int _11235 = _5836;
            for (int _5873 = _11234; _5873 < _11235; ++_5873)
            {
              {
                _ptr__5845[safe_add( _5843,_ptr__5845[safe_add( _5844,_ptr__5838[_5873] )] )] = _5873;
                ++ _ptr__5845[safe_add( _5844,_ptr__5838[_5873] )];
              }
            }
            int _11236 = (int)0;
            int _11237 = _5841;
            for (int _5874 = _11236; _5874 < _11237; ++_5874)
            {
              {
                _ptr__5845[(safe_add( _5844,_5841 ) - _5874)] = _ptr__5845[((safe_add( _5844,_5841 ) - _5874) - (int)1)];
              }
            }
            _ptr__5845[_5844] = (int)0;
          }
        }
      }
      if (((_5825 / _5834) == _5833))
      {
        {
          int _5875 = (int)0;
          {
            int _5876 = (int)0;
            while ( (_5876 < _5836) )
            {
              {
                ++ _5876;
                while ( ((_5876 < _5836) && (_ptr__5838[_ptr__5845[(safe_add( _5843,_5876 ) - (int)1)]] == _ptr__5838[_ptr__5845[safe_add( _5843,_5876 )]])) )
                {
                  {
                    ++ _5876;
                  }
                }
                ++ _5875;
              }
            }
          }
          _5848 = safe_mul( _5875,_5834 );
          _5847 = safe_mul( _5836,_5834 );
          bool _5877 = (_5875 < _5841);
          _5820->alloc_expr((int)2,_5848,_5847,_5877);
          int _5878 = mosek::fusion::p_WorkStack::_get_impl(_5820)->ptr_base;
          int _5879 = mosek::fusion::p_WorkStack::_get_impl(_5820)->shape_base;
          int _5880 = mosek::fusion::p_WorkStack::_get_impl(_5820)->nidxs_base;
          int _11238;
          bool _11239 = _5877;
          if (_11239)
          {
            _11238 = mosek::fusion::p_WorkStack::_get_impl(_5820)->sp_base;
          }
          else
          {
            _11238 = _5820->alloci64(_5848);
          }
          int _5881 = _11238;
          int _5882 = mosek::fusion::p_WorkStack::_get_impl(_5820)->cof_base;
          ((*mosek::fusion::p_WorkStack::_get_impl(_5820)->i32)(_5879)) = _5834;
          ((*mosek::fusion::p_WorkStack::_get_impl(_5820)->i32)(safe_add( _5879,(int)1 ))) = _5841;
          std::shared_ptr< monty::ndarray< int,1 > > _5883 = mosek::fusion::p_WorkStack::_get_impl(_5820)->i32;
          _checked_ptr_1<int> _ptr__5883(_5883 ? _5883->raw() : nullptr,_5883 ? _5883->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _5884 = mosek::fusion::p_WorkStack::_get_impl(_5820)->i64;
          _checked_ptr_1<long long> _ptr__5884(_5884 ? _5884->raw() : nullptr,_5884 ? _5884->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _5885 = mosek::fusion::p_WorkStack::_get_impl(_5820)->f64;
          _checked_ptr_1<double> _ptr__5885(_5885 ? _5885->raw() : nullptr,_5885 ? _5885->size(0) : 0);
          _ptr__5883[_5878] = (int)0;
          int _5886 = (int)0;
          int _5887 = (int)0;
          int _11240 = (int)0;
          int _11241 = _5834;
          for (int _5888 = _11240; _5888 < _11241; ++_5888)
          {
            {
              int _5889 = (int)0;
              while ( (_5889 < _5836) )
              {
                {
                  int _5890 = _5889;
                  ++ _5889;
                  while ( ((_5889 < _5836) && (_ptr__5838[_ptr__5845[safe_add( _5843,_5890 )]] == _ptr__5838[_ptr__5845[safe_add( _5843,_5889 )]])) )
                  {
                    {
                      ++ _5889;
                    }
                  }
                  int _5891 = _ptr__5838[_ptr__5845[safe_add( _5843,_5890 )]];
                  int _11242 = _5890;
                  int _11243 = _5889;
                  for (int _5892 = _11242; _5892 < _11243; ++_5892)
                  {
                    {
                      int _5893 = _ptr__5837[_ptr__5845[safe_add( _5843,_5892 )]];
                      _ptr__5884[safe_add( _5880,_5887 )] = _ptr__5846[safe_add( safe_add( _5826,safe_mul( _5888,_5833 ) ),_5893 )];
                      _ptr__5885[safe_add( _5882,_5887 )] = _ptr__5839[_ptr__5845[safe_add( _5843,_5892 )]];
                      ++ _5887;
                    }
                  }
                  _ptr__5884[safe_add( _5881,_5886 )] = safe_add( safe_mul( _5888,_5841 ),_5891 );
                  _ptr__5883[safe_add( safe_add( _5878,_5886 ),(int)1 )] = _5887;
                  ++ _5886;
                }
              }
            }
          }
          if ((!_5877))
          {
            {
              _5820->popi64(_5848);
            }
          }
          {}
        }
      }
      else
      {
        {
          int _11244 = (int)0;
          int _11245 = safe_add( _5834,(int)1 );
          for (int _5894 = _11244; _5894 < _11245; ++_5894)
          {
            {
              _ptr__5845[safe_add( _5835,_5894 )] = (int)0;
            }
          }
          if ((_5831 == (int)1))
          {
            {
              int _11246 = (int)0;
              int _11247 = _5825;
              for (int _5895 = _11246; _5895 < _11247; ++_5895)
              {
                {
                  _ptr__5845[safe_add( _5828,_5895 )] = (int)0;
                }
              }
              int _11248 = (int)0;
              int _11249 = _5825;
              for (int _5896 = _11248; _5896 < _11249; ++_5896)
              {
                {
                  _ptr__5845[safe_add( _5829,_5896 )] = (int)_ptr__5846[safe_add( _5827,_5896 )];
                }
              }
              _ptr__5845[_5835] = (int)0;
              _ptr__5845[safe_add( _5835,(int)1 )] = _5825;
            }
          }
          else
          {
            {
              int _11250 = (int)0;
              int _11251 = _5825;
              for (int _5897 = _11250; _5897 < _11251; ++_5897)
              {
                {
                  _ptr__5845[safe_add( _5828,_5897 )] = (int)(_ptr__5846[safe_add( _5827,_5897 )] / _ptr__5830[(int)1]);
                }
              }
              int _11252 = (int)0;
              int _11253 = _5825;
              for (int _5898 = _11252; _5898 < _11253; ++_5898)
              {
                {
                  _ptr__5845[safe_add( _5829,_5898 )] = (int)(_ptr__5846[safe_add( _5827,_5898 )] % _ptr__5830[(int)1]);
                }
              }
              _ptr__5845[_5835] = (int)0;
              int _11254 = (int)0;
              int _11255 = _5825;
              for (int _5899 = _11254; _5899 < _11255; ++_5899)
              {
                {
                  ++ _ptr__5845[safe_add( safe_add( _5835,_ptr__5845[safe_add( _5828,_5899 )] ),(int)1 )];
                }
              }
              int _11256 = (int)0;
              int _11257 = _5834;
              for (int _5900 = _11256; _5900 < _11257; ++_5900)
              {
                {
                  _ptr__5845[safe_add( safe_add( _5835,_5900 ),(int)1 )] += _ptr__5845[safe_add( _5835,_5900 )];
                }
              }
            }
          }
          int _11258 = (int)0;
          int _11259 = _5834;
          for (int _5901 = _11258; _5901 < _11259; ++_5901)
          {
            {
              int _11260 = (int)0;
              int _11261 = mdimj;
              for (int _5902 = _11260; _5902 < _11261; ++_5902)
              {
                {
                  int _5903 = (int)0;
                  int _5904 = _ptr__5845[safe_add( safe_add( _5835,_5901 ),(int)1 )];
                  int _5905 = _ptr__5845[safe_add( safe_add( _5844,_5902 ),(int)1 )];
                  int _5906 = _ptr__5845[safe_add( _5835,_5901 )];
                  int _5907 = _ptr__5845[safe_add( _5844,_5902 )];
                  while ( ((_5907 < _5905) && (_5906 < _5904)) )
                  {
                    {
                      if ((_ptr__5837[_ptr__5845[safe_add( _5843,_5907 )]] < _ptr__5845[safe_add( _5829,_5906 )]))
                      {
                        {
                          ++ _5907;
                        }
                      }
                      else if((_ptr__5837[_ptr__5845[safe_add( _5843,_5907 )]] > _ptr__5845[safe_add( _5829,_5906 )]))
                      {
                        {
                          ++ _5906;
                        }
                      }
                      else
                      {
                        {
                          ++ _5903;
                          ++ _5907;
                          ++ _5906;
                        }
                      }
                    }
                  }
                  if ((_5903 > (int)0))
                  {
                    {
                      _5847 += _5903;
                      ++ _5848;
                    }
                  }
                  {}
                }
              }
            }
          }
          bool _5908 = (_5848 < safe_mul( _5833,mdimi ));
          _5820->alloc_expr((int)2,_5848,_5847,_5908);
          int _5909 = mosek::fusion::p_WorkStack::_get_impl(_5820)->ptr_base;
          int _5910 = mosek::fusion::p_WorkStack::_get_impl(_5820)->shape_base;
          int _5911 = mosek::fusion::p_WorkStack::_get_impl(_5820)->nidxs_base;
          int _5912 = mosek::fusion::p_WorkStack::_get_impl(_5820)->sp_base;
          int _5913 = mosek::fusion::p_WorkStack::_get_impl(_5820)->cof_base;
          ((*mosek::fusion::p_WorkStack::_get_impl(_5820)->i32)(_5910)) = _5834;
          ((*mosek::fusion::p_WorkStack::_get_impl(_5820)->i32)(safe_add( _5910,(int)1 ))) = mdimj;
          std::shared_ptr< monty::ndarray< int,1 > > _5914 = mosek::fusion::p_WorkStack::_get_impl(_5820)->i32;
          _checked_ptr_1<int> _ptr__5914(_5914 ? _5914->raw() : nullptr,_5914 ? _5914->size(0) : 0);
          std::shared_ptr< monty::ndarray< long long,1 > > _5915 = mosek::fusion::p_WorkStack::_get_impl(_5820)->i64;
          _checked_ptr_1<long long> _ptr__5915(_5915 ? _5915->raw() : nullptr,_5915 ? _5915->size(0) : 0);
          std::shared_ptr< monty::ndarray< double,1 > > _5916 = mosek::fusion::p_WorkStack::_get_impl(_5820)->f64;
          _checked_ptr_1<double> _ptr__5916(_5916 ? _5916->raw() : nullptr,_5916 ? _5916->size(0) : 0);
          {
            int _5917 = (int)0;
            int _5918 = (int)0;
            int _5919 = (int)0;
            _ptr__5914[_5909] = (int)0;
            int _11262 = (int)0;
            int _11263 = _5834;
            for (int _5920 = _11262; _5920 < _11263; ++_5920)
            {
              {
                int _11264 = (int)0;
                int _11265 = mdimj;
                for (int _5921 = _11264; _5921 < _11265; ++_5921)
                {
                  {
                    int _5922 = (int)0;
                    int _5923 = _ptr__5845[safe_add( safe_add( _5835,_5920 ),(int)1 )];
                    int _5924 = _ptr__5845[safe_add( safe_add( _5844,_5921 ),(int)1 )];
                    int _5925 = _ptr__5845[safe_add( _5835,_5920 )];
                    int _5926 = _ptr__5845[safe_add( _5844,_5921 )];
                    while ( ((_5926 < _5924) && (_5925 < _5923)) )
                    {
                      {
                        if ((_ptr__5837[_ptr__5845[safe_add( _5843,_5926 )]] < _ptr__5845[safe_add( _5829,_5925 )]))
                        {
                          {
                            ++ _5926;
                          }
                        }
                        else if((_ptr__5837[_ptr__5845[safe_add( _5843,_5926 )]] > _ptr__5845[safe_add( _5829,_5925 )]))
                        {
                          {
                            ++ _5925;
                          }
                        }
                        else
                        {
                          {
                            _ptr__5915[safe_add( _5911,_5919 )] = _ptr__5846[safe_add( _5826,_5925 )];
                            _ptr__5916[safe_add( _5913,_5919 )] = _ptr__5839[_ptr__5845[safe_add( _5843,_5926 )]];
                            ++ _5922;
                            ++ _5919;
                            ++ _5926;
                            ++ _5925;
                          }
                        }
                      }
                    }
                    if ((_5922 > (int)0))
                    {
                      {
                        _ptr__5914[safe_add( safe_add( _5909,_5918 ),(int)1 )] = _5919;
                        _ptr__5915[safe_add( _5912,_5918 )] = _5917;
                        ++ _5918;
                      }
                    }
                    {}
                    ++ _5917;
                  }
                }
              }
            }
          }
          if ((!_5908))
          {
            {
              _5820->popi64(_5848);
            }
          }
          {}
        }
      }
    }
  }
  mosek::fusion::p_WorkStack::_get_impl(_5821)->pi32 = _5823;
  mosek::fusion::p_WorkStack::_get_impl(_5821)->pi64 = _5824;
}
void mosek::fusion::ExprMulVar :: eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _5927,monty::rc_ptr< ::mosek::fusion::WorkStack > _5928,monty::rc_ptr< ::mosek::fusion::WorkStack > _5929) { mosek::fusion::p_ExprMulVar::_get_impl(this)->eval_left(_5927,_5928,_5929); }void mosek::fusion::p_ExprMulVar::eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _5927,monty::rc_ptr< ::mosek::fusion::WorkStack > _5928,monty::rc_ptr< ::mosek::fusion::WorkStack > _5929){
  int _5930 = x->numInst();
  std::shared_ptr< monty::ndarray< int,1 > > _5931 = x->getShape();
  _checked_ptr_1<int> _ptr__5931(_5931 ? _5931->raw() : nullptr,_5931 ? _5931->size(0) : 0);
  int _5932 = (int)((_5931)->size(0));
  int _5933 = _5929->alloci64(_5930);
  int _5934 = _5929->alloci64(_5930);
  int _5935 = _5929->alloci32(_5930);
  int _5936 = _5929->alloci32(_5930);
  int _5937 = _5929->alloci32(_5930);
  int _5938 = _5929->alloci32(safe_add( mdimi,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _5939 = x->getShape();
  _checked_ptr_1<int> _ptr__5939(_5939 ? _5939->raw() : nullptr,_5939 ? _5939->size(0) : 0);
  int _5940 = (int)((_5939)->size(0));
  int _11266;
  bool _11267 = (_5940 == (int)1);
  if (_11267)
  {
    _11266 = (int)1;
  }
  else
  {
    _11266 = _ptr__5939[(int)1];
  }
  int _5941 = _11266;
  int _5942 = _ptr__5939[(int)0];
  int _5943 = _5929->alloci32(safe_add( _5941,(int)1 ));
  std::shared_ptr< monty::ndarray< int,1 > > _5944 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubi;
  _checked_ptr_1<int> _ptr__5944(_5944 ? _5944->raw() : nullptr,_5944 ? _5944->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _5945 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->msubj;
  _checked_ptr_1<int> _ptr__5945(_5945 ? _5945->raw() : nullptr,_5945 ? _5945->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5946 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mcof;
  _checked_ptr_1<double> _ptr__5946(_5946 ? _5946->raw() : nullptr,_5946 ? _5946->size(0) : 0);
  int _5947 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimi;
  int _5948 = mosek::fusion::p_ExprMulVar::_get_impl(::mosek::fusion::ExprMulVar::t(_pubthis))->mdimj;
  int _5949 = (int)0;
  int _5950 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _5951 = mosek::fusion::p_WorkStack::_get_impl(_5929)->i32;
  _checked_ptr_1<int> _ptr__5951(_5951 ? _5951->raw() : nullptr,_5951 ? _5951->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5952 = mosek::fusion::p_WorkStack::_get_impl(_5929)->i64;
  _checked_ptr_1<long long> _ptr__5952(_5952 ? _5952->raw() : nullptr,_5952 ? _5952->size(0) : 0);
  int _5953 = (int)((_5946)->size(0));
  x->inst(_5934,_5952,_5933,_5952);
  if ((x->numInst() < x->getSize()))
  {
    {
      {
        int _11268 = (int)0;
        int _11269 = safe_add( _5947,(int)1 );
        for (int _5954 = _11268; _5954 < _11269; ++_5954)
        {
          {
            _ptr__5951[safe_add( _5938,_5954 )] = (int)0;
          }
        }
        int _11270 = (int)0;
        int _11271 = (int)((_5944)->size(0));
        for (int _5955 = _11270; _5955 < _11271; ++_5955)
        {
          {
            ++ _ptr__5951[safe_add( safe_add( _5938,_ptr__5944[_5955] ),(int)1 )];
          }
        }
        int _11272 = (int)0;
        int _11273 = _5947;
        for (int _5956 = _11272; _5956 < _11273; ++_5956)
        {
          {
            _ptr__5951[safe_add( safe_add( _5938,_5956 ),(int)1 )] += _ptr__5951[safe_add( _5938,_5956 )];
          }
        }
        if ((_5940 == (int)1))
        {
          {
            int _11274 = (int)0;
            int _11275 = _5930;
            for (int _5957 = _11274; _5957 < _11275; ++_5957)
            {
              {
                _ptr__5951[safe_add( _5935,_5957 )] = (int)_ptr__5952[safe_add( _5934,_5957 )];
              }
            }
            int _11276 = (int)0;
            int _11277 = _5930;
            for (int _5958 = _11276; _5958 < _11277; ++_5958)
            {
              {
                _ptr__5951[safe_add( _5936,_5958 )] = (int)0;
              }
            }
          }
        }
        else
        {
          {
            int _11278 = (int)0;
            int _11279 = _5930;
            for (int _5959 = _11278; _5959 < _11279; ++_5959)
            {
              {
                _ptr__5951[safe_add( _5935,_5959 )] = (int)(_ptr__5952[safe_add( _5934,_5959 )] / _5941);
              }
            }
            int _11280 = (int)0;
            int _11281 = _5930;
            for (int _5960 = _11280; _5960 < _11281; ++_5960)
            {
              {
                _ptr__5951[safe_add( _5936,_5960 )] = (int)(_ptr__5952[safe_add( _5934,_5960 )] % _5941);
              }
            }
          }
        }
        if ((_5940 > (int)1))
        {
          {
            int _11282 = (int)0;
            int _11283 = safe_add( _5941,(int)1 );
            for (int _5961 = _11282; _5961 < _11283; ++_5961)
            {
              {
                _ptr__5951[safe_add( _5943,_5961 )] = (int)0;
              }
            }
            int _11284 = (int)0;
            int _11285 = _5930;
            for (int _5962 = _11284; _5962 < _11285; ++_5962)
            {
              {
                ++ _ptr__5951[safe_add( safe_add( _5943,_ptr__5951[safe_add( _5936,_5962 )] ),(int)1 )];
              }
            }
            int _11286 = (int)0;
            int _11287 = _5941;
            for (int _5963 = _11286; _5963 < _11287; ++_5963)
            {
              {
                _ptr__5951[safe_add( safe_add( _5943,_5963 ),(int)1 )] += _ptr__5951[safe_add( _5943,_5963 )];
              }
            }
            int _11288 = (int)0;
            int _11289 = _5930;
            for (int _5964 = _11288; _5964 < _11289; ++_5964)
            {
              {
                _ptr__5951[safe_add( _5937,_ptr__5951[safe_add( _5943,_ptr__5951[safe_add( _5936,_5964 )] )] )] = _5964;
                ++ _ptr__5951[safe_add( _5943,_ptr__5951[safe_add( _5936,_5964 )] )];
              }
            }
            int _11290 = (int)0;
            int _11291 = _5941;
            for (int _5965 = _11290; _5965 < _11291; ++_5965)
            {
              {
                _ptr__5951[(safe_add( _5943,_5941 ) - _5965)] = _ptr__5951[((safe_add( _5943,_5941 ) - _5965) - (int)1)];
              }
            }
            _ptr__5951[_5943] = (int)0;
          }
        }
        else
        {
          {
            _ptr__5951[_5943] = (int)0;
            _ptr__5951[safe_add( _5943,(int)1 )] = _5930;
            int _11292 = (int)0;
            int _11293 = _5930;
            for (int _5966 = _11292; _5966 < _11293; ++_5966)
            {
              {
                _ptr__5951[safe_add( _5937,_5966 )] = _5966;
              }
            }
          }
        }
        int _11294 = (int)0;
        int _11295 = _5947;
        for (int _5967 = _11294; _5967 < _11295; ++_5967)
        {
          {
            int _11296 = (int)0;
            int _11297 = _5941;
            for (int _5968 = _11296; _5968 < _11297; ++_5968)
            {
              {
                int _5969 = (int)0;
                int _5970 = _ptr__5951[safe_add( safe_add( _5943,_5968 ),(int)1 )];
                int _5971 = _ptr__5951[safe_add( safe_add( _5938,_5967 ),(int)1 )];
                int _5972 = _ptr__5951[safe_add( _5943,_5968 )];
                int _5973 = _ptr__5951[safe_add( _5938,_5967 )];
                while ( ((_5973 < _5971) && (_5972 < _5970)) )
                {
                  {
                    if ((_ptr__5945[_5973] < _ptr__5951[safe_add( _5935,_ptr__5951[safe_add( _5937,_5972 )] )]))
                    {
                      {
                        ++ _5973;
                      }
                    }
                    else if((_ptr__5945[_5973] > _ptr__5951[safe_add( _5935,_ptr__5951[safe_add( _5937,_5972 )] )]))
                    {
                      {
                        ++ _5972;
                      }
                    }
                    else
                    {
                      {
                        ++ _5969;
                        ++ _5973;
                        ++ _5972;
                      }
                    }
                  }
                }
                if ((_5969 > (int)0))
                {
                  {
                    _5949 += _5969;
                    ++ _5950;
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      _5949 = safe_mul( _5953,_5941 );
      int _5974 = (int)0;
      while ( (_5974 < _5953) )
      {
        {
          int _5975 = safe_add( _5974,(int)1 );
          while ( ((_5975 < _5953) && (_ptr__5944[_5974] == _ptr__5944[_5975])) )
          {
            {
              ++ _5975;
            }
          }
          ++ _5950;
          _5974 = _5975;
        }
      }
      _5950 *= _5941;
    }
  }
  bool _11298;
  bool _11299 = (_5950 < safe_mul( _5941,_5947 ));
  if (_11299)
  {
    _11298 = true;
  }
  else
  {
    _11298 = false;
  }
  bool _5976 = _11298;
  int _5977 = _5940;
  _5927->alloc_expr(_5977,_5950,_5949,_5976);
  int _5978 = mosek::fusion::p_WorkStack::_get_impl(_5927)->ptr_base;
  int _5979 = mosek::fusion::p_WorkStack::_get_impl(_5927)->shape_base;
  int _5980 = mosek::fusion::p_WorkStack::_get_impl(_5927)->nidxs_base;
  int _11300;
  bool _11301 = _5976;
  if (_11301)
  {
    _11300 = mosek::fusion::p_WorkStack::_get_impl(_5927)->sp_base;
  }
  else
  {
    _11300 = _5927->alloci64(_5950);
  }
  int _5981 = _11300;
  int _5982 = mosek::fusion::p_WorkStack::_get_impl(_5927)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _5983 = mosek::fusion::p_WorkStack::_get_impl(_5927)->i32;
  _checked_ptr_1<int> _ptr__5983(_5983 ? _5983->raw() : nullptr,_5983 ? _5983->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _5984 = mosek::fusion::p_WorkStack::_get_impl(_5927)->i64;
  _checked_ptr_1<long long> _ptr__5984(_5984 ? _5984->raw() : nullptr,_5984 ? _5984->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _5985 = mosek::fusion::p_WorkStack::_get_impl(_5927)->f64;
  _checked_ptr_1<double> _ptr__5985(_5985 ? _5985->raw() : nullptr,_5985 ? _5985->size(0) : 0);
  _ptr__5983[_5979] = _5947;
  if ((_5940 > (int)1))
  {
    {
      _ptr__5983[safe_add( _5979,(int)1 )] = _5941;
    }
  }
  {}
  if ((x->numInst() < x->getSize()))
  {
    {
      int _5986 = (int)0;
      int _5987 = (int)0;
      int _5988 = (int)0;
      _ptr__5983[_5978] = (int)0;
      int _11302 = (int)0;
      int _11303 = _5947;
      for (int _5989 = _11302; _5989 < _11303; ++_5989)
      {
        {
          int _11304 = (int)0;
          int _11305 = _5941;
          for (int _5990 = _11304; _5990 < _11305; ++_5990)
          {
            {
              int _5991 = (int)0;
              int _5992 = _ptr__5951[safe_add( safe_add( _5943,_5990 ),(int)1 )];
              int _5993 = _ptr__5951[safe_add( safe_add( _5938,_5989 ),(int)1 )];
              int _5994 = _ptr__5951[safe_add( _5943,_5990 )];
              int _5995 = _ptr__5951[safe_add( _5938,_5989 )];
              while ( ((_5995 < _5993) && (_5994 < _5992)) )
              {
                {
                  if ((_ptr__5945[_5995] < _ptr__5951[safe_add( _5935,_ptr__5951[safe_add( _5937,_5994 )] )]))
                  {
                    {
                      ++ _5995;
                    }
                  }
                  else if((_ptr__5945[_5995] > _ptr__5951[safe_add( _5935,_ptr__5951[safe_add( _5937,_5994 )] )]))
                  {
                    {
                      ++ _5994;
                    }
                  }
                  else
                  {
                    {
                      _ptr__5984[safe_add( _5980,_5988 )] = _ptr__5952[safe_add( _5933,_ptr__5951[safe_add( _5937,_5994 )] )];
                      _ptr__5985[safe_add( _5982,_5988 )] = _ptr__5946[_5995];
                      ++ _5991;
                      ++ _5988;
                      ++ _5995;
                      ++ _5994;
                    }
                  }
                }
              }
              if ((_5991 > (int)0))
              {
                {
                  _ptr__5983[safe_add( safe_add( _5978,_5987 ),(int)1 )] = _5988;
                  _ptr__5984[safe_add( _5981,_5987 )] = _5986;
                  ++ _5987;
                }
              }
              {}
              ++ _5986;
            }
          }
        }
      }
    }
  }
  else
  {
    {
      int _5996 = (int)0;
      int _5997 = (int)0;
      _ptr__5983[_5978] = (int)0;
      int _5998 = (int)0;
      while ( (_5998 < _5953) )
      {
        {
          int _5999 = safe_add( _5998,(int)1 );
          while ( ((_5999 < _5953) && (_ptr__5944[_5999] == _ptr__5944[_5998])) )
          {
            {
              ++ _5999;
            }
          }
          int _11306 = (int)0;
          int _11307 = _5941;
          for (int _6000 = _11306; _6000 < _11307; ++_6000)
          {
            {
              int _11308 = _5998;
              int _11309 = _5999;
              for (int _6001 = _11308; _6001 < _11309; ++_6001)
              {
                {
                  _ptr__5984[safe_add( _5980,_5996 )] = _ptr__5952[safe_add( safe_add( _5933,safe_mul( _ptr__5945[_6001],_5941 ) ),_6000 )];
                  _ptr__5985[safe_add( _5982,_5996 )] = _ptr__5946[_6001];
                  ++ _5996;
                }
              }
              _ptr__5983[safe_add( safe_add( _5978,_5997 ),(int)1 )] = _5996;
              _ptr__5984[safe_add( _5981,_5997 )] = safe_add( safe_mul( _ptr__5944[_5998],_5941 ),_6000 );
              ++ _5997;
            }
          }
          _5998 = _5999;
        }
      }
    }
  }
  if ((!_5976))
  {
    {
      _5927->popi64(_5950);
    }
  }
  {}
  _5929->clear();
}
void mosek::fusion::p_ExprMulVar::validate(int _6002,int _6003,std::shared_ptr< monty::ndarray< int,1 > > _6004,std::shared_ptr< monty::ndarray< int,1 > > _6005,std::shared_ptr< monty::ndarray< double,1 > > _6006){
  _checked_ptr_1<int> _ptr__6004(_6004 ? _6004->raw() : nullptr, _6004 ? _6004->size(0) : 0);
  _checked_ptr_1<int> _ptr__6005(_6005 ? _6005->raw() : nullptr, _6005 ? _6005->size(0) : 0);
  _checked_ptr_1<double> _ptr__6006(_6006 ? _6006->raw() : nullptr, _6006 ? _6006->size(0) : 0);
  bool _6007 = true;
  {
    int _11310 = (int)0;
    int _11311 = (int)((_6004)->size(0));
    for (int _6008 = _11310; _6008 < _11311; ++_6008)
    {
      {
        if (((_ptr__6004[_6008] < (int)0) || ((_ptr__6004[_6008] >= _6002) || ((_ptr__6005[_6008] < (int)0) || (_ptr__6005[_6008] >= _6003)))))
        {
          {
            _6007 = false;
          }
        }
        {}
      }
    }
    int _11312 = (int)1;
    int _11313 = (int)((_6004)->size(0));
    for (int _6009 = _11312; _6009 < _11313; ++_6009)
    {
      {
        if (((_ptr__6004[(_6009 - (int)1)] > _ptr__6004[_6009]) || ((_ptr__6004[(_6009 - (int)1)] == _ptr__6004[_6009]) && (_ptr__6005[(_6009 - (int)1)] >= _ptr__6005[_6009]))))
        {
          {
            _6007 = false;
          }
        }
        {}
      }
    }
  }
  if ((!_6007))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Invalid matrix data"));
    }
  }
  {}
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprMulVar::resshape(int _6010,int _6011,std::shared_ptr< monty::ndarray< int,1 > > _6012,bool _6013){
  _checked_ptr_1<int> _ptr__6012(_6012 ? _6012->raw() : nullptr, _6012 ? _6012->size(0) : 0);
  if (_6013)
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_6010),(int)(_ptr__6012[(int)1])});
    }
  }
  else
  {
    {
      return std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__6012[(int)0]),(int)(_6011)});
    }
  }
}
std::string mosek::fusion::ExprMulVar :: toString() { return mosek::fusion::p_ExprMulVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVar::toString(){
  if (left)
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar(M,"))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
    }
  }
  else
  {
    {
      return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulVar("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",M)"))->toString();
    }
  }
}
void mosek::fusion::p_ExprMulVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulVar::destroy() { mosek::fusion::p_ExprMulVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar(mosek::fusion::p_ExprMulScalarVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulScalarVar()" << this << std::endl; */ }mosek::fusion::ExprMulScalarVar::~ExprMulScalarVar() {  /* std::cout << "~ExprMulScalarVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulScalarVar::p_ExprMulScalarVar  (::mosek::fusion::ExprMulScalarVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _6014,    int _6015,    std::shared_ptr< monty::ndarray< int,1 > > _6016,    std::shared_ptr< monty::ndarray< int,1 > > _6017,    std::shared_ptr< monty::ndarray< double,1 > > _6018,    monty::rc_ptr< ::mosek::fusion::Variable > _6019){ return new mosek::fusion::ExprMulScalarVar(_6014,_6015,_6016,_6017,_6018,_6019); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _6014,    int _6015,    std::shared_ptr< monty::ndarray< int,1 > > _6016,    std::shared_ptr< monty::ndarray< int,1 > > _6017,    std::shared_ptr< monty::ndarray< double,1 > > _6018,    monty::rc_ptr< ::mosek::fusion::Variable > _6019) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_6014,_6015,_6016,_6017,_6018,_6019); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _6014,    int _6015,    std::shared_ptr< monty::ndarray< int,1 > > _6016,    std::shared_ptr< monty::ndarray< int,1 > > _6017,    std::shared_ptr< monty::ndarray< double,1 > > _6018,    monty::rc_ptr< ::mosek::fusion::Variable > _6019){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__6016(_6016 ? _6016->raw() : nullptr, _6016 ? _6016->size(0) : 0);
    _checked_ptr_1<int> _ptr__6017(_6017 ? _6017->raw() : nullptr, _6017 ? _6017->size(0) : 0);
    _checked_ptr_1<double> _ptr__6018(_6018 ? _6018->raw() : nullptr, _6018 ? _6018->size(0) : 0);
    mosek::fusion::p_ExprMulScalarVar::_initialize(_6014,_6015,::mosek::fusion::Utils::Tools::arraycopy(_6016),::mosek::fusion::Utils::Tools::arraycopy(_6017),::mosek::fusion::Utils::Tools::arraycopy(_6018),_6019,(int)1);
    if ((_6019->getND() != (int)0))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid Variable size"));
      }
    }
    {}
    if (((_6014 < (int)0) || ((_6015 < (int)0) || (((int)((_6016)->size(0)) != (int)((_6017)->size(0))) || ((int)((_6016)->size(0)) != (int)((_6018)->size(0)))))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    bool _6020 = false;
    int _11314 = (int)0;
    int _11315 = (int)((_6016)->size(0));
    for (int _6021 = _11314; _6021 < _11315; ++_6021)
    {
      {
        if (((_ptr__6016[_6021] < (int)0) || ((_ptr__6016[_6021] >= _6014) || ((_ptr__6017[_6021] < (int)0) || (_ptr__6017[_6021] >= _6015)))))
        {
          {
            _6020 = true;
          }
        }
        {}
      }
    }
    if (_6020)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Invalid Matrix data"));
      }
    }
    {}
    bool _6022 = false;
    int _11316 = (int)1;
    int _11317 = (int)((_6016)->size(0));
    for (int _6023 = _11316; _6023 < _11317; ++_6023)
    {
      {
        if (((_ptr__6016[_6023] < _ptr__6016[(_6023 - (int)1)]) || ((_ptr__6016[_6023] == _ptr__6016[(_6023 - (int)1)]) && (_ptr__6017[_6023] <= _ptr__6017[(_6023 - (int)1)]))))
        {
          {
            _6022 = true;
          }
        }
        {}
      }
    }
    if (_6022)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("Matrix data not correctly sorted"));
      }
    }
    {}
  }
}mosek::fusion::ExprMulScalarVar::t mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar  (int _6024,    int _6025,    std::shared_ptr< monty::ndarray< int,1 > > _6026,    std::shared_ptr< monty::ndarray< int,1 > > _6027,    std::shared_ptr< monty::ndarray< double,1 > > _6028,    monty::rc_ptr< ::mosek::fusion::Variable > _6029,    int _6030){ return new mosek::fusion::ExprMulScalarVar(_6024,_6025,_6026,_6027,_6028,_6029,_6030); }mosek::fusion::ExprMulScalarVar::ExprMulScalarVar  (int _6024,    int _6025,    std::shared_ptr< monty::ndarray< int,1 > > _6026,    std::shared_ptr< monty::ndarray< int,1 > > _6027,    std::shared_ptr< monty::ndarray< double,1 > > _6028,    monty::rc_ptr< ::mosek::fusion::Variable > _6029,    int _6030) :    ExprMulScalarVar(new mosek::fusion::p_ExprMulScalarVar(this)){ mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->_initialize(_6024,_6025,_6026,_6027,_6028,_6029,_6030); }void mosek::fusion::p_ExprMulScalarVar::_initialize  (int _6024,    int _6025,    std::shared_ptr< monty::ndarray< int,1 > > _6026,    std::shared_ptr< monty::ndarray< int,1 > > _6027,    std::shared_ptr< monty::ndarray< double,1 > > _6028,    monty::rc_ptr< ::mosek::fusion::Variable > _6029,    int _6030){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__6026(_6026 ? _6026->raw() : nullptr, _6026 ? _6026->size(0) : 0);
    _checked_ptr_1<int> _ptr__6027(_6027 ? _6027->raw() : nullptr, _6027 ? _6027->size(0) : 0);
    _checked_ptr_1<double> _ptr__6028(_6028 ? _6028->raw() : nullptr, _6028 ? _6028->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_6024),(int)(_6025)}));
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimi = _6024;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mdimj = _6025;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubi = _6026;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->msubj = _6027;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->mcof = _6028;
    mosek::fusion::p_ExprMulScalarVar::_get_impl(::mosek::fusion::ExprMulScalarVar::t(_pubthis))->x = _6029;
  }
}void mosek::fusion::ExprMulScalarVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6031,monty::rc_ptr< ::mosek::fusion::WorkStack > _6032,monty::rc_ptr< ::mosek::fusion::WorkStack > _6033) { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->eval(_6031,_6032,_6033); }void mosek::fusion::p_ExprMulScalarVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6031,monty::rc_ptr< ::mosek::fusion::WorkStack > _6032,monty::rc_ptr< ::mosek::fusion::WorkStack > _6033){
  if ((x->numInst() == (int)0))
  {
    {
      _6031->alloc_expr((int)2,(int)0,(int)0,false);
      ((*mosek::fusion::p_WorkStack::_get_impl(_6031)->i32)(mosek::fusion::p_WorkStack::_get_impl(_6031)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_6031)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_6031)->shape_base,(int)1 ))) = mdimj;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< long long,1 > > _6034 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)1)));
      _checked_ptr_1<long long> _ptr__6034(_6034 ? _6034->raw() : nullptr,_6034 ? _6034->size(0) : 0);
      x->inst((int)0,_6034);
      long long _6035 = _ptr__6034[(int)0];
      int _6036 = (int)((msubi)->size(0));
      int _6037 = _6036;
      bool _6038 = (_6036 < safe_mul( mdimi,mdimj ));
      _6031->alloc_expr((int)2,_6036,_6037,_6038);
      int _6039 = mosek::fusion::p_WorkStack::_get_impl(_6031)->ptr_base;
      ((*mosek::fusion::p_WorkStack::_get_impl(_6031)->i32)(mosek::fusion::p_WorkStack::_get_impl(_6031)->shape_base)) = mdimi;
      ((*mosek::fusion::p_WorkStack::_get_impl(_6031)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_6031)->shape_base,(int)1 ))) = mdimj;
      int _6040 = mosek::fusion::p_WorkStack::_get_impl(_6031)->nidxs_base;
      int _6041 = mosek::fusion::p_WorkStack::_get_impl(_6031)->sp_base;
      int _6042 = mosek::fusion::p_WorkStack::_get_impl(_6031)->cof_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6043 = mosek::fusion::p_WorkStack::_get_impl(_6031)->i32;
      _checked_ptr_1<int> _ptr__6043(_6043 ? _6043->raw() : nullptr,_6043 ? _6043->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6044 = mosek::fusion::p_WorkStack::_get_impl(_6031)->i64;
      _checked_ptr_1<long long> _ptr__6044(_6044 ? _6044->raw() : nullptr,_6044 ? _6044->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6045 = mosek::fusion::p_WorkStack::_get_impl(_6031)->f64;
      _checked_ptr_1<double> _ptr__6045(_6045 ? _6045->raw() : nullptr,_6045 ? _6045->size(0) : 0);
      {
        int _11318 = (int)0;
        int _11319 = _6037;
        for (int _6046 = _11318; _6046 < _11319; ++_6046)
        {
          {
            _ptr__6045[safe_add( _6042,_6046 )] = ((*mcof)(_6046));
          }
        }
        int _11320 = (int)0;
        int _11321 = _6037;
        for (int _6047 = _11320; _6047 < _11321; ++_6047)
        {
          {
            _ptr__6044[safe_add( _6040,_6047 )] = _6035;
          }
        }
        if (_6038)
        {
          {
            int _11322 = (int)0;
            int _11323 = _6036;
            for (int _6048 = _11322; _6048 < _11323; ++_6048)
            {
              {
                _ptr__6044[safe_add( _6041,_6048 )] = safe_add( safe_mul( ((*msubi)(_6048)),mdimj ),((*msubj)(_6048)) );
              }
            }
          }
        }
        {}
        int _11324 = (int)0;
        int _11325 = safe_add( _6036,(int)1 );
        for (int _6049 = _11324; _6049 < _11325; ++_6049)
        {
          {
            _ptr__6043[safe_add( _6039,_6049 )] = _6049;
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprMulScalarVar :: toString() { return mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulScalarVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprMulScalarVar(M("))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(mdimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("), "))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprMulScalarVar::destroy(){x.reset();mcof.reset();msubj.reset();msubi.reset();}void mosek::fusion::ExprMulScalarVar::destroy() { mosek::fusion::p_ExprMulScalarVar::_get_impl(this)->destroy(); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst(mosek::fusion::p_ExprMulVarScalarConst *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprMulVarScalarConst()" << this << std::endl; */ }mosek::fusion::ExprMulVarScalarConst::~ExprMulVarScalarConst() {  /* std::cout << "~ExprMulVarScalarConst()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprMulVarScalarConst::p_ExprMulVarScalarConst  (::mosek::fusion::ExprMulVarScalarConst * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprMulVarScalarConst::t mosek::fusion::p_ExprMulVarScalarConst::_new_ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _6050,    double _6051){ return new mosek::fusion::ExprMulVarScalarConst(_6050,_6051); }mosek::fusion::ExprMulVarScalarConst::ExprMulVarScalarConst  (monty::rc_ptr< ::mosek::fusion::Variable > _6050,    double _6051) :    ExprMulVarScalarConst(new mosek::fusion::p_ExprMulVarScalarConst(this)){ mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->_initialize(_6050,_6051); }void mosek::fusion::p_ExprMulVarScalarConst::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _6050,    double _6051){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6050->getShape());
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->x = _6050;
    mosek::fusion::p_ExprMulVarScalarConst::_get_impl(::mosek::fusion::ExprMulVarScalarConst::t(_pubthis))->c = _6051;
  }
}void mosek::fusion::ExprMulVarScalarConst :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6052,monty::rc_ptr< ::mosek::fusion::WorkStack > _6053,monty::rc_ptr< ::mosek::fusion::WorkStack > _6054) { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->eval(_6052,_6053,_6054); }void mosek::fusion::p_ExprMulVarScalarConst::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6052,monty::rc_ptr< ::mosek::fusion::WorkStack > _6053,monty::rc_ptr< ::mosek::fusion::WorkStack > _6054){
  int _6055 = x->numInst();
  int _6056 = _6055;
  std::shared_ptr< monty::ndarray< int,1 > > _6057 = x->getShape();
  _checked_ptr_1<int> _ptr__6057(_6057 ? _6057->raw() : nullptr,_6057 ? _6057->size(0) : 0);
  int _6058 = (int)((_6057)->size(0));
  bool _6059 = (::mosek::fusion::p_Set::size(_6057) > _6056);
  _6052->alloc_expr(_6058,_6056,_6055,_6059);
  int _6060 = mosek::fusion::p_WorkStack::_get_impl(_6052)->ptr_base;
  int _6061 = mosek::fusion::p_WorkStack::_get_impl(_6052)->nidxs_base;
  int _6062 = mosek::fusion::p_WorkStack::_get_impl(_6052)->sp_base;
  int _6063 = mosek::fusion::p_WorkStack::_get_impl(_6052)->cof_base;
  int _6064 = mosek::fusion::p_WorkStack::_get_impl(_6052)->shape_base;
  if (_6059)
  {
    {
      x->inst(_6062,mosek::fusion::p_WorkStack::_get_impl(_6052)->i64,_6061,mosek::fusion::p_WorkStack::_get_impl(_6052)->i64);
    }
  }
  else
  {
    {
      x->inst(_6061,mosek::fusion::p_WorkStack::_get_impl(_6052)->i64);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _6065 = mosek::fusion::p_WorkStack::_get_impl(_6052)->i32;
  _checked_ptr_1<int> _ptr__6065(_6065 ? _6065->raw() : nullptr,_6065 ? _6065->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6066 = mosek::fusion::p_WorkStack::_get_impl(_6052)->i64;
  _checked_ptr_1<long long> _ptr__6066(_6066 ? _6066->raw() : nullptr,_6066 ? _6066->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6067 = mosek::fusion::p_WorkStack::_get_impl(_6052)->f64;
  _checked_ptr_1<double> _ptr__6067(_6067 ? _6067->raw() : nullptr,_6067 ? _6067->size(0) : 0);
  {
    int _11326 = (int)0;
    int _11327 = _6058;
    for (int _6068 = _11326; _6068 < _11327; ++_6068)
    {
      {
        _ptr__6065[safe_add( _6064,_6068 )] = _ptr__6057[_6068];
      }
    }
    int _11328 = (int)0;
    int _11329 = safe_add( _6056,(int)1 );
    for (int _6069 = _11328; _6069 < _11329; ++_6069)
    {
      {
        _ptr__6065[safe_add( _6060,_6069 )] = _6069;
      }
    }
    int _11330 = (int)0;
    int _11331 = _6055;
    for (int _6070 = _11330; _6070 < _11331; ++_6070)
    {
      {
        _ptr__6067[safe_add( _6063,_6070 )] = 1.0;
      }
    }
  }
}
std::string mosek::fusion::ExprMulVarScalarConst :: toString() { return mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprMulVarScalarConst::toString(){
  return std::string ("ExprMulVarScalarConst()");
}
void mosek::fusion::p_ExprMulVarScalarConst::destroy(){x.reset();}void mosek::fusion::ExprMulVarScalarConst::destroy() { mosek::fusion::p_ExprMulVarScalarConst::_get_impl(this)->destroy(); }mosek::fusion::ExprAdd::ExprAdd(mosek::fusion::p_ExprAdd *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprAdd()" << this << std::endl; */ }mosek::fusion::ExprAdd::~ExprAdd() {  /* std::cout << "~ExprAdd()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprAdd::p_ExprAdd  (::mosek::fusion::ExprAdd * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprAdd::t mosek::fusion::p_ExprAdd::_new_ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _6071,    monty::rc_ptr< ::mosek::fusion::Expression > _6072,    double _6073,    double _6074){ return new mosek::fusion::ExprAdd(_6071,_6072,_6073,_6074); }mosek::fusion::ExprAdd::ExprAdd  (monty::rc_ptr< ::mosek::fusion::Expression > _6071,    monty::rc_ptr< ::mosek::fusion::Expression > _6072,    double _6073,    double _6074) :    ExprAdd(new mosek::fusion::p_ExprAdd(this)){ mosek::fusion::p_ExprAdd::_get_impl(this)->_initialize(_6071,_6072,_6073,_6074); }void mosek::fusion::p_ExprAdd::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _6071,    monty::rc_ptr< ::mosek::fusion::Expression > _6072,    double _6073,    double _6074){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6071->getShape());
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e1 = _6071;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->e2 = _6072;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1 = _6073;
    mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2 = _6074;
    if ((_6071->getND() != _6072->getND()))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
    int _11332 = (int)0;
    int _11333 = _6071->getND();
    for (int _6075 = _11332; _6075 < _11333; ++_6075)
    {
      {
        if ((_6071->getDim(_6075) != _6072->getDim(_6075)))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
          }
        }
        {}
      }
    }
  }
}void mosek::fusion::ExprAdd :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6076,monty::rc_ptr< ::mosek::fusion::WorkStack > _6077,monty::rc_ptr< ::mosek::fusion::WorkStack > _6078) { mosek::fusion::p_ExprAdd::_get_impl(this)->eval(_6076,_6077,_6078); }void mosek::fusion::p_ExprAdd::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6076,monty::rc_ptr< ::mosek::fusion::WorkStack > _6077,monty::rc_ptr< ::mosek::fusion::WorkStack > _6078){
  e1->eval(_6077,_6076,_6078);
  e2->eval(_6077,_6076,_6078);
  _6077->pop_expr();
  int _6079 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nd;
  int _6080 = mosek::fusion::p_WorkStack::_get_impl(_6077)->shape_base;
  int _6081 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nelem;
  int _6082 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nnz;
  int _6083 = mosek::fusion::p_WorkStack::_get_impl(_6077)->ncodeatom;
  bool _6084 = mosek::fusion::p_WorkStack::_get_impl(_6077)->hassp;
  int _6085 = mosek::fusion::p_WorkStack::_get_impl(_6077)->ptr_base;
  int _6086 = mosek::fusion::p_WorkStack::_get_impl(_6077)->sp_base;
  int _6087 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nidxs_base;
  int _6088 = mosek::fusion::p_WorkStack::_get_impl(_6077)->cof_base;
  int _6089 = mosek::fusion::p_WorkStack::_get_impl(_6077)->code_base;
  int _6090 = mosek::fusion::p_WorkStack::_get_impl(_6077)->codeptr_base;
  int _6091 = mosek::fusion::p_WorkStack::_get_impl(_6077)->cconst_base;
  _6077->pop_expr();
  int _6092 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nd;
  int _6093 = mosek::fusion::p_WorkStack::_get_impl(_6077)->shape_base;
  int _6094 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nelem;
  int _6095 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nnz;
  int _6096 = mosek::fusion::p_WorkStack::_get_impl(_6077)->ncodeatom;
  bool _6097 = mosek::fusion::p_WorkStack::_get_impl(_6077)->hassp;
  int _6098 = mosek::fusion::p_WorkStack::_get_impl(_6077)->ptr_base;
  int _6099 = mosek::fusion::p_WorkStack::_get_impl(_6077)->sp_base;
  int _6100 = mosek::fusion::p_WorkStack::_get_impl(_6077)->nidxs_base;
  int _6101 = mosek::fusion::p_WorkStack::_get_impl(_6077)->cof_base;
  int _6102 = mosek::fusion::p_WorkStack::_get_impl(_6077)->code_base;
  int _6103 = mosek::fusion::p_WorkStack::_get_impl(_6077)->codeptr_base;
  int _6104 = mosek::fusion::p_WorkStack::_get_impl(_6077)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6105 = mosek::fusion::p_WorkStack::_get_impl(_6077)->i32;
  _checked_ptr_1<int> _ptr__6105(_6105 ? _6105->raw() : nullptr,_6105 ? _6105->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6106 = mosek::fusion::p_WorkStack::_get_impl(_6077)->i64;
  _checked_ptr_1<long long> _ptr__6106(_6106 ? _6106->raw() : nullptr,_6106 ? _6106->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6107 = mosek::fusion::p_WorkStack::_get_impl(_6077)->f64;
  _checked_ptr_1<double> _ptr__6107(_6107 ? _6107->raw() : nullptr,_6107 ? _6107->size(0) : 0);
  bool _6108 = ((_6096 > (int)0) || (_6083 > (int)0));
  if ((_6092 != _6079))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
  {}
  int _11334 = (int)0;
  int _11335 = _6092;
  for (int _6109 = _11334; _6109 < _11335; ++_6109)
  {
    {
      if ((_ptr__6105[safe_add( _6093,_6109 )] != _ptr__6105[safe_add( _6080,_6109 )]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      {}
    }
  }
  if (((!_6097) && (!_6084)))
  {
    {
      int _6110 = _6094;
      int _6111 = safe_add( _6095,_6082 );
      int _6112 = (int)0;
      if (_6108)
      {
        {
          int _11336;
          bool _11337 = (_6096 > (int)0);
          if (_11337)
          {
            _11336 = safe_add( _6096,safe_mul( _6095,(int)2 ) );
          }
          else
          {
            _11336 = _6095;
          }
          _6112 += _11336;
          int _11338;
          bool _11339 = (_6083 > (int)0);
          if (_11339)
          {
            _11338 = safe_add( _6083,safe_mul( _6082,(int)2 ) );
          }
          else
          {
            _11338 = _6082;
          }
          _6112 += _11338;
        }
      }
      {}
      int _6113 = _6092;
      _6076->alloc_expr(_6113,_6110,_6111,false,_6112);
      int _6114 = mosek::fusion::p_WorkStack::_get_impl(_6076)->shape_base;
      int _6115 = mosek::fusion::p_WorkStack::_get_impl(_6076)->ptr_base;
      int _6116 = mosek::fusion::p_WorkStack::_get_impl(_6076)->sp_base;
      int _6117 = mosek::fusion::p_WorkStack::_get_impl(_6076)->nidxs_base;
      int _6118 = mosek::fusion::p_WorkStack::_get_impl(_6076)->cof_base;
      int _6119 = mosek::fusion::p_WorkStack::_get_impl(_6076)->code_base;
      int _6120 = mosek::fusion::p_WorkStack::_get_impl(_6076)->codeptr_base;
      int _6121 = mosek::fusion::p_WorkStack::_get_impl(_6076)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6122 = mosek::fusion::p_WorkStack::_get_impl(_6076)->i32;
      _checked_ptr_1<int> _ptr__6122(_6122 ? _6122->raw() : nullptr,_6122 ? _6122->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6123 = mosek::fusion::p_WorkStack::_get_impl(_6076)->i64;
      _checked_ptr_1<long long> _ptr__6123(_6123 ? _6123->raw() : nullptr,_6123 ? _6123->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6124 = mosek::fusion::p_WorkStack::_get_impl(_6076)->f64;
      _checked_ptr_1<double> _ptr__6124(_6124 ? _6124->raw() : nullptr,_6124 ? _6124->size(0) : 0);
      int _11340 = (int)0;
      int _11341 = _6113;
      for (int _6125 = _11340; _6125 < _11341; ++_6125)
      {
        {
          _ptr__6122[safe_add( _6114,_6125 )] = _ptr__6105[safe_add( _6093,_6125 )];
        }
      }
      int _6126 = (int)0;
      int _6127 = (int)0;
      if ((_6112 > (int)0))
      {
        {
          _ptr__6122[_6120] = (int)0;
        }
      }
      {}
      _ptr__6122[_6115] = (int)0;
      int _11342 = (int)0;
      int _11343 = _6110;
      for (int _6128 = _11342; _6128 < _11343; ++_6128)
      {
        {
          int _11344 = _ptr__6105[safe_add( _6098,_6128 )];
          int _11345 = _ptr__6105[safe_add( safe_add( _6098,_6128 ),(int)1 )];
          for (int _6129 = _11344; _6129 < _11345; ++_6129)
          {
            {
              _ptr__6123[safe_add( _6117,_6127 )] = _ptr__6106[safe_add( _6100,_6129 )];
              _ptr__6124[safe_add( _6118,_6127 )] = (_ptr__6107[safe_add( _6101,_6129 )] * m1);
              if ((_6096 > (int)0))
              {
                {
                  int _11346 = _ptr__6105[safe_add( _6103,_6129 )];
                  int _11347 = _ptr__6105[safe_add( safe_add( _6103,_6129 ),(int)1 )];
                  for (int _6130 = _11346; _6130 < _11347; ++_6130)
                  {
                    {
                      _ptr__6122[safe_add( _6119,_6126 )] = _ptr__6105[safe_add( _6102,_6130 )];
                      _ptr__6124[safe_add( _6121,_6126 )] = _ptr__6107[safe_add( _6104,_6130 )];
                      ++ _6126;
                    }
                  }
                  _ptr__6122[safe_add( _6119,_6126 )] = 2;
                  _ptr__6124[safe_add( _6121,_6126 )] = m1;
                  ++ _6126;
                  _ptr__6122[safe_add( _6119,_6126 )] = 5;
                  ++ _6126;
                  _ptr__6122[safe_add( safe_add( _6120,_6127 ),(int)1 )] = _6126;
                }
              }
              else
              {
                {
                  if ((_6112 > (int)0))
                  {
                    {
                      _ptr__6122[safe_add( _6119,_6126 )] = 2;
                      _ptr__6124[safe_add( _6121,_6126 )] = 0.0;
                      ++ _6126;
                      _ptr__6122[safe_add( safe_add( _6120,_6127 ),(int)1 )] = _6126;
                    }
                  }
                  {}
                }
              }
              ++ _6127;
            }
          }
          int _11348 = _ptr__6105[safe_add( _6085,_6128 )];
          int _11349 = _ptr__6105[safe_add( safe_add( _6085,_6128 ),(int)1 )];
          for (int _6131 = _11348; _6131 < _11349; ++_6131)
          {
            {
              _ptr__6123[safe_add( _6117,_6127 )] = _ptr__6106[safe_add( _6087,_6131 )];
              _ptr__6124[safe_add( _6118,_6127 )] = (_ptr__6107[safe_add( _6088,_6131 )] * m2);
              if ((_6083 > (int)0))
              {
                {
                  int _11350 = _ptr__6105[safe_add( _6090,_6131 )];
                  int _11351 = _ptr__6105[safe_add( safe_add( _6090,_6131 ),(int)1 )];
                  for (int _6132 = _11350; _6132 < _11351; ++_6132)
                  {
                    {
                      _ptr__6122[safe_add( _6119,_6126 )] = _ptr__6105[safe_add( _6089,_6132 )];
                      _ptr__6124[safe_add( _6121,_6126 )] = _ptr__6107[safe_add( _6091,_6132 )];
                      ++ _6126;
                    }
                  }
                  _ptr__6122[safe_add( _6119,_6126 )] = 2;
                  _ptr__6124[safe_add( _6121,_6126 )] = m2;
                  ++ _6126;
                  _ptr__6122[safe_add( _6119,_6126 )] = 5;
                  ++ _6126;
                  _ptr__6122[safe_add( safe_add( _6120,_6127 ),(int)1 )] = _6126;
                }
              }
              else
              {
                {
                  if ((_6112 > (int)0))
                  {
                    {
                      _ptr__6122[safe_add( _6119,_6126 )] = 2;
                      _ptr__6124[safe_add( _6121,_6126 )] = 0.0;
                      ++ _6126;
                      _ptr__6122[safe_add( safe_add( _6120,_6127 ),(int)1 )] = _6126;
                    }
                  }
                  {}
                }
              }
              ++ _6127;
            }
          }
          _ptr__6122[safe_add( safe_add( _6115,_6128 ),(int)1 )] = _6127;
        }
      }
    }
  }
  else if(((!_6097) || (!_6084)))
  {
    {
      if ((!_6084))
      {
        {
          int _6133 = _6081;
          int _6134 = _6082;
          int _6135 = _6085;
          int _6136 = _6086;
          int _6137 = _6087;
          int _6138 = _6083;
          int _6139 = _6090;
          int _6140 = _6089;
          int _6141 = _6091;
          int _6142 = _6088;
          _6081 = _6094;
          _6082 = _6095;
          _6085 = _6098;
          _6086 = _6099;
          _6087 = _6100;
          _6083 = _6096;
          _6090 = _6103;
          _6089 = _6102;
          _6091 = _6104;
          _6088 = _6101;
          _6094 = _6133;
          _6095 = _6134;
          _6098 = _6135;
          _6099 = _6136;
          _6100 = _6137;
          _6096 = _6138;
          _6103 = _6090;
          _6102 = _6089;
          _6104 = _6091;
          _6101 = _6142;
        }
      }
      {}
      double _11352;
      bool _11353 = (!_6097);
      if (_11353)
      {
        _11352 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      else
      {
        _11352 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      double _6143 = _11352;
      double _11354;
      bool _11355 = (!_6097);
      if (_11355)
      {
        _11354 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m2;
      }
      else
      {
        _11354 = mosek::fusion::p_ExprAdd::_get_impl(::mosek::fusion::ExprAdd::t(_pubthis))->m1;
      }
      double _6144 = _11354;
      int _6145 = _6094;
      int _6146 = safe_add( _6095,_6082 );
      int _6147 = _6092;
      int _6148 = safe_add( _6096,_6083 );
      if (_6108)
      {
        {
          int _11356;
          bool _11357 = (_6096 > (int)0);
          if (_11357)
          {
            _11356 = safe_mul( (int)2,_6095 );
          }
          else
          {
            _11356 = _6095;
          }
          _6148 += _11356;
          int _11358;
          bool _11359 = (_6083 > (int)0);
          if (_11359)
          {
            _11358 = safe_mul( (int)2,_6082 );
          }
          else
          {
            _11358 = _6082;
          }
          _6148 += _11358;
        }
      }
      {}
      _6076->alloc_expr(_6147,_6145,_6146,false,_6148);
      int _6149 = mosek::fusion::p_WorkStack::_get_impl(_6076)->shape_base;
      int _6150 = mosek::fusion::p_WorkStack::_get_impl(_6076)->ptr_base;
      int _6151 = mosek::fusion::p_WorkStack::_get_impl(_6076)->sp_base;
      int _6152 = mosek::fusion::p_WorkStack::_get_impl(_6076)->nidxs_base;
      int _6153 = mosek::fusion::p_WorkStack::_get_impl(_6076)->cof_base;
      int _6154 = mosek::fusion::p_WorkStack::_get_impl(_6076)->code_base;
      int _6155 = mosek::fusion::p_WorkStack::_get_impl(_6076)->codeptr_base;
      int _6156 = mosek::fusion::p_WorkStack::_get_impl(_6076)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6157 = mosek::fusion::p_WorkStack::_get_impl(_6076)->i32;
      _checked_ptr_1<int> _ptr__6157(_6157 ? _6157->raw() : nullptr,_6157 ? _6157->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6158 = mosek::fusion::p_WorkStack::_get_impl(_6076)->i64;
      _checked_ptr_1<long long> _ptr__6158(_6158 ? _6158->raw() : nullptr,_6158 ? _6158->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6159 = mosek::fusion::p_WorkStack::_get_impl(_6076)->f64;
      _checked_ptr_1<double> _ptr__6159(_6159 ? _6159->raw() : nullptr,_6159 ? _6159->size(0) : 0);
      {
        int _6160 = (int)0;
        int _6161 = (int)0;
        int _6162 = (int)0;
        int _11360 = (int)0;
        int _11361 = _6147;
        for (int _6163 = _11360; _6163 < _11361; ++_6163)
        {
          {
            _ptr__6157[safe_add( _6149,_6163 )] = _ptr__6105[safe_add( _6093,_6163 )];
          }
        }
        _ptr__6157[_6150] = (int)0;
        if ((_6148 > (int)0))
        {
          {
            _ptr__6157[_6155] = (int)0;
          }
        }
        {}
        int _6164 = (int)0;
        int _6165 = (int)0;
        while ( ((_6165 < _6094) || (_6164 < _6081)) )
        {
          {
            if (((_6165 < _6094) && ((_6164 >= _6081) || (_6165 < _ptr__6106[safe_add( _6086,_6164 )]))))
            {
              {
                int _11362 = _ptr__6105[safe_add( _6098,_6165 )];
                int _11363 = _ptr__6105[safe_add( safe_add( _6098,_6165 ),(int)1 )];
                for (int _6166 = _11362; _6166 < _11363; ++_6166)
                {
                  {
                    _ptr__6158[safe_add( _6152,_6162 )] = _ptr__6106[safe_add( _6100,_6166 )];
                    _ptr__6159[safe_add( _6153,_6162 )] = (_ptr__6107[safe_add( _6101,_6166 )] * _6143);
                    if ((_6096 > (int)0))
                    {
                      {
                        int _11364 = _ptr__6105[safe_add( _6103,_6166 )];
                        int _11365 = _ptr__6105[safe_add( safe_add( _6103,_6166 ),(int)1 )];
                        for (int _6167 = _11364; _6167 < _11365; ++_6167)
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = _ptr__6105[safe_add( _6102,_6167 )];
                            _ptr__6159[safe_add( _6156,_6160 )] = _ptr__6107[safe_add( _6104,_6167 )];
                            ++ _6160;
                          }
                        }
                        _ptr__6157[safe_add( _6154,_6160 )] = 2;
                        _ptr__6159[safe_add( _6156,_6160 )] = _6143;
                        ++ _6160;
                        _ptr__6157[safe_add( _6154,_6160 )] = 5;
                        ++ _6160;
                        _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                      }
                    }
                    else
                    {
                      {
                        if ((_6148 > (int)0))
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = 2;
                            _ptr__6159[safe_add( _6156,_6160 )] = 0.0;
                            ++ _6160;
                            _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6162;
                  }
                }
                _ptr__6157[safe_add( safe_add( _6150,_6161 ),(int)1 )] = _6162;
                ++ _6165;
              }
            }
            else if(((_6164 < _6081) && ((_6165 >= _6094) || (_6165 > _ptr__6106[safe_add( _6086,_6164 )]))))
            {
              {
                int _11366 = _ptr__6105[safe_add( _6085,_6164 )];
                int _11367 = _ptr__6105[safe_add( safe_add( _6085,_6164 ),(int)1 )];
                for (int _6168 = _11366; _6168 < _11367; ++_6168)
                {
                  {
                    _ptr__6158[safe_add( _6152,_6162 )] = _ptr__6106[safe_add( _6087,_6168 )];
                    _ptr__6159[safe_add( _6153,_6162 )] = (_ptr__6107[safe_add( _6088,_6168 )] * _6144);
                    if ((_6083 > (int)0))
                    {
                      {
                        int _11368 = _ptr__6105[safe_add( _6090,_6168 )];
                        int _11369 = _ptr__6105[safe_add( safe_add( _6090,_6168 ),(int)1 )];
                        for (int _6169 = _11368; _6169 < _11369; ++_6169)
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = _ptr__6105[safe_add( _6089,_6169 )];
                            _ptr__6159[safe_add( _6156,_6160 )] = _ptr__6107[safe_add( _6091,_6169 )];
                            ++ _6160;
                          }
                        }
                        _ptr__6157[safe_add( _6154,_6160 )] = 2;
                        _ptr__6159[safe_add( _6156,_6160 )] = _6144;
                        ++ _6160;
                        _ptr__6157[safe_add( _6154,_6160 )] = 5;
                        ++ _6160;
                        _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                      }
                    }
                    else
                    {
                      {
                        if ((_6148 > (int)0))
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = 2;
                            _ptr__6159[safe_add( _6156,_6160 )] = 0.0;
                            ++ _6160;
                            _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6162;
                  }
                }
                _ptr__6157[safe_add( safe_add( _6150,_6161 ),(int)1 )] = _6162;
                ++ _6164;
              }
            }
            else
            {
              {
                int _11370 = _ptr__6105[safe_add( _6098,_6165 )];
                int _11371 = _ptr__6105[safe_add( safe_add( _6098,_6165 ),(int)1 )];
                for (int _6170 = _11370; _6170 < _11371; ++_6170)
                {
                  {
                    _ptr__6158[safe_add( _6152,_6162 )] = _ptr__6106[safe_add( _6100,_6170 )];
                    _ptr__6159[safe_add( _6153,_6162 )] = (_ptr__6107[safe_add( _6101,_6170 )] * _6143);
                    if ((_6096 > (int)0))
                    {
                      {
                        int _11372 = _ptr__6105[safe_add( _6103,_6170 )];
                        int _11373 = _ptr__6105[safe_add( safe_add( _6103,_6170 ),(int)1 )];
                        for (int _6171 = _11372; _6171 < _11373; ++_6171)
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = _ptr__6105[safe_add( _6102,_6171 )];
                            _ptr__6159[safe_add( _6156,_6160 )] = _ptr__6107[safe_add( _6104,_6171 )];
                            ++ _6160;
                          }
                        }
                        _ptr__6157[safe_add( _6154,_6160 )] = 2;
                        _ptr__6159[safe_add( _6156,_6160 )] = _6143;
                        ++ _6160;
                        _ptr__6157[safe_add( _6154,_6160 )] = 5;
                        ++ _6160;
                        _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                      }
                    }
                    else
                    {
                      {
                        if ((_6148 > (int)0))
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = 2;
                            _ptr__6159[safe_add( _6156,_6160 )] = 0.0;
                            ++ _6160;
                            _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6162;
                  }
                }
                int _11374 = _ptr__6105[safe_add( _6085,_6164 )];
                int _11375 = _ptr__6105[safe_add( safe_add( _6085,_6164 ),(int)1 )];
                for (int _6172 = _11374; _6172 < _11375; ++_6172)
                {
                  {
                    _ptr__6158[safe_add( _6152,_6162 )] = _ptr__6106[safe_add( _6087,_6172 )];
                    _ptr__6159[safe_add( _6153,_6162 )] = (_ptr__6107[safe_add( _6088,_6172 )] * _6144);
                    if ((_6083 > (int)0))
                    {
                      {
                        int _11376 = _ptr__6105[safe_add( _6090,_6172 )];
                        int _11377 = _ptr__6105[safe_add( safe_add( _6090,_6172 ),(int)1 )];
                        for (int _6173 = _11376; _6173 < _11377; ++_6173)
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = _ptr__6105[safe_add( _6089,_6173 )];
                            _ptr__6159[safe_add( _6156,_6160 )] = _ptr__6107[safe_add( _6091,_6173 )];
                            ++ _6160;
                          }
                        }
                        _ptr__6157[safe_add( _6154,_6160 )] = 2;
                        _ptr__6159[safe_add( _6156,_6160 )] = _6144;
                        ++ _6160;
                        _ptr__6157[safe_add( _6154,_6160 )] = 5;
                        ++ _6160;
                        _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                      }
                    }
                    else
                    {
                      {
                        if ((_6148 > (int)0))
                        {
                          {
                            _ptr__6157[safe_add( _6154,_6160 )] = 2;
                            _ptr__6159[safe_add( _6156,_6160 )] = 0.0;
                            ++ _6160;
                            _ptr__6157[safe_add( safe_add( _6155,_6162 ),(int)1 )] = _6160;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6162;
                  }
                }
                _ptr__6157[safe_add( safe_add( _6150,_6161 ),(int)1 )] = _6162;
                ++ _6165;
                ++ _6164;
              }
            }
            ++ _6161;
          }
        }
        if ((_6162 != _6146))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: invalid nnz"));
          }
        }
        {}
        if ((_6160 != _6148))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: invalid codei"));
          }
        }
        {}
      }
    }
  }
  else
  {
    {
      int _6174 = safe_add( _6095,_6082 );
      int _6175 = (int)0;
      int _6176 = _6092;
      int _6177 = safe_add( _6096,_6083 );
      if (_6108)
      {
        {
          int _11378;
          bool _11379 = (_6096 > (int)0);
          if (_11379)
          {
            _11378 = safe_mul( (int)2,_6095 );
          }
          else
          {
            _11378 = _6095;
          }
          _6177 += _11378;
          int _11380;
          bool _11381 = (_6083 > (int)0);
          if (_11381)
          {
            _11380 = safe_mul( (int)2,_6082 );
          }
          else
          {
            _11380 = _6082;
          }
          _6177 += _11380;
        }
      }
      {}
      long long _6178 = (long long)1;
      int _11382 = (int)0;
      int _11383 = _6176;
      for (int _6179 = _11382; _6179 < _11383; ++_6179)
      {
        {
          _6178 *= _ptr__6105[safe_add( _6093,_6179 )];
        }
      }
      {
        int _6180 = (int)0;
        int _6181 = (int)0;
        while ( ((_6181 < _6094) && (_6180 < _6081)) )
        {
          {
            if ((_ptr__6106[safe_add( _6099,_6181 )] < _ptr__6106[safe_add( _6086,_6180 )]))
            {
              {
                ++ _6175;
                ++ _6181;
              }
            }
            else if((_ptr__6106[safe_add( _6099,_6181 )] > _ptr__6106[safe_add( _6086,_6180 )]))
            {
              {
                ++ _6175;
                ++ _6180;
              }
            }
            else
            {
              {
                ++ _6175;
                ++ _6181;
                ++ _6180;
              }
            }
          }
        }
        _6175 += (safe_add( (_6094 - _6181),_6081 ) - _6180);
      }
      bool _6182 = (_6175 < _6178);
      _6076->alloc_expr(_6176,_6175,_6174,_6182,_6177);
      int _6183 = mosek::fusion::p_WorkStack::_get_impl(_6076)->shape_base;
      int _6184 = mosek::fusion::p_WorkStack::_get_impl(_6076)->ptr_base;
      int _11384;
      bool _11385 = _6182;
      if (_11385)
      {
        _11384 = mosek::fusion::p_WorkStack::_get_impl(_6076)->sp_base;
      }
      else
      {
        _11384 = _6076->alloci64(_6175);
      }
      int _6185 = _11384;
      int _6186 = mosek::fusion::p_WorkStack::_get_impl(_6076)->nidxs_base;
      int _6187 = mosek::fusion::p_WorkStack::_get_impl(_6076)->cof_base;
      int _6188 = mosek::fusion::p_WorkStack::_get_impl(_6076)->code_base;
      int _6189 = mosek::fusion::p_WorkStack::_get_impl(_6076)->codeptr_base;
      int _6190 = mosek::fusion::p_WorkStack::_get_impl(_6076)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6191 = mosek::fusion::p_WorkStack::_get_impl(_6076)->i32;
      _checked_ptr_1<int> _ptr__6191(_6191 ? _6191->raw() : nullptr,_6191 ? _6191->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6192 = mosek::fusion::p_WorkStack::_get_impl(_6076)->i64;
      _checked_ptr_1<long long> _ptr__6192(_6192 ? _6192->raw() : nullptr,_6192 ? _6192->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6193 = mosek::fusion::p_WorkStack::_get_impl(_6076)->f64;
      _checked_ptr_1<double> _ptr__6193(_6193 ? _6193->raw() : nullptr,_6193 ? _6193->size(0) : 0);
      int _11386 = (int)0;
      int _11387 = _6176;
      for (int _6194 = _11386; _6194 < _11387; ++_6194)
      {
        {
          _ptr__6191[safe_add( _6183,_6194 )] = _ptr__6105[safe_add( _6093,_6194 )];
        }
      }
      {
        _ptr__6191[_6184] = (int)0;
        if ((_6177 > (int)0))
        {
          {
            _ptr__6191[_6189] = (int)0;
          }
        }
        {}
        int _6195 = (int)0;
        int _6196 = (int)0;
        int _6197 = (int)0;
        int _6198 = (int)0;
        int _6199 = (int)0;
        while ( ((_6199 < _6094) && (_6198 < _6081)) )
        {
          {
            if ((_ptr__6106[safe_add( _6099,_6199 )] < _ptr__6106[safe_add( _6086,_6198 )]))
            {
              {
                int _11388 = _ptr__6105[safe_add( _6098,_6199 )];
                int _11389 = _ptr__6105[safe_add( safe_add( _6098,_6199 ),(int)1 )];
                for (int _6200 = _11388; _6200 < _11389; ++_6200)
                {
                  {
                    _ptr__6192[safe_add( _6186,_6197 )] = _ptr__6106[safe_add( _6100,_6200 )];
                    _ptr__6193[safe_add( _6187,_6197 )] = (m1 * _ptr__6107[safe_add( _6101,_6200 )]);
                    if ((_6096 > (int)0))
                    {
                      {
                        int _11390 = _ptr__6105[safe_add( _6103,_6200 )];
                        int _11391 = _ptr__6105[safe_add( safe_add( _6103,_6200 ),(int)1 )];
                        for (int _6201 = _11390; _6201 < _11391; ++_6201)
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = _ptr__6105[safe_add( _6102,_6201 )];
                            _ptr__6193[safe_add( _6190,_6195 )] = _ptr__6107[safe_add( _6104,_6201 )];
                            ++ _6195;
                          }
                        }
                        _ptr__6191[safe_add( _6188,_6195 )] = 2;
                        _ptr__6193[safe_add( _6190,_6195 )] = m1;
                        ++ _6195;
                        _ptr__6191[safe_add( _6188,_6195 )] = 5;
                        ++ _6195;
                        _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                      }
                    }
                    else
                    {
                      {
                        if ((_6177 > (int)0))
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = 2;
                            _ptr__6193[safe_add( _6190,_6195 )] = (int)0;
                            ++ _6195;
                            _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6197;
                  }
                }
                _ptr__6192[safe_add( _6185,_6196 )] = _ptr__6106[safe_add( _6099,_6199 )];
                _ptr__6191[safe_add( safe_add( _6184,_6196 ),(int)1 )] = _6197;
                ++ _6196;
                ++ _6199;
              }
            }
            else if((_ptr__6106[safe_add( _6086,_6198 )] < _ptr__6106[safe_add( _6099,_6199 )]))
            {
              {
                int _11392 = _ptr__6105[safe_add( _6085,_6198 )];
                int _11393 = _ptr__6105[safe_add( safe_add( _6085,_6198 ),(int)1 )];
                for (int _6202 = _11392; _6202 < _11393; ++_6202)
                {
                  {
                    _ptr__6192[safe_add( _6186,_6197 )] = _ptr__6106[safe_add( _6087,_6202 )];
                    _ptr__6193[safe_add( _6187,_6197 )] = (m2 * _ptr__6107[safe_add( _6088,_6202 )]);
                    if ((_6083 > (int)0))
                    {
                      {
                        int _11394 = _ptr__6105[safe_add( _6090,_6202 )];
                        int _11395 = _ptr__6105[safe_add( safe_add( _6090,_6202 ),(int)1 )];
                        for (int _6203 = _11394; _6203 < _11395; ++_6203)
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = _ptr__6105[safe_add( _6089,_6203 )];
                            _ptr__6193[safe_add( _6190,_6195 )] = _ptr__6107[safe_add( _6091,_6203 )];
                            ++ _6195;
                          }
                        }
                        _ptr__6191[safe_add( _6188,_6195 )] = 2;
                        _ptr__6193[safe_add( _6190,_6195 )] = m2;
                        ++ _6195;
                        _ptr__6191[safe_add( _6188,_6195 )] = 5;
                        ++ _6195;
                        _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                      }
                    }
                    else
                    {
                      {
                        if ((_6177 > (int)0))
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = 2;
                            _ptr__6193[safe_add( _6190,_6195 )] = (int)0;
                            ++ _6195;
                            _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6197;
                  }
                }
                _ptr__6192[safe_add( _6185,_6196 )] = _ptr__6106[safe_add( _6086,_6198 )];
                _ptr__6191[safe_add( safe_add( _6184,_6196 ),(int)1 )] = _6197;
                ++ _6196;
                ++ _6198;
              }
            }
            else
            {
              {
                int _11396 = _ptr__6105[safe_add( _6098,_6199 )];
                int _11397 = _ptr__6105[safe_add( safe_add( _6098,_6199 ),(int)1 )];
                for (int _6204 = _11396; _6204 < _11397; ++_6204)
                {
                  {
                    _ptr__6192[safe_add( _6186,_6197 )] = _ptr__6106[safe_add( _6100,_6204 )];
                    _ptr__6193[safe_add( _6187,_6197 )] = (m1 * _ptr__6107[safe_add( _6101,_6204 )]);
                    if ((_6096 > (int)0))
                    {
                      {
                        int _11398 = _ptr__6105[safe_add( _6103,_6204 )];
                        int _11399 = _ptr__6105[safe_add( safe_add( _6103,_6204 ),(int)1 )];
                        for (int _6205 = _11398; _6205 < _11399; ++_6205)
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = _ptr__6105[safe_add( _6102,_6205 )];
                            _ptr__6193[safe_add( _6190,_6195 )] = _ptr__6107[safe_add( _6104,_6205 )];
                            ++ _6195;
                          }
                        }
                        _ptr__6191[safe_add( _6188,_6195 )] = 2;
                        _ptr__6193[safe_add( _6190,_6195 )] = m1;
                        ++ _6195;
                        _ptr__6191[safe_add( _6188,_6195 )] = 5;
                        ++ _6195;
                        _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                      }
                    }
                    else
                    {
                      {
                        if ((_6177 > (int)0))
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = 2;
                            _ptr__6193[safe_add( _6190,_6195 )] = (int)0;
                            ++ _6195;
                            _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6197;
                  }
                }
                int _11400 = _ptr__6105[safe_add( _6085,_6198 )];
                int _11401 = _ptr__6105[safe_add( safe_add( _6085,_6198 ),(int)1 )];
                for (int _6206 = _11400; _6206 < _11401; ++_6206)
                {
                  {
                    _ptr__6192[safe_add( _6186,_6197 )] = _ptr__6106[safe_add( _6087,_6206 )];
                    _ptr__6193[safe_add( _6187,_6197 )] = (m2 * _ptr__6107[safe_add( _6088,_6206 )]);
                    if ((_6083 > (int)0))
                    {
                      {
                        int _11402 = _ptr__6105[safe_add( _6090,_6206 )];
                        int _11403 = _ptr__6105[safe_add( safe_add( _6090,_6206 ),(int)1 )];
                        for (int _6207 = _11402; _6207 < _11403; ++_6207)
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = _ptr__6105[safe_add( _6089,_6207 )];
                            _ptr__6193[safe_add( _6190,_6195 )] = _ptr__6107[safe_add( _6091,_6207 )];
                            ++ _6195;
                          }
                        }
                        _ptr__6191[safe_add( _6188,_6195 )] = 2;
                        _ptr__6193[safe_add( _6190,_6195 )] = m2;
                        ++ _6195;
                        _ptr__6191[safe_add( _6188,_6195 )] = 5;
                        ++ _6195;
                        _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                      }
                    }
                    else
                    {
                      {
                        if ((_6177 > (int)0))
                        {
                          {
                            _ptr__6191[safe_add( _6188,_6195 )] = 2;
                            _ptr__6193[safe_add( _6190,_6195 )] = (int)0;
                            ++ _6195;
                            _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                          }
                        }
                        {}
                      }
                    }
                    ++ _6197;
                  }
                }
                _ptr__6192[safe_add( _6185,_6196 )] = _ptr__6106[safe_add( _6099,_6199 )];
                _ptr__6191[safe_add( safe_add( _6184,_6196 ),(int)1 )] = _6197;
                ++ _6196;
                ++ _6199;
                ++ _6198;
              }
            }
          }
        }
        while ( (_6199 < _6094) )
        {
          {
            int _11404 = _ptr__6105[safe_add( _6098,_6199 )];
            int _11405 = _ptr__6105[safe_add( safe_add( _6098,_6199 ),(int)1 )];
            for (int _6208 = _11404; _6208 < _11405; ++_6208)
            {
              {
                _ptr__6192[safe_add( _6186,_6197 )] = _ptr__6106[safe_add( _6100,_6208 )];
                _ptr__6193[safe_add( _6187,_6197 )] = (m1 * _ptr__6107[safe_add( _6101,_6208 )]);
                if ((_6096 > (int)0))
                {
                  {
                    int _11406 = _ptr__6105[safe_add( _6103,_6208 )];
                    int _11407 = _ptr__6105[safe_add( safe_add( _6103,_6208 ),(int)1 )];
                    for (int _6209 = _11406; _6209 < _11407; ++_6209)
                    {
                      {
                        _ptr__6191[safe_add( _6188,_6195 )] = _ptr__6105[safe_add( _6102,_6209 )];
                        _ptr__6193[safe_add( _6190,_6195 )] = _ptr__6107[safe_add( _6104,_6209 )];
                        ++ _6195;
                      }
                    }
                    _ptr__6191[safe_add( _6188,_6195 )] = 2;
                    _ptr__6193[safe_add( _6190,_6195 )] = m1;
                    ++ _6195;
                    _ptr__6191[safe_add( _6188,_6195 )] = 5;
                    ++ _6195;
                    _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                  }
                }
                else
                {
                  {
                    if ((_6177 > (int)0))
                    {
                      {
                        _ptr__6191[safe_add( _6188,_6195 )] = 2;
                        _ptr__6193[safe_add( _6190,_6195 )] = (int)0;
                        ++ _6195;
                        _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                      }
                    }
                    {}
                  }
                }
                ++ _6197;
              }
            }
            _ptr__6192[safe_add( _6185,_6196 )] = _ptr__6106[safe_add( _6099,_6199 )];
            _ptr__6191[safe_add( safe_add( _6184,_6196 ),(int)1 )] = _6197;
            ++ _6196;
            ++ _6199;
          }
        }
        while ( (_6198 < _6081) )
        {
          {
            int _11408 = _ptr__6105[safe_add( _6085,_6198 )];
            int _11409 = _ptr__6105[safe_add( safe_add( _6085,_6198 ),(int)1 )];
            for (int _6210 = _11408; _6210 < _11409; ++_6210)
            {
              {
                _ptr__6192[safe_add( _6186,_6197 )] = _ptr__6106[safe_add( _6087,_6210 )];
                _ptr__6193[safe_add( _6187,_6197 )] = (m2 * _ptr__6107[safe_add( _6088,_6210 )]);
                if ((_6083 > (int)0))
                {
                  {
                    int _11410 = _ptr__6105[safe_add( _6090,_6210 )];
                    int _11411 = _ptr__6105[safe_add( safe_add( _6090,_6210 ),(int)1 )];
                    for (int _6211 = _11410; _6211 < _11411; ++_6211)
                    {
                      {
                        _ptr__6191[safe_add( _6188,_6195 )] = _ptr__6105[safe_add( _6089,_6211 )];
                        _ptr__6193[safe_add( _6190,_6195 )] = _ptr__6107[safe_add( _6091,_6211 )];
                        ++ _6195;
                      }
                    }
                    _ptr__6191[safe_add( _6188,_6195 )] = 2;
                    _ptr__6193[safe_add( _6190,_6195 )] = m2;
                    ++ _6195;
                    _ptr__6191[safe_add( _6188,_6195 )] = 5;
                    ++ _6195;
                    _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                  }
                }
                else
                {
                  {
                    if ((_6177 > (int)0))
                    {
                      {
                        _ptr__6191[safe_add( _6188,_6195 )] = 2;
                        _ptr__6193[safe_add( _6190,_6195 )] = (int)0;
                        ++ _6195;
                        _ptr__6191[safe_add( safe_add( _6189,_6197 ),(int)1 )] = _6195;
                      }
                    }
                    {}
                  }
                }
                ++ _6197;
              }
            }
            _ptr__6192[safe_add( _6185,_6196 )] = _ptr__6106[safe_add( _6086,_6198 )];
            _ptr__6191[safe_add( safe_add( _6184,_6196 ),(int)1 )] = _6197;
            ++ _6196;
            ++ _6198;
          }
        }
      }
      if ((!_6182))
      {
        {
          _6076->popi64(_6175);
        }
      }
      {}
    }
  }
}
std::string mosek::fusion::ExprAdd :: toString() { return mosek::fusion::p_ExprAdd::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprAdd::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprAdd("))->__mosek_2fusion_2Utils_2StringBuffer__a(e1->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(e2->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("; "))->__mosek_2fusion_2Utils_2StringBuffer__a(m1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(m2)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprAdd::destroy(){e2.reset();e1.reset();}void mosek::fusion::ExprAdd::destroy() { mosek::fusion::p_ExprAdd::_get_impl(this)->destroy(); }mosek::fusion::ExprWSum::ExprWSum(mosek::fusion::p_ExprWSum *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprWSum()" << this << std::endl; */ }mosek::fusion::ExprWSum::~ExprWSum() {  /* std::cout << "~ExprWSum()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprWSum::p_ExprWSum  (::mosek::fusion::ExprWSum * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprWSum::t mosek::fusion::p_ExprWSum::_new_ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _6212,    std::shared_ptr< monty::ndarray< double,1 > > _6213){ return new mosek::fusion::ExprWSum(_6212,_6213); }mosek::fusion::ExprWSum::ExprWSum  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _6212,    std::shared_ptr< monty::ndarray< double,1 > > _6213) :    ExprWSum(new mosek::fusion::p_ExprWSum(this)){ mosek::fusion::p_ExprWSum::_get_impl(this)->_initialize(_6212,_6213); }void mosek::fusion::p_ExprWSum::_initialize  (std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _6212,    std::shared_ptr< monty::ndarray< double,1 > > _6213){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__6213(_6213 ? _6213->raw() : nullptr, _6213 ? _6213->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(((*_6212)((int)0))->getShape());
    if (((int)((_6213)->size(0)) != (int)((_6212)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching weights and expressions array lengths"));
      }
    }
    {}
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->w = ::mosek::fusion::Utils::Tools::arraycopy(_6213);
    std::shared_ptr< monty::ndarray< int,1 > > _6214 = ((*_6212)((int)0))->getShape();
    _checked_ptr_1<int> _ptr__6214(_6214 ? _6214->raw() : nullptr,_6214 ? _6214->size(0) : 0);
    int _6215 = (int)((_6214)->size(0));
    int _11412 = (int)1;
    int _11413 = (int)((_6212)->size(0));
    for (int _6216 = _11412; _6216 < _11413; ++_6216)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _6217 = ((*_6212)(_6216))->getShape();
        _checked_ptr_1<int> _ptr__6217(_6217 ? _6217->raw() : nullptr,_6217 ? _6217->size(0) : 0);
        if ((_6215 != (int)((_6217)->size(0))))
        {
          {
            throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
          }
        }
        else
        {
          {
            int _11414 = (int)0;
            int _11415 = _6215;
            for (int _6218 = _11414; _6218 < _11415; ++_6218)
            {
              {
                if ((_ptr__6214[_6218] != _ptr__6217[_6218]))
                {
                  {
                    throw ::mosek::fusion::DimensionError(std::string ("Mismatching expression shapes"));
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _11416;
    for (int _6219 = (int)0, _11417 = (int)((_6212)->size(0)); _6219 < _11417 ; ++_6219)
    {
      _11416.push_back(((*_6212)(_6219)));
    }
    auto _11418 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_11416.size()),_11416.begin(),_11416.end()));
    mosek::fusion::p_ExprWSum::_get_impl(::mosek::fusion::ExprWSum::t(_pubthis))->es = _11418;
  }
}void mosek::fusion::ExprWSum :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6220,monty::rc_ptr< ::mosek::fusion::WorkStack > _6221,monty::rc_ptr< ::mosek::fusion::WorkStack > _6222) { mosek::fusion::p_ExprWSum::_get_impl(this)->eval(_6220,_6221,_6222); }void mosek::fusion::p_ExprWSum::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6220,monty::rc_ptr< ::mosek::fusion::WorkStack > _6221,monty::rc_ptr< ::mosek::fusion::WorkStack > _6222){
  int _6223 = (int)((es)->size(0));
  int _11419 = (int)0;
  int _11420 = _6223;
  for (int _6224 = _11419; _6224 < _11420; ++_6224)
  {
    {
      ((*es)(_6224))->eval(_6221,_6220,_6222);
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _6225 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6225(_6225 ? _6225->raw() : nullptr,_6225 ? _6225->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6226 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6226(_6226 ? _6226->raw() : nullptr,_6226 ? _6226->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6227 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6227(_6227 ? _6227->raw() : nullptr,_6227 ? _6227->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6228 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6228(_6228 ? _6228->raw() : nullptr,_6228 ? _6228->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6229 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6229(_6229 ? _6229->raw() : nullptr,_6229 ? _6229->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6230 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6230(_6230 ? _6230->raw() : nullptr,_6230 ? _6230->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6231 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6231(_6231 ? _6231->raw() : nullptr,_6231 ? _6231->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6232 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6232(_6232 ? _6232->raw() : nullptr,_6232 ? _6232->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6233 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6233(_6233 ? _6233->raw() : nullptr,_6233 ? _6233->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6234 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6234(_6234 ? _6234->raw() : nullptr,_6234 ? _6234->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6235 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6235(_6235 ? _6235->raw() : nullptr,_6235 ? _6235->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6236 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
  _checked_ptr_1<int> _ptr__6236(_6236 ? _6236->raw() : nullptr,_6236 ? _6236->size(0) : 0);
  std::shared_ptr< monty::ndarray< bool,1 > > _6237 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape(_6223)));
  int _11421 = (int)0;
  int _11422 = _6223;
  for (int _6238 = _11421; _6238 < _11422; ++_6238)
  {
    {
      _6221->pop_expr();
      _ptr__6225[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->nd;
      _ptr__6226[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->nelem;
      _ptr__6227[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->nnz;
      _ptr__6228[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->ncodeatom;
      _ptr__6229[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->ptr_base;
      _ptr__6231[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->sp_base;
      _ptr__6230[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->nidxs_base;
      _ptr__6232[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->cof_base;
      _ptr__6233[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->shape_base;
      _ptr__6234[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->code_base;
      _ptr__6235[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->codeptr_base;
      _ptr__6236[((_6223 - (int)1) - _6238)] = mosek::fusion::p_WorkStack::_get_impl(_6221)->cconst_base;
      ((*_6237)(((_6223 - (int)1) - _6238))) = mosek::fusion::p_WorkStack::_get_impl(_6221)->hassp;
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _6239 = mosek::fusion::p_WorkStack::_get_impl(_6221)->i32;
  _checked_ptr_1<int> _ptr__6239(_6239 ? _6239->raw() : nullptr,_6239 ? _6239->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6240 = mosek::fusion::p_WorkStack::_get_impl(_6221)->i64;
  _checked_ptr_1<long long> _ptr__6240(_6240 ? _6240->raw() : nullptr,_6240 ? _6240->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6241 = mosek::fusion::p_WorkStack::_get_impl(_6221)->f64;
  _checked_ptr_1<double> _ptr__6241(_6241 ? _6241->raw() : nullptr,_6241 ? _6241->size(0) : 0);
  {
    bool _6242 = true;
    int _11423 = (int)1;
    int _11424 = _6223;
    for (int _6243 = _11423; _6243 < _11424; ++_6243)
    {
      {
        _6242 = (_6242 && (_ptr__6225[(int)0] == _ptr__6225[_6243]));
        int _11425 = (int)0;
        int _11426 = _ptr__6225[(int)0];
        for (int _6244 = _11425; _6244 < _11426; ++_6244)
        {
          {
            _6242 = (_6242 && (_ptr__6239[safe_add( _ptr__6233[(int)0],_6244 )] == _ptr__6239[safe_add( _ptr__6233[_6243],_6244 )]));
          }
        }
      }
    }
    if ((!_6242))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
      }
    }
    {}
  }
  std::vector<int> _11427;
  for (int _6246 = (int)0, _11428 = _ptr__6225[(int)0]; _6246 < _11428 ; ++_6246)
  {
    _11427.push_back(_ptr__6239[safe_add( _ptr__6233[(int)0],_6246 )]);
  }
  auto _11429 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11427.size()),_11427.begin(),_11427.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _6245 = _11429;
  _checked_ptr_1<int> _ptr__6245(_6245 ? _6245->raw() : nullptr,_6245 ? _6245->size(0) : 0);
  bool _6247 = false;
  int _11430 = (int)0;
  int _11431 = _6223;
  for (int _6248 = _11430; _6248 < _11431; ++_6248)
  {
    {
      if ((!((*_6237)(_6248))))
      {
        {
          _6247 = true;
        }
      }
      {}
    }
  }
  bool _6249 = false;
  int _11432 = (int)0;
  int _11433 = _6223;
  for (int _6250 = _11432; _6250 < _11433; ++_6250)
  {
    {
      if ((_ptr__6228[_6250] > (int)0))
      {
        {
          _6249 = true;
        }
      }
      {}
    }
  }
  int _6251 = (int)0;
  int _6252 = (int)0;
  int _6253 = (int)0;
  if (_6247)
  {
    {
      _6252 = (int)::mosek::fusion::p_Set::size(_6245);
      int _11434 = (int)0;
      int _11435 = _6223;
      for (int _6254 = _11434; _6254 < _11435; ++_6254)
      {
        {
          _6253 += _ptr__6227[_6254];
          if (_6249)
          {
            {
              int _11436;
              bool _11437 = (_ptr__6228[_6254] > (int)0);
              if (_11437)
              {
                _11436 = safe_add( _ptr__6228[_6254],safe_mul( (int)2,_ptr__6227[_6254] ) );
              }
              else
              {
                _11436 = _ptr__6227[_6254];
              }
              _6251 += _11436;
            }
          }
          {}
        }
      }
    }
  }
  else
  {
    {
      bool _6255 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _6256 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
      _checked_ptr_1<int> _ptr__6256(_6256 ? _6256->raw() : nullptr,_6256 ? _6256->size(0) : 0);
      int _11438 = (int)0;
      int _11439 = _6223;
      for (int _6257 = _11438; _6257 < _11439; ++_6257)
      {
        {
          _6253 += _ptr__6227[_6257];
          if (_6249)
          {
            {
              int _11440;
              bool _11441 = (_ptr__6228[_6257] > (int)0);
              if (_11441)
              {
                _11440 = safe_add( _ptr__6228[_6257],safe_mul( (int)2,_ptr__6227[_6257] ) );
              }
              else
              {
                _11440 = _ptr__6227[_6257];
              }
              _6251 += _11440;
            }
          }
          {}
        }
      }
      while ( (!_6255) )
      {
        {
          long long _6258 = (-(int)1);
          int _11442 = (int)0;
          int _11443 = _6223;
          for (int _6259 = _11442; _6259 < _11443; ++_6259)
          {
            {
              if (((_ptr__6256[_6259] < _ptr__6226[_6259]) && ((_6258 < (int)0) || (_ptr__6240[safe_add( _ptr__6231[_6259],_ptr__6256[_6259] )] < _6258))))
              {
                {
                  _6258 = _ptr__6240[safe_add( _ptr__6231[_6259],_ptr__6256[_6259] )];
                }
              }
              {}
            }
          }
          if ((_6258 < (int)0))
          {
            {
              _6255 = true;
            }
          }
          else
          {
            {
              int _11444 = (int)0;
              int _11445 = _6223;
              for (int _6260 = _11444; _6260 < _11445; ++_6260)
              {
                {
                  if (((_ptr__6256[_6260] < _ptr__6226[_6260]) && (_6258 == _ptr__6240[safe_add( _ptr__6231[_6260],_ptr__6256[_6260] )])))
                  {
                    {
                      ++ _ptr__6256[_6260];
                    }
                  }
                  {}
                }
              }
              ++ _6252;
            }
          }
        }
      }
    }
  }
  _6220->alloc_expr(_ptr__6225[(int)0],_6252,_6253,(!_6247),_6251);
  int _6261 = mosek::fusion::p_WorkStack::_get_impl(_6220)->ptr_base;
  int _6262 = mosek::fusion::p_WorkStack::_get_impl(_6220)->nidxs_base;
  int _6263 = mosek::fusion::p_WorkStack::_get_impl(_6220)->sp_base;
  int _6264 = mosek::fusion::p_WorkStack::_get_impl(_6220)->shape_base;
  int _6265 = mosek::fusion::p_WorkStack::_get_impl(_6220)->cof_base;
  int _6266 = mosek::fusion::p_WorkStack::_get_impl(_6220)->code_base;
  int _6267 = mosek::fusion::p_WorkStack::_get_impl(_6220)->codeptr_base;
  int _6268 = mosek::fusion::p_WorkStack::_get_impl(_6220)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6269 = mosek::fusion::p_WorkStack::_get_impl(_6220)->i32;
  _checked_ptr_1<int> _ptr__6269(_6269 ? _6269->raw() : nullptr,_6269 ? _6269->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6270 = mosek::fusion::p_WorkStack::_get_impl(_6220)->i64;
  _checked_ptr_1<long long> _ptr__6270(_6270 ? _6270->raw() : nullptr,_6270 ? _6270->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6271 = mosek::fusion::p_WorkStack::_get_impl(_6220)->f64;
  _checked_ptr_1<double> _ptr__6271(_6271 ? _6271->raw() : nullptr,_6271 ? _6271->size(0) : 0);
  int _11446 = (int)0;
  int _11447 = _ptr__6225[(int)0];
  for (int _6272 = _11446; _6272 < _11447; ++_6272)
  {
    {
      _ptr__6269[safe_add( _6264,_6272 )] = _ptr__6239[safe_add( _ptr__6233[(int)0],_6272 )];
    }
  }
  if ((_6251 > (int)0))
  {
    {
      _ptr__6269[_6267] = (int)0;
    }
  }
  {}
  int _11448 = (int)0;
  int _11449 = safe_add( _6252,(int)1 );
  for (int _6273 = _11448; _6273 < _11449; ++_6273)
  {
    {
      _ptr__6269[safe_add( _6261,_6273 )] = (int)0;
    }
  }
  if (_6247)
  {
    {
      int _6274 = (-(int)9999);
      if ((_6251 > (int)0))
      {
        {
          _6274 = _6222->alloci32(safe_add( _6252,(int)1 ));
        }
      }
      {}
      std::shared_ptr< monty::ndarray< int,1 > > _6275 = mosek::fusion::p_WorkStack::_get_impl(_6222)->i32;
      _checked_ptr_1<int> _ptr__6275(_6275 ? _6275->raw() : nullptr,_6275 ? _6275->size(0) : 0);
      if ((_6251 > (int)0))
      {
        {
          int _11450 = (int)0;
          int _11451 = safe_add( _6252,(int)1 );
          for (int _6276 = _11450; _6276 < _11451; ++_6276)
          {
            {
              _ptr__6275[safe_add( _6274,_6276 )] = (int)0;
            }
          }
        }
      }
      {}
      int _11452 = (int)0;
      int _11453 = _6223;
      for (int _6277 = _11452; _6277 < _11453; ++_6277)
      {
        {
          if (((*_6237)(_6277)))
          {
            {
              int _11454 = (int)0;
              int _11455 = _ptr__6226[_6277];
              for (int _6278 = _11454; _6278 < _11455; ++_6278)
              {
                {
                  _ptr__6269[safe_add( safe_add( _6261,_ptr__6240[safe_add( _ptr__6231[_6277],_6278 )] ),(int)1 )] += (_ptr__6239[safe_add( safe_add( _ptr__6229[_6277],_6278 ),(int)1 )] - _ptr__6239[safe_add( _ptr__6229[_6277],_6278 )]);
                }
              }
              if ((_ptr__6228[_6277] > (int)0))
              {
                {
                  int _11456 = (int)0;
                  int _11457 = _ptr__6226[_6277];
                  for (int _6279 = _11456; _6279 < _11457; ++_6279)
                  {
                    {
                      _ptr__6275[safe_add( safe_add( _6274,_ptr__6240[safe_add( _ptr__6231[_6277],_6279 )] ),(int)1 )] += safe_add( (_ptr__6239[safe_add( _ptr__6235[_6277],_ptr__6239[safe_add( safe_add( _ptr__6229[_6277],_6279 ),(int)1 )] )] - _ptr__6239[safe_add( _ptr__6235[_6277],_ptr__6239[safe_add( _ptr__6229[_6277],_6279 )] )]),safe_mul( (int)2,(_ptr__6239[safe_add( safe_add( _ptr__6229[_6277],_6279 ),(int)1 )] - _ptr__6239[safe_add( _ptr__6229[_6277],_6279 )]) ) );
                    }
                  }
                }
              }
              else if(_6249)
              {
                {
                  int _11458 = (int)0;
                  int _11459 = _ptr__6226[_6277];
                  for (int _6280 = _11458; _6280 < _11459; ++_6280)
                  {
                    {
                      _ptr__6275[safe_add( safe_add( _6274,_ptr__6240[safe_add( _ptr__6231[_6277],_6280 )] ),(int)1 )] += (int)1;
                    }
                  }
                }
              }
              {}
            }
          }
          else
          {
            {
              int _11460 = (int)0;
              int _11461 = _ptr__6226[_6277];
              for (int _6281 = _11460; _6281 < _11461; ++_6281)
              {
                {
                  _ptr__6269[safe_add( safe_add( _6261,_6281 ),(int)1 )] += (_ptr__6239[safe_add( safe_add( _ptr__6229[_6277],_6281 ),(int)1 )] - _ptr__6239[safe_add( _ptr__6229[_6277],_6281 )]);
                }
              }
              if ((_ptr__6228[_6277] > (int)0))
              {
                {
                  int _11462 = (int)0;
                  int _11463 = _ptr__6226[_6277];
                  for (int _6282 = _11462; _6282 < _11463; ++_6282)
                  {
                    {
                      _ptr__6275[safe_add( safe_add( _6274,_6282 ),(int)1 )] += safe_add( (_ptr__6239[safe_add( _ptr__6235[_6277],_ptr__6239[safe_add( safe_add( _ptr__6229[_6277],_6282 ),(int)1 )] )] - _ptr__6239[safe_add( _ptr__6235[_6277],_ptr__6239[safe_add( _ptr__6229[_6277],_6282 )] )]),safe_mul( (int)2,(_ptr__6239[safe_add( safe_add( _ptr__6229[_6277],_6282 ),(int)1 )] - _ptr__6239[safe_add( _ptr__6229[_6277],_6282 )]) ) );
                    }
                  }
                }
              }
              else if(_6249)
              {
                {
                  int _11464 = (int)0;
                  int _11465 = _ptr__6226[_6277];
                  for (int _6283 = _11464; _6283 < _11465; ++_6283)
                  {
                    {
                      _ptr__6275[safe_add( safe_add( _6274,_6283 ),(int)1 )] += (int)1;
                    }
                  }
                }
              }
              {}
            }
          }
        }
      }
      int _11466 = (int)0;
      int _11467 = _6252;
      for (int _6284 = _11466; _6284 < _11467; ++_6284)
      {
        {
          _ptr__6269[safe_add( safe_add( _6261,_6284 ),(int)1 )] += _ptr__6269[safe_add( _6261,_6284 )];
        }
      }
      if ((_6251 > (int)0))
      {
        {
          int _11468 = (int)0;
          int _11469 = _6252;
          for (int _6285 = _11468; _6285 < _11469; ++_6285)
          {
            {
              _ptr__6275[safe_add( safe_add( _6274,_6285 ),(int)1 )] += _ptr__6275[safe_add( _6274,_6285 )];
            }
          }
        }
      }
      {}
      int _11470 = (int)0;
      int _11471 = _6223;
      for (int _6286 = _11470; _6286 < _11471; ++_6286)
      {
        {
          if (((*_6237)(_6286)))
          {
            {
              int _11472 = (int)0;
              int _11473 = _ptr__6226[_6286];
              for (int _6287 = _11472; _6287 < _11473; ++_6287)
              {
                {
                  int _6288 = _ptr__6239[safe_add( _ptr__6229[_6286],_6287 )];
                  int _6289 = _ptr__6239[safe_add( safe_add( _ptr__6229[_6286],_6287 ),(int)1 )];
                  long long _6290 = _ptr__6240[safe_add( _ptr__6231[_6286],_6287 )];
                  int _6291 = _ptr__6269[safe_add( _6261,_6290 )];
                  int _11474;
                  bool _11475 = _6249;
                  if (_11475)
                  {
                    _11474 = _ptr__6275[safe_add( _6274,_6290 )];
                  }
                  else
                  {
                    _11474 = (-(int)10000);
                  }
                  int _6292 = _11474;
                  int _11476 = _6288;
                  int _11477 = _6289;
                  for (int _6293 = _11476; _6293 < _11477; ++_6293)
                  {
                    {
                      _ptr__6270[safe_add( _6262,_6291 )] = _ptr__6240[safe_add( _ptr__6230[_6286],_6293 )];
                      _ptr__6271[safe_add( _6265,_6291 )] = (((*w)(_6286)) * _ptr__6241[safe_add( _ptr__6232[_6286],_6293 )]);
                      if (_6249)
                      {
                        {
                          if ((_ptr__6228[_6286] > (int)0))
                          {
                            {
                              int _11478 = _ptr__6239[safe_add( _ptr__6235[_6286],_6293 )];
                              int _11479 = _ptr__6239[safe_add( safe_add( _ptr__6235[_6286],_6293 ),(int)1 )];
                              for (int _6294 = _11478; _6294 < _11479; ++_6294)
                              {
                                {
                                  _ptr__6269[safe_add( _6266,_6292 )] = _ptr__6239[safe_add( _ptr__6234[_6286],_6294 )];
                                  _ptr__6271[safe_add( _6268,_6292 )] = _ptr__6241[safe_add( _ptr__6236[_6286],_6294 )];
                                  ++ _6292;
                                }
                              }
                              _ptr__6269[safe_add( _6266,_6292 )] = 2;
                              _ptr__6271[safe_add( _6268,_6292 )] = ((*w)(_6286));
                              ++ _6292;
                              _ptr__6269[safe_add( _6266,_6292 )] = 5;
                              ++ _6292;
                            }
                          }
                          else
                          {
                            {
                              _ptr__6269[safe_add( _6266,_6292 )] = 2;
                              _ptr__6271[safe_add( _6268,_6292 )] = 0.0;
                              ++ _6292;
                            }
                          }
                          _ptr__6269[safe_add( safe_add( _6267,_6291 ),(int)1 )] = _6292;
                        }
                      }
                      {}
                      ++ _6291;
                    }
                  }
                  if (_6249)
                  {
                    {
                      _ptr__6275[safe_add( _6274,_6290 )] = _6292;
                    }
                  }
                  {}
                  _ptr__6269[safe_add( _6261,_6290 )] += (_6289 - _6288);
                }
              }
            }
          }
          else
          {
            {
              int _11480 = (int)0;
              int _11481 = _ptr__6226[_6286];
              for (int _6295 = _11480; _6295 < _11481; ++_6295)
              {
                {
                  int _6296 = _ptr__6239[safe_add( _ptr__6229[_6286],_6295 )];
                  int _6297 = _ptr__6239[safe_add( safe_add( _ptr__6229[_6286],_6295 ),(int)1 )];
                  int _6298 = _6295;
                  int _6299 = _ptr__6269[safe_add( _6261,_6298 )];
                  int _11482;
                  bool _11483 = _6249;
                  if (_11483)
                  {
                    _11482 = _ptr__6275[safe_add( _6274,_6298 )];
                  }
                  else
                  {
                    _11482 = (-(int)10000);
                  }
                  int _6300 = _11482;
                  int _11484 = _6296;
                  int _11485 = _6297;
                  for (int _6301 = _11484; _6301 < _11485; ++_6301)
                  {
                    {
                      _ptr__6270[safe_add( _6262,_6299 )] = _ptr__6240[safe_add( _ptr__6230[_6286],_6301 )];
                      _ptr__6271[safe_add( _6265,_6299 )] = (((*w)(_6286)) * _ptr__6241[safe_add( _ptr__6232[_6286],_6301 )]);
                      if (_6249)
                      {
                        {
                          if ((_ptr__6228[_6286] > (int)0))
                          {
                            {
                              int _11486 = _ptr__6239[safe_add( _ptr__6235[_6286],_6301 )];
                              int _11487 = _ptr__6239[safe_add( safe_add( _ptr__6235[_6286],_6301 ),(int)1 )];
                              for (int _6302 = _11486; _6302 < _11487; ++_6302)
                              {
                                {
                                  _ptr__6269[safe_add( _6266,_6300 )] = _ptr__6239[safe_add( _ptr__6234[_6286],_6302 )];
                                  _ptr__6271[safe_add( _6268,_6300 )] = _ptr__6241[safe_add( _ptr__6236[_6286],_6302 )];
                                  ++ _6300;
                                }
                              }
                              _ptr__6269[safe_add( _6266,_6300 )] = 2;
                              _ptr__6271[safe_add( _6268,_6300 )] = ((*w)(_6286));
                              ++ _6300;
                              _ptr__6269[safe_add( _6266,_6300 )] = 5;
                              ++ _6300;
                              _ptr__6269[safe_add( safe_add( _6267,_6299 ),(int)1 )] = _6300;
                            }
                          }
                          else
                          {
                            {
                              _ptr__6269[safe_add( _6266,_6300 )] = 2;
                              _ptr__6271[safe_add( _6268,_6300 )] = 0.0;
                              ++ _6300;
                            }
                          }
                          _ptr__6269[safe_add( safe_add( _6267,_6299 ),(int)1 )] = _6300;
                        }
                      }
                      {}
                      ++ _6299;
                    }
                  }
                  if (_6249)
                  {
                    {
                      _ptr__6275[safe_add( _6274,_6298 )] = _6300;
                    }
                  }
                  {}
                  _ptr__6269[safe_add( _6261,_6298 )] += (_6297 - _6296);
                }
              }
            }
          }
        }
      }
      int _11488 = (int)0;
      int _11489 = _6252;
      for (int _6303 = _11488; _6303 < _11489; ++_6303)
      {
        {
          _ptr__6269[(safe_add( _6261,_6252 ) - _6303)] = _ptr__6269[((safe_add( _6261,_6252 ) - _6303) - (int)1)];
        }
      }
      _ptr__6269[_6261] = (int)0;
    }
  }
  else
  {
    {
      bool _6304 = false;
      std::shared_ptr< monty::ndarray< int,1 > > _6305 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6223)));
      _checked_ptr_1<int> _ptr__6305(_6305 ? _6305->raw() : nullptr,_6305 ? _6305->size(0) : 0);
      int _6306 = (int)0;
      int _6307 = (int)0;
      int _6308 = (int)0;
      while ( (!_6304) )
      {
        {
          long long _6309 = (-(int)1);
          int _11490 = (int)0;
          int _11491 = _6223;
          for (int _6310 = _11490; _6310 < _11491; ++_6310)
          {
            {
              if (((_ptr__6305[_6310] < _ptr__6226[_6310]) && ((_6309 < (int)0) || (_ptr__6240[safe_add( _ptr__6231[_6310],_ptr__6305[_6310] )] < _6309))))
              {
                {
                  _6309 = _ptr__6240[safe_add( _ptr__6231[_6310],_ptr__6305[_6310] )];
                }
              }
              {}
            }
          }
          if ((_6309 < (int)0))
          {
            {
              _6304 = true;
            }
          }
          else
          {
            {
              int _11492 = (int)0;
              int _11493 = _6223;
              for (int _6311 = _11492; _6311 < _11493; ++_6311)
              {
                {
                  if (((_ptr__6305[_6311] < _ptr__6226[_6311]) && (_6309 == _ptr__6240[safe_add( _ptr__6231[_6311],_ptr__6305[_6311] )])))
                  {
                    {
                      int _11494 = _ptr__6239[safe_add( _ptr__6229[_6311],_ptr__6305[_6311] )];
                      int _11495 = _ptr__6239[safe_add( safe_add( _ptr__6229[_6311],_ptr__6305[_6311] ),(int)1 )];
                      for (int _6312 = _11494; _6312 < _11495; ++_6312)
                      {
                        {
                          _ptr__6270[safe_add( _6262,_6308 )] = _ptr__6240[safe_add( _ptr__6230[_6311],_6312 )];
                          _ptr__6271[safe_add( _6265,_6308 )] = (((*w)(_6311)) * _ptr__6241[safe_add( _ptr__6232[_6311],_6312 )]);
                          if (_6249)
                          {
                            {
                              if ((_ptr__6228[_6311] > (int)0))
                              {
                                {
                                  int _11496 = _ptr__6239[safe_add( _ptr__6235[_6311],_6312 )];
                                  int _11497 = _ptr__6239[safe_add( safe_add( _ptr__6235[_6311],_6312 ),(int)1 )];
                                  for (int _6313 = _11496; _6313 < _11497; ++_6313)
                                  {
                                    {
                                      _ptr__6269[safe_add( _6266,_6306 )] = _ptr__6239[safe_add( _ptr__6234[_6311],_6313 )];
                                      _ptr__6271[safe_add( _6268,_6306 )] = _ptr__6241[safe_add( _ptr__6236[_6311],_6313 )];
                                      ++ _6306;
                                    }
                                  }
                                  _ptr__6269[safe_add( _6266,_6306 )] = 2;
                                  _ptr__6271[safe_add( _6268,_6306 )] = ((*w)(_6311));
                                  ++ _6306;
                                  _ptr__6269[safe_add( _6266,_6306 )] = 5;
                                  ++ _6306;
                                }
                              }
                              else
                              {
                                {
                                  _ptr__6269[safe_add( _6266,_6306 )] = 2;
                                  _ptr__6271[safe_add( _6268,_6306 )] = 0.0;
                                  ++ _6306;
                                }
                              }
                              _ptr__6269[safe_add( safe_add( _6267,_6308 ),(int)1 )] = _6306;
                            }
                          }
                          {}
                          ++ _6308;
                        }
                      }
                      ++ _ptr__6305[_6311];
                    }
                  }
                  {}
                }
              }
              _ptr__6269[safe_add( safe_add( _6261,_6307 ),(int)1 )] = _6308;
              _ptr__6270[safe_add( _6263,_6307 )] = _6309;
            }
          }
          ++ _6307;
        }
      }
    }
  }
  _6222->clear();
}
std::string mosek::fusion::ExprWSum :: toString() { return mosek::fusion::p_ExprWSum::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprWSum::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _6314 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprWSum(["));
  _6314->__mosek_2fusion_2Utils_2StringBuffer__a(((*es)((int)0))->toString());
  int _11498 = (int)1;
  int _11499 = (int)((es)->size(0));
  for (int _6315 = _11498; _6315 < _11499; ++_6315)
  {
    {
      _6314->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*es)(_6315))->toString());
    }
  }
  _6314->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("])"));
  return _6314->toString();
}
void mosek::fusion::p_ExprWSum::destroy(){w.reset();es.reset();}void mosek::fusion::ExprWSum::destroy() { mosek::fusion::p_ExprWSum::_get_impl(this)->destroy(); }mosek::fusion::ExprSumReduce::ExprSumReduce(mosek::fusion::p_ExprSumReduce *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSumReduce()" << this << std::endl; */ }mosek::fusion::ExprSumReduce::~ExprSumReduce() {  /* std::cout << "~ExprSumReduce()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSumReduce::p_ExprSumReduce  (::mosek::fusion::ExprSumReduce * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSumReduce::t mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce  (int _6316,    monty::rc_ptr< ::mosek::fusion::Expression > _6317){ return new mosek::fusion::ExprSumReduce(_6316,_6317); }mosek::fusion::ExprSumReduce::ExprSumReduce  (int _6316,    monty::rc_ptr< ::mosek::fusion::Expression > _6317) :    ExprSumReduce(new mosek::fusion::p_ExprSumReduce(this)){ mosek::fusion::p_ExprSumReduce::_get_impl(this)->_initialize(_6316,_6317); }void mosek::fusion::p_ExprSumReduce::_initialize  (int _6316,    monty::rc_ptr< ::mosek::fusion::Expression > _6317){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::p_ExprSumReduce::computeShape(_6316,_6317->getShape()));
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->expr = _6317;
    mosek::fusion::p_ExprSumReduce::_get_impl(::mosek::fusion::ExprSumReduce::t(_pubthis))->dim = _6316;
    std::shared_ptr< monty::ndarray< int,1 > > _6318 = _6317->getShape();
    _checked_ptr_1<int> _ptr__6318(_6318 ? _6318->raw() : nullptr,_6318 ? _6318->size(0) : 0);
    if (((int)((_6318)->size(0)) <= _6316))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid summing dimension"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSumReduce :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6319,monty::rc_ptr< ::mosek::fusion::WorkStack > _6320,monty::rc_ptr< ::mosek::fusion::WorkStack > _6321) { mosek::fusion::p_ExprSumReduce::_get_impl(this)->eval(_6319,_6320,_6321); }void mosek::fusion::p_ExprSumReduce::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6319,monty::rc_ptr< ::mosek::fusion::WorkStack > _6320,monty::rc_ptr< ::mosek::fusion::WorkStack > _6321){
  expr->eval(_6320,_6319,_6321);
  _6320->pop_expr();
  int _6322 = mosek::fusion::p_WorkStack::_get_impl(_6320)->nd;
  int _6323 = mosek::fusion::p_WorkStack::_get_impl(_6320)->shape_base;
  int _6324 = mosek::fusion::p_WorkStack::_get_impl(_6320)->nelem;
  int _6325 = mosek::fusion::p_WorkStack::_get_impl(_6320)->nnz;
  int _6326 = mosek::fusion::p_WorkStack::_get_impl(_6320)->ncodeatom;
  bool _6327 = mosek::fusion::p_WorkStack::_get_impl(_6320)->hassp;
  int _6328 = mosek::fusion::p_WorkStack::_get_impl(_6320)->ptr_base;
  int _6329 = mosek::fusion::p_WorkStack::_get_impl(_6320)->sp_base;
  int _6330 = mosek::fusion::p_WorkStack::_get_impl(_6320)->nidxs_base;
  int _6331 = mosek::fusion::p_WorkStack::_get_impl(_6320)->cof_base;
  int _6332 = mosek::fusion::p_WorkStack::_get_impl(_6320)->code_base;
  int _6333 = mosek::fusion::p_WorkStack::_get_impl(_6320)->codeptr_base;
  int _6334 = mosek::fusion::p_WorkStack::_get_impl(_6320)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6335 = mosek::fusion::p_WorkStack::_get_impl(_6320)->i32;
  _checked_ptr_1<int> _ptr__6335(_6335 ? _6335->raw() : nullptr,_6335 ? _6335->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6336 = mosek::fusion::p_WorkStack::_get_impl(_6320)->i64;
  _checked_ptr_1<long long> _ptr__6336(_6336 ? _6336->raw() : nullptr,_6336 ? _6336->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6337 = mosek::fusion::p_WorkStack::_get_impl(_6320)->f64;
  _checked_ptr_1<double> _ptr__6337(_6337 ? _6337->raw() : nullptr,_6337 ? _6337->size(0) : 0);
  int _6338 = (int)99999;
  int _6339 = (int)99999;
  int _6340 = (int)99999;
  if (_6327)
  {
    {
      int _6341 = (int)0;
      int _11500 = (int)0;
      int _11501 = _6322;
      for (int _6342 = _11500; _6342 < _11501; ++_6342)
      {
        {
          if ((_6341 < _ptr__6335[safe_add( _6323,_6342 )]))
          {
            {
              _6341 = _ptr__6335[safe_add( _6323,_6342 )];
            }
          }
          {}
        }
      }
      _6338 = _6321->alloci32(safe_add( _6341,(int)1 ));
      _6339 = _6321->alloci32(_6324);
      _6340 = _6321->alloci32(_6324);
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _6343 = mosek::fusion::p_WorkStack::_get_impl(_6321)->i32;
  _checked_ptr_1<int> _ptr__6343(_6343 ? _6343->raw() : nullptr,_6343 ? _6343->size(0) : 0);
  if (_6327)
  {
    {
      int _6344 = _6339;
      int _6345 = _6340;
      int _11502 = (int)0;
      int _11503 = _6324;
      for (int _6346 = _11502; _6346 < _11503; ++_6346)
      {
        {
          _ptr__6343[safe_add( _6344,_6346 )] = _6346;
        }
      }
      if ((dim < (_6322 - (int)1)))
      {
        {
          std::shared_ptr< monty::ndarray< long long,1 > > _6347 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6322)));
          _checked_ptr_1<long long> _ptr__6347(_6347 ? _6347->raw() : nullptr,_6347 ? _6347->size(0) : 0);
          _ptr__6347[(_6322 - (int)1)] = (int)1;
          int _11504 = (int)1;
          int _11505 = _6322;
          for (int _6348 = _11504; _6348 < _11505; ++_6348)
          {
            {
              _ptr__6347[((_6322 - _6348) - (int)1)] = safe_mul( _ptr__6347[(_6322 - _6348)],_ptr__6335[(safe_add( _6323,_6322 ) - _6348)] );
            }
          }
          std::shared_ptr< monty::ndarray< int,1 > > _6349 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((_6322 - (int)1))));
          _checked_ptr_1<int> _ptr__6349(_6349 ? _6349->raw() : nullptr,_6349 ? _6349->size(0) : 0);
          int _11506 = (int)0;
          int _11507 = dim;
          for (int _6350 = _11506; _6350 < _11507; ++_6350)
          {
            {
              _ptr__6349[((_6322 - _6350) - (int)2)] = _6350;
            }
          }
          int _11508 = safe_add( dim,(int)1 );
          int _11509 = _6322;
          for (int _6351 = _11508; _6351 < _11509; ++_6351)
          {
            {
              _ptr__6349[((_6322 - _6351) - (int)1)] = _6351;
            }
          }
          int _11510 = (int)0;
          int _11511 = (_6322 - (int)1);
          for (int _6352 = _11510; _6352 < _11511; ++_6352)
          {
            {
              int _6353 = _ptr__6349[_6352];
              int _6354 = _ptr__6335[safe_add( _6323,_6353 )];
              int _11512 = (int)0;
              int _11513 = safe_add( _6354,(int)1 );
              for (int _6355 = _11512; _6355 < _11513; ++_6355)
              {
                {
                  _ptr__6343[safe_add( _6338,_6355 )] = (int)0;
                }
              }
              int _11514 = (int)0;
              int _11515 = _6324;
              for (int _6356 = _11514; _6356 < _11515; ++_6356)
              {
                {
                  ++ _ptr__6343[safe_add( safe_add( _6338,(int)1 ),((_ptr__6336[safe_add( _6329,_6356 )] / _ptr__6347[_6353]) % _6354) )];
                }
              }
              int _11516 = (int)0;
              int _11517 = _6354;
              for (int _6357 = _11516; _6357 < _11517; ++_6357)
              {
                {
                  _ptr__6343[safe_add( safe_add( _6338,_6357 ),(int)1 )] += _ptr__6343[safe_add( _6338,_6357 )];
                }
              }
              int _11518 = (int)0;
              int _11519 = _6324;
              for (int _6358 = _11518; _6358 < _11519; ++_6358)
              {
                {
                  int _6359 = _ptr__6343[safe_add( _6344,_6358 )];
                  long long _6360 = ((_ptr__6336[safe_add( _6329,_6359 )] / _ptr__6347[_6353]) % _6354);
                  _ptr__6343[safe_add( _6345,_ptr__6343[safe_add( _6338,_6360 )] )] = _6359;
                  ++ _ptr__6343[safe_add( _6338,_6360 )];
                }
              }
              int _6361 = _6345;
              _6345 = _6344;
              _6344 = _6361;
            }
          }
        }
      }
      {}
      int _6362 = (int)1;
      int _11520 = (int)0;
      int _11521 = dim;
      for (int _6363 = _11520; _6363 < _11521; ++_6363)
      {
        {
          _6362 *= _ptr__6335[safe_add( _6323,_6363 )];
        }
      }
      int _6364 = _ptr__6335[safe_add( _6323,dim )];
      int _6365 = (int)1;
      int _11522 = safe_add( dim,(int)1 );
      int _11523 = _6322;
      for (int _6366 = _11522; _6366 < _11523; ++_6366)
      {
        {
          _6365 *= _ptr__6335[safe_add( _6323,_6366 )];
        }
      }
      int _6367 = safe_mul( _6365,_6364 );
      int _6368 = _6365;
      int _6369 = (int)1;
      int _6370 = (int)0;
      long long _6371 = (-(int)1);
      long long _6372 = (-(int)1);
      int _11524 = (int)0;
      int _11525 = _6324;
      for (int _6373 = _11524; _6373 < _11525; ++_6373)
      {
        {
          int _6374 = _ptr__6343[safe_add( _6344,_6373 )];
          long long _6375 = ((_ptr__6336[safe_add( _6329,_6374 )] / _6367) % _6362);
          long long _6376 = (_ptr__6336[safe_add( _6329,_6374 )] % _6365);
          if (((_6372 != _6375) || (_6371 != _6376)))
          {
            {
              _6372 = _6375;
              _6371 = _6376;
              ++ _6370;
            }
          }
          {}
        }
      }
      int _6377 = (_6322 - (int)1);
      bool _6378 = (_6370 < safe_mul( _6362,_6365 ));
      int _6379 = _6325;
      int _6380 = _6326;
      _6319->alloc_expr(_6377,_6370,_6379,_6378,_6380);
      int _6381 = mosek::fusion::p_WorkStack::_get_impl(_6319)->ptr_base;
      int _6382 = mosek::fusion::p_WorkStack::_get_impl(_6319)->nidxs_base;
      int _11526;
      bool _11527 = _6378;
      if (_11527)
      {
        _11526 = mosek::fusion::p_WorkStack::_get_impl(_6319)->sp_base;
      }
      else
      {
        _11526 = _6319->alloci64(_6370);
      }
      int _6383 = _11526;
      int _6384 = mosek::fusion::p_WorkStack::_get_impl(_6319)->cof_base;
      int _6385 = mosek::fusion::p_WorkStack::_get_impl(_6319)->shape_base;
      int _6386 = mosek::fusion::p_WorkStack::_get_impl(_6319)->code_base;
      int _6387 = mosek::fusion::p_WorkStack::_get_impl(_6319)->codeptr_base;
      int _6388 = mosek::fusion::p_WorkStack::_get_impl(_6319)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6389 = mosek::fusion::p_WorkStack::_get_impl(_6319)->i32;
      _checked_ptr_1<int> _ptr__6389(_6389 ? _6389->raw() : nullptr,_6389 ? _6389->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6390 = mosek::fusion::p_WorkStack::_get_impl(_6319)->i64;
      _checked_ptr_1<long long> _ptr__6390(_6390 ? _6390->raw() : nullptr,_6390 ? _6390->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6391 = mosek::fusion::p_WorkStack::_get_impl(_6319)->f64;
      _checked_ptr_1<double> _ptr__6391(_6391 ? _6391->raw() : nullptr,_6391 ? _6391->size(0) : 0);
      int _11528 = (int)0;
      int _11529 = dim;
      for (int _6392 = _11528; _6392 < _11529; ++_6392)
      {
        {
          _ptr__6389[safe_add( _6385,_6392 )] = _ptr__6335[safe_add( _6323,_6392 )];
        }
      }
      int _11530 = safe_add( dim,(int)1 );
      int _11531 = _6322;
      for (int _6393 = _11530; _6393 < _11531; ++_6393)
      {
        {
          _ptr__6389[(safe_add( _6385,_6393 ) - (int)1)] = _ptr__6335[safe_add( _6323,_6393 )];
        }
      }
      _ptr__6389[_6381] = (int)0;
      if ((_6380 > (int)0))
      {
        {
          _ptr__6389[_6387] = (int)0;
        }
      }
      {}
      int _6394 = (int)0;
      int _6395 = (int)0;
      int _6396 = (int)0;
      int _6397 = (int)0;
      while ( (_6397 < _6324) )
      {
        {
          int _6398 = _6397;
          long long _6399 = ((_ptr__6336[safe_add( _6329,_ptr__6343[safe_add( _6344,_6398 )] )] / _6367) % _6362);
          long long _6400 = (_ptr__6336[safe_add( _6329,_ptr__6343[safe_add( _6344,_6398 )] )] % _6365);
          ++ _6397;
          while ( ((_6397 < _6324) && ((_6399 == ((_ptr__6336[safe_add( _6329,_ptr__6343[safe_add( _6344,_6397 )] )] / _6367) % _6362)) && (_6400 == (_ptr__6336[safe_add( _6329,_ptr__6343[safe_add( _6344,_6397 )] )] % _6365)))) )
          {
            {
              ++ _6397;
            }
          }
          int _11532 = _6398;
          int _11533 = _6397;
          for (int _6401 = _11532; _6401 < _11533; ++_6401)
          {
            {
              int _6402 = _ptr__6343[safe_add( _6344,_6401 )];
              int _11534 = _ptr__6335[safe_add( _6328,_6402 )];
              int _11535 = _ptr__6335[safe_add( safe_add( _6328,_6402 ),(int)1 )];
              for (int _6403 = _11534; _6403 < _11535; ++_6403)
              {
                {
                  _ptr__6390[safe_add( _6382,_6396 )] = _ptr__6336[safe_add( _6330,_6403 )];
                  _ptr__6391[safe_add( _6384,_6396 )] = _ptr__6337[safe_add( _6331,_6403 )];
                  if ((_6380 > (int)0))
                  {
                    {
                      int _11536 = _ptr__6335[safe_add( _6333,_6403 )];
                      int _11537 = _ptr__6335[safe_add( safe_add( _6333,_6403 ),(int)1 )];
                      for (int _6404 = _11536; _6404 < _11537; ++_6404)
                      {
                        {
                          _ptr__6389[safe_add( _6386,_6394 )] = _ptr__6335[safe_add( _6332,_6404 )];
                          _ptr__6391[safe_add( _6388,_6394 )] = _ptr__6337[safe_add( _6334,_6404 )];
                          ++ _6394;
                        }
                      }
                      _ptr__6389[safe_add( safe_add( _6387,_6396 ),(int)1 )] = _6394;
                    }
                  }
                  {}
                  ++ _6396;
                }
              }
            }
          }
          _ptr__6390[safe_add( _6383,_6395 )] = safe_add( safe_mul( _6399,_6365 ),_6400 );
          _ptr__6389[safe_add( safe_add( _6381,_6395 ),(int)1 )] = _6396;
          ++ _6395;
        }
      }
      if ((!_6378))
      {
        {
          _6319->popi64(_6370);
        }
      }
      {}
    }
  }
  else
  {
    {
      int _6405 = (int)1;
      int _11538 = (int)0;
      int _11539 = dim;
      for (int _6406 = _11538; _6406 < _11539; ++_6406)
      {
        {
          _6405 *= _ptr__6335[safe_add( _6323,_6406 )];
        }
      }
      int _6407 = _ptr__6335[safe_add( _6323,dim )];
      int _6408 = (int)1;
      int _11540 = safe_add( dim,(int)1 );
      int _11541 = _6322;
      for (int _6409 = _11540; _6409 < _11541; ++_6409)
      {
        {
          _6408 *= _ptr__6335[safe_add( _6323,_6409 )];
        }
      }
      int _6410 = safe_mul( _6408,_6407 );
      int _6411 = _6408;
      int _6412 = (int)1;
      int _6413 = safe_mul( _6405,_6408 );
      int _6414 = _6325;
      int _6415 = _6326;
      _6319->alloc_expr((_6322 - (int)1),_6413,_6414,false,_6415);
      int _6416 = mosek::fusion::p_WorkStack::_get_impl(_6319)->ptr_base;
      int _6417 = mosek::fusion::p_WorkStack::_get_impl(_6319)->nidxs_base;
      int _6418 = mosek::fusion::p_WorkStack::_get_impl(_6319)->cof_base;
      int _6419 = mosek::fusion::p_WorkStack::_get_impl(_6319)->shape_base;
      int _6420 = mosek::fusion::p_WorkStack::_get_impl(_6319)->code_base;
      int _6421 = mosek::fusion::p_WorkStack::_get_impl(_6319)->codeptr_base;
      int _6422 = mosek::fusion::p_WorkStack::_get_impl(_6319)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6423 = mosek::fusion::p_WorkStack::_get_impl(_6319)->i32;
      _checked_ptr_1<int> _ptr__6423(_6423 ? _6423->raw() : nullptr,_6423 ? _6423->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6424 = mosek::fusion::p_WorkStack::_get_impl(_6319)->i64;
      _checked_ptr_1<long long> _ptr__6424(_6424 ? _6424->raw() : nullptr,_6424 ? _6424->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6425 = mosek::fusion::p_WorkStack::_get_impl(_6319)->f64;
      _checked_ptr_1<double> _ptr__6425(_6425 ? _6425->raw() : nullptr,_6425 ? _6425->size(0) : 0);
      int _11542 = (int)0;
      int _11543 = dim;
      for (int _6426 = _11542; _6426 < _11543; ++_6426)
      {
        {
          _ptr__6423[safe_add( _6419,_6426 )] = _ptr__6335[safe_add( _6323,_6426 )];
        }
      }
      int _11544 = safe_add( dim,(int)1 );
      int _11545 = _6322;
      for (int _6427 = _11544; _6427 < _11545; ++_6427)
      {
        {
          _ptr__6423[(safe_add( _6419,_6427 ) - (int)1)] = _ptr__6335[safe_add( _6323,_6427 )];
        }
      }
      int _6428 = (int)0;
      int _6429 = (int)0;
      _ptr__6423[_6416] = (int)0;
      if ((_6415 > (int)0))
      {
        {
          _ptr__6423[_6421] = (int)0;
        }
      }
      {}
      int _6430 = (int)0;
      int _11546 = (int)0;
      int _11547 = _6405;
      for (int _6431 = _11546; _6431 < _11547; ++_6431)
      {
        {
          int _11548 = (int)0;
          int _11549 = _6408;
          for (int _6432 = _11548; _6432 < _11549; ++_6432)
          {
            {
              int _11550 = (int)0;
              int _11551 = _6407;
              for (int _6433 = _11550; _6433 < _11551; ++_6433)
              {
                {
                  int _6434 = safe_add( safe_add( safe_mul( _6431,_6410 ),safe_mul( _6433,_6411 ) ),_6432 );
                  int _11552 = _ptr__6335[safe_add( _6328,_6434 )];
                  int _11553 = _ptr__6335[safe_add( safe_add( _6328,_6434 ),(int)1 )];
                  for (int _6435 = _11552; _6435 < _11553; ++_6435)
                  {
                    {
                      _ptr__6424[safe_add( _6417,_6429 )] = _ptr__6336[safe_add( _6330,_6435 )];
                      _ptr__6425[safe_add( _6418,_6429 )] = _ptr__6337[safe_add( _6331,_6435 )];
                      if ((_6415 > (int)0))
                      {
                        {
                          int _11554 = _ptr__6335[safe_add( _6333,_6435 )];
                          int _11555 = _ptr__6335[safe_add( safe_add( _6333,_6435 ),(int)1 )];
                          for (int _6436 = _11554; _6436 < _11555; ++_6436)
                          {
                            {
                              _ptr__6423[safe_add( _6420,_6430 )] = _ptr__6335[safe_add( _6332,_6436 )];
                              _ptr__6425[safe_add( _6422,_6430 )] = _ptr__6337[safe_add( _6334,_6436 )];
                              ++ _6430;
                            }
                          }
                          _ptr__6423[safe_add( safe_add( _6421,_6429 ),(int)1 )] = _6430;
                        }
                      }
                      {}
                      ++ _6429;
                    }
                  }
                }
              }
              _ptr__6423[safe_add( safe_add( _6416,_6428 ),(int)1 )] = _6429;
              ++ _6428;
            }
          }
        }
      }
    }
  }
  _6321->clear();
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_ExprSumReduce::computeShape(int _6437,std::shared_ptr< monty::ndarray< int,1 > > _6438){
  _checked_ptr_1<int> _ptr__6438(_6438 ? _6438->raw() : nullptr, _6438 ? _6438->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _6439 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(((int)((_6438)->size(0)) - (int)1))));
  _checked_ptr_1<int> _ptr__6439(_6439 ? _6439->raw() : nullptr,_6439 ? _6439->size(0) : 0);
  int _11556 = (int)0;
  int _11557 = _6437;
  for (int _6440 = _11556; _6440 < _11557; ++_6440)
  {
    {
      _ptr__6439[_6440] = _ptr__6438[_6440];
    }
  }
  int _11558 = safe_add( _6437,(int)1 );
  int _11559 = (int)((_6438)->size(0));
  for (int _6441 = _11558; _6441 < _11559; ++_6441)
  {
    {
      _ptr__6439[(_6441 - (int)1)] = _ptr__6438[_6441];
    }
  }
  return _6439;
}
std::string mosek::fusion::ExprSumReduce :: toString() { return mosek::fusion::p_ExprSumReduce::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSumReduce::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSumReduce("))->__mosek_2fusion_2Utils_2StringBuffer__a(dim)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprSumReduce::destroy(){expr.reset();}void mosek::fusion::ExprSumReduce::destroy() { mosek::fusion::p_ExprSumReduce::_get_impl(this)->destroy(); }mosek::fusion::ExprDenseTril::ExprDenseTril(mosek::fusion::p_ExprDenseTril *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDenseTril()" << this << std::endl; */ }mosek::fusion::ExprDenseTril::~ExprDenseTril() {  /* std::cout << "~ExprDenseTril()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDenseTril::p_ExprDenseTril  (::mosek::fusion::ExprDenseTril * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _6442,    int _6443,    monty::rc_ptr< ::mosek::fusion::Expression > _6444,    int _6445){ return new mosek::fusion::ExprDenseTril(_6442,_6443,_6444,_6445); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _6442,    int _6443,    monty::rc_ptr< ::mosek::fusion::Expression > _6444,    int _6445) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_6442,_6443,_6444,_6445); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _6442,    int _6443,    monty::rc_ptr< ::mosek::fusion::Expression > _6444,    int _6445){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6444->getShape());
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->expr = _6444;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim0 = _6442;
    mosek::fusion::p_ExprDenseTril::_get_impl(::mosek::fusion::ExprDenseTril::t(_pubthis))->dim1 = _6443;
  }
}mosek::fusion::ExprDenseTril::t mosek::fusion::p_ExprDenseTril::_new_ExprDenseTril  (int _6446,    int _6447,    monty::rc_ptr< ::mosek::fusion::Expression > _6448){ return new mosek::fusion::ExprDenseTril(_6446,_6447,_6448); }mosek::fusion::ExprDenseTril::ExprDenseTril  (int _6446,    int _6447,    monty::rc_ptr< ::mosek::fusion::Expression > _6448) :    ExprDenseTril(new mosek::fusion::p_ExprDenseTril(this)){ mosek::fusion::p_ExprDenseTril::_get_impl(this)->_initialize(_6446,_6447,_6448); }void mosek::fusion::p_ExprDenseTril::_initialize  (int _6446,    int _6447,    monty::rc_ptr< ::mosek::fusion::Expression > _6448){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprDenseTril::_initialize(_6446,_6447,_6448,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _6449 = _6448->getShape();
    _checked_ptr_1<int> _ptr__6449(_6449 ? _6449->raw() : nullptr,_6449 ? _6449->size(0) : 0);
    if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= (int)((_6449)->size(0))) || ((dim1 < (int)0) || ((dim1 >= (int)((_6449)->size(0))) || (_ptr__6449[dim0] != _ptr__6449[dim1])))))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprDenseTril :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6450,monty::rc_ptr< ::mosek::fusion::WorkStack > _6451,monty::rc_ptr< ::mosek::fusion::WorkStack > _6452) { mosek::fusion::p_ExprDenseTril::_get_impl(this)->eval(_6450,_6451,_6452); }void mosek::fusion::p_ExprDenseTril::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6450,monty::rc_ptr< ::mosek::fusion::WorkStack > _6451,monty::rc_ptr< ::mosek::fusion::WorkStack > _6452){
  expr->eval(_6451,_6450,_6452);
  _6451->pop_expr();
  int _6453 = mosek::fusion::p_WorkStack::_get_impl(_6451)->nd;
  int _6454 = mosek::fusion::p_WorkStack::_get_impl(_6451)->nnz;
  int _6455 = mosek::fusion::p_WorkStack::_get_impl(_6451)->nelem;
  int _6456 = mosek::fusion::p_WorkStack::_get_impl(_6451)->ncodeatom;
  bool _6457 = mosek::fusion::p_WorkStack::_get_impl(_6451)->hassp;
  int _6458 = mosek::fusion::p_WorkStack::_get_impl(_6451)->shape_base;
  int _6459 = mosek::fusion::p_WorkStack::_get_impl(_6451)->ptr_base;
  int _6460 = mosek::fusion::p_WorkStack::_get_impl(_6451)->code_base;
  int _6461 = mosek::fusion::p_WorkStack::_get_impl(_6451)->codeptr_base;
  int _6462 = mosek::fusion::p_WorkStack::_get_impl(_6451)->cconst_base;
  int _6463 = mosek::fusion::p_WorkStack::_get_impl(_6451)->nidxs_base;
  int _6464 = mosek::fusion::p_WorkStack::_get_impl(_6451)->sp_base;
  int _6465 = mosek::fusion::p_WorkStack::_get_impl(_6451)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6466 = mosek::fusion::p_WorkStack::_get_impl(_6451)->i32;
  _checked_ptr_1<int> _ptr__6466(_6466 ? _6466->raw() : nullptr,_6466 ? _6466->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6467 = mosek::fusion::p_WorkStack::_get_impl(_6451)->i64;
  _checked_ptr_1<long long> _ptr__6467(_6467 ? _6467->raw() : nullptr,_6467 ? _6467->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6468 = mosek::fusion::p_WorkStack::_get_impl(_6451)->f64;
  _checked_ptr_1<double> _ptr__6468(_6468 ? _6468->raw() : nullptr,_6468 ? _6468->size(0) : 0);
  int _11560;
  bool _11561 = (dim0 < dim1);
  if (_11561)
  {
    _11560 = dim0;
  }
  else
  {
    _11560 = dim1;
  }
  int _6469 = _11560;
  int _11562;
  bool _11563 = (dim0 > dim1);
  if (_11563)
  {
    _11562 = dim0;
  }
  else
  {
    _11562 = dim1;
  }
  int _6470 = _11562;
  bool _6471 = (dim0 < dim1);
  if (((dim0 == dim1) || ((dim0 < (int)0) || ((dim0 >= _6453) || ((dim1 < (int)0) || (dim1 >= _6453))))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid symmetry dimensions"));
    }
  }
  else if((_ptr__6466[safe_add( _6458,dim0 )] != _ptr__6466[safe_add( _6458,dim1 )]))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Not symmetric in given dimensions"));
    }
  }
  {}
  std::vector<int> _11564;
  for (int _6473 = (int)0, _11565 = (int)5; _6473 < _11565 ; ++_6473)
  {
    _11564.push_back((int)1);
  }
  auto _11566 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11564.size()),_11564.begin(),_11564.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _6472 = _11566;
  _checked_ptr_1<int> _ptr__6472(_6472 ? _6472->raw() : nullptr,_6472 ? _6472->size(0) : 0);
  int _11567 = (int)0;
  int _11568 = _6469;
  for (int _6474 = _11567; _6474 < _11568; ++_6474)
  {
    {
      _ptr__6472[(int)0] *= _ptr__6466[safe_add( _6458,_6474 )];
    }
  }
  _ptr__6472[(int)1] = _ptr__6466[safe_add( _6458,dim0 )];
  int _11569 = safe_add( _6469,(int)1 );
  int _11570 = _6470;
  for (int _6475 = _11569; _6475 < _11570; ++_6475)
  {
    {
      _ptr__6472[(int)2] *= _ptr__6466[safe_add( _6458,_6475 )];
    }
  }
  _ptr__6472[(int)3] = _ptr__6466[safe_add( _6458,dim1 )];
  int _11571 = safe_add( _6470,(int)1 );
  int _11572 = _6453;
  for (int _6476 = _11571; _6476 < _11572; ++_6476)
  {
    {
      _ptr__6472[(int)4] *= _ptr__6466[safe_add( _6458,_6476 )];
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _6477 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)5)));
  _checked_ptr_1<int> _ptr__6477(_6477 ? _6477->raw() : nullptr,_6477 ? _6477->size(0) : 0);
  _ptr__6477[(int)4] = (int)1;
  int _11573 = (int)1;
  int _11574 = (int)5;
  for (int _6478 = _11573; _6478 < _11574; ++_6478)
  {
    {
      _ptr__6477[(((int)5 - _6478) - (int)1)] = safe_mul( _ptr__6477[((int)5 - _6478)],_ptr__6472[((int)5 - _6478)] );
    }
  }
  int _6479 = (int)0;
  int _6480 = safe_mul( safe_mul( safe_mul( _ptr__6472[(int)0],_ptr__6472[(int)2] ),_ptr__6472[(int)4] ),(safe_mul( _ptr__6472[(int)1],safe_add( _ptr__6472[(int)1],(int)1 ) ) / (int)2) );
  int _6481 = (int)0;
  {
    if (_6457)
    {
      {
        int _6482 = _ptr__6472[(int)1];
        if (_6471)
        {
          {
            int _11575 = (int)0;
            int _11576 = _6455;
            for (int _6483 = _11575; _6483 < _11576; ++_6483)
            {
              {
                long long _6484 = ((_ptr__6467[safe_add( _6464,_6483 )] / _ptr__6477[(int)1]) % _6482);
                long long _6485 = ((_ptr__6467[safe_add( _6464,_6483 )] / _ptr__6477[(int)3]) % _6482);
                if ((_6484 >= _6485))
                {
                  {
                    _6479 += (_ptr__6466[safe_add( safe_add( _6459,_6483 ),(int)1 )] - _ptr__6466[safe_add( _6459,_6483 )]);
                    if ((_6456 > (int)0))
                    {
                      {
                        _6481 += (_ptr__6466[safe_add( _6461,_ptr__6466[safe_add( safe_add( _6459,_6483 ),(int)1 )] )] - _ptr__6466[safe_add( _6461,_ptr__6466[safe_add( _6459,_6483 )] )]);
                      }
                    }
                    {}
                  }
                }
                {}
              }
            }
          }
        }
        else
        {
          {
            int _11577 = (int)0;
            int _11578 = _6455;
            for (int _6486 = _11577; _6486 < _11578; ++_6486)
            {
              {
                long long _6487 = ((_ptr__6467[safe_add( _6464,_6486 )] / _ptr__6477[(int)1]) % _ptr__6472[(int)1]);
                long long _6488 = ((_ptr__6467[safe_add( _6464,_6486 )] / _ptr__6477[(int)3]) % _ptr__6472[(int)3]);
                if ((_6487 <= _6488))
                {
                  {
                    _6479 += (_ptr__6466[safe_add( safe_add( _6459,_6486 ),(int)1 )] - _ptr__6466[safe_add( _6459,_6486 )]);
                    if ((_6456 > (int)0))
                    {
                      {
                        _6481 += (_ptr__6466[safe_add( _6461,_ptr__6466[safe_add( safe_add( _6459,_6486 ),(int)1 )] )] - _ptr__6466[safe_add( _6461,_ptr__6466[safe_add( _6459,_6486 )] )]);
                      }
                    }
                    {}
                  }
                }
                {}
              }
            }
          }
        }
      }
    }
    else
    {
      {
        if (_6471)
        {
          {
            int _11579 = (int)0;
            int _11580 = _ptr__6472[(int)0];
            for (int _6489 = _11579; _6489 < _11580; ++_6489)
            {
              {
                int _11581 = (int)0;
                int _11582 = _ptr__6472[(int)1];
                for (int _6490 = _11581; _6490 < _11582; ++_6490)
                {
                  {
                    int _11583 = (int)0;
                    int _11584 = _ptr__6472[(int)2];
                    for (int _6491 = _11583; _6491 < _11584; ++_6491)
                    {
                      {
                        int _11585 = (int)0;
                        int _11586 = safe_add( _6490,(int)1 );
                        for (int _6492 = _11585; _6492 < _11586; ++_6492)
                        {
                          {
                            int _11587 = (int)0;
                            int _11588 = _ptr__6472[(int)4];
                            for (int _6493 = _11587; _6493 < _11588; ++_6493)
                            {
                              {
                                int _6494 = safe_add( safe_add( safe_add( safe_add( safe_mul( _6489,_ptr__6477[(int)0] ),safe_mul( _6490,_ptr__6477[(int)1] ) ),safe_mul( _6491,_ptr__6477[(int)2] ) ),safe_mul( _6492,_ptr__6477[(int)3] ) ),safe_mul( _6493,_ptr__6477[(int)4] ) );
                                _6479 += (_ptr__6466[safe_add( safe_add( _6459,_6494 ),(int)1 )] - _ptr__6466[safe_add( _6459,_6494 )]);
                                if ((_6456 > (int)0))
                                {
                                  {
                                    _6481 += (_ptr__6466[safe_add( _6461,_ptr__6466[safe_add( safe_add( _6459,_6494 ),(int)1 )] )] - _ptr__6466[safe_add( _6461,_ptr__6466[safe_add( _6459,_6494 )] )]);
                                  }
                                }
                                {}
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
        else
        {
          {
            int _11589 = (int)0;
            int _11590 = _ptr__6472[(int)0];
            for (int _6495 = _11589; _6495 < _11590; ++_6495)
            {
              {
                int _11591 = (int)0;
                int _11592 = _ptr__6472[(int)1];
                for (int _6496 = _11591; _6496 < _11592; ++_6496)
                {
                  {
                    int _11593 = (int)0;
                    int _11594 = _ptr__6472[(int)2];
                    for (int _6497 = _11593; _6497 < _11594; ++_6497)
                    {
                      {
                        int _11595 = _6496;
                        int _11596 = _ptr__6472[(int)3];
                        for (int _6498 = _11595; _6498 < _11596; ++_6498)
                        {
                          {
                            int _11597 = (int)0;
                            int _11598 = _ptr__6472[(int)4];
                            for (int _6499 = _11597; _6499 < _11598; ++_6499)
                            {
                              {
                                int _6500 = safe_add( safe_add( safe_add( safe_add( safe_mul( _6495,_ptr__6477[(int)0] ),safe_mul( _6496,_ptr__6477[(int)1] ) ),safe_mul( _6497,_ptr__6477[(int)2] ) ),safe_mul( _6498,_ptr__6477[(int)3] ) ),safe_mul( _6499,_ptr__6477[(int)4] ) );
                                _6479 += (_ptr__6466[safe_add( safe_add( _6459,_6500 ),(int)1 )] - _ptr__6466[safe_add( _6459,_6500 )]);
                                if ((_6456 > (int)0))
                                {
                                  {
                                    _6481 += (_ptr__6466[safe_add( _6461,_ptr__6466[safe_add( safe_add( _6459,_6500 ),(int)1 )] )] - _ptr__6466[safe_add( _6461,_ptr__6466[safe_add( _6459,_6500 )] )]);
                                  }
                                }
                                {}
                              }
                            }
                          }
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
    }
  }
  int _6501 = (safe_mul( safe_mul( safe_mul( safe_mul( _ptr__6472[(int)0],_ptr__6472[(int)2] ),_ptr__6472[(int)4] ),_ptr__6472[(int)1] ),safe_add( _ptr__6472[(int)1],(int)1 ) ) / (int)2);
  _6450->alloc_expr(_6453,_6480,_6479,true,_6481);
  int _6502 = mosek::fusion::p_WorkStack::_get_impl(_6450)->ptr_base;
  int _6503 = mosek::fusion::p_WorkStack::_get_impl(_6450)->shape_base;
  int _6504 = mosek::fusion::p_WorkStack::_get_impl(_6450)->nidxs_base;
  int _6505 = mosek::fusion::p_WorkStack::_get_impl(_6450)->sp_base;
  int _6506 = mosek::fusion::p_WorkStack::_get_impl(_6450)->cof_base;
  int _6507 = mosek::fusion::p_WorkStack::_get_impl(_6450)->code_base;
  int _6508 = mosek::fusion::p_WorkStack::_get_impl(_6450)->codeptr_base;
  int _6509 = mosek::fusion::p_WorkStack::_get_impl(_6450)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6510 = mosek::fusion::p_WorkStack::_get_impl(_6450)->i32;
  _checked_ptr_1<int> _ptr__6510(_6510 ? _6510->raw() : nullptr,_6510 ? _6510->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6511 = mosek::fusion::p_WorkStack::_get_impl(_6450)->i64;
  _checked_ptr_1<long long> _ptr__6511(_6511 ? _6511->raw() : nullptr,_6511 ? _6511->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6512 = mosek::fusion::p_WorkStack::_get_impl(_6450)->f64;
  _checked_ptr_1<double> _ptr__6512(_6512 ? _6512->raw() : nullptr,_6512 ? _6512->size(0) : 0);
  _ptr__6510[_6502] = (int)0;
  if ((_6481 > (int)0))
  {
    {
      _ptr__6510[_6508] = (int)0;
    }
  }
  {}
  int _11599 = (int)0;
  int _11600 = _6453;
  for (int _6513 = _11599; _6513 < _11600; ++_6513)
  {
    {
      _ptr__6510[safe_add( _6503,_6513 )] = _ptr__6466[safe_add( _6458,_6513 )];
    }
  }
  if (_6471)
  {
    {
      int _6514 = (int)0;
      int _11601 = (int)0;
      int _11602 = _ptr__6472[(int)0];
      for (int _6515 = _11601; _6515 < _11602; ++_6515)
      {
        {
          int _11603 = (int)0;
          int _11604 = _ptr__6472[(int)1];
          for (int _6516 = _11603; _6516 < _11604; ++_6516)
          {
            {
              int _11605 = (int)0;
              int _11606 = _ptr__6472[(int)2];
              for (int _6517 = _11605; _6517 < _11606; ++_6517)
              {
                {
                  int _11607 = (int)0;
                  int _11608 = safe_add( _6516,(int)1 );
                  for (int _6518 = _11607; _6518 < _11608; ++_6518)
                  {
                    {
                      int _11609 = (int)0;
                      int _11610 = _ptr__6472[(int)4];
                      for (int _6519 = _11609; _6519 < _11610; ++_6519)
                      {
                        {
                          _ptr__6511[safe_add( _6505,_6514 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _6515,_ptr__6477[(int)0] ),safe_mul( _6516,_ptr__6477[(int)1] ) ),safe_mul( _6517,_ptr__6477[(int)2] ) ),safe_mul( _6518,_ptr__6477[(int)3] ) ),safe_mul( _6519,_ptr__6477[(int)4] ) );
                          ++ _6514;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      if ((_6514 != _6480))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid nelem"));
        }
      }
      {}
    }
  }
  else
  {
    {
      int _6520 = (int)0;
      int _11611 = (int)0;
      int _11612 = _ptr__6472[(int)0];
      for (int _6521 = _11611; _6521 < _11612; ++_6521)
      {
        {
          int _11613 = (int)0;
          int _11614 = _ptr__6472[(int)1];
          for (int _6522 = _11613; _6522 < _11614; ++_6522)
          {
            {
              int _11615 = (int)0;
              int _11616 = _ptr__6472[(int)2];
              for (int _6523 = _11615; _6523 < _11616; ++_6523)
              {
                {
                  int _11617 = _6522;
                  int _11618 = _ptr__6472[(int)3];
                  for (int _6524 = _11617; _6524 < _11618; ++_6524)
                  {
                    {
                      int _11619 = (int)0;
                      int _11620 = _ptr__6472[(int)4];
                      for (int _6525 = _11619; _6525 < _11620; ++_6525)
                      {
                        {
                          _ptr__6511[safe_add( _6505,_6520 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( _6521,_ptr__6477[(int)0] ),safe_mul( _6522,_ptr__6477[(int)1] ) ),safe_mul( _6523,_ptr__6477[(int)2] ) ),safe_mul( _6524,_ptr__6477[(int)3] ) ),safe_mul( _6525,_ptr__6477[(int)4] ) );
                          ++ _6520;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      if ((_6520 != _6480))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid nelem"));
        }
      }
      {}
    }
  }
  {
    int _6526 = (int)0;
    int _6527 = (int)0;
    if (_6457)
    {
      {
        int _6528 = (int)0;
        int _6529 = (int)0;
        while ( ((_6529 < _6455) && (_6528 < _6501)) )
        {
          {
            if ((_ptr__6467[safe_add( _6464,_6529 )] < _ptr__6511[safe_add( _6505,_6528 )]))
            {
              {
                ++ _6529;
              }
            }
            else if((_ptr__6467[safe_add( _6464,_6529 )] > _ptr__6511[safe_add( _6505,_6528 )]))
            {
              {
                _ptr__6510[safe_add( safe_add( _6502,_6528 ),(int)1 )] = _6526;
                ++ _6528;
              }
            }
            else
            {
              {
                int _11621 = _ptr__6466[safe_add( _6459,_6529 )];
                int _11622 = _ptr__6466[safe_add( safe_add( _6459,_6529 ),(int)1 )];
                for (int _6530 = _11621; _6530 < _11622; ++_6530)
                {
                  {
                    _ptr__6511[safe_add( _6504,_6526 )] = _ptr__6467[safe_add( _6463,_6530 )];
                    _ptr__6512[safe_add( _6506,_6526 )] = _ptr__6468[safe_add( _6465,_6530 )];
                    if ((_6481 > (int)0))
                    {
                      {
                        int _11623 = _ptr__6466[safe_add( _6461,_6530 )];
                        int _11624 = _ptr__6466[safe_add( safe_add( _6461,_6530 ),(int)1 )];
                        for (int _6531 = _11623; _6531 < _11624; ++_6531)
                        {
                          {
                            _ptr__6510[safe_add( _6507,_6527 )] = _ptr__6466[safe_add( _6460,_6531 )];
                            _ptr__6512[safe_add( _6509,_6527 )] = _ptr__6468[safe_add( _6462,_6531 )];
                            ++ _6527;
                          }
                        }
                        _ptr__6510[safe_add( safe_add( _6508,_6526 ),(int)1 )] = _6527;
                      }
                    }
                    {}
                    ++ _6526;
                  }
                }
                _ptr__6510[safe_add( safe_add( _6502,_6528 ),(int)1 )] = _6526;
                ++ _6529;
                ++ _6528;
              }
            }
          }
        }
        while ( (_6528 < _6501) )
        {
          {
            _ptr__6510[safe_add( safe_add( _6502,_6528 ),(int)1 )] = _6526;
            ++ _6528;
          }
        }
      }
    }
    else
    {
      {
        int _11625 = (int)0;
        int _11626 = _6501;
        for (int _6532 = _11625; _6532 < _11626; ++_6532)
        {
          {
            long long _6533 = _ptr__6511[safe_add( _6505,_6532 )];
            int _11627 = _ptr__6466[safe_add( _6459,_6533 )];
            int _11628 = _ptr__6466[safe_add( safe_add( _6459,_6533 ),(int)1 )];
            for (int _6534 = _11627; _6534 < _11628; ++_6534)
            {
              {
                _ptr__6511[safe_add( _6504,_6526 )] = _ptr__6467[safe_add( _6463,_6534 )];
                _ptr__6512[safe_add( _6506,_6526 )] = _ptr__6468[safe_add( _6465,_6534 )];
                if ((_6481 > (int)0))
                {
                  {
                    int _11629 = _ptr__6466[safe_add( _6461,_6534 )];
                    int _11630 = _ptr__6466[safe_add( safe_add( _6461,_6534 ),(int)1 )];
                    for (int _6535 = _11629; _6535 < _11630; ++_6535)
                    {
                      {
                        _ptr__6510[safe_add( _6507,_6527 )] = _ptr__6466[safe_add( _6460,_6535 )];
                        _ptr__6512[safe_add( _6509,_6527 )] = _ptr__6468[safe_add( _6462,_6535 )];
                        ++ _6527;
                      }
                    }
                    _ptr__6510[safe_add( safe_add( _6508,_6526 ),(int)1 )] = _6527;
                  }
                }
                {}
                ++ _6526;
              }
            }
            _ptr__6510[safe_add( safe_add( _6502,_6532 ),(int)1 )] = _6526;
          }
        }
      }
    }
    if ((_6526 != _6479))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid nnz"));
      }
    }
    {}
  }
}
std::string mosek::fusion::ExprDenseTril :: toString() { return mosek::fusion::p_ExprDenseTril::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDenseTril::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDenseTril(symdim=("))->__mosek_2fusion_2Utils_2StringBuffer__a(dim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDenseTril::destroy(){expr.reset();}void mosek::fusion::ExprDenseTril::destroy() { mosek::fusion::p_ExprDenseTril::_get_impl(this)->destroy(); }mosek::fusion::ExprDense::ExprDense(mosek::fusion::p_ExprDense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprDense()" << this << std::endl; */ }mosek::fusion::ExprDense::~ExprDense() {  /* std::cout << "~ExprDense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprDense::p_ExprDense  (::mosek::fusion::ExprDense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprDense::t mosek::fusion::p_ExprDense::_new_ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _6536){ return new mosek::fusion::ExprDense(_6536); }mosek::fusion::ExprDense::ExprDense  (monty::rc_ptr< ::mosek::fusion::Expression > _6536) :    ExprDense(new mosek::fusion::p_ExprDense(this)){ mosek::fusion::p_ExprDense::_get_impl(this)->_initialize(_6536); }void mosek::fusion::p_ExprDense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _6536){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6536->getShape());
    mosek::fusion::p_ExprDense::_get_impl(::mosek::fusion::ExprDense::t(_pubthis))->expr = _6536;
  }
}void mosek::fusion::ExprDense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6537,monty::rc_ptr< ::mosek::fusion::WorkStack > _6538,monty::rc_ptr< ::mosek::fusion::WorkStack > _6539) { mosek::fusion::p_ExprDense::_get_impl(this)->eval(_6537,_6538,_6539); }void mosek::fusion::p_ExprDense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6537,monty::rc_ptr< ::mosek::fusion::WorkStack > _6538,monty::rc_ptr< ::mosek::fusion::WorkStack > _6539){
  expr->eval(_6538,_6537,_6539);
  _6538->pop_expr();
  int _6540 = mosek::fusion::p_WorkStack::_get_impl(_6538)->nd;
  int _6541 = mosek::fusion::p_WorkStack::_get_impl(_6538)->nnz;
  int _6542 = mosek::fusion::p_WorkStack::_get_impl(_6538)->nelem;
  int _6543 = mosek::fusion::p_WorkStack::_get_impl(_6538)->ncodeatom;
  bool _6544 = mosek::fusion::p_WorkStack::_get_impl(_6538)->hassp;
  int _6545 = mosek::fusion::p_WorkStack::_get_impl(_6538)->shape_base;
  int _6546 = mosek::fusion::p_WorkStack::_get_impl(_6538)->ptr_base;
  int _6547 = mosek::fusion::p_WorkStack::_get_impl(_6538)->nidxs_base;
  int _6548 = mosek::fusion::p_WorkStack::_get_impl(_6538)->cof_base;
  int _6549 = mosek::fusion::p_WorkStack::_get_impl(_6538)->sp_base;
  int _6550 = mosek::fusion::p_WorkStack::_get_impl(_6538)->codeptr_base;
  int _6551 = mosek::fusion::p_WorkStack::_get_impl(_6538)->code_base;
  int _6552 = mosek::fusion::p_WorkStack::_get_impl(_6538)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6553 = mosek::fusion::p_WorkStack::_get_impl(_6538)->i32;
  _checked_ptr_1<int> _ptr__6553(_6553 ? _6553->raw() : nullptr,_6553 ? _6553->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6554 = mosek::fusion::p_WorkStack::_get_impl(_6538)->i64;
  _checked_ptr_1<long long> _ptr__6554(_6554 ? _6554->raw() : nullptr,_6554 ? _6554->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6555 = mosek::fusion::p_WorkStack::_get_impl(_6538)->f64;
  _checked_ptr_1<double> _ptr__6555(_6555 ? _6555->raw() : nullptr,_6555 ? _6555->size(0) : 0);
  int _6556 = (int)1;
  if (_6544)
  {
    {
      bool _6557 = true;
      int _11631 = (int)0;
      int _11632 = _6540;
      for (int _6558 = _11631; _6558 < _11632; ++_6558)
      {
        {
          int _6559 = safe_mul( _6556,_ptr__6553[safe_add( _6545,_6558 )] );
          _6557 = (_6557 && ((_ptr__6553[safe_add( _6545,_6558 )] == (int)0) || ((_6559 / _ptr__6553[safe_add( _6545,_6558 )]) == _6556)));
          _6556 = _6559;
        }
      }
      if ((!_6557))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("The domain is too large"));
        }
      }
      {}
    }
  }
  else
  {
    {
      _6556 = _6542;
    }
  }
  _6537->alloc_expr(_6540,_6556,_6541,false,_6543);
  int _6560 = mosek::fusion::p_WorkStack::_get_impl(_6537)->shape_base;
  int _6561 = mosek::fusion::p_WorkStack::_get_impl(_6537)->ptr_base;
  int _6562 = mosek::fusion::p_WorkStack::_get_impl(_6537)->nidxs_base;
  int _6563 = mosek::fusion::p_WorkStack::_get_impl(_6537)->cof_base;
  int _6564 = mosek::fusion::p_WorkStack::_get_impl(_6537)->codeptr_base;
  int _6565 = mosek::fusion::p_WorkStack::_get_impl(_6537)->code_base;
  int _6566 = mosek::fusion::p_WorkStack::_get_impl(_6537)->cconst_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6567 = mosek::fusion::p_WorkStack::_get_impl(_6537)->i32;
  _checked_ptr_1<int> _ptr__6567(_6567 ? _6567->raw() : nullptr,_6567 ? _6567->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6568 = mosek::fusion::p_WorkStack::_get_impl(_6537)->i64;
  _checked_ptr_1<long long> _ptr__6568(_6568 ? _6568->raw() : nullptr,_6568 ? _6568->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6569 = mosek::fusion::p_WorkStack::_get_impl(_6537)->f64;
  _checked_ptr_1<double> _ptr__6569(_6569 ? _6569->raw() : nullptr,_6569 ? _6569->size(0) : 0);
  {
    int _11633 = (int)0;
    int _11634 = _6540;
    for (int _6570 = _11633; _6570 < _11634; ++_6570)
    {
      {
        _ptr__6567[safe_add( _6560,_6570 )] = _ptr__6553[safe_add( _6545,_6570 )];
      }
    }
    int _11635 = (int)0;
    int _11636 = _6541;
    for (int _6571 = _11635; _6571 < _11636; ++_6571)
    {
      {
        _ptr__6568[safe_add( _6562,_6571 )] = _ptr__6554[safe_add( _6547,_6571 )];
      }
    }
    int _11637 = (int)0;
    int _11638 = _6541;
    for (int _6572 = _11637; _6572 < _11638; ++_6572)
    {
      {
        _ptr__6569[safe_add( _6563,_6572 )] = _ptr__6555[safe_add( _6548,_6572 )];
      }
    }
    if ((_6543 > (int)0))
    {
      {
        int _11639 = (int)0;
        int _11640 = safe_add( _6541,(int)1 );
        for (int _6573 = _11639; _6573 < _11640; ++_6573)
        {
          {
            _ptr__6567[safe_add( _6564,_6573 )] = _ptr__6553[safe_add( _6550,_6573 )];
          }
        }
        int _11641 = (int)0;
        int _11642 = _6543;
        for (int _6574 = _11641; _6574 < _11642; ++_6574)
        {
          {
            _ptr__6567[safe_add( _6565,_6574 )] = _ptr__6553[safe_add( _6551,_6574 )];
          }
        }
        int _11643 = (int)0;
        int _11644 = _6543;
        for (int _6575 = _11643; _6575 < _11644; ++_6575)
        {
          {
            _ptr__6569[safe_add( _6566,_6575 )] = _ptr__6555[safe_add( _6552,_6575 )];
          }
        }
      }
    }
    {}
    if ((!_6544))
    {
      {
        int _11645 = (int)0;
        int _11646 = safe_add( _6556,(int)1 );
        for (int _6576 = _11645; _6576 < _11646; ++_6576)
        {
          {
            _ptr__6567[safe_add( _6561,_6576 )] = _ptr__6553[safe_add( _6546,_6576 )];
          }
        }
      }
    }
    else
    {
      {
        int _11647 = (int)0;
        int _11648 = safe_add( _6556,(int)1 );
        for (int _6577 = _11647; _6577 < _11648; ++_6577)
        {
          {
            _ptr__6567[safe_add( _6561,_6577 )] = (int)0;
          }
        }
        int _11649 = (int)0;
        int _11650 = _6542;
        for (int _6578 = _11649; _6578 < _11650; ++_6578)
        {
          {
            _ptr__6567[safe_add( safe_add( _6561,_ptr__6554[safe_add( _6549,_6578 )] ),(int)1 )] = (_ptr__6553[safe_add( safe_add( _6546,_6578 ),(int)1 )] - _ptr__6553[safe_add( _6546,_6578 )]);
          }
        }
        int _11651 = (int)0;
        int _11652 = _6556;
        for (int _6579 = _11651; _6579 < _11652; ++_6579)
        {
          {
            _ptr__6567[safe_add( safe_add( _6561,_6579 ),(int)1 )] += _ptr__6567[safe_add( _6561,_6579 )];
          }
        }
      }
    }
  }
}
std::string mosek::fusion::ExprDense :: toString() { return mosek::fusion::p_ExprDense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprDense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprDense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprDense::destroy(){expr.reset();}void mosek::fusion::ExprDense::destroy() { mosek::fusion::p_ExprDense::_get_impl(this)->destroy(); }mosek::fusion::ExprSymmetrize::ExprSymmetrize(mosek::fusion::p_ExprSymmetrize *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprSymmetrize()" << this << std::endl; */ }mosek::fusion::ExprSymmetrize::~ExprSymmetrize() {  /* std::cout << "~ExprSymmetrize()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprSymmetrize::p_ExprSymmetrize  (::mosek::fusion::ExprSymmetrize * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _6580,    int _6581,    monty::rc_ptr< ::mosek::fusion::Expression > _6582,    int _6583){ return new mosek::fusion::ExprSymmetrize(_6580,_6581,_6582,_6583); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _6580,    int _6581,    monty::rc_ptr< ::mosek::fusion::Expression > _6582,    int _6583) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_6580,_6581,_6582,_6583); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _6580,    int _6581,    monty::rc_ptr< ::mosek::fusion::Expression > _6582,    int _6583){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6582->getShape());
    mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->expr = _6582;
    if ((_6580 < _6581))
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _6580;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _6581;
      }
    }
    else
    {
      {
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim0 = _6581;
        mosek::fusion::p_ExprSymmetrize::_get_impl(::mosek::fusion::ExprSymmetrize::t(_pubthis))->dim1 = _6580;
      }
    }
  }
}mosek::fusion::ExprSymmetrize::t mosek::fusion::p_ExprSymmetrize::_new_ExprSymmetrize  (int _6584,    int _6585,    monty::rc_ptr< ::mosek::fusion::Expression > _6586){ return new mosek::fusion::ExprSymmetrize(_6584,_6585,_6586); }mosek::fusion::ExprSymmetrize::ExprSymmetrize  (int _6584,    int _6585,    monty::rc_ptr< ::mosek::fusion::Expression > _6586) :    ExprSymmetrize(new mosek::fusion::p_ExprSymmetrize(this)){ mosek::fusion::p_ExprSymmetrize::_get_impl(this)->_initialize(_6584,_6585,_6586); }void mosek::fusion::p_ExprSymmetrize::_initialize  (int _6584,    int _6585,    monty::rc_ptr< ::mosek::fusion::Expression > _6586){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_ExprSymmetrize::_initialize(_6584,_6585,_6586,(int)1);
    std::shared_ptr< monty::ndarray< int,1 > > _6587 = _6586->getShape();
    _checked_ptr_1<int> _ptr__6587(_6587 ? _6587->raw() : nullptr,_6587 ? _6587->size(0) : 0);
    if (((dim0 < (int)0) || ((dim0 == dim1) || ((dim1 >= (int)((_6587)->size(0))) || (_ptr__6587[dim0] != _ptr__6587[dim1])))))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimension definitions"));
      }
    }
    {}
  }
}void mosek::fusion::ExprSymmetrize :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6588,monty::rc_ptr< ::mosek::fusion::WorkStack > _6589,monty::rc_ptr< ::mosek::fusion::WorkStack > _6590) { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->eval(_6588,_6589,_6590); }void mosek::fusion::p_ExprSymmetrize::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6588,monty::rc_ptr< ::mosek::fusion::WorkStack > _6589,monty::rc_ptr< ::mosek::fusion::WorkStack > _6590){
  expr->eval(_6589,_6588,_6590);
  _6589->pop_expr();
  int _6591 = (int)0;
  int _6592 = mosek::fusion::p_WorkStack::_get_impl(_6589)->nd;
  int _6593 = mosek::fusion::p_WorkStack::_get_impl(_6589)->nnz;
  int _6594 = mosek::fusion::p_WorkStack::_get_impl(_6589)->nelem;
  int _6595 = mosek::fusion::p_WorkStack::_get_impl(_6589)->ncodeatom;
  bool _6596 = mosek::fusion::p_WorkStack::_get_impl(_6589)->hassp;
  int _6597 = mosek::fusion::p_WorkStack::_get_impl(_6589)->shape_base;
  int _6598 = mosek::fusion::p_WorkStack::_get_impl(_6589)->ptr_base;
  int _6599 = mosek::fusion::p_WorkStack::_get_impl(_6589)->code_base;
  int _6600 = mosek::fusion::p_WorkStack::_get_impl(_6589)->codeptr_base;
  int _6601 = mosek::fusion::p_WorkStack::_get_impl(_6589)->cconst_base;
  int _6602 = mosek::fusion::p_WorkStack::_get_impl(_6589)->nidxs_base;
  int _6603 = mosek::fusion::p_WorkStack::_get_impl(_6589)->sp_base;
  int _6604 = mosek::fusion::p_WorkStack::_get_impl(_6589)->cof_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6605 = mosek::fusion::p_WorkStack::_get_impl(_6589)->i32;
  _checked_ptr_1<int> _ptr__6605(_6605 ? _6605->raw() : nullptr,_6605 ? _6605->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6606 = mosek::fusion::p_WorkStack::_get_impl(_6589)->i64;
  _checked_ptr_1<long long> _ptr__6606(_6606 ? _6606->raw() : nullptr,_6606 ? _6606->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6607 = mosek::fusion::p_WorkStack::_get_impl(_6589)->f64;
  _checked_ptr_1<double> _ptr__6607(_6607 ? _6607->raw() : nullptr,_6607 ? _6607->size(0) : 0);
  int _11653 = (int)0;
  int _11654 = _6592;
  for (int _6608 = _11653; _6608 < _11654; ++_6608)
  {
    {
      int _6609 = _ptr__6605[safe_add( _6597,_6608 )];
      if ((_6609 > _6591))
      {
        {
          _6609 = _6591;
        }
      }
      {}
    }
  }
  int _6610 = _6590->alloci32(_6594);
  int _6611 = _6590->alloci32(_6594);
  int _6612 = _6590->alloci32(safe_add( _6591,(int)1 ));
  int _6613 = _6590->alloci64(_6594);
  std::shared_ptr< monty::ndarray< int,1 > > _6614 = mosek::fusion::p_WorkStack::_get_impl(_6590)->i32;
  _checked_ptr_1<int> _ptr__6614(_6614 ? _6614->raw() : nullptr,_6614 ? _6614->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6615 = mosek::fusion::p_WorkStack::_get_impl(_6590)->i64;
  _checked_ptr_1<long long> _ptr__6615(_6615 ? _6615->raw() : nullptr,_6615 ? _6615->size(0) : 0);
  int _6616 = (int)0;
  int _6617 = (int)0;
  int _6618 = (int)0;
  std::vector<int> _11655;
  for (int _6620 = (int)0, _11656 = (int)5; _6620 < _11656 ; ++_6620)
  {
    _11655.push_back((int)1);
  }
  auto _11657 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11655.size()),_11655.begin(),_11655.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _6619 = _11657;
  _checked_ptr_1<int> _ptr__6619(_6619 ? _6619->raw() : nullptr,_6619 ? _6619->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6621 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)5)));
  _checked_ptr_1<long long> _ptr__6621(_6621 ? _6621->raw() : nullptr,_6621 ? _6621->size(0) : 0);
  int _11658 = (int)0;
  int _11659 = dim0;
  for (int _6622 = _11658; _6622 < _11659; ++_6622)
  {
    {
      _ptr__6619[(int)0] *= _ptr__6605[safe_add( _6597,_6622 )];
    }
  }
  _ptr__6619[(int)1] = _ptr__6605[safe_add( _6597,dim0 )];
  int _11660 = safe_add( dim0,(int)1 );
  int _11661 = dim1;
  for (int _6623 = _11660; _6623 < _11661; ++_6623)
  {
    {
      _ptr__6619[(int)2] *= _ptr__6605[safe_add( _6597,_6623 )];
    }
  }
  _ptr__6619[(int)3] = _ptr__6605[safe_add( _6597,dim1 )];
  int _11662 = safe_add( dim1,(int)1 );
  int _11663 = _6592;
  for (int _6624 = _11662; _6624 < _11663; ++_6624)
  {
    {
      _ptr__6619[(int)4] *= _ptr__6605[safe_add( _6597,_6624 )];
    }
  }
  _ptr__6621[(int)4] = (int)1;
  int _11664 = (int)1;
  int _11665 = (int)5;
  for (int _6625 = _11664; _6625 < _11665; ++_6625)
  {
    {
      _ptr__6621[(((int)5 - _6625) - (int)1)] = safe_mul( _ptr__6621[((int)5 - _6625)],_ptr__6619[((int)5 - _6625)] );
    }
  }
  if (_6596)
  {
    {
      int _6626 = _6610;
      int _11666 = (int)0;
      int _11667 = _6594;
      for (int _6627 = _11666; _6627 < _11667; ++_6627)
      {
        {
          _ptr__6614[safe_add( _6626,_6627 )] = _6627;
        }
      }
      int _6628 = _6611;
      std::shared_ptr< monty::ndarray< int,1 > > _6629 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)((int)2),(int)((int)3),(int)((int)0)});
      _checked_ptr_1<int> _ptr__6629(_6629 ? _6629->raw() : nullptr,_6629 ? _6629->size(0) : 0);
      int _11668 = (int)0;
      int _11669 = (int)4;
      for (int _6630 = _11668; _6630 < _11669; ++_6630)
      {
        {
          long long _6631 = _ptr__6621[_ptr__6629[_6630]];
          int _6632 = _ptr__6619[_ptr__6629[_6630]];
          if ((_6632 > (int)1))
          {
            {
              int _11670 = (int)0;
              int _11671 = safe_add( _6632,(int)1 );
              for (int _6633 = _11670; _6633 < _11671; ++_6633)
              {
                {
                  _ptr__6614[safe_add( _6612,_6633 )] = (int)0;
                }
              }
              int _11672 = (int)0;
              int _11673 = _6594;
              for (int _6634 = _11672; _6634 < _11673; ++_6634)
              {
                {
                  ++ _ptr__6614[safe_add( safe_add( _6612,((_ptr__6606[safe_add( _6603,_ptr__6614[safe_add( _6626,_6634 )] )] / _6631) % _6632) ),(int)1 )];
                }
              }
              int _11674 = (int)0;
              int _11675 = _ptr__6619[(int)3];
              for (int _6635 = _11674; _6635 < _11675; ++_6635)
              {
                {
                  _ptr__6614[safe_add( safe_add( _6612,_6635 ),(int)1 )] += _ptr__6614[safe_add( _6612,_6635 )];
                }
              }
              int _11676 = (int)0;
              int _11677 = _6594;
              for (int _6636 = _11676; _6636 < _11677; ++_6636)
              {
                {
                  int _6637 = _ptr__6614[safe_add( _6626,_6636 )];
                  long long _6638 = ((_ptr__6606[safe_add( _6603,_6637 )] / _6631) % _6632);
                  _ptr__6614[safe_add( _6628,_ptr__6614[safe_add( _6612,_6638 )] )] = _6637;
                  ++ _ptr__6614[safe_add( _6612,_6638 )];
                }
              }
              int _6639 = _6626;
              _6626 = _6628;
              _6628 = _6639;
            }
          }
          {}
        }
      }
      int _11678 = (int)0;
      int _11679 = _6594;
      for (int _6640 = _11678; _6640 < _11679; ++_6640)
      {
        {
          _ptr__6615[safe_add( _6613,_6640 )] = safe_add( safe_add( safe_add( safe_add( safe_mul( ((_ptr__6606[safe_add( _6603,_6640 )] / _ptr__6621[(int)0]) % _ptr__6619[(int)0]),_ptr__6621[(int)0] ),safe_mul( ((_ptr__6606[safe_add( _6603,_6640 )] / _ptr__6621[(int)1]) % _ptr__6619[(int)1]),_ptr__6621[(int)3] ) ),safe_mul( ((_ptr__6606[safe_add( _6603,_6640 )] / _ptr__6621[(int)2]) % _ptr__6619[(int)2]),_ptr__6621[(int)2] ) ),safe_mul( ((_ptr__6606[safe_add( _6603,_6640 )] / _ptr__6621[(int)3]) % _ptr__6619[(int)3]),_ptr__6621[(int)1] ) ),safe_mul( ((_ptr__6606[safe_add( _6603,_6640 )] / _ptr__6621[(int)4]) % _ptr__6619[(int)4]),_ptr__6621[(int)4] ) );
        }
      }
      {
        int _6641 = (int)0;
        int _6642 = (int)0;
        while ( ((_6642 < _6594) || (_6641 < _6594)) )
        {
          {
            int _6643 = _ptr__6614[safe_add( _6626,_6641 )];
            if (((_6642 < _6594) && ((_6641 == _6594) || (_ptr__6606[safe_add( _6603,_6642 )] < _ptr__6615[safe_add( _6613,_6643 )]))))
            {
              {
                _6617 += (_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6642 )]);
                if ((_6595 > (int)0))
                {
                  {
                    _6618 += safe_add( (_ptr__6605[safe_add( _6600,_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] )] - _ptr__6605[safe_add( _6600,_ptr__6605[safe_add( _6598,_6642 )] )]),safe_mul( (int)2,(_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6642 )]) ) );
                  }
                }
                {}
                ++ _6616;
                ++ _6642;
              }
            }
            else if(((_6641 < _6594) && ((_6642 == _6594) || (_ptr__6606[safe_add( _6603,_6642 )] > _ptr__6615[safe_add( _6613,_6643 )]))))
            {
              {
                _6617 += (_ptr__6605[safe_add( safe_add( _6598,_6643 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6643 )]);
                if ((_6595 > (int)0))
                {
                  {
                    _6618 += safe_add( (_ptr__6605[safe_add( _6600,_ptr__6605[safe_add( safe_add( _6598,_6643 ),(int)1 )] )] - _ptr__6605[safe_add( _6600,_ptr__6605[safe_add( _6598,_6643 )] )]),safe_mul( (int)2,(_ptr__6605[safe_add( safe_add( _6598,_6643 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6643 )]) ) );
                  }
                }
                {}
                ++ _6616;
                ++ _6641;
              }
            }
            else if((_ptr__6606[safe_add( _6603,_6642 )] != _ptr__6615[safe_add( _6613,_6643 )]))
            {
              {
                _6617 += (_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6642 )]);
                _6617 += (_ptr__6605[safe_add( safe_add( _6598,_6643 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6643 )]);
                if ((_6595 > (int)0))
                {
                  {
                    _6618 += safe_add( (_ptr__6605[safe_add( _6600,_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] )] - _ptr__6605[safe_add( _6600,_ptr__6605[safe_add( _6598,_6642 )] )]),safe_mul( (int)2,(_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6642 )]) ) );
                    _6618 += safe_add( (_ptr__6605[safe_add( _6600,_ptr__6605[safe_add( safe_add( _6598,_6643 ),(int)1 )] )] - _ptr__6605[safe_add( _6600,_ptr__6605[safe_add( _6598,_6643 )] )]),safe_mul( (int)2,(_ptr__6605[safe_add( safe_add( _6598,_6643 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6643 )]) ) );
                  }
                }
                {}
                ++ _6616;
                ++ _6641;
                ++ _6642;
              }
            }
            else
            {
              {
                _6617 += (_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6642 )]);
                if ((_6595 > (int)0))
                {
                  {
                    _6618 += (_ptr__6605[safe_add( _6600,_ptr__6605[safe_add( safe_add( _6598,_6642 ),(int)1 )] )] - _ptr__6605[safe_add( _6600,_ptr__6605[safe_add( _6598,_6642 )] )]);
                  }
                }
                {}
                ++ _6616;
                ++ _6641;
                ++ _6642;
              }
            }
          }
        }
      }
      _6588->alloc_expr(_6592,_6616,_6617,true,_6618);
      int _6644 = _6592;
      int _6645 = mosek::fusion::p_WorkStack::_get_impl(_6588)->ptr_base;
      int _6646 = mosek::fusion::p_WorkStack::_get_impl(_6588)->nidxs_base;
      int _6647 = mosek::fusion::p_WorkStack::_get_impl(_6588)->shape_base;
      int _6648 = mosek::fusion::p_WorkStack::_get_impl(_6588)->sp_base;
      int _6649 = mosek::fusion::p_WorkStack::_get_impl(_6588)->cof_base;
      int _6650 = mosek::fusion::p_WorkStack::_get_impl(_6588)->code_base;
      int _6651 = mosek::fusion::p_WorkStack::_get_impl(_6588)->codeptr_base;
      int _6652 = mosek::fusion::p_WorkStack::_get_impl(_6588)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6653 = mosek::fusion::p_WorkStack::_get_impl(_6588)->i32;
      _checked_ptr_1<int> _ptr__6653(_6653 ? _6653->raw() : nullptr,_6653 ? _6653->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6654 = mosek::fusion::p_WorkStack::_get_impl(_6588)->i64;
      _checked_ptr_1<long long> _ptr__6654(_6654 ? _6654->raw() : nullptr,_6654 ? _6654->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6655 = mosek::fusion::p_WorkStack::_get_impl(_6588)->f64;
      _checked_ptr_1<double> _ptr__6655(_6655 ? _6655->raw() : nullptr,_6655 ? _6655->size(0) : 0);
      int _11680 = (int)0;
      int _11681 = _6592;
      for (int _6656 = _11680; _6656 < _11681; ++_6656)
      {
        {
          _ptr__6653[safe_add( _6647,_6656 )] = _ptr__6605[safe_add( _6597,_6656 )];
        }
      }
      _ptr__6653[_6645] = (int)0;
      if ((_6618 > (int)0))
      {
        {
          _ptr__6653[_6651] = (int)0;
        }
      }
      {}
      {
        int _6657 = (int)0;
        int _6658 = (int)0;
        int _6659 = (int)0;
        int _6660 = (int)0;
        int _6661 = (int)0;
        _ptr__6653[_6645] = (int)0;
        while ( ((_6661 < _6594) || (_6660 < _6594)) )
        {
          {
            int _6662 = _ptr__6614[safe_add( _6626,_6660 )];
            if (((_6661 < _6594) && ((_6660 == _6594) || (_ptr__6606[safe_add( _6603,_6661 )] < _ptr__6615[safe_add( _6613,_6662 )]))))
            {
              {
                if ((_6618 == (int)0))
                {
                  {
                    int _11682 = _ptr__6605[safe_add( _6598,_6661 )];
                    int _11683 = _ptr__6605[safe_add( safe_add( _6598,_6661 ),(int)1 )];
                    for (int _6663 = _11682; _6663 < _11683; ++_6663)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6663 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6663 )] * 0.5);
                        ++ _6657;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _11684 = _ptr__6605[safe_add( _6598,_6661 )];
                    int _11685 = _ptr__6605[safe_add( safe_add( _6598,_6661 ),(int)1 )];
                    for (int _6664 = _11684; _6664 < _11685; ++_6664)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6664 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6664 )] * 0.5);
                        int _11686 = _ptr__6605[safe_add( _6600,_6664 )];
                        int _11687 = _ptr__6605[safe_add( safe_add( _6600,_6664 ),(int)1 )];
                        for (int _6665 = _11686; _6665 < _11687; ++_6665)
                        {
                          {
                            _ptr__6653[safe_add( _6650,_6658 )] = _ptr__6605[safe_add( _6599,_6665 )];
                            _ptr__6655[safe_add( _6652,_6658 )] = _ptr__6607[safe_add( _6601,_6665 )];
                            ++ _6658;
                          }
                        }
                        _ptr__6653[safe_add( _6650,_6658 )] = 2;
                        _ptr__6655[safe_add( _6652,_6658 )] = 0.5;
                        ++ _6658;
                        _ptr__6653[safe_add( _6650,_6658 )] = 5;
                        ++ _6658;
                        _ptr__6653[safe_add( safe_add( _6651,_6657 ),(int)1 )] = _6658;
                        ++ _6657;
                      }
                    }
                  }
                }
                _ptr__6654[safe_add( _6648,_6659 )] = _ptr__6606[safe_add( _6603,_6661 )];
                _ptr__6653[safe_add( safe_add( _6645,_6659 ),(int)1 )] = _6657;
                ++ _6659;
                ++ _6661;
              }
            }
            else if(((_6660 < _6594) && ((_6661 == _6594) || (_ptr__6606[safe_add( _6603,_6661 )] > _ptr__6615[safe_add( _6613,_6662 )]))))
            {
              {
                if ((_6618 == (int)0))
                {
                  {
                    int _11688 = _ptr__6605[safe_add( _6598,_6662 )];
                    int _11689 = _ptr__6605[safe_add( safe_add( _6598,_6662 ),(int)1 )];
                    for (int _6666 = _11688; _6666 < _11689; ++_6666)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6666 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6666 )] * 0.5);
                        ++ _6657;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _11690 = _ptr__6605[safe_add( _6598,_6662 )];
                    int _11691 = _ptr__6605[safe_add( safe_add( _6598,_6662 ),(int)1 )];
                    for (int _6667 = _11690; _6667 < _11691; ++_6667)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6667 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6667 )] * 0.5);
                        int _11692 = _ptr__6605[safe_add( _6600,_6667 )];
                        int _11693 = _ptr__6605[safe_add( safe_add( _6600,_6667 ),(int)1 )];
                        for (int _6668 = _11692; _6668 < _11693; ++_6668)
                        {
                          {
                            _ptr__6653[safe_add( _6650,_6658 )] = _ptr__6605[safe_add( _6599,_6668 )];
                            _ptr__6655[safe_add( _6652,_6658 )] = _ptr__6607[safe_add( _6601,_6668 )];
                            ++ _6658;
                          }
                        }
                        _ptr__6653[safe_add( _6650,_6658 )] = 2;
                        _ptr__6655[safe_add( _6652,_6658 )] = 0.5;
                        ++ _6658;
                        _ptr__6653[safe_add( _6650,_6658 )] = 5;
                        ++ _6658;
                        _ptr__6653[safe_add( safe_add( _6651,_6657 ),(int)1 )] = _6658;
                        ++ _6657;
                      }
                    }
                  }
                }
                _ptr__6654[safe_add( _6648,_6659 )] = _ptr__6606[safe_add( _6613,_6662 )];
                _ptr__6653[safe_add( safe_add( _6645,_6659 ),(int)1 )] = _6657;
                ++ _6659;
                ++ _6660;
              }
            }
            else if((_ptr__6606[safe_add( _6603,_6661 )] != _ptr__6615[safe_add( _6613,_6662 )]))
            {
              {
                if ((_6618 == (int)0))
                {
                  {
                    int _11694 = _ptr__6605[safe_add( _6598,_6661 )];
                    int _11695 = _ptr__6605[safe_add( safe_add( _6598,_6661 ),(int)1 )];
                    for (int _6669 = _11694; _6669 < _11695; ++_6669)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6669 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6669 )] * 0.5);
                        ++ _6657;
                      }
                    }
                    int _11696 = _ptr__6605[safe_add( _6598,_6662 )];
                    int _11697 = _ptr__6605[safe_add( safe_add( _6598,_6662 ),(int)1 )];
                    for (int _6670 = _11696; _6670 < _11697; ++_6670)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6670 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6670 )] * 0.5);
                        ++ _6657;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _11698 = _ptr__6605[safe_add( _6598,_6661 )];
                    int _11699 = _ptr__6605[safe_add( safe_add( _6598,_6661 ),(int)1 )];
                    for (int _6671 = _11698; _6671 < _11699; ++_6671)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6671 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6671 )] * 0.5);
                        int _11700 = _ptr__6605[safe_add( _6600,_6671 )];
                        int _11701 = _ptr__6605[safe_add( safe_add( _6600,_6671 ),(int)1 )];
                        for (int _6672 = _11700; _6672 < _11701; ++_6672)
                        {
                          {
                            _ptr__6653[safe_add( _6650,_6658 )] = _ptr__6605[safe_add( _6599,_6672 )];
                            _ptr__6655[safe_add( _6652,_6658 )] = _ptr__6607[safe_add( _6601,_6672 )];
                            ++ _6658;
                          }
                        }
                        _ptr__6653[safe_add( _6650,_6658 )] = 2;
                        _ptr__6655[safe_add( _6652,_6658 )] = 0.5;
                        ++ _6658;
                        _ptr__6653[safe_add( _6650,_6658 )] = 5;
                        ++ _6658;
                        _ptr__6653[safe_add( safe_add( _6651,_6657 ),(int)1 )] = _6658;
                        ++ _6657;
                      }
                    }
                    int _11702 = _ptr__6605[safe_add( _6598,_6662 )];
                    int _11703 = _ptr__6605[safe_add( safe_add( _6598,_6662 ),(int)1 )];
                    for (int _6673 = _11702; _6673 < _11703; ++_6673)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6673 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = (_ptr__6607[safe_add( _6604,_6673 )] * 0.5);
                        int _11704 = _ptr__6605[safe_add( _6600,_6673 )];
                        int _11705 = _ptr__6605[safe_add( safe_add( _6600,_6673 ),(int)1 )];
                        for (int _6674 = _11704; _6674 < _11705; ++_6674)
                        {
                          {
                            _ptr__6653[safe_add( _6650,_6658 )] = _ptr__6605[safe_add( _6599,_6674 )];
                            _ptr__6655[safe_add( _6652,_6658 )] = _ptr__6607[safe_add( _6601,_6674 )];
                            ++ _6658;
                          }
                        }
                        _ptr__6653[safe_add( _6650,_6658 )] = 2;
                        _ptr__6655[safe_add( _6652,_6658 )] = 0.5;
                        ++ _6658;
                        _ptr__6653[safe_add( _6650,_6658 )] = 5;
                        ++ _6658;
                        _ptr__6653[safe_add( safe_add( _6651,_6657 ),(int)1 )] = _6658;
                        ++ _6657;
                      }
                    }
                  }
                }
                _ptr__6654[safe_add( _6648,_6659 )] = _ptr__6606[safe_add( _6603,_6661 )];
                _ptr__6653[safe_add( safe_add( _6645,_6659 ),(int)1 )] = _6657;
                ++ _6659;
                ++ _6660;
                ++ _6661;
              }
            }
            else
            {
              {
                if ((_6618 == (int)0))
                {
                  {
                    int _11706 = _ptr__6605[safe_add( _6598,_6661 )];
                    int _11707 = _ptr__6605[safe_add( safe_add( _6598,_6661 ),(int)1 )];
                    for (int _6675 = _11706; _6675 < _11707; ++_6675)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6675 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = _ptr__6607[safe_add( _6604,_6675 )];
                        ++ _6657;
                      }
                    }
                  }
                }
                else
                {
                  {
                    int _11708 = _ptr__6605[safe_add( _6598,_6661 )];
                    int _11709 = _ptr__6605[safe_add( safe_add( _6598,_6661 ),(int)1 )];
                    for (int _6676 = _11708; _6676 < _11709; ++_6676)
                    {
                      {
                        _ptr__6654[safe_add( _6646,_6657 )] = _ptr__6606[safe_add( _6602,_6676 )];
                        _ptr__6655[safe_add( _6649,_6657 )] = _ptr__6607[safe_add( _6604,_6676 )];
                        int _11710 = _ptr__6605[safe_add( _6600,_6676 )];
                        int _11711 = _ptr__6605[safe_add( safe_add( _6600,_6676 ),(int)1 )];
                        for (int _6677 = _11710; _6677 < _11711; ++_6677)
                        {
                          {
                            _ptr__6653[safe_add( _6650,_6658 )] = _ptr__6605[safe_add( _6599,_6677 )];
                            _ptr__6655[safe_add( _6652,_6658 )] = _ptr__6607[safe_add( _6601,_6677 )];
                            ++ _6658;
                          }
                        }
                        _ptr__6653[safe_add( safe_add( _6651,_6657 ),(int)1 )] = _6658;
                        ++ _6657;
                      }
                    }
                  }
                }
                _ptr__6654[safe_add( _6648,_6659 )] = _ptr__6606[safe_add( _6603,_6661 )];
                _ptr__6653[safe_add( safe_add( _6645,_6659 ),(int)1 )] = _6657;
                ++ _6659;
                ++ _6660;
                ++ _6661;
              }
            }
          }
        }
        if ((_6657 != _6617))
        {
          {
            throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid nzi"));
          }
        }
        {}
      }
    }
  }
  else
  {
    {
      _6616 = _6594;
      _6617 = safe_mul( _6593,(int)2 );
      int _11712;
      bool _11713 = (_6595 > (int)0);
      if (_11713)
      {
        _11712 = safe_add( safe_mul( (int)2,_6595 ),safe_mul( safe_mul( (int)2,(int)2 ),_6593 ) );
      }
      else
      {
        _11712 = (int)0;
      }
      _6618 = _11712;
      int _11714 = (int)0;
      int _11715 = _ptr__6619[(int)0];
      for (int _6678 = _11714; _6678 < _11715; ++_6678)
      {
        {
          int _11716 = (int)0;
          int _11717 = _ptr__6619[(int)2];
          for (int _6679 = _11716; _6679 < _11717; ++_6679)
          {
            {
              int _11718 = (int)0;
              int _11719 = _ptr__6619[(int)4];
              for (int _6680 = _11718; _6680 < _11719; ++_6680)
              {
                {
                  int _11720 = (int)0;
                  int _11721 = _ptr__6619[(int)1];
                  for (int _6681 = _11720; _6681 < _11721; ++_6681)
                  {
                    {
                      long long _6682 = safe_add( safe_add( safe_add( safe_add( safe_mul( _ptr__6621[(int)0],_6678 ),safe_mul( _ptr__6621[(int)1],_6681 ) ),safe_mul( _ptr__6621[(int)2],_6679 ) ),safe_mul( _ptr__6621[(int)3],_6681 ) ),safe_mul( _ptr__6621[(int)4],_6680 ) );
                      _6617 -= (_ptr__6605[safe_add( safe_add( _6598,_6682 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6682 )]);
                      if ((_6595 > (int)0))
                      {
                        {
                          _6618 -= safe_add( (_ptr__6605[safe_add( _6600,_ptr__6605[safe_add( safe_add( _6598,_6682 ),(int)1 )] )] - _ptr__6605[safe_add( _6600,_ptr__6605[safe_add( _6598,_6682 )] )]),safe_mul( safe_mul( (int)2,(int)2 ),(_ptr__6605[safe_add( safe_add( _6598,_6682 ),(int)1 )] - _ptr__6605[safe_add( _6598,_6682 )]) ) );
                        }
                      }
                      {}
                    }
                  }
                }
              }
            }
          }
        }
      }
      _6588->alloc_expr(_6592,_6616,_6617,false,_6618);
      int _6683 = mosek::fusion::p_WorkStack::_get_impl(_6588)->ptr_base;
      int _6684 = mosek::fusion::p_WorkStack::_get_impl(_6588)->shape_base;
      int _6685 = mosek::fusion::p_WorkStack::_get_impl(_6588)->code_base;
      int _6686 = mosek::fusion::p_WorkStack::_get_impl(_6588)->codeptr_base;
      int _6687 = mosek::fusion::p_WorkStack::_get_impl(_6588)->nidxs_base;
      int _6688 = mosek::fusion::p_WorkStack::_get_impl(_6588)->sp_base;
      int _6689 = mosek::fusion::p_WorkStack::_get_impl(_6588)->cof_base;
      int _6690 = mosek::fusion::p_WorkStack::_get_impl(_6588)->cconst_base;
      std::shared_ptr< monty::ndarray< int,1 > > _6691 = mosek::fusion::p_WorkStack::_get_impl(_6588)->i32;
      _checked_ptr_1<int> _ptr__6691(_6691 ? _6691->raw() : nullptr,_6691 ? _6691->size(0) : 0);
      std::shared_ptr< monty::ndarray< long long,1 > > _6692 = mosek::fusion::p_WorkStack::_get_impl(_6588)->i64;
      _checked_ptr_1<long long> _ptr__6692(_6692 ? _6692->raw() : nullptr,_6692 ? _6692->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _6693 = mosek::fusion::p_WorkStack::_get_impl(_6588)->f64;
      _checked_ptr_1<double> _ptr__6693(_6693 ? _6693->raw() : nullptr,_6693 ? _6693->size(0) : 0);
      int _6694 = (int)0;
      int _6695 = (int)0;
      int _6696 = (int)0;
      int _11722 = (int)0;
      int _11723 = _6592;
      for (int _6697 = _11722; _6697 < _11723; ++_6697)
      {
        {
          _ptr__6691[safe_add( _6684,_6697 )] = _ptr__6605[safe_add( _6597,_6697 )];
        }
      }
      _ptr__6691[_6683] = (int)0;
      if ((_6618 > (int)0))
      {
        {
          _ptr__6691[_6686] = (int)0;
        }
      }
      {}
      int _6698 = (int)0;
      int _11724 = (int)0;
      int _11725 = _ptr__6619[(int)0];
      for (int _6699 = _11724; _6699 < _11725; ++_6699)
      {
        {
          int _11726 = (int)0;
          int _11727 = _ptr__6619[(int)1];
          for (int _6700 = _11726; _6700 < _11727; ++_6700)
          {
            {
              int _11728 = (int)0;
              int _11729 = _ptr__6619[(int)2];
              for (int _6701 = _11728; _6701 < _11729; ++_6701)
              {
                {
                  int _11730 = (int)0;
                  int _11731 = _ptr__6619[(int)3];
                  for (int _6702 = _11730; _6702 < _11731; ++_6702)
                  {
                    {
                      int _11732 = (int)0;
                      int _11733 = _ptr__6619[(int)4];
                      for (int _6703 = _11732; _6703 < _11733; ++_6703)
                      {
                        {
                          if ((_6700 == _6702))
                          {
                            {
                              if ((_6618 == (int)0))
                              {
                                {
                                  int _11734 = _ptr__6605[safe_add( _6598,_6698 )];
                                  int _11735 = _ptr__6605[safe_add( safe_add( _6598,_6698 ),(int)1 )];
                                  for (int _6704 = _11734; _6704 < _11735; ++_6704)
                                  {
                                    {
                                      _ptr__6692[safe_add( _6687,_6694 )] = _ptr__6606[safe_add( _6602,_6704 )];
                                      _ptr__6693[safe_add( _6689,_6694 )] = _ptr__6607[safe_add( _6604,_6704 )];
                                      ++ _6694;
                                    }
                                  }
                                }
                              }
                              else
                              {
                                {
                                  int _11736 = _ptr__6605[safe_add( _6598,_6698 )];
                                  int _11737 = _ptr__6605[safe_add( safe_add( _6598,_6698 ),(int)1 )];
                                  for (int _6705 = _11736; _6705 < _11737; ++_6705)
                                  {
                                    {
                                      _ptr__6692[safe_add( _6687,_6694 )] = _ptr__6606[safe_add( _6602,_6705 )];
                                      _ptr__6693[safe_add( _6689,_6694 )] = _ptr__6607[safe_add( _6604,_6705 )];
                                      int _11738 = _ptr__6605[safe_add( _6600,_6705 )];
                                      int _11739 = _ptr__6605[safe_add( safe_add( _6600,_6705 ),(int)1 )];
                                      for (int _6706 = _11738; _6706 < _11739; ++_6706)
                                      {
                                        {
                                          _ptr__6691[safe_add( _6685,_6696 )] = _ptr__6605[safe_add( _6599,_6706 )];
                                          _ptr__6693[safe_add( _6690,_6696 )] = _ptr__6607[safe_add( _6601,_6706 )];
                                          ++ _6696;
                                        }
                                      }
                                      _ptr__6691[safe_add( safe_add( _6686,_6694 ),(int)1 )] = _6696;
                                      ++ _6694;
                                    }
                                  }
                                }
                              }
                              _ptr__6691[safe_add( safe_add( _6683,_6695 ),(int)1 )] = _6694;
                              ++ _6698;
                            }
                          }
                          else
                          {
                            {
                              long long _6707 = safe_add( safe_add( safe_add( safe_add( safe_mul( _6699,_ptr__6621[(int)0] ),safe_mul( _6702,_ptr__6621[(int)1] ) ),safe_mul( _6701,_ptr__6621[(int)2] ) ),safe_mul( _6700,_ptr__6621[(int)3] ) ),_6703 );
                              if ((_6618 == (int)0))
                              {
                                {
                                  int _11740 = _ptr__6605[safe_add( _6598,_6698 )];
                                  int _11741 = _ptr__6605[safe_add( safe_add( _6598,_6698 ),(int)1 )];
                                  for (int _6708 = _11740; _6708 < _11741; ++_6708)
                                  {
                                    {
                                      _ptr__6692[safe_add( _6687,_6694 )] = _ptr__6606[safe_add( _6602,_6708 )];
                                      _ptr__6693[safe_add( _6689,_6694 )] = (_ptr__6607[safe_add( _6604,_6708 )] * 0.5);
                                      ++ _6694;
                                    }
                                  }
                                  int _11742 = _ptr__6605[safe_add( _6598,_6707 )];
                                  int _11743 = _ptr__6605[safe_add( safe_add( _6598,_6707 ),(int)1 )];
                                  for (int _6709 = _11742; _6709 < _11743; ++_6709)
                                  {
                                    {
                                      _ptr__6692[safe_add( _6687,_6694 )] = _ptr__6606[safe_add( _6602,_6709 )];
                                      _ptr__6693[safe_add( _6689,_6694 )] = (_ptr__6607[safe_add( _6604,_6709 )] * 0.5);
                                      ++ _6694;
                                    }
                                  }
                                }
                              }
                              else
                              {
                                {
                                  int _11744 = _ptr__6605[safe_add( _6598,_6698 )];
                                  int _11745 = _ptr__6605[safe_add( safe_add( _6598,_6698 ),(int)1 )];
                                  for (int _6710 = _11744; _6710 < _11745; ++_6710)
                                  {
                                    {
                                      _ptr__6692[safe_add( _6687,_6694 )] = _ptr__6606[safe_add( _6602,_6710 )];
                                      _ptr__6693[safe_add( _6689,_6694 )] = (_ptr__6607[safe_add( _6604,_6710 )] * 0.5);
                                      int _11746 = _ptr__6605[safe_add( _6600,_6710 )];
                                      int _11747 = _ptr__6605[safe_add( safe_add( _6600,_6710 ),(int)1 )];
                                      for (int _6711 = _11746; _6711 < _11747; ++_6711)
                                      {
                                        {
                                          _ptr__6691[safe_add( _6685,_6696 )] = _ptr__6605[safe_add( _6599,_6711 )];
                                          _ptr__6693[safe_add( _6690,_6696 )] = _ptr__6607[safe_add( _6601,_6711 )];
                                          ++ _6696;
                                        }
                                      }
                                      _ptr__6691[safe_add( _6685,_6696 )] = 2;
                                      _ptr__6693[safe_add( _6690,_6696 )] = 0.5;
                                      ++ _6696;
                                      _ptr__6691[safe_add( _6685,_6696 )] = 5;
                                      ++ _6696;
                                      _ptr__6691[safe_add( safe_add( _6686,_6694 ),(int)1 )] = _6696;
                                      ++ _6694;
                                    }
                                  }
                                  int _11748 = _ptr__6605[safe_add( _6598,_6707 )];
                                  int _11749 = _ptr__6605[safe_add( safe_add( _6598,_6707 ),(int)1 )];
                                  for (int _6712 = _11748; _6712 < _11749; ++_6712)
                                  {
                                    {
                                      _ptr__6692[safe_add( _6687,_6694 )] = _ptr__6606[safe_add( _6602,_6712 )];
                                      _ptr__6693[safe_add( _6689,_6694 )] = (_ptr__6607[safe_add( _6604,_6712 )] * 0.5);
                                      int _11750 = _ptr__6605[safe_add( _6600,_6712 )];
                                      int _11751 = _ptr__6605[safe_add( safe_add( _6600,_6712 ),(int)1 )];
                                      for (int _6713 = _11750; _6713 < _11751; ++_6713)
                                      {
                                        {
                                          _ptr__6691[safe_add( _6685,_6696 )] = _ptr__6605[safe_add( _6599,_6713 )];
                                          _ptr__6693[safe_add( _6690,_6696 )] = _ptr__6607[safe_add( _6601,_6713 )];
                                          ++ _6696;
                                        }
                                      }
                                      _ptr__6691[safe_add( _6685,_6696 )] = 2;
                                      _ptr__6693[safe_add( _6690,_6696 )] = 0.5;
                                      ++ _6696;
                                      _ptr__6691[safe_add( _6685,_6696 )] = 5;
                                      ++ _6696;
                                      _ptr__6691[safe_add( safe_add( _6686,_6694 ),(int)1 )] = _6696;
                                      ++ _6694;
                                    }
                                  }
                                }
                              }
                              _ptr__6691[safe_add( safe_add( _6683,_6695 ),(int)1 )] = _6694;
                              ++ _6698;
                            }
                          }
                          ++ _6695;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }
      if ((_6694 != _6617))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid nnz"));
        }
      }
      {}
      if ((_6695 != _6616))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid nelem"));
        }
      }
      {}
    }
  }
  _6590->clear();
  _6588->peek_expr();
  if ((mosek::fusion::p_WorkStack::_get_impl(_6588)->nnz != ((*mosek::fusion::p_WorkStack::_get_impl(_6588)->i32)(safe_add( mosek::fusion::p_WorkStack::_get_impl(_6588)->ptr_base,mosek::fusion::p_WorkStack::_get_impl(_6588)->nelem )))))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid ptr"));
    }
  }
  {}
  if ((((*mosek::fusion::p_WorkStack::_get_impl(_6588)->i32)(mosek::fusion::p_WorkStack::_get_impl(_6588)->ptr_base)) != (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: Invalid ptr"));
    }
  }
  {}
}
std::string mosek::fusion::ExprSymmetrize :: toString() { return mosek::fusion::p_ExprSymmetrize::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprSymmetrize::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprSymmetrize(symdim=("))->__mosek_2fusion_2Utils_2StringBuffer__a(dim0)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dim1)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprSymmetrize::destroy(){expr.reset();}void mosek::fusion::ExprSymmetrize::destroy() { mosek::fusion::p_ExprSymmetrize::_get_impl(this)->destroy(); }mosek::fusion::ExprCondense::ExprCondense(mosek::fusion::p_ExprCondense *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprCondense()" << this << std::endl; */ }mosek::fusion::ExprCondense::~ExprCondense() {  /* std::cout << "~ExprCondense()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprCondense::p_ExprCondense  (::mosek::fusion::ExprCondense * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprCondense::t mosek::fusion::p_ExprCondense::_new_ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _6714){ return new mosek::fusion::ExprCondense(_6714); }mosek::fusion::ExprCondense::ExprCondense  (monty::rc_ptr< ::mosek::fusion::Expression > _6714) :    ExprCondense(new mosek::fusion::p_ExprCondense(this)){ mosek::fusion::p_ExprCondense::_get_impl(this)->_initialize(_6714); }void mosek::fusion::p_ExprCondense::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _6714){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6714->getShape());
    mosek::fusion::p_ExprCondense::_get_impl(::mosek::fusion::ExprCondense::t(_pubthis))->expr = _6714;
  }
}void mosek::fusion::ExprCondense :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6715,monty::rc_ptr< ::mosek::fusion::WorkStack > _6716,monty::rc_ptr< ::mosek::fusion::WorkStack > _6717) { mosek::fusion::p_ExprCondense::_get_impl(this)->eval(_6715,_6716,_6717); }void mosek::fusion::p_ExprCondense::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6715,monty::rc_ptr< ::mosek::fusion::WorkStack > _6716,monty::rc_ptr< ::mosek::fusion::WorkStack > _6717){
  expr->eval(_6715,_6716,_6717);
  _6715->peek_expr();
  if (mosek::fusion::p_WorkStack::_get_impl(_6715)->hassp)
  {
    {
      int _6718 = _6715->popi32();
      _6715->popi32(_6718);
      int _6719 = _6715->popi32();
      int _6720 = _6715->popi32();
      _6715->popi32();
      _6715->popi64(_6719);
      _6715->pushi32((int)0);
      _6715->pushi32(_6720);
      _6715->pushi32(_6719);
      _6715->pushi32(_6719);
      _6715->pushi32((int)1);
      _6715->peek_expr();
    }
  }
  {}
}
std::string mosek::fusion::ExprCondense :: toString() { return mosek::fusion::p_ExprCondense::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprCondense::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprCondense("))->__mosek_2fusion_2Utils_2StringBuffer__a(expr->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprCondense::destroy(){expr.reset();}void mosek::fusion::ExprCondense::destroy() { mosek::fusion::p_ExprCondense::_get_impl(this)->destroy(); }mosek::fusion::ExprFromVar::ExprFromVar(mosek::fusion::p_ExprFromVar *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprFromVar()" << this << std::endl; */ }mosek::fusion::ExprFromVar::~ExprFromVar() {  /* std::cout << "~ExprFromVar()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprFromVar::p_ExprFromVar  (::mosek::fusion::ExprFromVar * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprFromVar::t mosek::fusion::p_ExprFromVar::_new_ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _6721){ return new mosek::fusion::ExprFromVar(_6721); }mosek::fusion::ExprFromVar::ExprFromVar  (monty::rc_ptr< ::mosek::fusion::Variable > _6721) :    ExprFromVar(new mosek::fusion::p_ExprFromVar(this)){ mosek::fusion::p_ExprFromVar::_get_impl(this)->_initialize(_6721); }void mosek::fusion::p_ExprFromVar::_initialize  (monty::rc_ptr< ::mosek::fusion::Variable > _6721){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6721->getShape());
    mosek::fusion::p_ExprFromVar::_get_impl(::mosek::fusion::ExprFromVar::t(_pubthis))->x = _6721;
  }
}void mosek::fusion::ExprFromVar :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6722,monty::rc_ptr< ::mosek::fusion::WorkStack > _6723,monty::rc_ptr< ::mosek::fusion::WorkStack > _6724) { mosek::fusion::p_ExprFromVar::_get_impl(this)->eval(_6722,_6723,_6724); }void mosek::fusion::p_ExprFromVar::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6722,monty::rc_ptr< ::mosek::fusion::WorkStack > _6723,monty::rc_ptr< ::mosek::fusion::WorkStack > _6724){
  std::shared_ptr< monty::ndarray< int,1 > > _6725 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__6725(_6725 ? _6725->raw() : nullptr,_6725 ? _6725->size(0) : 0);
  long long _6726 = ::mosek::fusion::p_Set::size(_6725);
  int _6727 = x->numInst();
  int _6728 = _6727;
  bool _6729 = (_6726 > _6727);
  _6722->alloc_expr((int)((_6725)->size(0)),_6727,_6728,_6729);
  int _6730 = mosek::fusion::p_WorkStack::_get_impl(_6722)->ptr_base;
  int _6731 = mosek::fusion::p_WorkStack::_get_impl(_6722)->nidxs_base;
  int _6732 = mosek::fusion::p_WorkStack::_get_impl(_6722)->sp_base;
  int _6733 = mosek::fusion::p_WorkStack::_get_impl(_6722)->cof_base;
  int _6734 = mosek::fusion::p_WorkStack::_get_impl(_6722)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _6735 = mosek::fusion::p_WorkStack::_get_impl(_6722)->i32;
  _checked_ptr_1<int> _ptr__6735(_6735 ? _6735->raw() : nullptr,_6735 ? _6735->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6736 = mosek::fusion::p_WorkStack::_get_impl(_6722)->i64;
  _checked_ptr_1<long long> _ptr__6736(_6736 ? _6736->raw() : nullptr,_6736 ? _6736->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6737 = mosek::fusion::p_WorkStack::_get_impl(_6722)->f64;
  _checked_ptr_1<double> _ptr__6737(_6737 ? _6737->raw() : nullptr,_6737 ? _6737->size(0) : 0);
  int _11752 = (int)0;
  int _11753 = (int)((_6725)->size(0));
  for (int _6738 = _11752; _6738 < _11753; ++_6738)
  {
    {
      _ptr__6735[safe_add( _6734,_6738 )] = _ptr__6725[_6738];
    }
  }
  {
    int _11754 = (int)0;
    int _11755 = safe_add( _6727,(int)1 );
    for (int _6739 = _11754; _6739 < _11755; ++_6739)
    {
      {
        _ptr__6735[safe_add( _6730,_6739 )] = _6739;
      }
    }
    int _11756 = (int)0;
    int _11757 = _6728;
    for (int _6740 = _11756; _6740 < _11757; ++_6740)
    {
      {
        _ptr__6737[safe_add( _6733,_6740 )] = 1.0;
      }
    }
  }
  if (_6729)
  {
    {
      x->inst(_6732,_6736,_6731,_6736);
    }
  }
  else
  {
    {
      x->inst(_6731,_6736);
    }
  }
}
std::string mosek::fusion::ExprFromVar :: toString() { return mosek::fusion::p_ExprFromVar::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprFromVar::toString(){
  return ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("Expr("))->__mosek_2fusion_2Utils_2StringBuffer__a(x->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"))->toString();
}
void mosek::fusion::p_ExprFromVar::destroy(){x.reset();}void mosek::fusion::ExprFromVar::destroy() { mosek::fusion::p_ExprFromVar::_get_impl(this)->destroy(); }mosek::fusion::ExprReshape::ExprReshape(mosek::fusion::p_ExprReshape *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "ExprReshape()" << this << std::endl; */ }mosek::fusion::ExprReshape::~ExprReshape() {  /* std::cout << "~ExprReshape()" << this << std::endl << std::flush; */ }mosek::fusion::p_ExprReshape::p_ExprReshape  (::mosek::fusion::ExprReshape * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::ExprReshape::t mosek::fusion::p_ExprReshape::_new_ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _6741,    monty::rc_ptr< ::mosek::fusion::Expression > _6742){ return new mosek::fusion::ExprReshape(_6741,_6742); }mosek::fusion::ExprReshape::ExprReshape  (std::shared_ptr< monty::ndarray< int,1 > > _6741,    monty::rc_ptr< ::mosek::fusion::Expression > _6742) :    ExprReshape(new mosek::fusion::p_ExprReshape(this)){ mosek::fusion::p_ExprReshape::_get_impl(this)->_initialize(_6741,_6742); }void mosek::fusion::p_ExprReshape::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _6741,    monty::rc_ptr< ::mosek::fusion::Expression > _6742){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__6741(_6741 ? _6741->raw() : nullptr, _6741 ? _6741->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_6741));
    long long _6743 = _6742->getSize();
    if ((::mosek::fusion::p_Set::size(_6741) != _6742->getSize()))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Cannot reshape to mismatching shape"));
      }
    }
    {}
    mosek::fusion::p_ExprReshape::_get_impl(::mosek::fusion::ExprReshape::t(_pubthis))->e = _6742;
  }
}void mosek::fusion::ExprReshape :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6744,monty::rc_ptr< ::mosek::fusion::WorkStack > _6745,monty::rc_ptr< ::mosek::fusion::WorkStack > _6746) { mosek::fusion::p_ExprReshape::_get_impl(this)->eval(_6744,_6745,_6746); }void mosek::fusion::p_ExprReshape::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6744,monty::rc_ptr< ::mosek::fusion::WorkStack > _6745,monty::rc_ptr< ::mosek::fusion::WorkStack > _6746){
  std::shared_ptr< monty::ndarray< int,1 > > _6747 = _pubthis->getShape();
  _checked_ptr_1<int> _ptr__6747(_6747 ? _6747->raw() : nullptr,_6747 ? _6747->size(0) : 0);
  e->eval(_6744,_6745,_6746);
  _6744->peek_expr();
  int _6748 = _6744->popi32();
  long long _6749 = (int)1;
  int _11758 = (int)0;
  int _11759 = _6748;
  for (int _6750 = _11758; _6750 < _11759; ++_6750)
  {
    {
      _6749 *= _6744->popi32();
    }
  }
  if ((_6749 != _pubthis->getSize()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("The two shapes have different sizes"));
    }
  }
  {}
  int _11760 = (int)0;
  int _11761 = (int)((_6747)->size(0));
  for (int _6751 = _11760; _6751 < _11761; ++_6751)
  {
    {
      _6744->pushi32(_ptr__6747[_6751]);
    }
  }
  _6744->pushi32((int)((_6747)->size(0)));
}
std::string mosek::fusion::ExprReshape :: toString() { return mosek::fusion::p_ExprReshape::_get_impl(this)->toString(); }std::string mosek::fusion::p_ExprReshape::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _6752 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer()->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("ExprReshape(("));
  if ((_pubthis->getND() > (int)0))
  {
    {
      _6752->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim((int)0));
      int _11762 = (int)1;
      int _11763 = _pubthis->getND();
      for (int _6753 = _11762; _6753 < _11763; ++_6753)
      {
        {
          _6752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(_pubthis->getDim(_6753));
        }
      }
    }
  }
  {}
  _6752->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("),"))->__mosek_2fusion_2Utils_2StringBuffer__a(e->toString())->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _6752->toString();
}
void mosek::fusion::p_ExprReshape::destroy(){e.reset();}void mosek::fusion::ExprReshape::destroy() { mosek::fusion::p_ExprReshape::_get_impl(this)->destroy(); }mosek::fusion::BaseExpression::BaseExpression(mosek::fusion::p_BaseExpression *_impl) : _impl(_impl) { /*std::cout << "BaseExpression() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::BaseExpression::~BaseExpression() { delete _impl; _impl = nullptr; }mosek::fusion::p_BaseExpression::p_BaseExpression  (::mosek::fusion::BaseExpression * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_BaseExpression::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _6754){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__6754(_6754 ? _6754->raw() : nullptr, _6754 ? _6754->size(0) : 0);
    mosek::fusion::p_BaseExpression::_get_impl(::mosek::fusion::BaseExpression::t(_pubthis))->shape = _6754;
  }
}std::string mosek::fusion::BaseExpression :: toString() { return mosek::fusion::p_BaseExpression::_get_impl(this)->toString(); }std::string mosek::fusion::p_BaseExpression::toString(){
  return std::string ("Expression()");
}
void mosek::fusion::p_BaseExpression::printStack(monty::rc_ptr< ::mosek::fusion::WorkStack > _6755){
  std::shared_ptr< monty::ndarray< int,1 > > _6756 = mosek::fusion::p_WorkStack::_get_impl(_6755)->i32;
  _checked_ptr_1<int> _ptr__6756(_6756 ? _6756->raw() : nullptr,_6756 ? _6756->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6757 = mosek::fusion::p_WorkStack::_get_impl(_6755)->i64;
  _checked_ptr_1<long long> _ptr__6757(_6757 ? _6757->raw() : nullptr,_6757 ? _6757->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _6758 = mosek::fusion::p_WorkStack::_get_impl(_6755)->f64;
  _checked_ptr_1<double> _ptr__6758(_6758 ? _6758->raw() : nullptr,_6758 ? _6758->size(0) : 0);
  int _6759 = mosek::fusion::p_WorkStack::_get_impl(_6755)->ptr_base;
  int _6760 = mosek::fusion::p_WorkStack::_get_impl(_6755)->nidxs_base;
  int _6761 = mosek::fusion::p_WorkStack::_get_impl(_6755)->cof_base;
  int _6762 = mosek::fusion::p_WorkStack::_get_impl(_6755)->shape_base;
  int _6763 = mosek::fusion::p_WorkStack::_get_impl(_6755)->codeptr_base;
  int _6764 = mosek::fusion::p_WorkStack::_get_impl(_6755)->code_base;
  int _6765 = mosek::fusion::p_WorkStack::_get_impl(_6755)->cconst_base;
  int _6766 = mosek::fusion::p_WorkStack::_get_impl(_6755)->sp_base;
  int _6767 = mosek::fusion::p_WorkStack::_get_impl(_6755)->nelem;
  int _6768 = mosek::fusion::p_WorkStack::_get_impl(_6755)->nnz;
  int _6769 = mosek::fusion::p_WorkStack::_get_impl(_6755)->ncodeatom;
  int _6770 = mosek::fusion::p_WorkStack::_get_impl(_6755)->nd;
  bool _6771 = mosek::fusion::p_WorkStack::_get_impl(_6755)->hassp;
  std::vector<int> _11764;
  for (int _6772 = (int)0, _11765 = _6770; _6772 < _11765 ; ++_6772)
  {
    _11764.push_back(_ptr__6756[safe_add( _6762,_6772 )]);
  }
  auto _11766 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11764.size()),_11764.begin(),_11764.end()));
  std::vector<int> _11767;
  for (int _6773 = (int)0, _11768 = safe_add( _6767,(int)1 ); _6773 < _11768 ; ++_6773)
  {
    _11767.push_back(_ptr__6756[safe_add( _6759,_6773 )]);
  }
  auto _11769 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11767.size()),_11767.begin(),_11767.end()));
  ::mosek::fusion::p_Debug::o()->__mosek_2fusion_2Debug__p(std::string ("### "))->__mosek_2fusion_2Debug__p(_pubthis->toString())->__mosek_2fusion_2Debug__p(std::string (" ###"))->__mosek_2fusion_2Debug__lf()->__mosek_2fusion_2Debug__p(std::string ("  nelem     = "))->__mosek_2fusion_2Debug__p(_6767)->__mosek_2fusion_2Debug__lf()->__mosek_2fusion_2Debug__p(std::string ("  nnz       = "))->__mosek_2fusion_2Debug__p(_6768)->__mosek_2fusion_2Debug__lf()->__mosek_2fusion_2Debug__p(std::string ("  hassp     = "))->__mosek_2fusion_2Debug__p(_6771)->__mosek_2fusion_2Debug__p(std::string (" / "))->__mosek_2fusion_2Debug__p(_ptr__6756[((mosek::fusion::p_WorkStack::_get_impl(_6755)->pi32 - _6770) - (int)4)])->__mosek_2fusion_2Debug__lf()->__mosek_2fusion_2Debug__p(std::string ("  shape     = "))->__mosek_2fusion_2Debug__p(_11766)->__mosek_2fusion_2Debug__lf()->__mosek_2fusion_2Debug__p(std::string ("  ptr       = "))->__mosek_2fusion_2Debug__p(_11769)->__mosek_2fusion_2Debug__lf();
  if (mosek::fusion::p_WorkStack::_get_impl(_6755)->hassp)
  {
    {
      std::vector<long long> _11770;
      for (int _6774 = (int)0, _11771 = _6767; _6774 < _11771 ; ++_6774)
      {
        _11770.push_back(_ptr__6757[safe_add( _6766,_6774 )]);
      }
      auto _11772 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11770.size()),_11770.begin(),_11770.end()));
      ::mosek::fusion::p_Debug::o()->__mosek_2fusion_2Debug__p(std::string ("  sp       = "))->__mosek_2fusion_2Debug__p(_11772)->__mosek_2fusion_2Debug__lf();
    }
  }
  {}
  int _11773 = (int)0;
  int _11774 = _6767;
  for (int _6775 = _11773; _6775 < _11774; ++_6775)
  {
    {
      ::mosek::fusion::p_Debug::o()->__mosek_2fusion_2Debug__p(std::string ("  row["))->__mosek_2fusion_2Debug__p(_6775)->__mosek_2fusion_2Debug__p(std::string ("]"))->__mosek_2fusion_2Debug__lf();
      std::vector<long long> _11775;
      for (int _6776 = _ptr__6756[safe_add( _6759,_6775 )], _11776 = _ptr__6756[safe_add( safe_add( _6759,_6775 ),(int)1 )]; _6776 < _11776 ; ++_6776)
      {
        _11775.push_back(_ptr__6757[safe_add( _6760,_6776 )]);
      }
      auto _11777 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11775.size()),_11775.begin(),_11775.end()));
      std::vector<double> _11778;
      for (int _6777 = _ptr__6756[safe_add( _6759,_6775 )], _11779 = _ptr__6756[safe_add( safe_add( _6759,_6775 ),(int)1 )]; _6777 < _11779 ; ++_6777)
      {
        _11778.push_back(_ptr__6758[safe_add( _6761,_6777 )]);
      }
      auto _11780 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11778.size()),_11778.begin(),_11778.end()));
      ::mosek::fusion::p_Debug::o()->__mosek_2fusion_2Debug__p(std::string ("    nidx : "))->__mosek_2fusion_2Debug__p(_11777)->__mosek_2fusion_2Debug__lf()->__mosek_2fusion_2Debug__p(std::string ("    cof  : "))->__mosek_2fusion_2Debug__p(_11780)->__mosek_2fusion_2Debug__lf();
      if ((_6769 > (int)0))
      {
        {
          int _11781 = _ptr__6756[safe_add( _6759,_6775 )];
          int _11782 = _ptr__6756[safe_add( safe_add( _6759,_6775 ),(int)1 )];
          for (int _6778 = _11781; _6778 < _11782; ++_6778)
          {
            {
              std::vector<int> _11783;
              for (int _6779 = _ptr__6756[safe_add( _6763,_6778 )], _11784 = _ptr__6756[safe_add( safe_add( _6763,_6778 ),(int)1 )]; _6779 < _11784 ; ++_6779)
              {
                _11783.push_back(_ptr__6756[safe_add( _6764,_6779 )]);
              }
              auto _11785 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11783.size()),_11783.begin(),_11783.end()));
              std::vector<double> _11786;
              for (int _6780 = _ptr__6756[safe_add( _6763,_6778 )], _11787 = _ptr__6756[safe_add( safe_add( _6763,_6778 ),(int)1 )]; _6780 < _11787 ; ++_6780)
              {
                _11786.push_back(_ptr__6758[safe_add( _6765,_6780 )]);
              }
              auto _11788 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11786.size()),_11786.begin(),_11786.end()));
              ::mosek::fusion::p_Debug::o()->__mosek_2fusion_2Debug__p(std::string ("      code["))->__mosek_2fusion_2Debug__p(_ptr__6757[safe_add( _6760,_6778 )])->__mosek_2fusion_2Debug__p(std::string ("] "))->__mosek_2fusion_2Debug__p(_11785)->__mosek_2fusion_2Debug__p(_11788)->__mosek_2fusion_2Debug__lf();
            }
          }
        }
      }
      {}
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _6784) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_6784); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,2 > > _6784) { return __mosek_2fusion_2BaseExpression__pick(_6784); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _6784) { return __mosek_2fusion_2BaseExpression__pick(_6784); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _6784){
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_6784)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _6785) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__pick(_6785); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::pick(std::shared_ptr< monty::ndarray< int,1 > > _6785) { return __mosek_2fusion_2BaseExpression__pick(_6785); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _6785) { return __mosek_2fusion_2BaseExpression__pick(_6785); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _6785){
  _checked_ptr_1<int> _ptr__6785(_6785 ? _6785->raw() : nullptr, _6785 ? _6785->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _6786 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_6785)->size(0)),(int)1)));
  int _11789 = (int)0;
  int _11790 = (int)((_6785)->size(0));
  for (int _6787 = _11789; _6787 < _11790; ++_6787)
  {
    {
      ((*_6786)(_6787,(int)0)) = _ptr__6785[_6787];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_6786)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _6788) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_6788); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(std::shared_ptr< monty::ndarray< int,1 > > _6788) { return __mosek_2fusion_2BaseExpression__index(_6788); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _6788) { return __mosek_2fusion_2BaseExpression__index(_6788); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _6788){
  _checked_ptr_1<int> _ptr__6788(_6788 ? _6788->raw() : nullptr, _6788 ? _6788->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,2 > > _6789 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)((_6788)->size(0)))));
  int _11791 = (int)0;
  int _11792 = (int)((_6788)->size(0));
  for (int _6790 = _11791; _6790 < _11792; ++_6790)
  {
    {
      ((*_6789)((int)0,_6790)) = _ptr__6788[_6790];
    }
  }
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_6789)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__index(int _6791) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__index(_6791); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::index(int _6791) { return __mosek_2fusion_2BaseExpression__index(_6791); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__index(int _6791) { return __mosek_2fusion_2BaseExpression__index(_6791); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__index(int _6791){
  std::shared_ptr< monty::ndarray< int,2 > > _6792 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)1,(int)1)));
  ((*_6792)((int)0,(int)0)) = _6791;
  return (::mosek::fusion::p_ExprPick::_new_ExprPick((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_6792)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _6793,std::shared_ptr< monty::ndarray< int,1 > > _6794) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_6793,_6794); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(std::shared_ptr< monty::ndarray< int,1 > > _6793,std::shared_ptr< monty::ndarray< int,1 > > _6794) { return __mosek_2fusion_2BaseExpression__slice(_6793,_6794); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _6793,std::shared_ptr< monty::ndarray< int,1 > > _6794) { return __mosek_2fusion_2BaseExpression__slice(_6793,_6794); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _6793,std::shared_ptr< monty::ndarray< int,1 > > _6794){
  _checked_ptr_1<int> _ptr__6793(_6793 ? _6793->raw() : nullptr, _6793 ? _6793->size(0) : 0);
  _checked_ptr_1<int> _ptr__6794(_6794 ? _6794->raw() : nullptr, _6794 ? _6794->size(0) : 0);
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),_6793,_6794)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression :: __mosek_2fusion_2BaseExpression__slice(int _6795,int _6796) { return mosek::fusion::p_BaseExpression::_get_impl(this)->__mosek_2fusion_2BaseExpression__slice(_6795,_6796); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::slice(int _6795,int _6796) { return __mosek_2fusion_2BaseExpression__slice(_6795,_6796); }
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::BaseExpression::__mosek_2fusion_2Expression__slice(int _6795,int _6796) { return __mosek_2fusion_2BaseExpression__slice(_6795,_6796); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_BaseExpression::__mosek_2fusion_2BaseExpression__slice(int _6795,int _6796){
  return (::mosek::fusion::p_ExprSlice::_new_ExprSlice((::mosek::fusion::BaseExpression::t(_pubthis)).as<::mosek::fusion::Expression>(),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_6795)}),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_6796)}))).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::BaseExpression :: getSize() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getSize(); }long long mosek::fusion::p_BaseExpression::getSize(){
  return ::mosek::fusion::p_Set::size(shape);
}
int mosek::fusion::BaseExpression :: getND() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getND(); }int mosek::fusion::p_BaseExpression::getND(){
  return (int)((shape)->size(0));
}
int mosek::fusion::BaseExpression :: getDim(int _6797) { return mosek::fusion::p_BaseExpression::_get_impl(this)->getDim(_6797); }int mosek::fusion::p_BaseExpression::getDim(int _6797){
  return ((*shape)(_6797));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::BaseExpression :: getShape() { return mosek::fusion::p_BaseExpression::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_BaseExpression::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::p_BaseExpression::destroy(){shape.reset();}void mosek::fusion::BaseExpression::destroy() { mosek::fusion::p_BaseExpression::_get_impl(this)->destroy(); }mosek::fusion::WorkStack::WorkStack(mosek::fusion::p_WorkStack *_impl) : _impl(_impl) { /*std::cout << "WorkStack() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::WorkStack::~WorkStack() { delete _impl; _impl = nullptr; }mosek::fusion::p_WorkStack::p_WorkStack  (::mosek::fusion::WorkStack * _pubthis) :     _pubthis(_pubthis){}int mosek::fusion::WorkStack::get_code_base() { return _impl->code_base; }
void mosek::fusion::WorkStack::set_code_base(int _val) { _impl->code_base = _val; }
int mosek::fusion::WorkStack::get_cconst_base() { return _impl->cconst_base; }
void mosek::fusion::WorkStack::set_cconst_base(int _val) { _impl->cconst_base = _val; }
int mosek::fusion::WorkStack::get_codeptr_base() { return _impl->codeptr_base; }
void mosek::fusion::WorkStack::set_codeptr_base(int _val) { _impl->codeptr_base = _val; }
int mosek::fusion::WorkStack::get_cof_base() { return _impl->cof_base; }
void mosek::fusion::WorkStack::set_cof_base(int _val) { _impl->cof_base = _val; }
int mosek::fusion::WorkStack::get_nidxs_base() { return _impl->nidxs_base; }
void mosek::fusion::WorkStack::set_nidxs_base(int _val) { _impl->nidxs_base = _val; }
int mosek::fusion::WorkStack::get_sp_base() { return _impl->sp_base; }
void mosek::fusion::WorkStack::set_sp_base(int _val) { _impl->sp_base = _val; }
int mosek::fusion::WorkStack::get_shape_base() { return _impl->shape_base; }
void mosek::fusion::WorkStack::set_shape_base(int _val) { _impl->shape_base = _val; }
int mosek::fusion::WorkStack::get_ptr_base() { return _impl->ptr_base; }
void mosek::fusion::WorkStack::set_ptr_base(int _val) { _impl->ptr_base = _val; }
bool mosek::fusion::WorkStack::get_hassp() { return _impl->hassp; }
void mosek::fusion::WorkStack::set_hassp(bool _val) { _impl->hassp = _val; }
int mosek::fusion::WorkStack::get_ncodeatom() { return _impl->ncodeatom; }
void mosek::fusion::WorkStack::set_ncodeatom(int _val) { _impl->ncodeatom = _val; }
int mosek::fusion::WorkStack::get_nelem() { return _impl->nelem; }
void mosek::fusion::WorkStack::set_nelem(int _val) { _impl->nelem = _val; }
int mosek::fusion::WorkStack::get_nnz() { return _impl->nnz; }
void mosek::fusion::WorkStack::set_nnz(int _val) { _impl->nnz = _val; }
int mosek::fusion::WorkStack::get_nd() { return _impl->nd; }
void mosek::fusion::WorkStack::set_nd(int _val) { _impl->nd = _val; }
int mosek::fusion::WorkStack::get_pf64() { return _impl->pf64; }
void mosek::fusion::WorkStack::set_pf64(int _val) { _impl->pf64 = _val; }
int mosek::fusion::WorkStack::get_pi64() { return _impl->pi64; }
void mosek::fusion::WorkStack::set_pi64(int _val) { _impl->pi64 = _val; }
int mosek::fusion::WorkStack::get_pi32() { return _impl->pi32; }
void mosek::fusion::WorkStack::set_pi32(int _val) { _impl->pi32 = _val; }
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::WorkStack::get_f64() { return _impl->f64; }
void mosek::fusion::WorkStack::set_f64(std::shared_ptr< monty::ndarray< double,1 > > _val) { _impl->f64 = _val; }
std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::WorkStack::get_i64() { return _impl->i64; }
void mosek::fusion::WorkStack::set_i64(std::shared_ptr< monty::ndarray< long long,1 > > _val) { _impl->i64 = _val; }
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::WorkStack::get_i32() { return _impl->i32; }
void mosek::fusion::WorkStack::set_i32(std::shared_ptr< monty::ndarray< int,1 > > _val) { _impl->i32 = _val; }
mosek::fusion::WorkStack::t mosek::fusion::p_WorkStack::_new_WorkStack  (){ return new mosek::fusion::WorkStack(); }mosek::fusion::WorkStack::WorkStack  () :    WorkStack(new mosek::fusion::p_WorkStack(this)){ mosek::fusion::p_WorkStack::_get_impl(this)->_initialize(); }void mosek::fusion::p_WorkStack::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    i32 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)256)));
    i64 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)256)));
    f64 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)256)));
    pi32 = (int)0;
    pi64 = (int)0;
    pf64 = (int)0;
    nd = (int)0;
    nnz = (int)0;
    nelem = (int)0;
    hassp = false;
    ncodeatom = (int)0;
    ptr_base = (int)0;
    shape_base = (int)0;
    sp_base = (int)0;
    nidxs_base = (int)0;
    cof_base = (int)0;
    cconst_base = (int)0;
    code_base = (int)0;
    codeptr_base = (int)0;
  }
}std::string mosek::fusion::WorkStack :: formatCurrent() { return mosek::fusion::p_WorkStack::_get_impl(this)->formatCurrent(); }std::string mosek::fusion::p_WorkStack::formatCurrent(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _6798 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  std::vector<int> _11793;
  for (int _6799 = (int)0, _11794 = nd; _6799 < _11794 ; ++_6799)
  {
    _11793.push_back(((*i32)(safe_add( shape_base,_6799 ))));
  }
  auto _11795 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11793.size()),_11793.begin(),_11793.end()));
  std::vector<int> _11796;
  for (int _6800 = (int)0, _11797 = safe_add( nelem,(int)1 ); _6800 < _11797 ; ++_6800)
  {
    _11796.push_back(((*i32)(safe_add( ptr_base,_6800 ))));
  }
  auto _11798 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11796.size()),_11796.begin(),_11796.end()));
  _6798->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  nelem     = "))->__mosek_2fusion_2Utils_2StringBuffer__a(nelem)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  nnz       = "))->__mosek_2fusion_2Utils_2StringBuffer__a(nnz)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  hassp     = "))->__mosek_2fusion_2Utils_2StringBuffer__a(hassp)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" / "))->__mosek_2fusion_2Utils_2StringBuffer__a(hassp)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  shape     = "))->__mosek_2fusion_2Utils_2StringBuffer__a(_11795)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  ptr       = "))->__mosek_2fusion_2Utils_2StringBuffer__a(_11798)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"));
  if ((ncodeatom > (int)0))
  {
    {
      std::vector<int> _11799;
      for (int _6801 = (int)0, _11800 = safe_add( nnz,(int)1 ); _6801 < _11800 ; ++_6801)
      {
        _11799.push_back(((*i32)(safe_add( codeptr_base,_6801 ))));
      }
      auto _11801 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11799.size()),_11799.begin(),_11799.end()));
      _6798->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  codeptr   = "))->__mosek_2fusion_2Utils_2StringBuffer__a(_11801)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"));
    }
  }
  {}
  if (hassp)
  {
    {
      std::vector<long long> _11802;
      for (int _6802 = (int)0, _11803 = nelem; _6802 < _11803 ; ++_6802)
      {
        _11802.push_back(((*i64)(safe_add( sp_base,_6802 ))));
      }
      auto _11804 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11802.size()),_11802.begin(),_11802.end()));
      _6798->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  sp        = "))->__mosek_2fusion_2Utils_2StringBuffer__a(_11804)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"));
    }
  }
  {}
  int _11805 = (int)0;
  int _11806 = nelem;
  for (int _6803 = _11805; _6803 < _11806; ++_6803)
  {
    {
      std::vector<long long> _11807;
      for (int _6804 = ((*i32)(safe_add( ptr_base,_6803 ))), _11808 = ((*i32)(safe_add( safe_add( ptr_base,_6803 ),(int)1 ))); _6804 < _11808 ; ++_6804)
      {
        _11807.push_back(((*i64)(safe_add( nidxs_base,_6804 ))));
      }
      auto _11809 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11807.size()),_11807.begin(),_11807.end()));
      std::vector<double> _11810;
      for (int _6805 = ((*i32)(safe_add( ptr_base,_6803 ))), _11811 = ((*i32)(safe_add( safe_add( ptr_base,_6803 ),(int)1 ))); _6805 < _11811 ; ++_6805)
      {
        _11810.push_back(((*f64)(safe_add( cof_base,_6805 ))));
      }
      auto _11812 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11810.size()),_11810.begin(),_11810.end()));
      _6798->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("  row["))->__mosek_2fusion_2Utils_2StringBuffer__a(_6803)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("]"))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("    nidx : "))->__mosek_2fusion_2Utils_2StringBuffer__a(_11809)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("    cof  : "))->__mosek_2fusion_2Utils_2StringBuffer__a(_11812)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"));
      if ((ncodeatom > (int)0))
      {
        {
          int _11813 = ((*i32)(safe_add( ptr_base,_6803 )));
          int _11814 = ((*i32)(safe_add( safe_add( ptr_base,_6803 ),(int)1 )));
          for (int _6806 = _11813; _6806 < _11814; ++_6806)
          {
            {
              std::vector<int> _11815;
              for (int _6807 = ((*i32)(safe_add( codeptr_base,_6806 ))), _11816 = ((*i32)(safe_add( safe_add( codeptr_base,_6806 ),(int)1 ))); _6807 < _11816 ; ++_6807)
              {
                _11815.push_back(((*i32)(safe_add( code_base,_6807 ))));
              }
              auto _11817 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11815.size()),_11815.begin(),_11815.end()));
              std::vector<double> _11818;
              for (int _6808 = ((*i32)(safe_add( codeptr_base,_6806 ))), _11819 = ((*i32)(safe_add( safe_add( codeptr_base,_6806 ),(int)1 ))); _6808 < _11819 ; ++_6808)
              {
                _11818.push_back(((*f64)(safe_add( cconst_base,_6808 ))));
              }
              auto _11820 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11818.size()),_11818.begin(),_11818.end()));
              _6798->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("      code["))->__mosek_2fusion_2Utils_2StringBuffer__a(((*i64)(safe_add( nidxs_base,_6806 ))))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("] "))->__mosek_2fusion_2Utils_2StringBuffer__a(_11817)->__mosek_2fusion_2Utils_2StringBuffer__a(_11820)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("\n"));
            }
          }
        }
      }
      {}
    }
  }
  return _6798->toString();
}
bool mosek::fusion::WorkStack :: peek_hassp() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_hassp(); }bool mosek::fusion::p_WorkStack::peek_hassp(){
  return (_pubthis->peeki32(safe_add( (int)3,_pubthis->peek_nd() )) != (int)0);
}
int mosek::fusion::WorkStack :: peek_nnz() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nnz(); }int mosek::fusion::p_WorkStack::peek_nnz(){
  return _pubthis->peeki32(safe_add( (int)2,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_nelem() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nelem(); }int mosek::fusion::p_WorkStack::peek_nelem(){
  return _pubthis->peeki32(safe_add( (int)1,_pubthis->peek_nd() ));
}
int mosek::fusion::WorkStack :: peek_dim(int _6809) { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_dim(_6809); }int mosek::fusion::p_WorkStack::peek_dim(int _6809){
  return _pubthis->peeki32(safe_add( _6809,(int)1 ));
}
int mosek::fusion::WorkStack :: peek_nd() { return mosek::fusion::p_WorkStack::_get_impl(this)->peek_nd(); }int mosek::fusion::p_WorkStack::peek_nd(){
  return _pubthis->peeki32();
}
void mosek::fusion::WorkStack :: alloc_expr(int _6810,int _6811,int _6812,bool _6813) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_6810,_6811,_6812,_6813); }void mosek::fusion::p_WorkStack::alloc_expr(int _6810,int _6811,int _6812,bool _6813){
  _pubthis->alloc_expr(_6810,_6811,_6812,_6813,(int)0);
}
void mosek::fusion::WorkStack :: alloc_expr(int _6814,int _6815,int _6816,bool _6817,int _6818) { mosek::fusion::p_WorkStack::_get_impl(this)->alloc_expr(_6814,_6815,_6816,_6817,_6818); }void mosek::fusion::p_WorkStack::alloc_expr(int _6814,int _6815,int _6816,bool _6817,int _6818){
  cof_base = _pubthis->allocf64(_6816);
  cconst_base = _pubthis->allocf64(_6818);
  nidxs_base = _pubthis->alloci64(_6816);
  int _11821;
  bool _11822 = _6817;
  if (_11822)
  {
    _11821 = _pubthis->alloci64(_6815);
  }
  else
  {
    _11821 = (-(int)9999);
  }
  sp_base = _11821;
  code_base = _pubthis->alloci32(_6818);
  int _11823;
  bool _11824 = (_6818 > (int)0);
  if (_11824)
  {
    _11823 = _pubthis->alloci32(safe_add( _6816,(int)1 ));
  }
  else
  {
    _11823 = (-(int)9999);
  }
  codeptr_base = _11823;
  ptr_base = _pubthis->alloci32(safe_add( _6815,(int)1 ));
  _pubthis->pushi32(_6818);
  int _11825;
  bool _11826 = _6817;
  if (_11826)
  {
    _11825 = (int)1;
  }
  else
  {
    _11825 = (int)0;
  }
  _pubthis->pushi32(_11825);
  _pubthis->pushi32(_6816);
  _pubthis->pushi32(_6815);
  shape_base = _pubthis->alloci32(_6814);
  _pubthis->pushi32(_6814);
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->ncodeatom = _6818;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nd = _6814;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nelem = _6815;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->nnz = _6816;
  mosek::fusion::p_WorkStack::_get_impl(::mosek::fusion::WorkStack::t(_pubthis))->hassp = _6817;
}
void mosek::fusion::WorkStack :: pop_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->pop_expr(); }void mosek::fusion::p_WorkStack::pop_expr(){
  nd = _pubthis->popi32();
  shape_base = _pubthis->popi32(nd);
  nelem = _pubthis->popi32();
  nnz = _pubthis->popi32();
  hassp = (_pubthis->popi32() != (int)0);
  ncodeatom = _pubthis->popi32();
  ptr_base = _pubthis->popi32(safe_add( nelem,(int)1 ));
  int _11827;
  bool _11828 = (ncodeatom > (int)0);
  if (_11828)
  {
    _11827 = _pubthis->popi32(safe_add( nnz,(int)1 ));
  }
  else
  {
    _11827 = (-(int)9999);
  }
  codeptr_base = _11827;
  code_base = _pubthis->popi32(ncodeatom);
  int _11829;
  bool _11830 = hassp;
  if (_11830)
  {
    _11829 = _pubthis->popi64(nelem);
  }
  else
  {
    _11829 = (-(int)9999);
  }
  sp_base = _11829;
  nidxs_base = _pubthis->popi64(nnz);
  cconst_base = _pubthis->popf64(ncodeatom);
  cof_base = _pubthis->popf64(nnz);
}
void mosek::fusion::WorkStack :: move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _6819) { mosek::fusion::p_WorkStack::_get_impl(this)->move_expr(_6819); }void mosek::fusion::p_WorkStack::move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _6819){
  int _6820 = pi32;
  int _6821 = pi64;
  int _6822 = pf64;
  _pubthis->pop_expr();
  int _6823 = _6819->alloci32((_6820 - pi32));
  int _6824 = _6819->alloci64((_6821 - pi64));
  int _6825 = _6819->allocf64((_6822 - pf64));
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,mosek::fusion::p_WorkStack::_get_impl(_6819)->i32,_6823,(_6820 - pi32));
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,mosek::fusion::p_WorkStack::_get_impl(_6819)->i64,_6824,(_6821 - pi64));
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,mosek::fusion::p_WorkStack::_get_impl(_6819)->f64,_6825,(_6822 - pf64));
}
void mosek::fusion::WorkStack :: peek_expr() { mosek::fusion::p_WorkStack::_get_impl(this)->peek_expr(); }void mosek::fusion::p_WorkStack::peek_expr(){
  int _6826 = pi32;
  int _6827 = pi64;
  int _6828 = pf64;
  _pubthis->pop_expr();
  pi32 = _6826;
  pi64 = _6827;
  pf64 = _6828;
}
void mosek::fusion::WorkStack :: ensure_sparsity() { mosek::fusion::p_WorkStack::_get_impl(this)->ensure_sparsity(); }void mosek::fusion::p_WorkStack::ensure_sparsity(){
  int _6829 = ((*i32)((pi32 - (int)1)));
  bool _6830 = (((*i32)(((pi32 - _6829) - (int)3))) != (int)0);
  int _6831 = ((*i32)(((pi32 - _6829) - (int)1)));
  if ((!_6830))
  {
    {
      ((*i32)(((pi32 - _6829) - (int)3))) = (int)1;
      int _6832 = _pubthis->alloci64(_6831);
      int _11831 = (int)0;
      int _11832 = _6831;
      for (int _6833 = _11831; _6833 < _11832; ++_6833)
      {
        {
          ((*i64)(_6832)) = _6833;
        }
      }
    }
  }
  {}
}
void mosek::fusion::WorkStack :: clear() { mosek::fusion::p_WorkStack::_get_impl(this)->clear(); }void mosek::fusion::p_WorkStack::clear(){
  pi32 = (int)0;
  pi64 = (int)0;
  pf64 = (int)0;
}
int mosek::fusion::WorkStack :: allocf64(int _6834) { return mosek::fusion::p_WorkStack::_get_impl(this)->allocf64(_6834); }int mosek::fusion::p_WorkStack::allocf64(int _6834){
  _pubthis->ensuref64(_6834);
  int _6835 = pf64;
  pf64 += _6834;
  return _6835;
}
int mosek::fusion::WorkStack :: alloci64(int _6836) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci64(_6836); }int mosek::fusion::p_WorkStack::alloci64(int _6836){
  _pubthis->ensurei64(_6836);
  int _6837 = pi64;
  pi64 += _6836;
  return _6837;
}
int mosek::fusion::WorkStack :: alloci32(int _6838) { return mosek::fusion::p_WorkStack::_get_impl(this)->alloci32(_6838); }int mosek::fusion::p_WorkStack::alloci32(int _6838){
  if ((_6838 > (int)0))
  {
    {
      _pubthis->ensurei32(_6838);
      int _6839 = pi32;
      pi32 += _6838;
      return _6839;
    }
  }
  else
  {
    {
      return (int)0;
    }
  }
}
void mosek::fusion::WorkStack :: pushf64(double _6840) { mosek::fusion::p_WorkStack::_get_impl(this)->pushf64(_6840); }void mosek::fusion::p_WorkStack::pushf64(double _6840){
  _pubthis->ensuref64((int)1);
  ((*f64)(pf64)) = _6840;
  ++ pf64;
}
void mosek::fusion::WorkStack :: pushi64(long long _6841) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi64(_6841); }void mosek::fusion::p_WorkStack::pushi64(long long _6841){
  _pubthis->ensurei64((int)1);
  ((*i64)(pi64)) = _6841;
  ++ pi64;
}
void mosek::fusion::WorkStack :: pushi32(int _6842) { mosek::fusion::p_WorkStack::_get_impl(this)->pushi32(_6842); }void mosek::fusion::p_WorkStack::pushi32(int _6842){
  _pubthis->ensurei32((int)1);
  ((*i32)(pi32)) = _6842;
  ++ pi32;
}
void mosek::fusion::WorkStack :: ensuref64(int _6843) { mosek::fusion::p_WorkStack::_get_impl(this)->ensuref64(_6843); }void mosek::fusion::p_WorkStack::ensuref64(int _6843){
  if ((safe_add( pf64,_6843 ) > (int)((f64)->size(0))))
  {
    {
      int _11833;
      bool _11834 = (_6843 < (int)((f64)->size(0)));
      if (_11834)
      {
        _11833 = safe_mul( (int)((f64)->size(0)),(int)2 );
      }
      else
      {
        _11833 = safe_add( (int)((f64)->size(0)),_6843 );
      }
      int _6844 = _11833;
      std::shared_ptr< monty::ndarray< double,1 > > _6845 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6844)));
      _checked_ptr_1<double> _ptr__6845(_6845 ? _6845->raw() : nullptr,_6845 ? _6845->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(f64,(int)0,_6845,(int)0,pf64);
      f64 = _6845;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei64(int _6846) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei64(_6846); }void mosek::fusion::p_WorkStack::ensurei64(int _6846){
  if ((safe_add( pi64,_6846 ) > (int)((i64)->size(0))))
  {
    {
      int _11835;
      bool _11836 = (_6846 < (int)((i64)->size(0)));
      if (_11836)
      {
        _11835 = (int)((i64)->size(0));
      }
      else
      {
        _11835 = _6846;
      }
      int _6847 = safe_add( (int)((i64)->size(0)),_11835 );
      std::shared_ptr< monty::ndarray< long long,1 > > _6848 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6847)));
      _checked_ptr_1<long long> _ptr__6848(_6848 ? _6848->raw() : nullptr,_6848 ? _6848->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i64,(int)0,_6848,(int)0,pi64);
      i64 = _6848;
    }
  }
  {}
}
void mosek::fusion::WorkStack :: ensurei32(int _6849) { mosek::fusion::p_WorkStack::_get_impl(this)->ensurei32(_6849); }void mosek::fusion::p_WorkStack::ensurei32(int _6849){
  if ((safe_add( pi32,_6849 ) > (int)((i32)->size(0))))
  {
    {
      int _11837;
      bool _11838 = (_6849 < (int)((i32)->size(0)));
      if (_11838)
      {
        _11837 = safe_mul( (int)((i32)->size(0)),(int)2 );
      }
      else
      {
        _11837 = safe_add( (int)((i32)->size(0)),_6849 );
      }
      int _6850 = _11837;
      std::shared_ptr< monty::ndarray< int,1 > > _6851 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6850)));
      _checked_ptr_1<int> _ptr__6851(_6851 ? _6851->raw() : nullptr,_6851 ? _6851->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(i32,(int)0,_6851,(int)0,pi32);
      i32 = _6851;
    }
  }
  {}
}
int mosek::fusion::WorkStack :: popf64(int _6852) { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_6852); }int mosek::fusion::p_WorkStack::popf64(int _6852){
  pf64 -= _6852;
  if ((pf64 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  return pf64;
}
int mosek::fusion::WorkStack :: popi64(int _6853) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_6853); }int mosek::fusion::p_WorkStack::popi64(int _6853){
  pi64 -= _6853;
  if ((pi64 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  return pi64;
}
int mosek::fusion::WorkStack :: popi32(int _6854) { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_6854); }int mosek::fusion::p_WorkStack::popi32(int _6854){
  pi32 -= _6854;
  if ((pi32 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  return pi32;
}
void mosek::fusion::WorkStack :: popf64(int _6855,std::shared_ptr< monty::ndarray< double,1 > > _6856,int _6857) { mosek::fusion::p_WorkStack::_get_impl(this)->popf64(_6855,_6856,_6857); }void mosek::fusion::p_WorkStack::popf64(int _6855,std::shared_ptr< monty::ndarray< double,1 > > _6856,int _6857){
  _checked_ptr_1<double> _ptr__6856(_6856 ? _6856->raw() : nullptr, _6856 ? _6856->size(0) : 0);
  pf64 -= _6855;
  if ((pf64 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(f64,pf64,_6856,_6857,_6855);
}
void mosek::fusion::WorkStack :: popi64(int _6858,std::shared_ptr< monty::ndarray< long long,1 > > _6859,int _6860) { mosek::fusion::p_WorkStack::_get_impl(this)->popi64(_6858,_6859,_6860); }void mosek::fusion::p_WorkStack::popi64(int _6858,std::shared_ptr< monty::ndarray< long long,1 > > _6859,int _6860){
  _checked_ptr_1<long long> _ptr__6859(_6859 ? _6859->raw() : nullptr, _6859 ? _6859->size(0) : 0);
  pi64 -= _6858;
  if ((pi64 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(i64,pi64,_6859,_6860,_6858);
}
void mosek::fusion::WorkStack :: popi32(int _6861,std::shared_ptr< monty::ndarray< int,1 > > _6862,int _6863) { mosek::fusion::p_WorkStack::_get_impl(this)->popi32(_6861,_6862,_6863); }void mosek::fusion::p_WorkStack::popi32(int _6861,std::shared_ptr< monty::ndarray< int,1 > > _6862,int _6863){
  _checked_ptr_1<int> _ptr__6862(_6862 ? _6862->raw() : nullptr, _6862 ? _6862->size(0) : 0);
  pi32 -= _6861;
  if ((pi32 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(i32,pi32,_6862,_6863,_6861);
}
double mosek::fusion::WorkStack :: popf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popf64(); }double mosek::fusion::p_WorkStack::popf64(){
  -- pf64;
  if ((pf64 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  return ((*f64)(pf64));
}
long long mosek::fusion::WorkStack :: popi64() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi64(); }long long mosek::fusion::p_WorkStack::popi64(){
  if ((pi64 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  -- pi64;
  return ((*i64)(pi64));
}
int mosek::fusion::WorkStack :: popi32() { return mosek::fusion::p_WorkStack::_get_impl(this)->popi32(); }int mosek::fusion::p_WorkStack::popi32(){
  -- pi32;
  if ((pi32 < (int)0))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("Internal: stack underflow"));
    }
  }
  {}
  return ((*i32)(pi32));
}
double mosek::fusion::WorkStack :: peekf64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(); }double mosek::fusion::p_WorkStack::peekf64(){
  return ((*f64)((pf64 - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(); }long long mosek::fusion::p_WorkStack::peeki64(){
  return ((*i64)((pi64 - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32() { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(); }int mosek::fusion::p_WorkStack::peeki32(){
  return ((*i32)((pi32 - (int)1)));
}
double mosek::fusion::WorkStack :: peekf64(int _6864) { return mosek::fusion::p_WorkStack::_get_impl(this)->peekf64(_6864); }double mosek::fusion::p_WorkStack::peekf64(int _6864){
  return ((*f64)(((pf64 - _6864) - (int)1)));
}
long long mosek::fusion::WorkStack :: peeki64(int _6865) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki64(_6865); }long long mosek::fusion::p_WorkStack::peeki64(int _6865){
  return ((*i64)(((pi64 - _6865) - (int)1)));
}
int mosek::fusion::WorkStack :: peeki32(int _6866) { return mosek::fusion::p_WorkStack::_get_impl(this)->peeki32(_6866); }int mosek::fusion::p_WorkStack::peeki32(int _6866){
  return ((*i32)(((pi32 - _6866) - (int)1)));
}
void mosek::fusion::p_WorkStack::destroy(){f64.reset();i64.reset();i32.reset();}void mosek::fusion::WorkStack::destroy() { mosek::fusion::p_WorkStack::_get_impl(this)->destroy(); }mosek::fusion::SymmetricExpr::SymmetricExpr(mosek::fusion::p_SymmetricExpr *_impl) : _impl(_impl) { /*std::cout << "SymmetricExpr() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricExpr::~SymmetricExpr() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricExpr::p_SymmetricExpr  (::mosek::fusion::SymmetricExpr * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricExpr::t mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr  (int _6867,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _6868,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6869,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6870){ return new mosek::fusion::SymmetricExpr(_6867,_6868,_6869,_6870); }mosek::fusion::SymmetricExpr::SymmetricExpr  (int _6867,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _6868,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6869,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6870) :    SymmetricExpr(new mosek::fusion::p_SymmetricExpr(this)){ mosek::fusion::p_SymmetricExpr::_get_impl(this)->_initialize(_6867,_6868,_6869,_6870); }void mosek::fusion::p_SymmetricExpr::_initialize  (int _6867,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _6868,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6869,    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6870){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->n = _6867;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->Ms = _6868;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->xs = _6869;
    mosek::fusion::p_SymmetricExpr::_get_impl(::mosek::fusion::SymmetricExpr::t(_pubthis))->b = _6870;
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6871,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6872){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_6871)->n != _6872->getdim()))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimension does not match"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _11839;
  bool _11840 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_6871)->b.get());
  if (_11840)
  {
    _11839 = mosek::fusion::p_SymmetricExpr::_get_impl(_6871)->b->__mosek_2fusion_2SymmetricMatrix__add(_6872);
  }
  else
  {
    _11839 = _6872;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_6871)->n,mosek::fusion::p_SymmetricExpr::_get_impl(_6871)->Ms,mosek::fusion::p_SymmetricExpr::_get_impl(_6871)->xs,_11839);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6873,double _6874){
  std::vector<monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >> _11841;
  for (int _6875 = (int)0, _11842 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6873)->Ms)->size(0)); _6875 < _11842 ; ++_6875)
  {
    _11841.push_back(((*mosek::fusion::p_SymmetricExpr::_get_impl(_6873)->Ms)(_6875))->__mosek_2fusion_2SymmetricMatrix__mul(_6874));
  }
  auto _11843 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(_11841.size()),_11841.begin(),_11841.end()));
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _11844;
  bool _11845 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_6873)->b.get());
  if (_11845)
  {
    _11844 = mosek::fusion::p_SymmetricExpr::_get_impl(_6873)->b->__mosek_2fusion_2SymmetricMatrix__mul(_6874);
  }
  else
  {
    _11844 = nullptr;
  }
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_6873)->n,_11843,mosek::fusion::p_SymmetricExpr::_get_impl(_6873)->xs,_11844);
}
monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mosek::fusion::p_SymmetricExpr::add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6876,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6877){
  if ((mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->n != mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->n))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions of operands"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _6878 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->Ms)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->Ms)->size(0)) ))));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6879 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->xs)->size(0)),(int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->xs)->size(0)) ))));
  int _6880 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->Ms)->size(0));
  int _11846 = (int)0;
  int _11847 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->Ms)->size(0));
  for (int _6881 = _11846; _6881 < _11847; ++_6881)
  {
    {
      ((*_6878)(_6881)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->Ms)(_6881));
    }
  }
  int _11848 = (int)0;
  int _11849 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->Ms)->size(0));
  for (int _6882 = _11848; _6882 < _11849; ++_6882)
  {
    {
      ((*_6878)(safe_add( _6882,_6880 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->Ms)(_6882));
    }
  }
  int _6883 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->xs)->size(0));
  int _11850 = (int)0;
  int _11851 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->xs)->size(0));
  for (int _6884 = _11850; _6884 < _11851; ++_6884)
  {
    {
      ((*_6879)(_6884)) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->xs)(_6884));
    }
  }
  int _11852 = (int)0;
  int _11853 = (int)((mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->xs)->size(0));
  for (int _6885 = _11852; _6885 < _11853; ++_6885)
  {
    {
      ((*_6879)(safe_add( _6885,_6883 ))) = ((*mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->xs)(_6885));
    }
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _11854;
  bool _11855 = ((NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->b.get()) && (NULL == mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->b.get()));
  if (_11855)
  {
    _11854 = nullptr;
  }
  else
  {
    monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _11856;
    bool _11857 = ((NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->b.get()) && (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->b.get()));
    if (_11857)
    {
      _11856 = mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->b->__mosek_2fusion_2SymmetricMatrix__add(mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->b);
    }
    else
    {
      monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _11858;
      bool _11859 = (NULL != mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->b.get());
      if (_11859)
      {
        _11858 = mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->b;
      }
      else
      {
        _11858 = mosek::fusion::p_SymmetricExpr::_get_impl(_6877)->b;
      }
      _11856 = _11858;
    }
    _11854 = _11856;
  }
  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6886 = _11854;
  return ::mosek::fusion::p_SymmetricExpr::_new_SymmetricExpr(mosek::fusion::p_SymmetricExpr::_get_impl(_6876)->n,_6878,_6879,_6886);
}
std::string mosek::fusion::SymmetricExpr :: toString() { return mosek::fusion::p_SymmetricExpr::_get_impl(this)->toString(); }std::string mosek::fusion::p_SymmetricExpr::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _6887 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _6887->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SymmetricExpr( ("))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(n)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (") )"));
  return _6887->toString();
}
void mosek::fusion::p_SymmetricExpr::destroy(){xs.reset();b.reset();Ms.reset();}void mosek::fusion::SymmetricExpr::destroy() { mosek::fusion::p_SymmetricExpr::_get_impl(this)->destroy(); }mosek::fusion::Expr::Expr(mosek::fusion::p_Expr *_impl) : mosek::fusion::BaseExpression(_impl) { /*std::cout << "Expr()" << this << std::endl; */ }mosek::fusion::Expr::~Expr() {  /* std::cout << "~Expr()" << this << std::endl << std::flush; */ }mosek::fusion::p_Expr::p_Expr  (::mosek::fusion::Expr * _pubthis) :     mosek::fusion::p_BaseExpression(_pubthis),    _pubthis(_pubthis){}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _6888,    std::shared_ptr< monty::ndarray< long long,1 > > _6889,    std::shared_ptr< monty::ndarray< double,1 > > _6890,    std::shared_ptr< monty::ndarray< double,1 > > _6891,    std::shared_ptr< monty::ndarray< int,1 > > _6892,    std::shared_ptr< monty::ndarray< long long,1 > > _6893){ return new mosek::fusion::Expr(_6888,_6889,_6890,_6891,_6892,_6893); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _6888,    std::shared_ptr< monty::ndarray< long long,1 > > _6889,    std::shared_ptr< monty::ndarray< double,1 > > _6890,    std::shared_ptr< monty::ndarray< double,1 > > _6891,    std::shared_ptr< monty::ndarray< int,1 > > _6892,    std::shared_ptr< monty::ndarray< long long,1 > > _6893) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_6888,_6889,_6890,_6891,_6892,_6893); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _6888,    std::shared_ptr< monty::ndarray< long long,1 > > _6889,    std::shared_ptr< monty::ndarray< double,1 > > _6890,    std::shared_ptr< monty::ndarray< double,1 > > _6891,    std::shared_ptr< monty::ndarray< int,1 > > _6892,    std::shared_ptr< monty::ndarray< long long,1 > > _6893){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__6888(_6888 ? _6888->raw() : nullptr, _6888 ? _6888->size(0) : 0);
    _checked_ptr_1<long long> _ptr__6889(_6889 ? _6889->raw() : nullptr, _6889 ? _6889->size(0) : 0);
    _checked_ptr_1<double> _ptr__6890(_6890 ? _6890->raw() : nullptr, _6890 ? _6890->size(0) : 0);
    _checked_ptr_1<double> _ptr__6891(_6891 ? _6891->raw() : nullptr, _6891 ? _6891->size(0) : 0);
    _checked_ptr_1<int> _ptr__6892(_6892 ? _6892->raw() : nullptr, _6892 ? _6892->size(0) : 0);
    _checked_ptr_1<long long> _ptr__6893(_6893 ? _6893->raw() : nullptr, _6893 ? _6893->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _11860;
    bool _11861 = (NULL != _6892.get());
    if (_11861)
    {
      _11860 = ::mosek::fusion::Utils::Tools::arraycopy(_6892);
    }
    else
    {
      _11860 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(((int)((_6888)->size(0)) - (int)1))});
    }
    std::shared_ptr< monty::ndarray< long long,1 > > _11862;
    bool _11863 = (NULL != _6893.get());
    if (_11863)
    {
      _11862 = ::mosek::fusion::Utils::Tools::arraycopy(_6893);
    }
    else
    {
      _11862 = nullptr;
    }
    mosek::fusion::p_Expr::_initialize(::mosek::fusion::Utils::Tools::arraycopy(_6888),::mosek::fusion::Utils::Tools::arraycopy(_6889),::mosek::fusion::Utils::Tools::arraycopy(_6890),::mosek::fusion::Utils::Tools::arraycopy(_6891),_11860,_11862,(int)1);
    int _6894 = ((int)((_6888)->size(0)) - (int)1);
    if ((_6894 < (int)0))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    long long _6895 = _ptr__6888[_6894];
    if (((_6895 < (int)0) || ((_6895 != (int)((_6890)->size(0))) || (_6895 != (int)((_6889)->size(0))))))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb construction"));
      }
    }
    {}
    bool _6896 = true;
    bool _6897 = true;
    bool _6898 = true;
    std::shared_ptr< monty::ndarray< int,1 > > _6899 = mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape;
    _checked_ptr_1<int> _ptr__6899(_6899 ? _6899->raw() : nullptr,_6899 ? _6899->size(0) : 0);
    long long _6900 = ::mosek::fusion::p_Set::size(_6899);
    {
      int _11864 = (int)0;
      int _11865 = (int)((_6899)->size(0));
      for (int _6901 = _11864; _6901 < _11865; ++_6901)
      {
        {
          _6897 = (_6897 && (_ptr__6899[_6901] >= (int)0));
        }
      }
      int _11866 = (int)0;
      int _11867 = _6894;
      for (int _6902 = _11866; _6902 < _11867; ++_6902)
      {
        {
          _6896 = (_6896 && (_ptr__6888[_6902] <= _ptr__6888[safe_add( _6902,(int)1 )]));
        }
      }
      if (((NULL != _6893.get()) && ((int)((_6893)->size(0)) > (int)0)))
      {
        {
          _6898 = ((_ptr__6893[(int)0] >= (int)0) && (_ptr__6893[(_6894 - (int)1)] < _6900));
          int _11868 = (int)0;
          int _11869 = (_6894 - (int)1);
          for (int _6903 = _11868; _6903 < _11869; ++_6903)
          {
            {
              _6898 = (_6898 && (_ptr__6893[_6903] < _ptr__6893[safe_add( _6903,(int)1 )]));
            }
          }
        }
      }
      {}
    }
    if ((!_6897))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid shape"));
      }
    }
    {}
    if ((!_6896))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid ptrb"));
      }
    }
    {}
    if ((!_6898))
    {
      {
        throw ::mosek::fusion::ExpressionError(std::string ("Invalid sparsity pattern"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _6904,    std::shared_ptr< monty::ndarray< long long,1 > > _6905,    std::shared_ptr< monty::ndarray< double,1 > > _6906,    std::shared_ptr< monty::ndarray< double,1 > > _6907,    std::shared_ptr< monty::ndarray< int,1 > > _6908,    std::shared_ptr< monty::ndarray< long long,1 > > _6909,    int _6910){ return new mosek::fusion::Expr(_6904,_6905,_6906,_6907,_6908,_6909,_6910); }mosek::fusion::Expr::Expr  (std::shared_ptr< monty::ndarray< long long,1 > > _6904,    std::shared_ptr< monty::ndarray< long long,1 > > _6905,    std::shared_ptr< monty::ndarray< double,1 > > _6906,    std::shared_ptr< monty::ndarray< double,1 > > _6907,    std::shared_ptr< monty::ndarray< int,1 > > _6908,    std::shared_ptr< monty::ndarray< long long,1 > > _6909,    int _6910) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_6904,_6905,_6906,_6907,_6908,_6909,_6910); }void mosek::fusion::p_Expr::_initialize  (std::shared_ptr< monty::ndarray< long long,1 > > _6904,    std::shared_ptr< monty::ndarray< long long,1 > > _6905,    std::shared_ptr< monty::ndarray< double,1 > > _6906,    std::shared_ptr< monty::ndarray< double,1 > > _6907,    std::shared_ptr< monty::ndarray< int,1 > > _6908,    std::shared_ptr< monty::ndarray< long long,1 > > _6909,    int _6910){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<long long> _ptr__6904(_6904 ? _6904->raw() : nullptr, _6904 ? _6904->size(0) : 0);
    _checked_ptr_1<long long> _ptr__6905(_6905 ? _6905->raw() : nullptr, _6905 ? _6905->size(0) : 0);
    _checked_ptr_1<double> _ptr__6906(_6906 ? _6906->raw() : nullptr, _6906 ? _6906->size(0) : 0);
    _checked_ptr_1<double> _ptr__6907(_6907 ? _6907->raw() : nullptr, _6907 ? _6907->size(0) : 0);
    _checked_ptr_1<int> _ptr__6908(_6908 ? _6908->raw() : nullptr, _6908 ? _6908->size(0) : 0);
    _checked_ptr_1<long long> _ptr__6909(_6909 ? _6909->raw() : nullptr, _6909 ? _6909->size(0) : 0);
    mosek::fusion::p_BaseExpression::_initialize(_6908);
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape = _6908;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->ptrb = _6904;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->subj = _6905;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->cof_v = _6906;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->bfix = _6907;
    mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->inst = _6909;
    if ((NULL == mosek::fusion::p_Expr::_get_impl(::mosek::fusion::Expr::t(_pubthis))->shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}mosek::fusion::Expr::t mosek::fusion::p_Expr::_new_Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _6911){ return new mosek::fusion::Expr(_6911); }mosek::fusion::Expr::Expr  (monty::rc_ptr< ::mosek::fusion::Expression > _6911) :    Expr(new mosek::fusion::p_Expr(this)){ mosek::fusion::p_Expr::_get_impl(this)->_initialize(_6911); }void mosek::fusion::p_Expr::_initialize  (monty::rc_ptr< ::mosek::fusion::Expression > _6911){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_BaseExpression::_initialize(_6911->getShape());
    monty::rc_ptr< ::mosek::fusion::Expression > _11870 = _6911;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::Expr*>(_11870.get()))
    {
      ::mosek::fusion::Expr::t _6912 (dynamic_cast<::mosek::fusion::Expr*>(_11870.get()));
      {
        shape = mosek::fusion::p_Expr::_get_impl(_6912)->shape;
        ptrb = mosek::fusion::p_Expr::_get_impl(_6912)->ptrb;
        subj = mosek::fusion::p_Expr::_get_impl(_6912)->subj;
        cof_v = mosek::fusion::p_Expr::_get_impl(_6912)->cof_v;
        bfix = mosek::fusion::p_Expr::_get_impl(_6912)->bfix;
        inst = mosek::fusion::p_Expr::_get_impl(_6912)->inst;
      }
    }
    else
    {
      mosek::fusion::Expression::t _6913 = _11870;
      {
        monty::rc_ptr< ::mosek::fusion::WorkStack > _6914 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _6915 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        monty::rc_ptr< ::mosek::fusion::WorkStack > _6916 = ::mosek::fusion::p_WorkStack::_new_WorkStack();
        _6913->eval(_6916,_6915,_6914);
        int _6917 = _6916->popi32();
        int _6918 = _6916->popi32(_6917);
        int _6919 = _6916->popi32();
        int _6920 = _6916->popi32();
        bool _6921 = (_6916->popi32() != (int)0);
        int _6922 = _6916->popi32(safe_add( _6919,(int)1 ));
        int _11871;
        bool _11872 = _6921;
        if (_11872)
        {
          _11871 = _6916->popi64(_6919);
        }
        else
        {
          _11871 = (int)0;
        }
        int _6923 = _11871;
        int _6924 = _6916->popi64(_6920);
        int _6925 = _6916->popf64(_6919);
        int _6926 = _6916->popf64(_6920);
        std::shared_ptr< monty::ndarray< int,1 > > _6927 = mosek::fusion::p_WorkStack::_get_impl(_6916)->i32;
        _checked_ptr_1<int> _ptr__6927(_6927 ? _6927->raw() : nullptr,_6927 ? _6927->size(0) : 0);
        std::shared_ptr< monty::ndarray< long long,1 > > _6928 = mosek::fusion::p_WorkStack::_get_impl(_6916)->i64;
        _checked_ptr_1<long long> _ptr__6928(_6928 ? _6928->raw() : nullptr,_6928 ? _6928->size(0) : 0);
        std::shared_ptr< monty::ndarray< double,1 > > _6929 = mosek::fusion::p_WorkStack::_get_impl(_6916)->f64;
        _checked_ptr_1<double> _ptr__6929(_6929 ? _6929->raw() : nullptr,_6929 ? _6929->size(0) : 0);
        std::vector<int> _11873;
        for (int _6930 = (int)0, _11874 = _6917; _6930 < _11874 ; ++_6930)
        {
          _11873.push_back(_ptr__6927[safe_add( _6918,_6930 )]);
        }
        auto _11875 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11873.size()),_11873.begin(),_11873.end()));
        shape = _11875;
        std::vector<long long> _11876;
        for (int _6931 = (int)0, _11877 = safe_add( _6919,(int)1 ); _6931 < _11877 ; ++_6931)
        {
          _11876.push_back(_ptr__6927[safe_add( _6922,_6931 )]);
        }
        auto _11878 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11876.size()),_11876.begin(),_11876.end()));
        ptrb = _11878;
        std::vector<long long> _11879;
        for (int _6932 = (int)0, _11880 = _6920; _6932 < _11880 ; ++_6932)
        {
          _11879.push_back(_ptr__6928[safe_add( _6924,_6932 )]);
        }
        auto _11881 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11879.size()),_11879.begin(),_11879.end()));
        subj = _11881;
        std::vector<double> _11882;
        for (int _6933 = (int)0, _11883 = _6920; _6933 < _11883 ; ++_6933)
        {
          _11882.push_back(_ptr__6929[safe_add( _6926,_6933 )]);
        }
        auto _11884 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11882.size()),_11882.begin(),_11882.end()));
        cof_v = _11884;
        std::vector<double> _11885;
        for (int _6934 = (int)0, _11886 = _6920; _6934 < _11886 ; ++_6934)
        {
          _11885.push_back(_ptr__6929[safe_add( _6925,_6934 )]);
        }
        auto _11887 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11885.size()),_11885.begin(),_11885.end()));
        bfix = _11887;
        std::shared_ptr< monty::ndarray< long long,1 > > _11888;
        bool _11889 = _6921;
        if (_11889)
        {
          std::vector<long long> _11890;
          for (int _6935 = (int)0, _11891 = _6920; _6935 < _11891 ; ++_6935)
          {
            _11890.push_back(_ptr__6928[safe_add( _6923,_6935 )]);
          }
          auto _11892 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11890.size()),_11890.begin(),_11890.end()));
          _11888 = _11892;
        }
        else
        {
          _11888 = nullptr;
        }
        inst = _11888;
      }
    }
    if ((NULL == shape.get()))
    {
      {
        throw ::mosek::fusion::UnexpectedError(std::string ("Internal: NULL shape"));
      }
    }
    {}
  }
}long long mosek::fusion::p_Expr::prod(std::shared_ptr< monty::ndarray< int,1 > > _6936){
  _checked_ptr_1<int> _ptr__6936(_6936 ? _6936->raw() : nullptr, _6936 ? _6936->size(0) : 0);
  int _6937 = (int)1;
  int _11893 = (int)0;
  int _11894 = (int)((_6936)->size(0));
  for (int _6938 = _11893; _6938 < _11894; ++_6938)
  {
    {
      _6937 *= _ptr__6936[_6938];
    }
  }
  return _6937;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _6939){
  std::vector<monty::rc_ptr< ::mosek::fusion::Variable >> _11895;
  for (int _6940 = (int)0, _11896 = (int)((_6939)->size(0)); _6940 < _11896 ; ++_6940)
  {
    for (int _6941 = (int)0, _11897 = (int)((((*_6939)(_6940)))->size(0)); _6941 < _11897 ; ++_6941)
    {
      _11895.push_back(((*((*_6939)(_6940)))(_6941)));
    }
  }
  auto _11898 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(_11895.size()),_11895.begin(),_11895.end()));
  return _11898;
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > mosek::fusion::p_Expr::varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6942,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6943){
  if ((NULL == _6942.get()))
  {
    {
      return _6943;
    }
  }
  else if((NULL == _6943.get()))
  {
    {
      return _6942;
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6944 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 >(monty::shape(safe_add( (int)((_6942)->size(0)),(int)((_6943)->size(0)) ))));
      int _11899 = (int)0;
      int _11900 = (int)((_6942)->size(0));
      for (int _6945 = _11899; _6945 < _11900; ++_6945)
      {
        {
          ((*_6944)(_6945)) = ((*_6942)(_6945));
        }
      }
      int _11901 = (int)0;
      int _11902 = (int)((_6943)->size(0));
      for (int _6946 = _11901; _6946 < _11902; ++_6946)
      {
        {
          ((*_6944)(safe_add( _6946,(int)((_6942)->size(0)) ))) = ((*_6943)(_6946));
        }
      }
      return _6944;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::condense  ( monty::rc_ptr< ::mosek::fusion::Expression > _6947) { return mosek::fusion::p_Expr::condense(_6947); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::condense(monty::rc_ptr< ::mosek::fusion::Expression > _6947){
  return (::mosek::fusion::p_ExprCondense::_new_ExprCondense(_6947)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::flatten  ( monty::rc_ptr< ::mosek::fusion::Expression > _6948) { return mosek::fusion::p_Expr::flatten(_6948); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::flatten(monty::rc_ptr< ::mosek::fusion::Expression > _6948){
  if ((NULL == _6948.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for flatten may not be null"));
    }
  }
  {}
  long long _6949 = _6948->getSize();
  if ((!(_6949 <= (int)0x7fffffff)))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Maximum dimension size exceeded"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_6948,(int)_6949);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _6950,    int _6951,    int _6952) { return mosek::fusion::p_Expr::reshape(_6950,_6951,_6952); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _6950,int _6951,int _6952){
  if ((NULL == _6950.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_6950,::mosek::fusion::p_Set::make(_6951,_6952));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _6953,    int _6954) { return mosek::fusion::p_Expr::reshape(_6953,_6954); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _6953,int _6954){
  if ((NULL == _6953.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for reshape may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::reshape(_6953,::mosek::fusion::p_Set::make(_6954));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::reshape  ( monty::rc_ptr< ::mosek::fusion::Expression > _6955,    std::shared_ptr< monty::ndarray< int,1 > > _6956) { return mosek::fusion::p_Expr::reshape(_6955,_6956); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::reshape(monty::rc_ptr< ::mosek::fusion::Expression > _6955,std::shared_ptr< monty::ndarray< int,1 > > _6956){
  _checked_ptr_1<int> _ptr__6956(_6956 ? _6956->raw() : nullptr, _6956 ? _6956->size(0) : 0);
  return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_6956,_6955)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: size() { return mosek::fusion::p_Expr::_get_impl(this)->size(); }long long mosek::fusion::p_Expr::size(){
  return ((long long)((ptrb)->size(0)) - (int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( std::shared_ptr< monty::ndarray< int,1 > > _6957) { return mosek::fusion::p_Expr::zeros(_6957); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(std::shared_ptr< monty::ndarray< int,1 > > _6957){
  _checked_ptr_1<int> _ptr__6957(_6957 ? _6957->raw() : nullptr, _6957 ? _6957->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_6957,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::zeros  ( int _6958) { return mosek::fusion::p_Expr::zeros(_6958); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::zeros(int _6958){
  return ::mosek::fusion::p_Expr::constTerm(_6958,(double)((int)0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( ) { return mosek::fusion::p_Expr::ones(); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(){
  return ::mosek::fusion::p_Expr::constTerm((double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _6959,    std::shared_ptr< monty::ndarray< int,2 > > _6960) { return mosek::fusion::p_Expr::ones(_6959,_6960); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _6959,std::shared_ptr< monty::ndarray< int,2 > > _6960){
  _checked_ptr_1<int> _ptr__6959(_6959 ? _6959->raw() : nullptr, _6959 ? _6959->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_6959,_6960,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( std::shared_ptr< monty::ndarray< int,1 > > _6961) { return mosek::fusion::p_Expr::ones(_6961); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(std::shared_ptr< monty::ndarray< int,1 > > _6961){
  _checked_ptr_1<int> _ptr__6961(_6961 ? _6961->raw() : nullptr, _6961 ? _6961->size(0) : 0);
  return ::mosek::fusion::p_Expr::constTerm(_6961,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::ones  ( int _6962) { return mosek::fusion::p_Expr::ones(_6962); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::ones(int _6962){
  return ::mosek::fusion::p_Expr::constTerm(_6962,(double)((int)1));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _6963) { return mosek::fusion::p_Expr::constTerm(_6963); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _6963){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(mosek::fusion::p_NDSparseArray::_get_impl(_6963)->dims,mosek::fusion::p_NDSparseArray::_get_impl(_6963)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_6963)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _6964) { return mosek::fusion::p_Expr::constTerm(_6964); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _6964){
  int _6965 = _6964->numRows();
  int _6966 = _6964->numColumns();
  std::shared_ptr< monty::ndarray< int,1 > > _6967 = ::mosek::fusion::p_Set::make(_6965,_6966);
  _checked_ptr_1<int> _ptr__6967(_6967 ? _6967->raw() : nullptr,_6967 ? _6967->size(0) : 0);
  if (_6964->isSparse())
  {
    {
      std::shared_ptr< monty::ndarray< double,1 > > _6968 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_6964->numNonzeros())));
      _checked_ptr_1<double> _ptr__6968(_6968 ? _6968->raw() : nullptr,_6968 ? _6968->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _6969 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6964->numNonzeros())));
      _checked_ptr_1<int> _ptr__6969(_6969 ? _6969->raw() : nullptr,_6969 ? _6969->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _6970 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_6964->numNonzeros())));
      _checked_ptr_1<int> _ptr__6970(_6970 ? _6970->raw() : nullptr,_6970 ? _6970->size(0) : 0);
      _6964->getDataAsTriplets(_6970,_6969,_6968);
      std::vector<long long> _11903;
      for (int _6972 = (int)0, _11904 = (int)((_6969)->size(0)); _6972 < _11904 ; ++_6972)
      {
        _11903.push_back(safe_add( safe_mul( _ptr__6970[_6972],_6966 ),_ptr__6969[_6972] ));
      }
      auto _11905 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11903.size()),_11903.begin(),_11903.end()));
      std::shared_ptr< monty::ndarray< long long,1 > > _6971 = _11905;
      _checked_ptr_1<long long> _ptr__6971(_6971 ? _6971->raw() : nullptr,_6971 ? _6971->size(0) : 0);
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_6967,_6971,_6968)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprConst::_new_ExprConst(_6967,nullptr,_6964->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( double _6973) { return mosek::fusion::p_Expr::constTerm(_6973); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(double _6973){
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),nullptr,_6973)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _6974,    std::shared_ptr< monty::ndarray< int,2 > > _6975,    double _6976) { return mosek::fusion::p_Expr::constTerm(_6974,_6975,_6976); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _6974,std::shared_ptr< monty::ndarray< int,2 > > _6975,double _6976){
  _checked_ptr_1<int> _ptr__6974(_6974 ? _6974->raw() : nullptr, _6974 ? _6974->size(0) : 0);
  int _6977 = (int)((_6975)->size(0));
  int _6978 = (int)((_6974)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _6979 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6977)));
  _checked_ptr_1<long long> _ptr__6979(_6979 ? _6979->raw() : nullptr,_6979 ? _6979->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6980 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6978)));
  _checked_ptr_1<long long> _ptr__6980(_6980 ? _6980->raw() : nullptr,_6980 ? _6980->size(0) : 0);
  _ptr__6980[(_6978 - (int)1)] = (int)1;
  int _11906 = (int)1;
  int _11907 = _6978;
  for (int _6981 = _11906; _6981 < _11907; ++_6981)
  {
    {
      _ptr__6980[((_6978 - _6981) - (int)1)] = safe_mul( _ptr__6980[(_6978 - _6981)],_ptr__6974[(_6978 - _6981)] );
    }
  }
  int _11908 = (int)0;
  int _11909 = _6977;
  for (int _6982 = _11908; _6982 < _11909; ++_6982)
  {
    {
      int _11910 = (int)0;
      int _11911 = _6978;
      for (int _6983 = _11910; _6983 < _11911; ++_6983)
      {
        {
          _ptr__6979[_6982] += safe_mul( _ptr__6980[_6983],((*_6975)(_6982,_6983)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_6974,_6979,_6976)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _6984,    std::shared_ptr< monty::ndarray< int,2 > > _6985,    std::shared_ptr< monty::ndarray< double,1 > > _6986) { return mosek::fusion::p_Expr::constTerm(_6984,_6985,_6986); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _6984,std::shared_ptr< monty::ndarray< int,2 > > _6985,std::shared_ptr< monty::ndarray< double,1 > > _6986){
  _checked_ptr_1<int> _ptr__6984(_6984 ? _6984->raw() : nullptr, _6984 ? _6984->size(0) : 0);
  _checked_ptr_1<double> _ptr__6986(_6986 ? _6986->raw() : nullptr, _6986 ? _6986->size(0) : 0);
  int _6987 = (int)((_6985)->size(0));
  int _6988 = (int)((_6984)->size(0));
  std::shared_ptr< monty::ndarray< long long,1 > > _6989 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6987)));
  _checked_ptr_1<long long> _ptr__6989(_6989 ? _6989->raw() : nullptr,_6989 ? _6989->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _6990 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_6988)));
  _checked_ptr_1<long long> _ptr__6990(_6990 ? _6990->raw() : nullptr,_6990 ? _6990->size(0) : 0);
  _ptr__6990[(_6988 - (int)1)] = (int)1;
  int _11912 = (int)1;
  int _11913 = _6988;
  for (int _6991 = _11912; _6991 < _11913; ++_6991)
  {
    {
      _ptr__6990[((_6988 - _6991) - (int)1)] = safe_mul( _ptr__6990[(_6988 - _6991)],_ptr__6984[(_6988 - _6991)] );
    }
  }
  int _11914 = (int)0;
  int _11915 = _6987;
  for (int _6992 = _11914; _6992 < _11915; ++_6992)
  {
    {
      int _11916 = (int)0;
      int _11917 = _6988;
      for (int _6993 = _11916; _6993 < _11917; ++_6993)
      {
        {
          _ptr__6989[_6992] += safe_mul( _ptr__6990[_6993],((*_6985)(_6992,_6993)) );
        }
      }
    }
  }
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_6984,_6989,_6986)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< int,1 > > _6994,    double _6995) { return mosek::fusion::p_Expr::constTerm(_6994,_6995); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< int,1 > > _6994,double _6995){
  _checked_ptr_1<int> _ptr__6994(_6994 ? _6994->raw() : nullptr, _6994 ? _6994->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(_6994,nullptr,_6995)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( int _6996,    double _6997) { return mosek::fusion::p_Expr::constTerm(_6996,_6997); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(int _6996,double _6997){
  std::vector<double> _11918;
  for (int _6998 = (int)0, _11919 = _6996; _6998 < _11919 ; ++_6998)
  {
    _11918.push_back(_6997);
  }
  auto _11920 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11918.size()),_11918.begin(),_11918.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_6996)}),nullptr,_11920)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,2 > > _6999) { return mosek::fusion::p_Expr::constTerm(_6999); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,2 > > _6999){
  std::vector<double> _11921;
  for (int _7000 = (int)0, _11922 = (int)((_6999)->size(0)); _7000 < _11922 ; ++_7000)
  {
    for (int _7001 = (int)0, _11923 = (int)((_6999)->size(1)); _7001 < _11923 ; ++_7001)
    {
      _11921.push_back(((*_6999)(_7000,_7001)));
    }
  }
  auto _11924 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11921.size()),_11921.begin(),_11921.end()));
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_6999)->size(0))),(int)((int)((_6999)->size(1)))}),nullptr,_11924)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::constTerm  ( std::shared_ptr< monty::ndarray< double,1 > > _7002) { return mosek::fusion::p_Expr::constTerm(_7002); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::constTerm(std::shared_ptr< monty::ndarray< double,1 > > _7002){
  _checked_ptr_1<double> _ptr__7002(_7002 ? _7002->raw() : nullptr, _7002 ? _7002->size(0) : 0);
  return (::mosek::fusion::p_ExprConst::_new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_7002)->size(0)))}),nullptr,_7002)).as<::mosek::fusion::Expression>();
}
long long mosek::fusion::Expr :: numNonzeros() { return mosek::fusion::p_Expr::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_Expr::numNonzeros(){
  return (long long)((cof_v)->size(0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _7003,    int _7004) { return mosek::fusion::p_Expr::sum(_7003,_7004); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _7003,int _7004){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce(_7004,_7003)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sum  ( monty::rc_ptr< ::mosek::fusion::Expression > _7005) { return mosek::fusion::p_Expr::sum(_7005); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sum(monty::rc_ptr< ::mosek::fusion::Expression > _7005){
  return (::mosek::fusion::p_ExprSumReduce::_new_ExprSumReduce((int)0,::mosek::fusion::p_Expr::flatten(_7005))).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::neg  ( monty::rc_ptr< ::mosek::fusion::Expression > _7006) { return mosek::fusion::p_Expr::neg(_7006); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::neg(monty::rc_ptr< ::mosek::fusion::Expression > _7006){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst((double)((-(int)1)),_7006)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(bool _7007,monty::rc_ptr< ::mosek::fusion::Matrix > _7008,monty::rc_ptr< ::mosek::fusion::Expression > _7009){
  long long _7010 = _7008->numNonzeros();
  int _7011 = _7008->numRows();
  int _7012 = _7008->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _7013 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7010)));
  _checked_ptr_1<double> _ptr__7013(_7013 ? _7013->raw() : nullptr,_7013 ? _7013->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7014 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7010)));
  _checked_ptr_1<int> _ptr__7014(_7014 ? _7014->raw() : nullptr,_7014 ? _7014->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7015 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7010)));
  _checked_ptr_1<int> _ptr__7015(_7015 ? _7015->raw() : nullptr,_7015 ? _7015->size(0) : 0);
  _7008->getDataAsTriplets(_7015,_7014,_7013);
  if (_7007)
  {
    {
      return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft(_7011,_7012,_7015,_7014,_7013,_7009)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight(_7011,_7012,_7015,_7014,_7013,_7009)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _7016,    monty::rc_ptr< ::mosek::fusion::Parameter > _7017) { return mosek::fusion::p_Expr::mulDiag(_7016,_7017); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _7016,monty::rc_ptr< ::mosek::fusion::Parameter > _7017){
  return (::mosek::fusion::p_ExprMulParamDiagRight::_new_ExprMulParamDiagRight(_7016->__mosek_2fusion_2Variable__asExpr(),_7017)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Parameter > _7018,    monty::rc_ptr< ::mosek::fusion::Variable > _7019) { return mosek::fusion::p_Expr::mulDiag(_7018,_7019); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Parameter > _7018,monty::rc_ptr< ::mosek::fusion::Variable > _7019){
  return (::mosek::fusion::p_ExprMulParamDiagLeft::_new_ExprMulParamDiagLeft(_7018,_7019->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _7020,    monty::rc_ptr< ::mosek::fusion::Parameter > _7021) { return mosek::fusion::p_Expr::mulDiag(_7020,_7021); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _7020,monty::rc_ptr< ::mosek::fusion::Parameter > _7021){
  return (::mosek::fusion::p_ExprMulParamDiagRight::_new_ExprMulParamDiagRight(_7020,_7021)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Parameter > _7022,    monty::rc_ptr< ::mosek::fusion::Expression > _7023) { return mosek::fusion::p_Expr::mulDiag(_7022,_7023); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Parameter > _7022,monty::rc_ptr< ::mosek::fusion::Expression > _7023){
  return (::mosek::fusion::p_ExprMulParamDiagLeft::_new_ExprMulParamDiagLeft(_7022,_7023)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _7024,    monty::rc_ptr< ::mosek::fusion::Matrix > _7025) { return mosek::fusion::p_Expr::mulDiag(_7024,_7025); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _7024,monty::rc_ptr< ::mosek::fusion::Matrix > _7025){
  return ::mosek::fusion::p_Expr::mulDiag(false,_7025,_7024->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7026,    monty::rc_ptr< ::mosek::fusion::Variable > _7027) { return mosek::fusion::p_Expr::mulDiag(_7026,_7027); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _7026,monty::rc_ptr< ::mosek::fusion::Variable > _7027){
  return ::mosek::fusion::p_Expr::mulDiag(true,_7026,_7027->__mosek_2fusion_2Variable__asExpr());
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _7028,    monty::rc_ptr< ::mosek::fusion::Matrix > _7029) { return mosek::fusion::p_Expr::mulDiag(_7028,_7029); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _7028,monty::rc_ptr< ::mosek::fusion::Matrix > _7029){
  return ::mosek::fusion::p_Expr::mulDiag(false,_7029,_7028);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7030,    monty::rc_ptr< ::mosek::fusion::Expression > _7031) { return mosek::fusion::p_Expr::mulDiag(_7030,_7031); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _7030,monty::rc_ptr< ::mosek::fusion::Expression > _7031){
  return ::mosek::fusion::p_Expr::mulDiag(true,_7030,_7031);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Variable > _7032,    std::shared_ptr< monty::ndarray< double,2 > > _7033) { return mosek::fusion::p_Expr::mulDiag(_7032,_7033); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _7032,std::shared_ptr< monty::ndarray< double,2 > > _7033){
  std::vector<int> _11925;
  for (int _7034 = (int)0, _11926 = (int)((_7033)->size(0)); _7034 < _11926 ; ++_7034)
  {
    for (int _7035 = (int)0, _11927 = (int)((_7033)->size(1)); _7035 < _11927 ; ++_7035)
    {
      _11925.push_back(_7034);
    }
  }
  auto _11928 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11925.size()),_11925.begin(),_11925.end()));
  std::vector<int> _11929;
  for (int _7036 = (int)0, _11930 = (int)((_7033)->size(0)); _7036 < _11930 ; ++_7036)
  {
    for (int _7037 = (int)0, _11931 = (int)((_7033)->size(1)); _7037 < _11931 ; ++_7037)
    {
      _11929.push_back(_7037);
    }
  }
  auto _11932 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11929.size()),_11929.begin(),_11929.end()));
  std::vector<double> _11933;
  for (int _7038 = (int)0, _11934 = (int)((_7033)->size(0)); _7038 < _11934 ; ++_7038)
  {
    for (int _7039 = (int)0, _11935 = (int)((_7033)->size(1)); _7039 < _11935 ; ++_7039)
    {
      _11933.push_back(((*_7033)(_7038,_7039)));
    }
  }
  auto _11936 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11933.size()),_11933.begin(),_11933.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_7033)->size(0)),(int)((_7033)->size(1)),_11928,_11932,_11936,_7032->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( monty::rc_ptr< ::mosek::fusion::Expression > _7040,    std::shared_ptr< monty::ndarray< double,2 > > _7041) { return mosek::fusion::p_Expr::mulDiag(_7040,_7041); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _7040,std::shared_ptr< monty::ndarray< double,2 > > _7041){
  std::vector<int> _11937;
  for (int _7042 = (int)0, _11938 = (int)((_7041)->size(0)); _7042 < _11938 ; ++_7042)
  {
    for (int _7043 = (int)0, _11939 = (int)((_7041)->size(1)); _7043 < _11939 ; ++_7043)
    {
      _11937.push_back(_7042);
    }
  }
  auto _11940 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11937.size()),_11937.begin(),_11937.end()));
  std::vector<int> _11941;
  for (int _7044 = (int)0, _11942 = (int)((_7041)->size(0)); _7044 < _11942 ; ++_7044)
  {
    for (int _7045 = (int)0, _11943 = (int)((_7041)->size(1)); _7045 < _11943 ; ++_7045)
    {
      _11941.push_back(_7045);
    }
  }
  auto _11944 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11941.size()),_11941.begin(),_11941.end()));
  std::vector<double> _11945;
  for (int _7046 = (int)0, _11946 = (int)((_7041)->size(0)); _7046 < _11946 ; ++_7046)
  {
    for (int _7047 = (int)0, _11947 = (int)((_7041)->size(1)); _7047 < _11947 ; ++_7047)
    {
      _11945.push_back(((*_7041)(_7046,_7047)));
    }
  }
  auto _11948 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11945.size()),_11945.begin(),_11945.end()));
  return (::mosek::fusion::p_ExprMulDiagRight::_new_ExprMulDiagRight((int)((_7041)->size(0)),(int)((_7041)->size(1)),_11940,_11944,_11948,_7040)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _7048,    monty::rc_ptr< ::mosek::fusion::Variable > _7049) { return mosek::fusion::p_Expr::mulDiag(_7048,_7049); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _7048,monty::rc_ptr< ::mosek::fusion::Variable > _7049){
  std::vector<int> _11949;
  for (int _7050 = (int)0, _11950 = (int)((_7048)->size(0)); _7050 < _11950 ; ++_7050)
  {
    for (int _7051 = (int)0, _11951 = (int)((_7048)->size(1)); _7051 < _11951 ; ++_7051)
    {
      _11949.push_back(_7050);
    }
  }
  auto _11952 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11949.size()),_11949.begin(),_11949.end()));
  std::vector<int> _11953;
  for (int _7052 = (int)0, _11954 = (int)((_7048)->size(0)); _7052 < _11954 ; ++_7052)
  {
    for (int _7053 = (int)0, _11955 = (int)((_7048)->size(1)); _7053 < _11955 ; ++_7053)
    {
      _11953.push_back(_7053);
    }
  }
  auto _11956 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11953.size()),_11953.begin(),_11953.end()));
  std::vector<double> _11957;
  for (int _7054 = (int)0, _11958 = (int)((_7048)->size(0)); _7054 < _11958 ; ++_7054)
  {
    for (int _7055 = (int)0, _11959 = (int)((_7048)->size(1)); _7055 < _11959 ; ++_7055)
    {
      _11957.push_back(((*_7048)(_7054,_7055)));
    }
  }
  auto _11960 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11957.size()),_11957.begin(),_11957.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_7048)->size(0)),(int)((_7048)->size(1)),_11952,_11956,_11960,_7049->__mosek_2fusion_2Variable__asExpr())).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulDiag  ( std::shared_ptr< monty::ndarray< double,2 > > _7056,    monty::rc_ptr< ::mosek::fusion::Expression > _7057) { return mosek::fusion::p_Expr::mulDiag(_7056,_7057); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _7056,monty::rc_ptr< ::mosek::fusion::Expression > _7057){
  std::vector<int> _11961;
  for (int _7058 = (int)0, _11962 = (int)((_7056)->size(0)); _7058 < _11962 ; ++_7058)
  {
    for (int _7059 = (int)0, _11963 = (int)((_7056)->size(1)); _7059 < _11963 ; ++_7059)
    {
      _11961.push_back(_7058);
    }
  }
  auto _11964 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11961.size()),_11961.begin(),_11961.end()));
  std::vector<int> _11965;
  for (int _7060 = (int)0, _11966 = (int)((_7056)->size(0)); _7060 < _11966 ; ++_7060)
  {
    for (int _7061 = (int)0, _11967 = (int)((_7056)->size(1)); _7061 < _11967 ; ++_7061)
    {
      _11965.push_back(_7061);
    }
  }
  auto _11968 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11965.size()),_11965.begin(),_11965.end()));
  std::vector<double> _11969;
  for (int _7062 = (int)0, _11970 = (int)((_7056)->size(0)); _7062 < _11970 ; ++_7062)
  {
    for (int _7063 = (int)0, _11971 = (int)((_7056)->size(1)); _7063 < _11971 ; ++_7063)
    {
      _11969.push_back(((*_7056)(_7062,_7063)));
    }
  }
  auto _11972 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_11969.size()),_11969.begin(),_11969.end()));
  return (::mosek::fusion::p_ExprMulDiagLeft::_new_ExprMulDiagLeft((int)((_7056)->size(0)),(int)((_7056)->size(1)),_11964,_11968,_11972,_7057)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _7064,monty::rc_ptr< ::mosek::fusion::Expression > _7065){
  std::shared_ptr< monty::ndarray< int,1 > > _7066 = _7065->getShape();
  _checked_ptr_1<int> _ptr__7066(_7066 ? _7066->raw() : nullptr,_7066 ? _7066->size(0) : 0);
  monty::rc_ptr< ::mosek::fusion::Expression > _7067 = _7065;
  if (((int)((_7066)->size(0)) == (int)1))
  {
    {
      _7066 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__7066[(int)0]),(int)((int)1)});
      _ptr__7066.update(_7066 ? _7066->raw() : nullptr, _7066 ? _7066->size(0) : 0);
      _7067 = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_7066,_7065)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_7066)->size(0)) != (int)2) || ((_7064->numRows() != _ptr__7066[(int)0]) || (_7064->numColumns() != _ptr__7066[(int)1]))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  {}
  int _7068 = _7064->numColumns();
  long long _7069 = _7064->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _7070 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7069)));
  _checked_ptr_1<int> _ptr__7070(_7070 ? _7070->raw() : nullptr,_7070 ? _7070->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7071 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7069)));
  _checked_ptr_1<int> _ptr__7071(_7071 ? _7071->raw() : nullptr,_7071 ? _7071->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7072 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7069)));
  _checked_ptr_1<double> _ptr__7072(_7072 ? _7072->raw() : nullptr,_7072 ? _7072->size(0) : 0);
  _7064->getDataAsTriplets(_7070,_7071,_7072);
  std::vector<long long> _11973;
  for (long long _7073 = (int)0, _11974 = _7069; _7073 < _11974 ; ++_7073)
  {
    _11973.push_back(safe_add( safe_mul( _ptr__7070[_7073],_7068 ),_ptr__7071[_7073] ));
  }
  auto _11975 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11973.size()),_11973.begin(),_11973.end()));
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_7072,_11975,_7067,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _7074,monty::rc_ptr< ::mosek::fusion::Expression > _7075){
  _checked_ptr_1<double> _ptr__7074(_7074 ? _7074->raw() : nullptr, _7074 ? _7074->size(0) : 0);
  if (((NULL == _7074.get()) || (NULL == _7075.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  if (((_7075->getND() == (int)0) && ((int)((_7074)->size(0)) == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_ptr__7074[(int)0],_7075)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_7075->getND() != (int)1) || (_7075->getDim((int)0) != (int)((_7074)->size(0)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
    }
  }
  else
  {
    {
      std::vector<long long> _11976;
      for (int _7076 = (int)0, _11977 = (int)((_7074)->size(0)); _7076 < _11977 ; ++_7076)
      {
        _11976.push_back(_7076);
      }
      auto _11978 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_11976.size()),_11976.begin(),_11976.end()));
      return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(_7074,_11978,_7075)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7077,monty::rc_ptr< ::mosek::fusion::Expression > _7078){
  if (((NULL == _7077.get()) || (NULL == _7078.get())))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments for mulElm may not be null"));
    }
  }
  {}
  std::shared_ptr< monty::ndarray< int,1 > > _7079 = _7078->getShape();
  _checked_ptr_1<int> _ptr__7079(_7079 ? _7079->raw() : nullptr,_7079 ? _7079->size(0) : 0);
  if (((int)((_7079)->size(0)) != (int)((mosek::fusion::p_NDSparseArray::_get_impl(_7077)->dims)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Dimension mismatch"));
    }
  }
  {}
  int _11979 = (int)0;
  int _11980 = (int)((mosek::fusion::p_NDSparseArray::_get_impl(_7077)->dims)->size(0));
  for (int _7080 = _11979; _7080 < _11980; ++_7080)
  {
    {
      if ((((*mosek::fusion::p_NDSparseArray::_get_impl(_7077)->dims)(_7080)) != _ptr__7079[_7080]))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Dimensions of operands do not match"));
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_ExprMulElement::_new_ExprMulElement(mosek::fusion::p_NDSparseArray::_get_impl(_7077)->cof,mosek::fusion::p_NDSparseArray::_get_impl(_7077)->inst,_7078)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _7081,    double _7082) { return mosek::fusion::p_Expr::mul(_7081,_7082); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _7081,double _7082){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_7082,_7081)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( double _7083,    monty::rc_ptr< ::mosek::fusion::Expression > _7084) { return mosek::fusion::p_Expr::mul(_7083,_7084); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(double _7083,monty::rc_ptr< ::mosek::fusion::Expression > _7084){
  return (::mosek::fusion::p_ExprMulScalarConst::_new_ExprMulScalarConst(_7083,_7084)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _7085,    std::shared_ptr< monty::ndarray< double,1 > > _7086) { return mosek::fusion::p_Expr::mul(_7085,_7086); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _7085,std::shared_ptr< monty::ndarray< double,1 > > _7086){
  _checked_ptr_1<double> _ptr__7086(_7086 ? _7086->raw() : nullptr, _7086 ? _7086->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(false,_7086,_7085);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,1 > > _7087,    monty::rc_ptr< ::mosek::fusion::Expression > _7088) { return mosek::fusion::p_Expr::mul(_7087,_7088); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,1 > > _7087,monty::rc_ptr< ::mosek::fusion::Expression > _7088){
  _checked_ptr_1<double> _ptr__7087(_7087 ? _7087->raw() : nullptr, _7087 ? _7087->size(0) : 0);
  return ::mosek::fusion::p_Expr::mul(true,_7087,_7088);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _7089,    std::shared_ptr< monty::ndarray< double,2 > > _7090) { return mosek::fusion::p_Expr::mul(_7089,_7090); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _7089,std::shared_ptr< monty::ndarray< double,2 > > _7090){
  return ::mosek::fusion::p_Expr::mul(false,_7090,_7089);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( std::shared_ptr< monty::ndarray< double,2 > > _7091,    monty::rc_ptr< ::mosek::fusion::Expression > _7092) { return mosek::fusion::p_Expr::mul(_7091,_7092); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(std::shared_ptr< monty::ndarray< double,2 > > _7091,monty::rc_ptr< ::mosek::fusion::Expression > _7092){
  return ::mosek::fusion::p_Expr::mul(true,_7091,_7092);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _7093,    monty::rc_ptr< ::mosek::fusion::Matrix > _7094) { return mosek::fusion::p_Expr::mul(_7093,_7094); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _7093,monty::rc_ptr< ::mosek::fusion::Matrix > _7094){
  return ::mosek::fusion::p_Expr::mul(false,_7094,_7093);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7095,    monty::rc_ptr< ::mosek::fusion::Expression > _7096) { return mosek::fusion::p_Expr::mul(_7095,_7096); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _7095,monty::rc_ptr< ::mosek::fusion::Expression > _7096){
  return ::mosek::fusion::p_Expr::mul(true,_7095,_7096);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _7097,std::shared_ptr< monty::ndarray< double,1 > > _7098,monty::rc_ptr< ::mosek::fusion::Expression > _7099){
  _checked_ptr_1<double> _ptr__7098(_7098 ? _7098->raw() : nullptr, _7098 ? _7098->size(0) : 0);
  int _7100 = (int)((_7098)->size(0));
  int _7101 = _7100;
  std::shared_ptr< monty::ndarray< double,1 > > _7102 = ::mosek::fusion::Utils::Tools::arraycopy(_7098);
  _checked_ptr_1<double> _ptr__7102(_7102 ? _7102->raw() : nullptr,_7102 ? _7102->size(0) : 0);
  int _7103 = _7099->getND();
  if ((_7103 == (int)0))
  {
    {
      std::vector<int> _11981;
      for (int _7104 = (int)0, _11982 = _7100; _7104 < _11982 ; ++_7104)
      {
        _11981.push_back(_7104);
      }
      auto _11983 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11981.size()),_11981.begin(),_11981.end()));
      std::vector<int> _11984;
      for (int _7105 = (int)0, _11985 = _7100; _7105 < _11985 ; ++_7105)
      {
        _11984.push_back((int)0);
      }
      auto _11986 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11984.size()),_11984.begin(),_11984.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7100)}),(::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_7100,(int)1,_11983,_11986,_7102,_7099,(int)1)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7103 != (int)2))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions"));
    }
  }
  else if((_7097 && (_7099->getDim((int)0) == (int)((_7098)->size(0)))))
  {
    {
      std::vector<int> _11987;
      for (int _7106 = (int)0, _11988 = _7100; _7106 < _11988 ; ++_7106)
      {
        _11987.push_back((int)0);
      }
      auto _11989 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11987.size()),_11987.begin(),_11987.end()));
      std::vector<int> _11990;
      for (int _7107 = (int)0, _11991 = _7100; _7107 < _11991 ; ++_7107)
      {
        _11990.push_back(_7107);
      }
      auto _11992 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11990.size()),_11990.begin(),_11990.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7099->getDim((int)1))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft((int)1,_7100,_11989,_11992,_7102,_7099)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7097 && (_7099->getDim((int)0) == (int)1)))
  {
    {
      std::vector<int> _11993;
      for (int _7108 = (int)0, _11994 = _7100; _7108 < _11994 ; ++_7108)
      {
        _11993.push_back(_7108);
      }
      auto _11995 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11993.size()),_11993.begin(),_11993.end()));
      std::vector<int> _11996;
      for (int _7109 = (int)0, _11997 = _7100; _7109 < _11997 ; ++_7109)
      {
        _11996.push_back((int)0);
      }
      auto _11998 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11996.size()),_11996.begin(),_11996.end()));
      return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_7100,(int)1,_11995,_11998,_7102,_7099,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_7097) && (_7099->getDim((int)1) == _7100)))
  {
    {
      std::vector<int> _11999;
      for (int _7110 = (int)0, _12000 = _7100; _7110 < _12000 ; ++_7110)
      {
        _11999.push_back(_7110);
      }
      auto _12001 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_11999.size()),_11999.begin(),_11999.end()));
      std::vector<int> _12002;
      for (int _7111 = (int)0, _12003 = _7100; _7111 < _12003 ; ++_7111)
      {
        _12002.push_back((int)0);
      }
      auto _12004 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12002.size()),_12002.begin(),_12002.end()));
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7099->getDim((int)0))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_7100,(int)1,_12001,_12004,_7102,_7099)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((!_7097) && (_7099->getDim((int)1) == (int)1)))
  {
    {
      std::vector<int> _12005;
      for (int _7112 = (int)0, _12006 = _7100; _7112 < _12006 ; ++_7112)
      {
        _12005.push_back((int)0);
      }
      auto _12007 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12005.size()),_12005.begin(),_12005.end()));
      std::vector<int> _12008;
      for (int _7113 = (int)0, _12009 = _7100; _7113 < _12009 ; ++_7113)
      {
        _12008.push_back(_7113);
      }
      auto _12010 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12008.size()),_12008.begin(),_12008.end()));
      return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight((int)1,_7100,_12007,_12010,_7102,_7099,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _7114,std::shared_ptr< monty::ndarray< double,2 > > _7115,monty::rc_ptr< ::mosek::fusion::Expression > _7116){
  int _7117 = (int)((_7115)->size(0));
  int _7118 = (int)((_7115)->size(1));
  int _7119 = safe_mul( _7117,_7118 );
  std::vector<int> _12011;
  for (int _7121 = (int)0, _12012 = _7117; _7121 < _12012 ; ++_7121)
  {
    for (int _7122 = (int)0, _12013 = _7118; _7122 < _12013 ; ++_7122)
    {
      _12011.push_back(_7121);
    }
  }
  auto _12014 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12011.size()),_12011.begin(),_12011.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7120 = _12014;
  _checked_ptr_1<int> _ptr__7120(_7120 ? _7120->raw() : nullptr,_7120 ? _7120->size(0) : 0);
  std::vector<int> _12015;
  for (int _7124 = (int)0, _12016 = _7117; _7124 < _12016 ; ++_7124)
  {
    for (int _7125 = (int)0, _12017 = _7118; _7125 < _12017 ; ++_7125)
    {
      _12015.push_back(_7125);
    }
  }
  auto _12018 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12015.size()),_12015.begin(),_12015.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7123 = _12018;
  _checked_ptr_1<int> _ptr__7123(_7123 ? _7123->raw() : nullptr,_7123 ? _7123->size(0) : 0);
  std::vector<double> _12019;
  for (int _7127 = (int)0, _12020 = _7117; _7127 < _12020 ; ++_7127)
  {
    for (int _7128 = (int)0, _12021 = _7118; _7128 < _12021 ; ++_7128)
    {
      _12019.push_back(((*_7115)(_7127,_7128)));
    }
  }
  auto _12022 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12019.size()),_12019.begin(),_12019.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _7126 = _12022;
  _checked_ptr_1<double> _ptr__7126(_7126 ? _7126->raw() : nullptr,_7126 ? _7126->size(0) : 0);
  long long _7129 = _7116->getSize();
  std::shared_ptr< monty::ndarray< int,1 > > _7130 = _7116->getShape();
  _checked_ptr_1<int> _ptr__7130(_7130 ? _7130->raw() : nullptr,_7130 ? _7130->size(0) : 0);
  if (((int)((_7130)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_7117,_7118,_7120,_7123,_7126,_7116,(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  else if(_7114)
  {
    {
      if (((int)((_7130)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_7115)->size(0)))}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_7117,_7118,_7120,_7123,_7126,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__7130[(int)0]),(int)((int)1)}),_7116)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_7130)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_7117,_7118,_7120,_7123,_7126,_7116)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
  else
  {
    {
      if (((int)((_7130)->size(0)) == (int)1))
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)((_7115)->size(1)))}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_7117,_7118,_7120,_7123,_7126,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__7130[(int)0])}),_7116)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else if(((int)((_7130)->size(0)) == (int)2))
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_7117,_7118,_7120,_7123,_7126,_7116)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _7131,monty::rc_ptr< ::mosek::fusion::Matrix > _7132,monty::rc_ptr< ::mosek::fusion::Expression > _7133){
  long long _7134 = _7132->numNonzeros();
  std::shared_ptr< monty::ndarray< int,1 > > _7135 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7134)));
  _checked_ptr_1<int> _ptr__7135(_7135 ? _7135->raw() : nullptr,_7135 ? _7135->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7136 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7134)));
  _checked_ptr_1<int> _ptr__7136(_7136 ? _7136->raw() : nullptr,_7136 ? _7136->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7137 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7134)));
  _checked_ptr_1<double> _ptr__7137(_7137 ? _7137->raw() : nullptr,_7137 ? _7137->size(0) : 0);
  int _7138 = _7132->numRows();
  int _7139 = _7132->numColumns();
  _7132->getDataAsTriplets(_7135,_7136,_7137);
  int _7140 = _7133->getND();
  if ((_7140 == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprScalarMul::_new_ExprScalarMul(_7138,_7139,_7135,_7136,_7137,_7133)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7140 == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7141 = _7133->getShape();
      _checked_ptr_1<int> _ptr__7141(_7141 ? _7141->raw() : nullptr,_7141 ? _7141->size(0) : 0);
      if (_7131)
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7138)}),(::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_7138,_7139,_7135,_7136,_7137,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__7141[(int)0]),(int)((int)1)}),_7133)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7139)}),(::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_7138,_7139,_7135,_7136,_7137,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__7141[(int)0])}),_7133)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else if((_7140 == (int)2))
  {
    {
      if (_7131)
      {
        {
          return (::mosek::fusion::p_ExprMulLeft::_new_ExprMulLeft(_7138,_7139,_7135,_7136,_7137,_7133)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprMulRight::_new_ExprMulRight(_7138,_7139,_7135,_7136,_7137,_7133)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Variable > _7142,    monty::rc_ptr< ::mosek::fusion::Matrix > _7143) { return mosek::fusion::p_Expr::mul(_7142,_7143); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Variable > _7142,monty::rc_ptr< ::mosek::fusion::Matrix > _7143){
  int _7144 = _7143->numRows();
  int _7145 = _7143->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _7146 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7143->numNonzeros())));
  _checked_ptr_1<double> _ptr__7146(_7146 ? _7146->raw() : nullptr,_7146 ? _7146->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7147 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7143->numNonzeros())));
  _checked_ptr_1<int> _ptr__7147(_7147 ? _7147->raw() : nullptr,_7147 ? _7147->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7148 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7143->numNonzeros())));
  _checked_ptr_1<int> _ptr__7148(_7148 ? _7148->raw() : nullptr,_7148 ? _7148->size(0) : 0);
  _7143->getDataAsTriplets(_7148,_7147,_7146);
  return ::mosek::fusion::p_Expr::mul(false,_7144,_7145,_7148,_7147,_7146,_7142);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7149,    monty::rc_ptr< ::mosek::fusion::Variable > _7150) { return mosek::fusion::p_Expr::mul(_7149,_7150); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Matrix > _7149,monty::rc_ptr< ::mosek::fusion::Variable > _7150){
  int _7151 = _7149->numRows();
  int _7152 = _7149->numColumns();
  std::shared_ptr< monty::ndarray< double,1 > > _7153 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7149->numNonzeros())));
  _checked_ptr_1<double> _ptr__7153(_7153 ? _7153->raw() : nullptr,_7153 ? _7153->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7154 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7149->numNonzeros())));
  _checked_ptr_1<int> _ptr__7154(_7154 ? _7154->raw() : nullptr,_7154 ? _7154->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7155 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7149->numNonzeros())));
  _checked_ptr_1<int> _ptr__7155(_7155 ? _7155->raw() : nullptr,_7155 ? _7155->size(0) : 0);
  _7149->getDataAsTriplets(_7155,_7154,_7153);
  return ::mosek::fusion::p_Expr::mul(true,_7151,_7152,_7155,_7154,_7153,_7150);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(bool _7156,int _7157,int _7158,std::shared_ptr< monty::ndarray< int,1 > > _7159,std::shared_ptr< monty::ndarray< int,1 > > _7160,std::shared_ptr< monty::ndarray< double,1 > > _7161,monty::rc_ptr< ::mosek::fusion::Variable > _7162){
  _checked_ptr_1<int> _ptr__7159(_7159 ? _7159->raw() : nullptr, _7159 ? _7159->size(0) : 0);
  _checked_ptr_1<int> _ptr__7160(_7160 ? _7160->raw() : nullptr, _7160 ? _7160->size(0) : 0);
  _checked_ptr_1<double> _ptr__7161(_7161 ? _7161->raw() : nullptr, _7161 ? _7161->size(0) : 0);
  if ((_7162->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulScalarVar::_new_ExprMulScalarVar(_7157,_7158,_7159,_7160,_7161,_7162)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7162->getND() == (int)1))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7163 = _7162->getShape();
      _checked_ptr_1<int> _ptr__7163(_7163 ? _7163->raw() : nullptr,_7163 ? _7163->size(0) : 0);
      int _12023;
      bool _12024 = _7156;
      if (_12024)
      {
        _12023 = _7157;
      }
      else
      {
        _12023 = _7158;
      }
      std::shared_ptr< monty::ndarray< int,1 > > _12025;
      bool _12026 = _7156;
      if (_12026)
      {
        _12025 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_ptr__7163[(int)0]),(int)((int)1)});
      }
      else
      {
        _12025 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_ptr__7163[(int)0])});
      }
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_12023)}),(::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_7156,_7157,_7158,_7159,_7160,_7161,::mosek::fusion::p_Var::reshape(_7162,_12025))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprMulVar::_new_ExprMulVar(_7156,_7157,_7158,_7159,_7160,_7161,_7162)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Expression > _7164,    monty::rc_ptr< ::mosek::fusion::Parameter > _7165) { return mosek::fusion::p_Expr::mul(_7164,_7165); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Expression > _7164,monty::rc_ptr< ::mosek::fusion::Parameter > _7165){
  if (((_7165->getND() == (int)2) && (_7164->getND() == (int)2)))
  {
    {
      return (::mosek::fusion::p_ExprMulParamRight::_new_ExprMulParamRight(_7164,_7165)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_7165->getND() == (int)1) && (_7164->getND() == (int)2)))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7164->getDim((int)0))}),(::mosek::fusion::p_ExprMulParamRight::_new_ExprMulParamRight(_7164,_7165->__mosek_2fusion_2Parameter__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7165->getDim((int)0)),(int)((int)1)})))).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_7165->getND() == (int)2) && (_7164->getND() == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7165->getDim((int)1))}),(::mosek::fusion::p_ExprMulParamRight::_new_ExprMulParamRight((::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_7164->getDim((int)0))}),_7164)).as<::mosek::fusion::Expression>(),_7165)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7165->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulParamScalar::_new_ExprMulParamScalar(_7165,_7164)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7164->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulParamScalarExpr::_new_ExprMulParamScalarExpr(_7165,_7164)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mul  ( monty::rc_ptr< ::mosek::fusion::Parameter > _7166,    monty::rc_ptr< ::mosek::fusion::Expression > _7167) { return mosek::fusion::p_Expr::mul(_7166,_7167); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mul(monty::rc_ptr< ::mosek::fusion::Parameter > _7166,monty::rc_ptr< ::mosek::fusion::Expression > _7167){
  if (((_7166->getND() == (int)2) && (_7167->getND() == (int)2)))
  {
    {
      return (::mosek::fusion::p_ExprMulParamLeft::_new_ExprMulParamLeft(_7166,_7167)).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_7166->getND() == (int)1) && (_7167->getND() == (int)2)))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7167->getDim((int)1))}),(::mosek::fusion::p_ExprMulParamLeft::_new_ExprMulParamLeft(_7166->__mosek_2fusion_2Parameter__reshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_7166->getDim((int)0))})),_7167)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if(((_7166->getND() == (int)2) && (_7167->getND() == (int)1)))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7166->getDim((int)0))}),(::mosek::fusion::p_ExprMulParamLeft::_new_ExprMulParamLeft(_7166,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7167->getDim((int)0)),(int)((int)1)}),_7167)).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>())).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7166->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulParamScalar::_new_ExprMulParamScalar(_7166,_7167)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7167->getND() == (int)0))
  {
    {
      return (::mosek::fusion::p_ExprMulParamScalarExpr::_new_ExprMulParamScalarExpr(_7166,_7167)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid operand dimensions for multiplication"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _7168,    monty::rc_ptr< ::mosek::fusion::Matrix > _7169) { return mosek::fusion::p_Expr::dot(_7168,_7169); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _7168,monty::rc_ptr< ::mosek::fusion::Matrix > _7169){
  long long _7170 = _7169->numNonzeros();
  if ((!_7169->isSparse()))
  {
    {
      std::vector<long long> _12027;
      for (long long _7171 = (int)0, _12028 = _7170; _7171 < _12028 ; ++_7171)
      {
        _12027.push_back(_7171);
      }
      auto _12029 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_12027.size()),_12027.begin(),_12027.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_7168,_12029,_7169->getDataAsArray())).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7172 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7170)));
      _checked_ptr_1<int> _ptr__7172(_7172 ? _7172->raw() : nullptr,_7172 ? _7172->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7173 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7170)));
      _checked_ptr_1<int> _ptr__7173(_7173 ? _7173->raw() : nullptr,_7173 ? _7173->size(0) : 0);
      std::shared_ptr< monty::ndarray< double,1 > > _7174 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7170)));
      _checked_ptr_1<double> _ptr__7174(_7174 ? _7174->raw() : nullptr,_7174 ? _7174->size(0) : 0);
      int _7175 = _7169->numColumns();
      _7169->getDataAsTriplets(_7172,_7173,_7174);
      std::vector<long long> _12030;
      for (int _7176 = (int)0, _12031 = (int)((_7172)->size(0)); _7176 < _12031 ; ++_7176)
      {
        _12030.push_back(safe_add( safe_mul( _ptr__7172[_7176],_7175 ),_ptr__7173[_7176] ));
      }
      auto _12032 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_12030.size()),_12030.begin(),_12030.end()));
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_7168,_12032,_7174)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _7177,    std::shared_ptr< monty::ndarray< double,2 > > _7178) { return mosek::fusion::p_Expr::dot(_7177,_7178); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _7177,std::shared_ptr< monty::ndarray< double,2 > > _7178){
  std::vector<long long> _12033;
  for (int _7179 = (int)0, _12034 = safe_mul( (int)((_7178)->size(0)),(int)((_7178)->size(1)) ); _7179 < _12034 ; ++_7179)
  {
    _12033.push_back(_7179);
  }
  auto _12035 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_12033.size()),_12033.begin(),_12033.end()));
  std::vector<double> _12036;
  for (int _7180 = (int)0, _12037 = (int)((_7178)->size(0)); _7180 < _12037 ; ++_7180)
  {
    for (int _7181 = (int)0, _12038 = (int)((_7178)->size(1)); _7181 < _12038 ; ++_7181)
    {
      _12036.push_back(((*_7178)(_7180,_7181)));
    }
  }
  auto _12039 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12036.size()),_12036.begin(),_12036.end()));
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_7177,_12035,_12039)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _7182,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7183) { return mosek::fusion::p_Expr::dot(_7182,_7183); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _7182,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7183){
  return (::mosek::fusion::p_ExprInner::_new_ExprInner(_7182,mosek::fusion::p_NDSparseArray::_get_impl(_7183)->inst,mosek::fusion::p_NDSparseArray::_get_impl(_7183)->cof)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _7184,    std::shared_ptr< monty::ndarray< double,1 > > _7185) { return mosek::fusion::p_Expr::dot(_7184,_7185); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _7184,std::shared_ptr< monty::ndarray< double,1 > > _7185){
  _checked_ptr_1<double> _ptr__7185(_7185 ? _7185->raw() : nullptr, _7185 ? _7185->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7186 = _7184->getShape();
  _checked_ptr_1<int> _ptr__7186(_7186 ? _7186->raw() : nullptr,_7186 ? _7186->size(0) : 0);
  if (((_7184->getSize() == (int)((_7185)->size(0))) && ((int)((_7186)->size(0)) > (int)1)))
  {
    {
      int _7187 = (int)0;
      int _12040 = (int)0;
      int _12041 = (int)((_7186)->size(0));
      for (int _7188 = _12040; _7188 < _12041; ++_7188)
      {
        {
          if ((_ptr__7186[_7188] > (int)1))
          {
            {
              ++ _7187;
            }
          }
          {}
        }
      }
      if ((_7187 > (int)1))
      {
        {
          throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand shapes"));
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _7189 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)_7184->getSize())});
          _checked_ptr_1<int> _ptr__7189(_7189 ? _7189->raw() : nullptr,_7189 ? _7189->size(0) : 0);
          return (::mosek::fusion::p_ExprInner::_new_ExprInner((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_7189,_7184)).as<::mosek::fusion::Expression>(),_7185)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprInner::_new_ExprInner(_7184,_7185)).as<::mosek::fusion::Expression>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7190,    monty::rc_ptr< ::mosek::fusion::Expression > _7191) { return mosek::fusion::p_Expr::dot(_7190,_7191); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Matrix > _7190,monty::rc_ptr< ::mosek::fusion::Expression > _7191){
  return ::mosek::fusion::p_Expr::dot(_7191,_7190);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7192,    monty::rc_ptr< ::mosek::fusion::Expression > _7193) { return mosek::fusion::p_Expr::dot(_7192,_7193); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7192,monty::rc_ptr< ::mosek::fusion::Expression > _7193){
  return ::mosek::fusion::p_Expr::dot(_7193,_7192);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,2 > > _7194,    monty::rc_ptr< ::mosek::fusion::Expression > _7195) { return mosek::fusion::p_Expr::dot(_7194,_7195); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,2 > > _7194,monty::rc_ptr< ::mosek::fusion::Expression > _7195){
  return ::mosek::fusion::p_Expr::dot(_7195,_7194);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( std::shared_ptr< monty::ndarray< double,1 > > _7196,    monty::rc_ptr< ::mosek::fusion::Expression > _7197) { return mosek::fusion::p_Expr::dot(_7196,_7197); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(std::shared_ptr< monty::ndarray< double,1 > > _7196,monty::rc_ptr< ::mosek::fusion::Expression > _7197){
  _checked_ptr_1<double> _ptr__7196(_7196 ? _7196->raw() : nullptr, _7196 ? _7196->size(0) : 0);
  return ::mosek::fusion::p_Expr::dot(_7197,_7196);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Expression > _7198,    monty::rc_ptr< ::mosek::fusion::Parameter > _7199) { return mosek::fusion::p_Expr::dot(_7198,_7199); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Expression > _7198,monty::rc_ptr< ::mosek::fusion::Parameter > _7199){
  return (::mosek::fusion::p_ExprDotParam::_new_ExprDotParam(_7199,_7198)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::dot  ( monty::rc_ptr< ::mosek::fusion::Parameter > _7200,    monty::rc_ptr< ::mosek::fusion::Expression > _7201) { return mosek::fusion::p_Expr::dot(_7200,_7201); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::dot(monty::rc_ptr< ::mosek::fusion::Parameter > _7200,monty::rc_ptr< ::mosek::fusion::Expression > _7201){
  return (::mosek::fusion::p_ExprDotParam::_new_ExprDotParam(_7200,_7201)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7202,    monty::rc_ptr< ::mosek::fusion::Variable > _7203) { return mosek::fusion::p_Expr::outer(_7202,_7203); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Matrix > _7202,monty::rc_ptr< ::mosek::fusion::Variable > _7203){
  std::shared_ptr< monty::ndarray< int,1 > > _7204 = _7203->getShape();
  _checked_ptr_1<int> _ptr__7204(_7204 ? _7204->raw() : nullptr,_7204 ? _7204->size(0) : 0);
  if ((!(((int)((_7204)->size(0)) == (int)1) || (((int)((_7204)->size(0)) == (int)2) && (_ptr__7204[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_7202)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _12042 = _7202;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_12042.get()))
  {
    ::mosek::fusion::DenseMatrix::t _7205 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_12042.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_7203,_ptr__7204[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_7205)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_7205)->data)->size(0)),true);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _7206 = _12042;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _7207 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7206->numNonzeros())));
      _checked_ptr_1<double> _ptr__7207(_7207 ? _7207->raw() : nullptr,_7207 ? _7207->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7208 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7206->numNonzeros())));
      _checked_ptr_1<int> _ptr__7208(_7208 ? _7208->raw() : nullptr,_7208 ? _7208->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7209 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7206->numNonzeros())));
      _checked_ptr_1<int> _ptr__7209(_7209 ? _7209->raw() : nullptr,_7209 ? _7209->size(0) : 0);
      _7206->getDataAsTriplets(_7209,_7208,_7207);
      return ::mosek::fusion::p_Expr::outer_(_7203,_ptr__7204[(int)0],_7207,_7209,mosek::fusion::p_Matrix::_get_impl(_7206)->dimi,true);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _7210,    monty::rc_ptr< ::mosek::fusion::Matrix > _7211) { return mosek::fusion::p_Expr::outer(_7210,_7211); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _7210,monty::rc_ptr< ::mosek::fusion::Matrix > _7211){
  std::shared_ptr< monty::ndarray< int,1 > > _7212 = _7210->getShape();
  _checked_ptr_1<int> _ptr__7212(_7212 ? _7212->raw() : nullptr,_7212 ? _7212->size(0) : 0);
  if ((!((_7210->getND() == (int)1) || ((_7210->getND() == (int)2) && (_ptr__7212[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  if ((mosek::fusion::p_Matrix::_get_impl(_7211)->dimj != (int)1))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Constant matrix must be a column-vector"));
    }
  }
  {}
  monty::rc_ptr< ::mosek::fusion::Matrix > _12043 = _7211;
  if (false) {}
  else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_12043.get()))
  {
    ::mosek::fusion::DenseMatrix::t _7213 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_12043.get()));
    {
      return ::mosek::fusion::p_Expr::outer_(_7210,_ptr__7212[(int)0],mosek::fusion::p_DenseMatrix::_get_impl(_7213)->data,nullptr,(int)((mosek::fusion::p_DenseMatrix::_get_impl(_7213)->data)->size(0)),false);
    }
  }
  else
  {
    mosek::fusion::Matrix::t _7214 = _12043;
    {
      std::shared_ptr< monty::ndarray< double,1 > > _7215 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7214->numNonzeros())));
      _checked_ptr_1<double> _ptr__7215(_7215 ? _7215->raw() : nullptr,_7215 ? _7215->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7216 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7214->numNonzeros())));
      _checked_ptr_1<int> _ptr__7216(_7216 ? _7216->raw() : nullptr,_7216 ? _7216->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7217 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7211->numNonzeros())));
      _checked_ptr_1<int> _ptr__7217(_7217 ? _7217->raw() : nullptr,_7217 ? _7217->size(0) : 0);
      _7214->getDataAsTriplets(_7217,_7216,_7215);
      return ::mosek::fusion::p_Expr::outer_(_7210,((*_7210->getShape())((int)0)),_7215,_7217,mosek::fusion::p_Matrix::_get_impl(_7214)->dimi,false);
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( std::shared_ptr< monty::ndarray< double,1 > > _7218,    monty::rc_ptr< ::mosek::fusion::Variable > _7219) { return mosek::fusion::p_Expr::outer(_7218,_7219); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(std::shared_ptr< monty::ndarray< double,1 > > _7218,monty::rc_ptr< ::mosek::fusion::Variable > _7219){
  _checked_ptr_1<double> _ptr__7218(_7218 ? _7218->raw() : nullptr, _7218 ? _7218->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7220 = _7219->getShape();
  _checked_ptr_1<int> _ptr__7220(_7220 ? _7220->raw() : nullptr,_7220 ? _7220->size(0) : 0);
  if ((!((_7219->getND() == (int)1) || ((_7219->getND() == (int)2) && (_ptr__7220[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_7219,_ptr__7220[(int)0],_7218,nullptr,(int)((_7218)->size(0)),true);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::outer  ( monty::rc_ptr< ::mosek::fusion::Variable > _7221,    std::shared_ptr< monty::ndarray< double,1 > > _7222) { return mosek::fusion::p_Expr::outer(_7221,_7222); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer(monty::rc_ptr< ::mosek::fusion::Variable > _7221,std::shared_ptr< monty::ndarray< double,1 > > _7222){
  _checked_ptr_1<double> _ptr__7222(_7222 ? _7222->raw() : nullptr, _7222 ? _7222->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7223 = _7221->getShape();
  _checked_ptr_1<int> _ptr__7223(_7223 ? _7223->raw() : nullptr,_7223 ? _7223->size(0) : 0);
  if ((!((_7221->getND() == (int)1) || ((_7221->getND() == (int)2) && (_ptr__7223[(int)1] == (int)1)))))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Variable argument must be one-dimensional"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::outer_(_7221,_ptr__7223[(int)0],_7222,nullptr,(int)((_7222)->size(0)),false);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(int _7224,std::shared_ptr< monty::ndarray< long long,1 > > _7225,std::shared_ptr< monty::ndarray< long long,1 > > _7226,std::shared_ptr< monty::ndarray< double,1 > > _7227,std::shared_ptr< monty::ndarray< double,1 > > _7228,std::shared_ptr< monty::ndarray< long long,1 > > _7229,std::shared_ptr< monty::ndarray< double,1 > > _7230,std::shared_ptr< monty::ndarray< int,1 > > _7231,int _7232,bool _7233){
  _checked_ptr_1<long long> _ptr__7225(_7225 ? _7225->raw() : nullptr, _7225 ? _7225->size(0) : 0);
  _checked_ptr_1<long long> _ptr__7226(_7226 ? _7226->raw() : nullptr, _7226 ? _7226->size(0) : 0);
  _checked_ptr_1<double> _ptr__7227(_7227 ? _7227->raw() : nullptr, _7227 ? _7227->size(0) : 0);
  _checked_ptr_1<double> _ptr__7228(_7228 ? _7228->raw() : nullptr, _7228 ? _7228->size(0) : 0);
  _checked_ptr_1<long long> _ptr__7229(_7229 ? _7229->raw() : nullptr, _7229 ? _7229->size(0) : 0);
  _checked_ptr_1<double> _ptr__7230(_7230 ? _7230->raw() : nullptr, _7230 ? _7230->size(0) : 0);
  _checked_ptr_1<int> _ptr__7231(_7231 ? _7231->raw() : nullptr, _7231 ? _7231->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _12044;
  bool _12045 = (!_7233);
  if (_12045)
  {
    _12044 = ::mosek::fusion::p_Set::make(_7224,_7232);
  }
  else
  {
    _12044 = ::mosek::fusion::p_Set::make(_7232,_7224);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _7234 = _12044;
  _checked_ptr_1<int> _ptr__7234(_7234 ? _7234->raw() : nullptr,_7234 ? _7234->size(0) : 0);
  int _7235 = safe_mul( (int)((_7230)->size(0)),(int)((_7229)->size(0)) );
  int _7236 = safe_mul( (int)((_7230)->size(0)),(int)((_7226)->size(0)) );
  std::shared_ptr< monty::ndarray< long long,1 > > _7237 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7235)));
  _checked_ptr_1<long long> _ptr__7237(_7237 ? _7237->raw() : nullptr,_7237 ? _7237->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _12046;
  bool _12047 = (NULL != _7228.get());
  if (_12047)
  {
    _12046 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7235)));
  }
  else
  {
    _12046 = nullptr;
  }
  std::shared_ptr< monty::ndarray< double,1 > > _7238 = _12046;
  _checked_ptr_1<double> _ptr__7238(_7238 ? _7238->raw() : nullptr,_7238 ? _7238->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7239 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7236)));
  _checked_ptr_1<double> _ptr__7239(_7239 ? _7239->raw() : nullptr,_7239 ? _7239->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _7240 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7236)));
  _checked_ptr_1<long long> _ptr__7240(_7240 ? _7240->raw() : nullptr,_7240 ? _7240->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _7241 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _7235,(int)1 ))));
  _checked_ptr_1<long long> _ptr__7241(_7241 ? _7241->raw() : nullptr,_7241 ? _7241->size(0) : 0);
  int _7242 = (int)_ptr__7241[((int)((_7241)->size(0)) - (int)1)];
  if ((!_7233))
  {
    {
      long long _7243 = (long long)0;
      long long _7244 = (long long)0;
      int _12048 = (int)0;
      int _12049 = (int)((_7229)->size(0));
      for (int _7245 = _12048; _7245 < _12049; ++_7245)
      {
        {
          long long _7246 = (_ptr__7225[safe_add( _7245,(int)1 )] - _ptr__7225[_7245]);
          int _12050 = (int)0;
          int _12051 = (int)((_7230)->size(0));
          for (int _7247 = _12050; _7247 < _12051; ++_7247)
          {
            {
              _ptr__7229[_7243] = safe_add( safe_mul( _ptr__7229[_7245],_7232 ),_ptr__7231[_7247] );
              _ptr__7241[safe_add( _7243,(int)1 )] = safe_add( _ptr__7241[_7243],_7246 );
              ++ _7243;
              long long _12052 = _ptr__7225[_7245];
              long long _12053 = _ptr__7225[safe_add( _7245,(int)1 )];
              for (long long _7248 = _12052; _7248 < _12053; ++_7248)
              {
                {
                  _ptr__7240[_7244] = _ptr__7226[_7248];
                  _ptr__7239[_7244] = (_ptr__7227[_7248] * _ptr__7230[_7247]);
                  ++ _7244;
                }
              }
            }
          }
        }
      }
      if ((NULL != _7238.get()))
      {
        {
          int _7249 = (int)0;
          int _12054 = (int)0;
          int _12055 = (int)((_7229)->size(0));
          for (int _7250 = _12054; _7250 < _12055; ++_7250)
          {
            {
              int _12056 = (int)0;
              int _12057 = (int)((_7230)->size(0));
              for (int _7251 = _12056; _7251 < _12057; ++_7251)
              {
                {
                  _ptr__7238[_7249] = (_ptr__7230[_7251] * _ptr__7228[_7250]);
                  ++ _7249;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  else
  {
    {
      long long _7252 = (long long)0;
      long long _7253 = (long long)0;
      int _12058 = (int)0;
      int _12059 = (int)((_7230)->size(0));
      for (int _7254 = _12058; _7254 < _12059; ++_7254)
      {
        {
          double _7255 = _ptr__7230[_7254];
          ::mosek::fusion::Utils::Tools::arraycopy(_7226,(long long)((int)0),_7240,_7253,(long long)(_7242));
          int _12060 = (int)0;
          int _12061 = _7242;
          for (int _7256 = _12060; _7256 < _12061; ++_7256)
          {
            {
              _ptr__7239[safe_add( _7253,_7256 )] = (_ptr__7227[_7256] * _ptr__7230[_7254]);
            }
          }
          int _12062 = (int)0;
          int _12063 = (int)((_7229)->size(0));
          for (int _7257 = _12062; _7257 < _12063; ++_7257)
          {
            {
              long long _7258 = (_ptr__7225[safe_add( _7257,(int)1 )] - _ptr__7225[_7257]);
              _ptr__7229[_7252] = safe_add( safe_mul( _ptr__7229[_7257],_7232 ),_ptr__7231[_7254] );
              _ptr__7241[safe_add( _7252,(int)1 )] = safe_add( _ptr__7241[_7252],_7258 );
              ++ _7252;
            }
          }
          _7253 += _7242;
        }
      }
      if ((NULL != _7238.get()))
      {
        {
          int _7259 = (int)0;
          int _12064 = (int)0;
          int _12065 = (int)((_7230)->size(0));
          for (int _7260 = _12064; _7260 < _12065; ++_7260)
          {
            {
              double _7261 = _ptr__7230[_7260];
              int _12066 = (int)0;
              int _12067 = (int)((_7229)->size(0));
              for (int _7262 = _12066; _7262 < _12067; ++_7262)
              {
                {
                  _ptr__7238[_7259] = (_ptr__7228[_7262] * _7261);
                  ++ _7259;
                }
              }
            }
          }
        }
      }
      {}
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_7241,_7240,_7239,_7238,_7234,_7237)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::outer_(monty::rc_ptr< ::mosek::fusion::Variable > _7263,int _7264,std::shared_ptr< monty::ndarray< double,1 > > _7265,std::shared_ptr< monty::ndarray< int,1 > > _7266,int _7267,bool _7268){
  _checked_ptr_1<double> _ptr__7265(_7265 ? _7265->raw() : nullptr, _7265 ? _7265->size(0) : 0);
  _checked_ptr_1<int> _ptr__7266(_7266 ? _7266->raw() : nullptr, _7266 ? _7266->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _12068;
  bool _12069 = (!_7268);
  if (_12069)
  {
    _12068 = ::mosek::fusion::p_Set::make(_7264,_7267);
  }
  else
  {
    _12068 = ::mosek::fusion::p_Set::make(_7267,_7264);
  }
  std::shared_ptr< monty::ndarray< int,1 > > _7269 = _12068;
  _checked_ptr_1<int> _ptr__7269(_7269 ? _7269->raw() : nullptr,_7269 ? _7269->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _12070;
  bool _12071 = (_7267 == (int)((_7265)->size(0)));
  if (_12071)
  {
    _12070 = nullptr;
  }
  else
  {
    _12070 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_7265)->size(0)),_7264 ))));
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _7270 = _12070;
  _checked_ptr_1<long long> _ptr__7270(_7270 ? _7270->raw() : nullptr,_7270 ? _7270->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7271 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_7265)->size(0)),_7264 ))));
  _checked_ptr_1<double> _ptr__7271(_7271 ? _7271->raw() : nullptr,_7271 ? _7271->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7272 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( (int)((_7265)->size(0)),_7264 ))));
  _checked_ptr_1<double> _ptr__7272(_7272 ? _7272->raw() : nullptr,_7272 ? _7272->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _7273 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_mul( (int)((_7265)->size(0)),_7264 ))));
  _checked_ptr_1<long long> _ptr__7273(_7273 ? _7273->raw() : nullptr,_7273 ? _7273->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _7274 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( safe_mul( (int)((_7265)->size(0)),_7264 ),(int)1 ))));
  _checked_ptr_1<long long> _ptr__7274(_7274 ? _7274->raw() : nullptr,_7274 ? _7274->size(0) : 0);
  if ((_7267 == (int)((_7265)->size(0))))
  {
    {
      long long _7275 = (long long)0;
      if ((!_7268))
      {
        {
          int _12072 = (int)0;
          int _12073 = _7264;
          for (int _7276 = _12072; _7276 < _12073; ++_7276)
          {
            {
              int _12074 = (int)0;
              int _12075 = _7267;
              for (int _7277 = _12074; _7277 < _12075; ++_7277)
              {
                {
                  _ptr__7274[safe_add( _7275,(int)1 )] = safe_add( _7275,(int)1 );
                  _ptr__7273[_7275] = (long long)_7276;
                  _ptr__7272[_7275] = _ptr__7265[_7277];
                  ++ _7275;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _12076 = (int)0;
          int _12077 = _7267;
          for (int _7278 = _12076; _7278 < _12077; ++_7278)
          {
            {
              int _12078 = (int)0;
              int _12079 = _7264;
              for (int _7279 = _12078; _7279 < _12079; ++_7279)
              {
                {
                  _ptr__7274[safe_add( _7275,(int)1 )] = safe_add( _7275,(int)1 );
                  _ptr__7273[_7275] = (long long)_7279;
                  _ptr__7272[_7275] = _ptr__7265[_7278];
                  ++ _7275;
                }
              }
            }
          }
        }
      }
    }
  }
  else
  {
    {
      long long _7280 = (long long)0;
      if ((!_7268))
      {
        {
          int _12080 = (int)0;
          int _12081 = _7264;
          for (int _7281 = _12080; _7281 < _12081; ++_7281)
          {
            {
              int _12082 = (int)0;
              int _12083 = (int)((_7265)->size(0));
              for (int _7282 = _12082; _7282 < _12083; ++_7282)
              {
                {
                  _ptr__7274[safe_add( _7280,(int)1 )] = safe_add( _7280,(int)1 );
                  _ptr__7273[_7280] = (long long)_7281;
                  _ptr__7272[_7280] = _ptr__7265[_7282];
                  _ptr__7270[_7280] = safe_add( safe_mul( _7281,_7267 ),_ptr__7266[_7282] );
                  ++ _7280;
                }
              }
            }
          }
        }
      }
      else
      {
        {
          int _12084 = (int)0;
          int _12085 = (int)((_7265)->size(0));
          for (int _7283 = _12084; _7283 < _12085; ++_7283)
          {
            {
              int _12086 = (int)0;
              int _12087 = _7264;
              for (int _7284 = _12086; _7284 < _12087; ++_7284)
              {
                {
                  _ptr__7274[safe_add( _7280,(int)1 )] = safe_add( _7280,(int)1 );
                  _ptr__7273[_7280] = (long long)_7284;
                  _ptr__7272[_7280] = _ptr__7265[_7283];
                  _ptr__7270[_7280] = safe_add( safe_mul( _ptr__7266[_7283],_7264 ),_7284 );
                  ++ _7280;
                }
              }
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_Expr::_new_Expr(_7274,_7273,_7272,_7271,_7269,_7270)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _7285) { return mosek::fusion::p_Expr::stack(_7285); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _7285){
  if ((NULL == _7285.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _12088 = (int)0;
  int _12089 = (int)((_7285)->size(0));
  for (int _7286 = _12088; _7286 < _12089; ++_7286)
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7287 = ((*_7285)(_7286));
      if ((NULL == _7287.get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
        }
      }
      {}
      int _12090 = (int)0;
      int _12091 = (int)((_7287)->size(0));
      for (int _7288 = _12090; _7288 < _12091; ++_7288)
      {
        {
          if ((NULL == ((*_7287)(_7288)).get()))
          {
            {
              throw monty::NullPointerException(std::string ("Arguments for stack may not be null"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<monty::rc_ptr< ::mosek::fusion::Expression >> _12092;
  for (int _7290 = (int)0, _12093 = (int)((_7285)->size(0)); _7290 < _12093 ; ++_7290)
  {
    _12092.push_back(::mosek::fusion::p_Expr::stack_(((*_7285)(_7290)),(int)1));
  }
  auto _12094 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_12092.size()),_12092.begin(),_12092.end()));
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7289 = _12094;
  return ::mosek::fusion::p_Expr::stack_(_7289,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _7291,    double _7292,    double _7293) { return mosek::fusion::p_Expr::vstack(_7291,_7292,_7293); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _7291,double _7292,double _7293){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7291).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7292).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7293).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _7294,    double _7295,    monty::rc_ptr< ::mosek::fusion::Expression > _7296) { return mosek::fusion::p_Expr::vstack(_7294,_7295,_7296); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _7294,double _7295,monty::rc_ptr< ::mosek::fusion::Expression > _7296){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7294).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7295).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7296.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _7297,    monty::rc_ptr< ::mosek::fusion::Expression > _7298,    double _7299) { return mosek::fusion::p_Expr::vstack(_7297,_7298,_7299); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _7297,monty::rc_ptr< ::mosek::fusion::Expression > _7298,double _7299){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7297).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7298.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7299).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _7300,    monty::rc_ptr< ::mosek::fusion::Expression > _7301,    monty::rc_ptr< ::mosek::fusion::Expression > _7302) { return mosek::fusion::p_Expr::vstack(_7300,_7301,_7302); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _7300,monty::rc_ptr< ::mosek::fusion::Expression > _7301,monty::rc_ptr< ::mosek::fusion::Expression > _7302){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7300).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7301.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7302.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7303,    double _7304,    double _7305) { return mosek::fusion::p_Expr::vstack(_7303,_7304,_7305); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7303,double _7304,double _7305){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7303.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7304).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7305).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7306,    double _7307,    monty::rc_ptr< ::mosek::fusion::Expression > _7308) { return mosek::fusion::p_Expr::vstack(_7306,_7307,_7308); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7306,double _7307,monty::rc_ptr< ::mosek::fusion::Expression > _7308){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7306.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7307).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7308.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7309,    monty::rc_ptr< ::mosek::fusion::Expression > _7310,    double _7311) { return mosek::fusion::p_Expr::vstack(_7309,_7310,_7311); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7309,monty::rc_ptr< ::mosek::fusion::Expression > _7310,double _7311){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7309.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7310.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7311).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7312,    monty::rc_ptr< ::mosek::fusion::Expression > _7313,    monty::rc_ptr< ::mosek::fusion::Expression > _7314) { return mosek::fusion::p_Expr::vstack(_7312,_7313,_7314); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7312,monty::rc_ptr< ::mosek::fusion::Expression > _7313,monty::rc_ptr< ::mosek::fusion::Expression > _7314){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7312.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7313.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7314.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( double _7315,    monty::rc_ptr< ::mosek::fusion::Expression > _7316) { return mosek::fusion::p_Expr::vstack(_7315,_7316); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(double _7315,monty::rc_ptr< ::mosek::fusion::Expression > _7316){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7315).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7316.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7317,    double _7318) { return mosek::fusion::p_Expr::vstack(_7317,_7318); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7317,double _7318){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7317.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7318).get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7319,    monty::rc_ptr< ::mosek::fusion::Expression > _7320) { return mosek::fusion::p_Expr::vstack(_7319,_7320); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7319,monty::rc_ptr< ::mosek::fusion::Expression > _7320){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7319.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7320.get())}),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::vstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7321) { return mosek::fusion::p_Expr::vstack(_7321); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7321){
  if ((NULL == _7321.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _12095 = (int)0;
  int _12096 = (int)((_7321)->size(0));
  for (int _7322 = _12095; _7322 < _12096; ++_7322)
  {
    {
      if ((NULL == ((*_7321)(_7322)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for vstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_7321,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7323,    monty::rc_ptr< ::mosek::fusion::Expression > _7324,    monty::rc_ptr< ::mosek::fusion::Expression > _7325) { return mosek::fusion::p_Expr::hstack(_7323,_7324,_7325); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7323,monty::rc_ptr< ::mosek::fusion::Expression > _7324,monty::rc_ptr< ::mosek::fusion::Expression > _7325){
  if (((NULL == _7323.get()) || ((NULL == _7324.get()) || (NULL == _7325.get()))))
  {
    {
      throw monty::NullPointerException(std::string ("Arguments e1, e2 and e3 may not be null"));
    }
  }
  {}
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7323.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7324.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7325.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7326,    monty::rc_ptr< ::mosek::fusion::Expression > _7327,    double _7328) { return mosek::fusion::p_Expr::hstack(_7326,_7327,_7328); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7326,monty::rc_ptr< ::mosek::fusion::Expression > _7327,double _7328){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7326.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7327.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7328).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7329,    double _7330,    monty::rc_ptr< ::mosek::fusion::Expression > _7331) { return mosek::fusion::p_Expr::hstack(_7329,_7330,_7331); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7329,double _7330,monty::rc_ptr< ::mosek::fusion::Expression > _7331){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7329.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7330).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7331.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7332,    double _7333,    double _7334) { return mosek::fusion::p_Expr::hstack(_7332,_7333,_7334); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7332,double _7333,double _7334){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7332.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7333).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7334).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _7335,    monty::rc_ptr< ::mosek::fusion::Expression > _7336,    monty::rc_ptr< ::mosek::fusion::Expression > _7337) { return mosek::fusion::p_Expr::hstack(_7335,_7336,_7337); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _7335,monty::rc_ptr< ::mosek::fusion::Expression > _7336,monty::rc_ptr< ::mosek::fusion::Expression > _7337){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7335).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7336.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7337.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _7338,    monty::rc_ptr< ::mosek::fusion::Expression > _7339,    double _7340) { return mosek::fusion::p_Expr::hstack(_7338,_7339,_7340); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _7338,monty::rc_ptr< ::mosek::fusion::Expression > _7339,double _7340){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7338).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7339.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7340).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _7341,    double _7342,    monty::rc_ptr< ::mosek::fusion::Expression > _7343) { return mosek::fusion::p_Expr::hstack(_7341,_7342,_7343); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _7341,double _7342,monty::rc_ptr< ::mosek::fusion::Expression > _7343){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7341).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7342).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7343.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( double _7344,    monty::rc_ptr< ::mosek::fusion::Expression > _7345) { return mosek::fusion::p_Expr::hstack(_7344,_7345); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(double _7344,monty::rc_ptr< ::mosek::fusion::Expression > _7345){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7344).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7345.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7346,    double _7347) { return mosek::fusion::p_Expr::hstack(_7346,_7347); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7346,double _7347){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7346.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7347).get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( monty::rc_ptr< ::mosek::fusion::Expression > _7348,    monty::rc_ptr< ::mosek::fusion::Expression > _7349) { return mosek::fusion::p_Expr::hstack(_7348,_7349); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7348,monty::rc_ptr< ::mosek::fusion::Expression > _7349){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7348.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7349.get())}),(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::hstack  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7350) { return mosek::fusion::p_Expr::hstack(_7350); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7350){
  if ((NULL == _7350.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument exprs may not be null"));
    }
  }
  {}
  int _12097 = (int)0;
  int _12098 = (int)((_7350)->size(0));
  for (int _7351 = _12097; _7351 < _12098; ++_7351)
  {
    {
      if ((NULL == ((*_7350)(_7351)).get()))
      {
        {
          throw monty::NullPointerException(std::string ("Arguments for hstack may not be null"));
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Expr::stack_(_7350,(int)1);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7352,    monty::rc_ptr< ::mosek::fusion::Expression > _7353,    monty::rc_ptr< ::mosek::fusion::Expression > _7354,    monty::rc_ptr< ::mosek::fusion::Expression > _7355) { return mosek::fusion::p_Expr::stack(_7352,_7353,_7354,_7355); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7352,monty::rc_ptr< ::mosek::fusion::Expression > _7353,monty::rc_ptr< ::mosek::fusion::Expression > _7354,monty::rc_ptr< ::mosek::fusion::Expression > _7355){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7353.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7354.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7355.get())}),_7352);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7356,    monty::rc_ptr< ::mosek::fusion::Expression > _7357,    monty::rc_ptr< ::mosek::fusion::Expression > _7358,    double _7359) { return mosek::fusion::p_Expr::stack(_7356,_7357,_7358,_7359); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7356,monty::rc_ptr< ::mosek::fusion::Expression > _7357,monty::rc_ptr< ::mosek::fusion::Expression > _7358,double _7359){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7357.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7358.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7359).get())}),_7356);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7360,    monty::rc_ptr< ::mosek::fusion::Expression > _7361,    double _7362,    monty::rc_ptr< ::mosek::fusion::Expression > _7363) { return mosek::fusion::p_Expr::stack(_7360,_7361,_7362,_7363); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7360,monty::rc_ptr< ::mosek::fusion::Expression > _7361,double _7362,monty::rc_ptr< ::mosek::fusion::Expression > _7363){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7361.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7362).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7363.get())}),_7360);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7364,    monty::rc_ptr< ::mosek::fusion::Expression > _7365,    double _7366,    double _7367) { return mosek::fusion::p_Expr::stack(_7364,_7365,_7366,_7367); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7364,monty::rc_ptr< ::mosek::fusion::Expression > _7365,double _7366,double _7367){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7365.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7366).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7367).get())}),_7364);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7368,    double _7369,    monty::rc_ptr< ::mosek::fusion::Expression > _7370,    monty::rc_ptr< ::mosek::fusion::Expression > _7371) { return mosek::fusion::p_Expr::stack(_7368,_7369,_7370,_7371); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7368,double _7369,monty::rc_ptr< ::mosek::fusion::Expression > _7370,monty::rc_ptr< ::mosek::fusion::Expression > _7371){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7369).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7370.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7371.get())}),_7368);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7372,    double _7373,    monty::rc_ptr< ::mosek::fusion::Expression > _7374,    double _7375) { return mosek::fusion::p_Expr::stack(_7372,_7373,_7374,_7375); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7372,double _7373,monty::rc_ptr< ::mosek::fusion::Expression > _7374,double _7375){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7373).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7374.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7375).get())}),_7372);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7376,    double _7377,    double _7378,    monty::rc_ptr< ::mosek::fusion::Expression > _7379) { return mosek::fusion::p_Expr::stack(_7376,_7377,_7378,_7379); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7376,double _7377,double _7378,monty::rc_ptr< ::mosek::fusion::Expression > _7379){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7377).get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7378).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7379.get())}),_7376);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7380,    double _7381,    monty::rc_ptr< ::mosek::fusion::Expression > _7382) { return mosek::fusion::p_Expr::stack(_7380,_7381,_7382); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7380,double _7381,monty::rc_ptr< ::mosek::fusion::Expression > _7382){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7381).get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7382.get())}),_7380);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7383,    monty::rc_ptr< ::mosek::fusion::Expression > _7384,    double _7385) { return mosek::fusion::p_Expr::stack(_7383,_7384,_7385); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7383,monty::rc_ptr< ::mosek::fusion::Expression > _7384,double _7385){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7384.get()),::monty::rc_ptr<::mosek::fusion::Expression>(::mosek::fusion::p_Expr::constTerm(_7385).get())}),_7383);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7386,    monty::rc_ptr< ::mosek::fusion::Expression > _7387,    monty::rc_ptr< ::mosek::fusion::Expression > _7388) { return mosek::fusion::p_Expr::stack(_7386,_7387,_7388); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7386,monty::rc_ptr< ::mosek::fusion::Expression > _7387,monty::rc_ptr< ::mosek::fusion::Expression > _7388){
  return ::mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >{::monty::rc_ptr<::mosek::fusion::Expression>(_7387.get()),::monty::rc_ptr<::mosek::fusion::Expression>(_7388.get())}),_7386);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::stack  ( int _7389,    std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7390) { return mosek::fusion::p_Expr::stack(_7389,_7390); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack(int _7389,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7390){
  return ::mosek::fusion::p_Expr::stack_(_7390,_7389);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7391,int _7392){
  if (((int)((_7391)->size(0)) == (int)1))
  {
    {
      return ((*_7391)((int)0));
    }
  }
  else
  {
    {
      return (::mosek::fusion::p_ExprStack::_new_ExprStack(::mosek::fusion::p_Expr::promote(_7391,_7392),_7392)).as<::mosek::fusion::Expression>();
    }
  }
}
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > mosek::fusion::p_Expr::promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7393,int _7394){
  int _7395 = (int)((_7393)->size(0));
  std::vector<int> _12099;
  for (int _7397 = (int)0, _12100 = _7395; _7397 < _12100 ; ++_7397)
  {
    _12099.push_back(((*_7393)(_7397))->getND());
  }
  auto _12101 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12099.size()),_12099.begin(),_12099.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7396 = _12101;
  _checked_ptr_1<int> _ptr__7396(_7396 ? _7396->raw() : nullptr,_7396 ? _7396->size(0) : 0);
  int _7398 = _ptr__7396[(int)0];
  int _7399 = _ptr__7396[(int)0];
  int _12102 = (int)1;
  int _12103 = _7395;
  for (int _7400 = _12102; _7400 < _12103; ++_7400)
  {
    {
      if ((_ptr__7396[_7400] < _7399))
      {
        {
          _7399 = _ptr__7396[_7400];
        }
      }
      {}
      if ((_ptr__7396[_7400] > _7398))
      {
        {
          _7398 = _ptr__7396[_7400];
        }
      }
      {}
    }
  }
  if ((_7398 < _7394))
  {
    {
      _7398 = _7394;
    }
  }
  {}
  if ((_7399 < _7398))
  {
    {
      std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7401 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 >(monty::shape(_7395)));
      std::shared_ptr< monty::ndarray< int,1 > > _7402 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7398)));
      _checked_ptr_1<int> _ptr__7402(_7402 ? _7402->raw() : nullptr,_7402 ? _7402->size(0) : 0);
      int _12104 = (int)0;
      int _12105 = _7395;
      for (int _7403 = _12104; _7403 < _12105; ++_7403)
      {
        {
          if ((((*_7393)(_7403))->getND() == _7398))
          {
            {
              ((*_7401)(_7403)) = ((*_7393)(_7403));
            }
          }
          else
          {
            {
              std::shared_ptr< monty::ndarray< int,1 > > _7404 = ((*_7393)(_7403))->getShape();
              _checked_ptr_1<int> _ptr__7404(_7404 ? _7404->raw() : nullptr,_7404 ? _7404->size(0) : 0);
              int _12106 = (int)0;
              int _12107 = (int)((_7404)->size(0));
              for (int _7405 = _12106; _7405 < _12107; ++_7405)
              {
                {
                  _ptr__7402[_7405] = _ptr__7404[_7405];
                }
              }
              int _12108 = (int)((_7404)->size(0));
              int _12109 = _7398;
              for (int _7406 = _12108; _7406 < _12109; ++_7406)
              {
                {
                  _ptr__7402[_7406] = (int)1;
                }
              }
              ((*_7401)(_7403)) = (::mosek::fusion::p_ExprReshape::_new_ExprReshape(_7402,((*_7393)(_7403)))).as<::mosek::fusion::Expression>();
            }
          }
        }
      }
      return _7401;
    }
  }
  else
  {
    {
      return _7393;
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Variable > _7407,    int _7408,    int _7409) { return mosek::fusion::p_Expr::repeat(_7407,_7408,_7409); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Variable > _7407,int _7408,int _7409){
  return ::mosek::fusion::p_Expr::repeat(_7407->__mosek_2fusion_2Variable__asExpr(),_7408,_7409);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::repeat  ( monty::rc_ptr< ::mosek::fusion::Expression > _7410,    int _7411,    int _7412) { return mosek::fusion::p_Expr::repeat(_7410,_7411,_7412); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::repeat(monty::rc_ptr< ::mosek::fusion::Expression > _7410,int _7411,int _7412){
  if ((_7411 <= (int)0))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Cannot repeat Expression 0 or less times"));
    }
  }
  {}
  if (((_7412 < (int)0) || (_7412 > _7410->getND())))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Invalid stacking dimension"));
    }
  }
  else
  {
    {
      if ((_7412 == _7410->getND()))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _7413 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(safe_add( _7412,(int)1 ))));
          _checked_ptr_1<int> _ptr__7413(_7413 ? _7413->raw() : nullptr,_7413 ? _7413->size(0) : 0);
          int _12110 = (int)0;
          int _12111 = _7412;
          for (int _7414 = _12110; _7414 < _12111; ++_7414)
          {
            {
              _ptr__7413[_7414] = _7410->getDim(_7414);
            }
          }
          _ptr__7413[_7412] = (int)1;
          return (::mosek::fusion::p_ExprRepeat::_new_ExprRepeat(::mosek::fusion::p_Expr::reshape(_7410,_7413),_7412,_7411)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          return (::mosek::fusion::p_ExprRepeat::_new_ExprRepeat(_7410,_7412,_7411)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7415) { return mosek::fusion::p_Expr::add(_7415); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7415){
  std::vector<double> _12112;
  for (int _7416 = (int)0, _12113 = (int)((_7415)->size(0)); _7416 < _12113 ; ++_7416)
  {
    _12112.push_back(1.0);
  }
  auto _12114 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12112.size()),_12112.begin(),_12112.end()));
  return (::mosek::fusion::p_ExprWSum::_new_ExprWSum(_7415,_12114)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _7417) { return mosek::fusion::p_Expr::add(_7417); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _7417){
  if ((NULL == _7417.get()))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may not be null"));
    }
  }
  {}
  if (((int)((_7417)->size(0)) == (int)0))
  {
    {
      return (::mosek::fusion::p_Expr::_new_Expr(std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >{(long long)((int)0)}),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),nullptr,::mosek::fusion::p_Set::make((int)0),std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)0))),(int)1)).as<::mosek::fusion::Expression>();
    }
  }
  {}
  if ((((int)((_7417)->size(0)) > (int)0) && (NULL == ((*_7417)((int)0)).get())))
  {
    {
      throw monty::NullPointerException(std::string ("Argument vs may contain null"));
    }
  }
  {}
  int _7418 = ((*_7417)((int)0))->getND();
  int _12115 = (int)1;
  int _12116 = (int)((_7417)->size(0));
  for (int _7419 = _12115; _7419 < _12116; ++_7419)
  {
    {
      if ((_7418 < ((*_7417)(_7419))->getND()))
      {
        {
          _7418 = ((*_7417)(_7419))->getND();
        }
      }
      {}
    }
  }
  std::shared_ptr< monty::ndarray< int,2 > > _7420 = std::shared_ptr< monty::ndarray< int,2 > >(new monty::ndarray< int,2 >(monty::shape((int)((_7417)->size(0)),_7418)));
  int _12117 = (int)0;
  int _12118 = (int)((_7417)->size(0));
  for (int _7421 = _12117; _7421 < _12118; ++_7421)
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7422 = ((*_7417)(_7421))->getShape();
      _checked_ptr_1<int> _ptr__7422(_7422 ? _7422->raw() : nullptr,_7422 ? _7422->size(0) : 0);
      int _12119 = (int)0;
      int _12120 = (int)((_7422)->size(0));
      for (int _7423 = _12119; _7423 < _12120; ++_7423)
      {
        {
          ((*_7420)(_7421,_7423)) = _ptr__7422[_7423];
        }
      }
      int _12121 = (int)((_7422)->size(0));
      int _12122 = _7418;
      for (int _7424 = _12121; _7424 < _12122; ++_7424)
      {
        {
          ((*_7420)(_7421,_7424)) = (int)1;
        }
      }
    }
  }
  int _12123 = (int)1;
  int _12124 = (int)((_7417)->size(0));
  for (int _7425 = _12123; _7425 < _12124; ++_7425)
  {
    {
      int _12125 = (int)0;
      int _12126 = _7418;
      for (int _7426 = _12125; _7426 < _12126; ++_7426)
      {
        {
          if ((((*_7420)((int)0,_7426)) != ((*_7420)(_7425,_7426))))
          {
            {
              throw ::mosek::fusion::DimensionError(std::string ("Mismatching operand dimensions"));
            }
          }
          {}
        }
      }
    }
  }
  std::vector<int> _12127;
  for (int _7428 = (int)0, _12128 = _7418; _7428 < _12128 ; ++_7428)
  {
    _12127.push_back(((*_7420)((int)0,_7428)));
  }
  auto _12129 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12127.size()),_12127.begin(),_12127.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7427 = _12129;
  _checked_ptr_1<int> _ptr__7427(_7427 ? _7427->raw() : nullptr,_7427 ? _7427->size(0) : 0);
  int _7429 = (int)1;
  int _12130 = (int)0;
  int _12131 = _7418;
  for (int _7430 = _12130; _7430 < _12131; ++_7430)
  {
    {
      _7429 *= _ptr__7427[_7430];
    }
  }
  int _7431 = (int)0;
  int _7432 = (int)0;
  int _12132 = (int)0;
  int _12133 = (int)((_7417)->size(0));
  for (int _7433 = _12132; _7433 < _12133; ++_7433)
  {
    {
      int _7434 = ((*_7417)(_7433))->numInst();
      _7431 += _7434;
      int _12134;
      bool _12135 = (_7432 > _7434);
      if (_12135)
      {
        _12134 = _7432;
      }
      else
      {
        _12134 = _7434;
      }
      _7432 = _12134;
    }
  }
  std::shared_ptr< monty::ndarray< long long,1 > > _7435 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( _7429,(int)1 ))));
  _checked_ptr_1<long long> _ptr__7435(_7435 ? _7435->raw() : nullptr,_7435 ? _7435->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _7436 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7431)));
  _checked_ptr_1<long long> _ptr__7436(_7436 ? _7436->raw() : nullptr,_7436 ? _7436->size(0) : 0);
  std::vector<double> _12136;
  for (int _7438 = (int)0, _12137 = _7431; _7438 < _12137 ; ++_7438)
  {
    _12136.push_back(1.0);
  }
  auto _12138 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12136.size()),_12136.begin(),_12136.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _7437 = _12138;
  _checked_ptr_1<double> _ptr__7437(_7437 ? _7437->raw() : nullptr,_7437 ? _7437->size(0) : 0);
  {
    std::shared_ptr< monty::ndarray< long long,1 > > _7439 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7432)));
    _checked_ptr_1<long long> _ptr__7439(_7439 ? _7439->raw() : nullptr,_7439 ? _7439->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _7440 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7432)));
    _checked_ptr_1<long long> _ptr__7440(_7440 ? _7440->raw() : nullptr,_7440 ? _7440->size(0) : 0);
    int _12139 = (int)0;
    int _12140 = (int)((_7417)->size(0));
    for (int _7441 = _12139; _7441 < _12140; ++_7441)
    {
      {
        int _7442 = ((*_7417)(_7441))->inst((int)0,_7439,(int)0,_7440);
        int _12141 = (int)0;
        int _12142 = _7442;
        for (int _7443 = _12141; _7443 < _12142; ++_7443)
        {
          {
            _ptr__7435[safe_add( _ptr__7439[_7443],(int)1 )] += (int)1;
          }
        }
      }
    }
    int _12143 = (int)0;
    int _12144 = _7429;
    for (int _7444 = _12143; _7444 < _12144; ++_7444)
    {
      {
        _ptr__7435[safe_add( _7444,(int)1 )] += _ptr__7435[_7444];
      }
    }
    int _12145 = (int)0;
    int _12146 = (int)((_7417)->size(0));
    for (int _7445 = _12145; _7445 < _12146; ++_7445)
    {
      {
        int _7446 = ((*_7417)(_7445))->inst((int)0,_7439,(int)0,_7440);
        int _12147 = (int)0;
        int _12148 = _7446;
        for (int _7447 = _12147; _7447 < _12148; ++_7447)
        {
          {
            _ptr__7436[_ptr__7435[_ptr__7439[_7447]]] = _ptr__7440[_7447];
            ++ _ptr__7435[_ptr__7439[_7447]];
          }
        }
      }
    }
    int _12149 = (int)0;
    int _12150 = _7429;
    for (int _7448 = _12149; _7448 < _12150; ++_7448)
    {
      {
        _ptr__7435[(_7429 - _7448)] = _ptr__7435[((_7429 - _7448) - (int)1)];
      }
    }
    _ptr__7435[(int)0] = (int)0;
  }
  std::vector<double> _12151;
  for (int _7449 = (int)0, _12152 = _7429; _7449 < _12152 ; ++_7449)
  {
    _12151.push_back(0.0);
  }
  auto _12153 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12151.size()),_12151.begin(),_12151.end()));
  return (::mosek::fusion::p_Expr::_new_Expr(_7435,_7436,_7437,_12153,_7427,nullptr,(int)1)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add_(monty::rc_ptr< ::mosek::fusion::Expression > _7450,double _7451,monty::rc_ptr< ::mosek::fusion::Expression > _7452,double _7453){
  int _7454 = _7450->getND();
  int _7455 = _7452->getND();
  if ((_7454 == _7455))
  {
    {
      return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_7450,_7452,_7451,_7453)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      int _12154;
      bool _12155 = (_7454 > _7455);
      if (_12155)
      {
        _12154 = _7454;
      }
      else
      {
        _12154 = _7455;
      }
      int _7456 = _12154;
      std::shared_ptr< monty::ndarray< int,1 > > _7457 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7456)));
      _checked_ptr_1<int> _ptr__7457(_7457 ? _7457->raw() : nullptr,_7457 ? _7457->size(0) : 0);
      if ((_7454 < _7455))
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _7458 = _7450->getShape();
          _checked_ptr_1<int> _ptr__7458(_7458 ? _7458->raw() : nullptr,_7458 ? _7458->size(0) : 0);
          int _12156 = (int)0;
          int _12157 = _7454;
          for (int _7459 = _12156; _7459 < _12157; ++_7459)
          {
            {
              _ptr__7457[_7459] = _ptr__7458[_7459];
            }
          }
          int _12158 = _7454;
          int _12159 = _7456;
          for (int _7460 = _12158; _7460 < _12159; ++_7460)
          {
            {
              _ptr__7457[_7460] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd((::mosek::fusion::p_ExprReshape::_new_ExprReshape(_7457,_7450)).as<::mosek::fusion::Expression>(),_7452,_7451,_7453)).as<::mosek::fusion::Expression>();
        }
      }
      else
      {
        {
          std::shared_ptr< monty::ndarray< int,1 > > _7461 = _7452->getShape();
          _checked_ptr_1<int> _ptr__7461(_7461 ? _7461->raw() : nullptr,_7461 ? _7461->size(0) : 0);
          int _12160 = (int)0;
          int _12161 = _7455;
          for (int _7462 = _12160; _7462 < _12161; ++_7462)
          {
            {
              _ptr__7457[_7462] = _ptr__7461[_7462];
            }
          }
          int _12162 = _7455;
          int _12163 = _7456;
          for (int _7463 = _12162; _7463 < _12163; ++_7463)
          {
            {
              _ptr__7457[_7463] = (int)1;
            }
          }
          return (::mosek::fusion::p_ExprAdd::_new_ExprAdd(_7450,(::mosek::fusion::p_ExprReshape::_new_ExprReshape(_7457,_7452)).as<::mosek::fusion::Expression>(),_7451,_7453)).as<::mosek::fusion::Expression>();
        }
      }
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::transpose  ( monty::rc_ptr< ::mosek::fusion::Expression > _7464) { return mosek::fusion::p_Expr::transpose(_7464); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::transpose(monty::rc_ptr< ::mosek::fusion::Expression > _7464){
  if ((_7464->getND() == (int)0))
  {
    {
      return _7464;
    }
  }
  else if((_7464->getND() == (int)1))
  {
    {
      return (::mosek::fusion::p_ExprReshape::_new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)((int)1),(int)(_7464->getDim((int)0))}),_7464)).as<::mosek::fusion::Expression>();
    }
  }
  else if((_7464->getND() == (int)2))
  {
    {
      return (::mosek::fusion::p_ExprTranspose::_new_ExprTranspose(_7464)).as<::mosek::fusion::Expression>();
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Incorrect number of dimensions for transpose"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7465,    monty::rc_ptr< ::mosek::fusion::Expression > _7466) { return mosek::fusion::p_Expr::mulElm(_7465,_7466); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _7465,monty::rc_ptr< ::mosek::fusion::Expression > _7466){
  return ::mosek::fusion::p_Expr::mulElm_(_7465,_7466);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7467,    monty::rc_ptr< ::mosek::fusion::Expression > _7468) { return mosek::fusion::p_Expr::mulElm(_7467,_7468); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7467,monty::rc_ptr< ::mosek::fusion::Expression > _7468){
  return ::mosek::fusion::p_Expr::mulElm_(_7467,_7468);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,2 > > _7469,    monty::rc_ptr< ::mosek::fusion::Expression > _7470) { return mosek::fusion::p_Expr::mulElm(_7469,_7470); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,2 > > _7469,monty::rc_ptr< ::mosek::fusion::Expression > _7470){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_7469),_7470);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( std::shared_ptr< monty::ndarray< double,1 > > _7471,    monty::rc_ptr< ::mosek::fusion::Expression > _7472) { return mosek::fusion::p_Expr::mulElm(_7471,_7472); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(std::shared_ptr< monty::ndarray< double,1 > > _7471,monty::rc_ptr< ::mosek::fusion::Expression > _7472){
  _checked_ptr_1<double> _ptr__7471(_7471 ? _7471->raw() : nullptr, _7471 ? _7471->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_7471,_7472);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _7473,    monty::rc_ptr< ::mosek::fusion::Matrix > _7474) { return mosek::fusion::p_Expr::mulElm(_7473,_7474); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7473,monty::rc_ptr< ::mosek::fusion::Matrix > _7474){
  return ::mosek::fusion::p_Expr::mulElm_(_7474,_7473);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _7475,    std::shared_ptr< monty::ndarray< double,2 > > _7476) { return mosek::fusion::p_Expr::mulElm(_7475,_7476); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7475,std::shared_ptr< monty::ndarray< double,2 > > _7476){
  return ::mosek::fusion::p_Expr::mulElm_(::mosek::fusion::p_Matrix::dense(_7476),_7475);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _7477,    std::shared_ptr< monty::ndarray< double,1 > > _7478) { return mosek::fusion::p_Expr::mulElm(_7477,_7478); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7477,std::shared_ptr< monty::ndarray< double,1 > > _7478){
  _checked_ptr_1<double> _ptr__7478(_7478 ? _7478->raw() : nullptr, _7478 ? _7478->size(0) : 0);
  return ::mosek::fusion::p_Expr::mulElm_(_7478,_7477);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _7479,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7480) { return mosek::fusion::p_Expr::mulElm(_7479,_7480); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7479,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7480){
  return ::mosek::fusion::p_Expr::mulElm_(_7480,_7479);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Parameter > _7481,    monty::rc_ptr< ::mosek::fusion::Expression > _7482) { return mosek::fusion::p_Expr::mulElm(_7481,_7482); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Parameter > _7481,monty::rc_ptr< ::mosek::fusion::Expression > _7482){
  return (::mosek::fusion::p_ExprMulParamElem::_new_ExprMulParamElem(_7481,_7482)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::mulElm  ( monty::rc_ptr< ::mosek::fusion::Expression > _7483,    monty::rc_ptr< ::mosek::fusion::Parameter > _7484) { return mosek::fusion::p_Expr::mulElm(_7483,_7484); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7483,monty::rc_ptr< ::mosek::fusion::Parameter > _7484){
  return (::mosek::fusion::p_ExprMulParamElem::_new_ExprMulParamElem(_7484,_7483)).as<::mosek::fusion::Expression>();
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7485,    monty::rc_ptr< ::mosek::fusion::Expression > _7486) { return mosek::fusion::p_Expr::sub(_7485,_7486); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7485,monty::rc_ptr< ::mosek::fusion::Expression > _7486){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_7485),1.0,_7486,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _7487,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7488) { return mosek::fusion::p_Expr::sub(_7487,_7488); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _7487,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7488){
  return ::mosek::fusion::p_Expr::add_(_7487,1.0,::mosek::fusion::p_Expr::constTerm(_7488),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7489,    monty::rc_ptr< ::mosek::fusion::Expression > _7490) { return mosek::fusion::p_Expr::sub(_7489,_7490); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Matrix > _7489,monty::rc_ptr< ::mosek::fusion::Expression > _7490){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_7489),1.0,_7490,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _7491,    monty::rc_ptr< ::mosek::fusion::Matrix > _7492) { return mosek::fusion::p_Expr::sub(_7491,_7492); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _7491,monty::rc_ptr< ::mosek::fusion::Matrix > _7492){
  return ::mosek::fusion::p_Expr::add_(_7491,1.0,::mosek::fusion::p_Expr::constTerm(_7492),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( double _7493,    monty::rc_ptr< ::mosek::fusion::Expression > _7494) { return mosek::fusion::p_Expr::sub(_7493,_7494); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(double _7493,monty::rc_ptr< ::mosek::fusion::Expression > _7494){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_7494->getShape(),_7493),1.0,_7494,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _7495,    double _7496) { return mosek::fusion::p_Expr::sub(_7495,_7496); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _7495,double _7496){
  return ::mosek::fusion::p_Expr::add_(_7495,1.0,::mosek::fusion::p_Expr::constTerm(_7495->getShape(),_7496),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,2 > > _7497,    monty::rc_ptr< ::mosek::fusion::Expression > _7498) { return mosek::fusion::p_Expr::sub(_7497,_7498); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,2 > > _7497,monty::rc_ptr< ::mosek::fusion::Expression > _7498){
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_7497),1.0,_7498,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( std::shared_ptr< monty::ndarray< double,1 > > _7499,    monty::rc_ptr< ::mosek::fusion::Expression > _7500) { return mosek::fusion::p_Expr::sub(_7499,_7500); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(std::shared_ptr< monty::ndarray< double,1 > > _7499,monty::rc_ptr< ::mosek::fusion::Expression > _7500){
  _checked_ptr_1<double> _ptr__7499(_7499 ? _7499->raw() : nullptr, _7499 ? _7499->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(::mosek::fusion::p_Expr::constTerm(_7499),1.0,_7500,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _7501,    std::shared_ptr< monty::ndarray< double,2 > > _7502) { return mosek::fusion::p_Expr::sub(_7501,_7502); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _7501,std::shared_ptr< monty::ndarray< double,2 > > _7502){
  return ::mosek::fusion::p_Expr::add_(_7501,1.0,::mosek::fusion::p_Expr::constTerm(_7502),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _7503,    std::shared_ptr< monty::ndarray< double,1 > > _7504) { return mosek::fusion::p_Expr::sub(_7503,_7504); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _7503,std::shared_ptr< monty::ndarray< double,1 > > _7504){
  _checked_ptr_1<double> _ptr__7504(_7504 ? _7504->raw() : nullptr, _7504 ? _7504->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_7503,1.0,::mosek::fusion::p_Expr::constTerm(_7504),(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::sub  ( monty::rc_ptr< ::mosek::fusion::Expression > _7505,    monty::rc_ptr< ::mosek::fusion::Expression > _7506) { return mosek::fusion::p_Expr::sub(_7505,_7506); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::sub(monty::rc_ptr< ::mosek::fusion::Expression > _7505,monty::rc_ptr< ::mosek::fusion::Expression > _7506){
  return ::mosek::fusion::p_Expr::add_(_7505,1.0,_7506,(-1.0));
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7507,    monty::rc_ptr< ::mosek::fusion::Expression > _7508) { return mosek::fusion::p_Expr::add(_7507,_7508); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7507,monty::rc_ptr< ::mosek::fusion::Expression > _7508){
  return ::mosek::fusion::p_Expr::add_(_7508,1.0,::mosek::fusion::p_Expr::constTerm(_7507),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _7509,    monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7510) { return mosek::fusion::p_Expr::add(_7509,_7510); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _7509,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7510){
  return ::mosek::fusion::p_Expr::add_(_7509,1.0,::mosek::fusion::p_Expr::constTerm(_7510),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7511,    monty::rc_ptr< ::mosek::fusion::Expression > _7512) { return mosek::fusion::p_Expr::add(_7511,_7512); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Matrix > _7511,monty::rc_ptr< ::mosek::fusion::Expression > _7512){
  return ::mosek::fusion::p_Expr::add_(_7512,1.0,::mosek::fusion::p_Expr::constTerm(_7511),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _7513,    monty::rc_ptr< ::mosek::fusion::Matrix > _7514) { return mosek::fusion::p_Expr::add(_7513,_7514); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _7513,monty::rc_ptr< ::mosek::fusion::Matrix > _7514){
  return ::mosek::fusion::p_Expr::add_(_7513,1.0,::mosek::fusion::p_Expr::constTerm(_7514),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( double _7515,    monty::rc_ptr< ::mosek::fusion::Expression > _7516) { return mosek::fusion::p_Expr::add(_7515,_7516); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(double _7515,monty::rc_ptr< ::mosek::fusion::Expression > _7516){
  return ::mosek::fusion::p_Expr::add_(_7516,1.0,::mosek::fusion::p_Expr::constTerm(_7516->getShape(),_7515),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _7517,    double _7518) { return mosek::fusion::p_Expr::add(_7517,_7518); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _7517,double _7518){
  return ::mosek::fusion::p_Expr::add_(_7517,1.0,::mosek::fusion::p_Expr::constTerm(_7517->getShape(),_7518),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,2 > > _7519,    monty::rc_ptr< ::mosek::fusion::Expression > _7520) { return mosek::fusion::p_Expr::add(_7519,_7520); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,2 > > _7519,monty::rc_ptr< ::mosek::fusion::Expression > _7520){
  return ::mosek::fusion::p_Expr::add_(_7520,1.0,::mosek::fusion::p_Expr::constTerm(_7519),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( std::shared_ptr< monty::ndarray< double,1 > > _7521,    monty::rc_ptr< ::mosek::fusion::Expression > _7522) { return mosek::fusion::p_Expr::add(_7521,_7522); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(std::shared_ptr< monty::ndarray< double,1 > > _7521,monty::rc_ptr< ::mosek::fusion::Expression > _7522){
  _checked_ptr_1<double> _ptr__7521(_7521 ? _7521->raw() : nullptr, _7521 ? _7521->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_7522,1.0,::mosek::fusion::p_Expr::constTerm(_7521),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _7523,    std::shared_ptr< monty::ndarray< double,2 > > _7524) { return mosek::fusion::p_Expr::add(_7523,_7524); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _7523,std::shared_ptr< monty::ndarray< double,2 > > _7524){
  return ::mosek::fusion::p_Expr::add_(_7523,1.0,::mosek::fusion::p_Expr::constTerm(_7524),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _7525,    std::shared_ptr< monty::ndarray< double,1 > > _7526) { return mosek::fusion::p_Expr::add(_7525,_7526); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _7525,std::shared_ptr< monty::ndarray< double,1 > > _7526){
  _checked_ptr_1<double> _ptr__7526(_7526 ? _7526->raw() : nullptr, _7526 ? _7526->size(0) : 0);
  return ::mosek::fusion::p_Expr::add_(_7525,1.0,::mosek::fusion::p_Expr::constTerm(_7526),1.0);
}
monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::Expr::add  ( monty::rc_ptr< ::mosek::fusion::Expression > _7527,    monty::rc_ptr< ::mosek::fusion::Expression > _7528) { return mosek::fusion::p_Expr::add(_7527,_7528); }monty::rc_ptr< ::mosek::fusion::Expression > mosek::fusion::p_Expr::add(monty::rc_ptr< ::mosek::fusion::Expression > _7527,monty::rc_ptr< ::mosek::fusion::Expression > _7528){
  return ::mosek::fusion::p_Expr::add_(_7527,1.0,_7528,1.0);
}
int mosek::fusion::Expr :: getND() { return mosek::fusion::p_Expr::_get_impl(this)->getND(); }int mosek::fusion::p_Expr::getND(){
  return (int)((shape)->size(0));
}
std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::Expr :: getShape() { return mosek::fusion::p_Expr::_get_impl(this)->getShape(); }std::shared_ptr< monty::ndarray< int,1 > > mosek::fusion::p_Expr::getShape(){
  return ::mosek::fusion::Utils::Tools::arraycopy(shape);
}
void mosek::fusion::Expr :: eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _7529,monty::rc_ptr< ::mosek::fusion::WorkStack > _7530,monty::rc_ptr< ::mosek::fusion::WorkStack > _7531) { mosek::fusion::p_Expr::_get_impl(this)->eval(_7529,_7530,_7531); }void mosek::fusion::p_Expr::eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _7529,monty::rc_ptr< ::mosek::fusion::WorkStack > _7530,monty::rc_ptr< ::mosek::fusion::WorkStack > _7531){
  int _7532 = ((int)((ptrb)->size(0)) - (int)1);
  int _7533 = safe_add( (int)((*ptrb)(_7532)),_7532 );
  int _7534 = (int)((shape)->size(0));
  _7529->alloc_expr(_7534,_7532,_7533,(NULL != inst.get()));
  int _7535 = mosek::fusion::p_WorkStack::_get_impl(_7529)->ptr_base;
  int _7536 = mosek::fusion::p_WorkStack::_get_impl(_7529)->nidxs_base;
  int _7537 = mosek::fusion::p_WorkStack::_get_impl(_7529)->sp_base;
  int _7538 = mosek::fusion::p_WorkStack::_get_impl(_7529)->cof_base;
  int _7539 = mosek::fusion::p_WorkStack::_get_impl(_7529)->shape_base;
  std::shared_ptr< monty::ndarray< int,1 > > _7540 = mosek::fusion::p_WorkStack::_get_impl(_7529)->i32;
  _checked_ptr_1<int> _ptr__7540(_7540 ? _7540->raw() : nullptr,_7540 ? _7540->size(0) : 0);
  std::shared_ptr< monty::ndarray< long long,1 > > _7541 = mosek::fusion::p_WorkStack::_get_impl(_7529)->i64;
  _checked_ptr_1<long long> _ptr__7541(_7541 ? _7541->raw() : nullptr,_7541 ? _7541->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7542 = mosek::fusion::p_WorkStack::_get_impl(_7529)->f64;
  _checked_ptr_1<double> _ptr__7542(_7542 ? _7542->raw() : nullptr,_7542 ? _7542->size(0) : 0);
  {
    int _12164 = (int)0;
    int _12165 = _7534;
    for (int _7543 = _12164; _7543 < _12165; ++_7543)
    {
      {
        _ptr__7540[safe_add( _7539,_7543 )] = ((*shape)(_7543));
      }
    }
    _ptr__7540[_7535] = (int)0;
    int _7544 = (int)0;
    int _12166 = (int)0;
    int _12167 = _7532;
    for (int _7545 = _12166; _7545 < _12167; ++_7545)
    {
      {
        long long _12168 = ((*ptrb)(_7545));
        long long _12169 = ((*ptrb)(safe_add( _7545,(int)1 )));
        for (long long _7546 = _12168; _7546 < _12169; ++_7546)
        {
          {
            _ptr__7541[safe_add( _7536,_7544 )] = ((*subj)(_7546));
            _ptr__7542[safe_add( _7538,_7544 )] = ((*cof_v)(_7546));
            ++ _7544;
          }
        }
        _ptr__7541[safe_add( _7536,_7544 )] = (int)0;
        _ptr__7542[safe_add( _7538,_7544 )] = ((*bfix)(_7545));
        ++ _7544;
        _ptr__7540[safe_add( safe_add( _7535,_7545 ),(int)1 )] = _7544;
      }
    }
  }
}
void mosek::fusion::p_Expr::validateData(std::shared_ptr< monty::ndarray< long long,1 > > _7547,std::shared_ptr< monty::ndarray< long long,1 > > _7548,std::shared_ptr< monty::ndarray< double,1 > > _7549,std::shared_ptr< monty::ndarray< double,1 > > _7550,std::shared_ptr< monty::ndarray< int,1 > > _7551,std::shared_ptr< monty::ndarray< long long,1 > > _7552){
  _checked_ptr_1<long long> _ptr__7547(_7547 ? _7547->raw() : nullptr, _7547 ? _7547->size(0) : 0);
  _checked_ptr_1<long long> _ptr__7548(_7548 ? _7548->raw() : nullptr, _7548 ? _7548->size(0) : 0);
  _checked_ptr_1<double> _ptr__7549(_7549 ? _7549->raw() : nullptr, _7549 ? _7549->size(0) : 0);
  _checked_ptr_1<double> _ptr__7550(_7550 ? _7550->raw() : nullptr, _7550 ? _7550->size(0) : 0);
  _checked_ptr_1<int> _ptr__7551(_7551 ? _7551->raw() : nullptr, _7551 ? _7551->size(0) : 0);
  _checked_ptr_1<long long> _ptr__7552(_7552 ? _7552->raw() : nullptr, _7552 ? _7552->size(0) : 0);
  if ((NULL == _7551.get()))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'shape' in expression is null"));
    }
  }
  {}
  int _7553 = ((int)((_7547)->size(0)) - (int)1);
  long long _7554 = _ptr__7547[((int)((_7547)->size(0)) - (int)1)];
  int _7555 = (int)((_7551)->size(0));
  long long _7556 = (long long)1;
  int _12170 = (int)0;
  int _12171 = _7555;
  for (int _7557 = _12170; _7557 < _12171; ++_7557)
  {
    {
      _7556 *= _ptr__7551[_7557];
    }
  }
  if (((int)((_7547)->size(0)) < (int)1))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong size"));
    }
  }
  {}
  if ((_7554 != (int)((_7548)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'subj' in expression has wrong size"));
    }
  }
  {}
  if ((_7554 != (int)((_7549)->size(0))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'cof' in expression has wrong size"));
    }
  }
  {}
  if (((NULL == _7550.get()) || (_7553 != (int)((_7550)->size(0)))))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Array 'bfix' in expression has wrong length"));
    }
  }
  {}
  if (((NULL != _7552.get()) && ((int)((_7552)->size(0)) < _7556)))
  {
    {
      if (((int)((_7552)->size(0)) != ((int)((_7547)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' in expression has wrong length"));
        }
      }
      {}
      if (((int)((_7552)->size(0)) > (int)0))
      {
        {
          if (((_ptr__7552[(int)0] < (int)0) || (_ptr__7552[(int)0] >= _7556)))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Array 'inst' contains an invalid index"));
            }
          }
          {}
          bool _7558 = true;
          long long _7559 = _7556;
          int _12172 = (int)1;
          int _12173 = (int)((_7552)->size(0));
          for (int _7560 = _12172; _7560 < _12173; ++_7560)
          {
            {
              _7558 = (_7558 && ((_ptr__7552[_7560] >= (int)0) && ((_ptr__7552[_7560] < _7559) && (_ptr__7552[_7560] > _ptr__7552[(_7560 - (int)1)]))));
            }
          }
          if ((!_7558))
          {
            {
              throw ::mosek::fusion::ExpressionError(std::string ("Invalid array 'inst'"));
            }
          }
          {}
        }
      }
      {}
    }
  }
  else
  {
    {
      if ((_7556 != ((long long)((_7547)->size(0)) - (int)1)))
      {
        {
          throw ::mosek::fusion::ExpressionError(std::string ("Array 'ptrb' in expression has wrong length"));
        }
      }
      {}
    }
  }
  bool _7561 = false;
  bool _7562 = false;
  if ((_ptr__7547[(int)0] != (long long)0))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
  bool _7563 = true;
  int _12174 = (int)0;
  int _12175 = _7553;
  for (int _7564 = _12174; _7564 < _12175; ++_7564)
  {
    {
      _7563 = (_7563 && (_ptr__7547[_7564] <= _ptr__7547[safe_add( _7564,(int)1 )]));
    }
  }
  if ((!_7563))
  {
    {
      throw ::mosek::fusion::ExpressionError(std::string ("Invalid 'ptrb' argument in expression"));
    }
  }
  {}
}
monty::rc_ptr< ::mosek::fusion::Model > mosek::fusion::p_Expr::extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _7565){
  monty::rc_ptr< ::mosek::fusion::Model > _12176;
  bool _12177 = ((NULL == _7565.get()) || ((int)((_7565)->size(0)) == (int)0));
  if (_12177)
  {
    _12176 = nullptr;
  }
  else
  {
    _12176 = ((*_7565)((int)0))->__mosek_2fusion_2Variable__getModel();
  }
  return _12176;
}
void mosek::fusion::p_Expr::destroy(){inst.reset();cof_v.reset();subj.reset();ptrb.reset();bfix.reset();shape.reset();}void mosek::fusion::Expr::destroy() { mosek::fusion::p_Expr::_get_impl(this)->destroy(); }monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,2 > > _7566) { return __mosek_2fusion_2Expression__pick(_7566); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::pick(std::shared_ptr< monty::ndarray< int,1 > > _7567) { return __mosek_2fusion_2Expression__pick(_7567); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(std::shared_ptr< monty::ndarray< int,1 > > _7568) { return __mosek_2fusion_2Expression__index(_7568); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::index(int _7569) { return __mosek_2fusion_2Expression__index(_7569); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(std::shared_ptr< monty::ndarray< int,1 > > _7570,std::shared_ptr< monty::ndarray< int,1 > > _7571) { return __mosek_2fusion_2Expression__slice(_7570,_7571); }
monty::rc_ptr< mosek::fusion::Expression > mosek::fusion::Expression::slice(int _7572,int _7573) { return __mosek_2fusion_2Expression__slice(_7572,_7573); }
mosek::fusion::SymmetricMatrix::SymmetricMatrix(mosek::fusion::p_SymmetricMatrix *_impl) : _impl(_impl) { /*std::cout << "SymmetricMatrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::SymmetricMatrix::~SymmetricMatrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_SymmetricMatrix::p_SymmetricMatrix  (::mosek::fusion::SymmetricMatrix * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::SymmetricMatrix::t mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix  (int _7578,    int _7579,    std::shared_ptr< monty::ndarray< int,1 > > _7580,    std::shared_ptr< monty::ndarray< int,1 > > _7581,    std::shared_ptr< monty::ndarray< double,1 > > _7582,    std::shared_ptr< monty::ndarray< int,1 > > _7583,    std::shared_ptr< monty::ndarray< int,1 > > _7584,    std::shared_ptr< monty::ndarray< double,1 > > _7585,    double _7586){ return new mosek::fusion::SymmetricMatrix(_7578,_7579,_7580,_7581,_7582,_7583,_7584,_7585,_7586); }mosek::fusion::SymmetricMatrix::SymmetricMatrix  (int _7578,    int _7579,    std::shared_ptr< monty::ndarray< int,1 > > _7580,    std::shared_ptr< monty::ndarray< int,1 > > _7581,    std::shared_ptr< monty::ndarray< double,1 > > _7582,    std::shared_ptr< monty::ndarray< int,1 > > _7583,    std::shared_ptr< monty::ndarray< int,1 > > _7584,    std::shared_ptr< monty::ndarray< double,1 > > _7585,    double _7586) :    SymmetricMatrix(new mosek::fusion::p_SymmetricMatrix(this)){ mosek::fusion::p_SymmetricMatrix::_get_impl(this)->_initialize(_7578,_7579,_7580,_7581,_7582,_7583,_7584,_7585,_7586); }void mosek::fusion::p_SymmetricMatrix::_initialize  (int _7578,    int _7579,    std::shared_ptr< monty::ndarray< int,1 > > _7580,    std::shared_ptr< monty::ndarray< int,1 > > _7581,    std::shared_ptr< monty::ndarray< double,1 > > _7582,    std::shared_ptr< monty::ndarray< int,1 > > _7583,    std::shared_ptr< monty::ndarray< int,1 > > _7584,    std::shared_ptr< monty::ndarray< double,1 > > _7585,    double _7586){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__7580(_7580 ? _7580->raw() : nullptr, _7580 ? _7580->size(0) : 0);
    _checked_ptr_1<int> _ptr__7581(_7581 ? _7581->raw() : nullptr, _7581 ? _7581->size(0) : 0);
    _checked_ptr_1<double> _ptr__7582(_7582 ? _7582->raw() : nullptr, _7582 ? _7582->size(0) : 0);
    _checked_ptr_1<int> _ptr__7583(_7583 ? _7583->raw() : nullptr, _7583 ? _7583->size(0) : 0);
    _checked_ptr_1<int> _ptr__7584(_7584 ? _7584->raw() : nullptr, _7584 ? _7584->size(0) : 0);
    _checked_ptr_1<double> _ptr__7585(_7585 ? _7585->raw() : nullptr, _7585 ? _7585->size(0) : 0);
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d0 = _7578;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->d1 = _7579;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubi = _7580;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->usubj = _7581;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->uval = _7582;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubi = _7583;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vsubj = _7584;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->vval = _7585;
    mosek::fusion::p_SymmetricMatrix::_get_impl(::mosek::fusion::SymmetricMatrix::t(_pubthis))->scale = _7586;
    nnz = (-(int)1);
  }
}monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( int _7587,    std::shared_ptr< monty::ndarray< int,1 > > _7588,    std::shared_ptr< monty::ndarray< double,1 > > _7589) { return mosek::fusion::p_SymmetricMatrix::rankOne(_7587,_7588,_7589); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(int _7587,std::shared_ptr< monty::ndarray< int,1 > > _7588,std::shared_ptr< monty::ndarray< double,1 > > _7589){
  _checked_ptr_1<int> _ptr__7588(_7588 ? _7588->raw() : nullptr, _7588 ? _7588->size(0) : 0);
  _checked_ptr_1<double> _ptr__7589(_7589 ? _7589->raw() : nullptr, _7589 ? _7589->size(0) : 0);
  if (((int)((_7588)->size(0)) != (int)((_7589)->size(0))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Mismatching array lengths"));
    }
  }
  {}
  int _12178 = (int)0;
  int _12179 = (int)((_7588)->size(0));
  for (int _7590 = _12178; _7590 < _12179; ++_7590)
  {
    {
      if (((_ptr__7588[_7590] < (int)0) || (_ptr__7588[_7590] >= _7587)))
      {
        {
          throw ::mosek::fusion::LengthError(std::string ("Invalid index in argument 'sub'"));
        }
      }
      {}
    }
  }
  std::vector<int> _12180;
  for (int _7592 = (int)0, _12181 = (int)((_7588)->size(0)); _7592 < _12181 ; ++_7592)
  {
    _12180.push_back(_ptr__7588[_7592]);
  }
  auto _12182 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12180.size()),_12180.begin(),_12180.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7591 = _12182;
  _checked_ptr_1<int> _ptr__7591(_7591 ? _7591->raw() : nullptr,_7591 ? _7591->size(0) : 0);
  std::vector<int> _12183;
  for (int _7594 = (int)0, _12184 = (int)((_7588)->size(0)); _7594 < _12184 ; ++_7594)
  {
    _12183.push_back((int)1);
  }
  auto _12185 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12183.size()),_12183.begin(),_12183.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7593 = _12185;
  _checked_ptr_1<int> _ptr__7593(_7593 ? _7593->raw() : nullptr,_7593 ? _7593->size(0) : 0);
  std::vector<double> _12186;
  for (int _7596 = (int)0, _12187 = (int)((_7589)->size(0)); _7596 < _12187 ; ++_7596)
  {
    _12186.push_back(_ptr__7589[_7596]);
  }
  auto _12188 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12186.size()),_12186.begin(),_12186.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _7595 = _12188;
  _checked_ptr_1<double> _ptr__7595(_7595 ? _7595->raw() : nullptr,_7595 ? _7595->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_7587,(int)1,_7591,_7593,_7595,_7591,_7593,_7595,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::rankOne  ( std::shared_ptr< monty::ndarray< double,1 > > _7597) { return mosek::fusion::p_SymmetricMatrix::rankOne(_7597); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::rankOne(std::shared_ptr< monty::ndarray< double,1 > > _7597){
  _checked_ptr_1<double> _ptr__7597(_7597 ? _7597->raw() : nullptr, _7597 ? _7597->size(0) : 0);
  int _7598 = (int)((_7597)->size(0));
  std::vector<int> _12189;
  for (int _7600 = (int)0, _12190 = _7598; _7600 < _12190 ; ++_7600)
  {
    _12189.push_back(_7600);
  }
  auto _12191 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12189.size()),_12189.begin(),_12189.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7599 = _12191;
  _checked_ptr_1<int> _ptr__7599(_7599 ? _7599->raw() : nullptr,_7599 ? _7599->size(0) : 0);
  std::vector<int> _12192;
  for (int _7602 = (int)0, _12193 = _7598; _7602 < _12193 ; ++_7602)
  {
    _12192.push_back((int)1);
  }
  auto _12194 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12192.size()),_12192.begin(),_12192.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7601 = _12194;
  _checked_ptr_1<int> _ptr__7601(_7601 ? _7601->raw() : nullptr,_7601 ? _7601->size(0) : 0);
  std::vector<double> _12195;
  for (int _7604 = (int)0, _12196 = _7598; _7604 < _12196 ; ++_7604)
  {
    _12195.push_back(_ptr__7597[_7604]);
  }
  auto _12197 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12195.size()),_12195.begin(),_12195.end()));
  std::shared_ptr< monty::ndarray< double,1 > > _7603 = _12197;
  _checked_ptr_1<double> _ptr__7603(_7603 ? _7603->raw() : nullptr,_7603 ? _7603->size(0) : 0);
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_7598,(int)1,_7599,_7601,_7603,_7599,_7601,_7603,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::antiDiag  ( std::shared_ptr< monty::ndarray< double,1 > > _7605) { return mosek::fusion::p_SymmetricMatrix::antiDiag(_7605); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _7605){
  _checked_ptr_1<double> _ptr__7605(_7605 ? _7605->raw() : nullptr, _7605 ? _7605->size(0) : 0);
  int _7606 = (int)((_7605)->size(0));
  std::vector<int> _12198;
  for (int _7608 = (int)0, _12199 = _7606; _7608 < _12199 ; ++_7608)
  {
    _12198.push_back(_7608);
  }
  auto _12200 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12198.size()),_12198.begin(),_12198.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7607 = _12200;
  _checked_ptr_1<int> _ptr__7607(_7607 ? _7607->raw() : nullptr,_7607 ? _7607->size(0) : 0);
  std::vector<int> _12201;
  for (int _7609 = (int)0, _12202 = _7606; _7609 < _12202 ; ++_7609)
  {
    _12201.push_back((_7606 - _7609));
  }
  auto _12203 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12201.size()),_12201.begin(),_12201.end()));
  std::vector<double> _12204;
  for (int _7610 = (int)0, _12205 = _7606; _7610 < _12205 ; ++_7610)
  {
    _12204.push_back(_ptr__7605[_7610]);
  }
  auto _12206 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12204.size()),_12204.begin(),_12204.end()));
  std::vector<double> _12207;
  for (int _7611 = (int)0, _12208 = _7606; _7611 < _12208 ; ++_7611)
  {
    _12207.push_back(1.0);
  }
  auto _12209 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12207.size()),_12207.begin(),_12207.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_7606,_7606,_7607,_12203,_12206,_7607,_7607,_12209,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _7612) { return mosek::fusion::p_SymmetricMatrix::diag(_7612); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _7612){
  _checked_ptr_1<double> _ptr__7612(_7612 ? _7612->raw() : nullptr, _7612 ? _7612->size(0) : 0);
  int _7613 = (int)((_7612)->size(0));
  std::vector<int> _12210;
  for (int _7615 = (int)0, _12211 = _7613; _7615 < _12211 ; ++_7615)
  {
    _12210.push_back(_7615);
  }
  auto _12212 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12210.size()),_12210.begin(),_12210.end()));
  std::shared_ptr< monty::ndarray< int,1 > > _7614 = _12212;
  _checked_ptr_1<int> _ptr__7614(_7614 ? _7614->raw() : nullptr,_7614 ? _7614->size(0) : 0);
  std::vector<double> _12213;
  for (int _7616 = (int)0, _12214 = _7613; _7616 < _12214 ; ++_7616)
  {
    _12213.push_back(_ptr__7612[_7616]);
  }
  auto _12215 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12213.size()),_12213.begin(),_12213.end()));
  std::vector<double> _12216;
  for (int _7617 = (int)0, _12217 = _7613; _7617 < _12217 ; ++_7617)
  {
    _12216.push_back(1.0);
  }
  auto _12218 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12216.size()),_12216.begin(),_12216.end()));
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(_7613,_7613,_7614,_7614,_12215,_7614,_7614,_12218,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7618) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__add(_7618); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7618) { return __mosek_2fusion_2SymmetricMatrix__add(_7618); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7618){
  int _7619 = _pubthis->getdim();
  if ((_7618->getdim() != _7619))
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Mismatching dimensions"));
    }
  }
  {}
  int _7620 = (int)((usubi)->size(0));
  int _7621 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->usubi)->size(0));
  int _7622 = safe_add( _7620,_7621 );
  int _7623 = (int)((vsubi)->size(0));
  int _7624 = (int)((mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->vsubi)->size(0));
  int _7625 = safe_add( _7623,_7624 );
  std::shared_ptr< monty::ndarray< double,1 > > _7626 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7625)));
  _checked_ptr_1<double> _ptr__7626(_7626 ? _7626->raw() : nullptr,_7626 ? _7626->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7627 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7625)));
  _checked_ptr_1<int> _ptr__7627(_7627 ? _7627->raw() : nullptr,_7627 ? _7627->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7628 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7625)));
  _checked_ptr_1<int> _ptr__7628(_7628 ? _7628->raw() : nullptr,_7628 ? _7628->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7629 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7622)));
  _checked_ptr_1<double> _ptr__7629(_7629 ? _7629->raw() : nullptr,_7629 ? _7629->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7630 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7622)));
  _checked_ptr_1<int> _ptr__7630(_7630 ? _7630->raw() : nullptr,_7630 ? _7630->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7631 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7622)));
  _checked_ptr_1<int> _ptr__7631(_7631 ? _7631->raw() : nullptr,_7631 ? _7631->size(0) : 0);
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_7631,(int)0,_7620);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->usubi,(int)0,_7631,_7620,_7621);
  ::mosek::fusion::Utils::Tools::arraycopy(usubj,(int)0,_7630,(int)0,_7620);
  int _12219 = (int)0;
  int _12220 = _7621;
  for (int _7632 = _12219; _7632 < _12220; ++_7632)
  {
    {
      _ptr__7630[safe_add( _7632,_7620 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->usubj)(_7632)),d1 );
    }
  }
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(uval,(int)0,_7629,(int)0,_7620);
    }
  }
  else
  {
    {
      int _12221 = (int)0;
      int _12222 = _7620;
      for (int _7633 = _12221; _7633 < _12222; ++_7633)
      {
        {
          _ptr__7629[_7633] = (scale * ((*uval)(_7633)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->uval,(int)0,_7629,_7620,_7621);
    }
  }
  else
  {
    {
      int _12223 = (int)0;
      int _12224 = _7621;
      for (int _7634 = _12223; _7634 < _12224; ++_7634)
      {
        {
          _ptr__7629[safe_add( _7634,_7620 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->uval)(_7634)));
        }
      }
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(usubi,(int)0,_7631,(int)0,_7620);
  int _12225 = (int)0;
  int _12226 = _7624;
  for (int _7635 = _12225; _7635 < _12226; ++_7635)
  {
    {
      _ptr__7628[safe_add( _7635,_7623 )] = safe_add( ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->vsubi)(_7635)),mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->d1 );
    }
  }
  ::mosek::fusion::Utils::Tools::arraycopy(vsubj,(int)0,_7627,(int)0,_7623);
  ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->vsubj,_7623,_7627,_7623,_7624);
  if (((scale > 1.0) || (scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(vval,(int)0,_7626,(int)0,_7623);
    }
  }
  else
  {
    {
      int _12227 = (int)0;
      int _12228 = _7623;
      for (int _7636 = _12227; _7636 < _12228; ++_7636)
      {
        {
          _ptr__7626[_7636] = (scale * ((*vval)(_7636)));
        }
      }
    }
  }
  if (((mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->scale > 1.0) || (mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->scale < 1.0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->vval,(int)0,_7626,_7623,_7624);
    }
  }
  else
  {
    {
      int _12229 = (int)0;
      int _12230 = _7624;
      for (int _7637 = _12229; _7637 < _12230; ++_7637)
      {
        {
          _ptr__7626[safe_add( _7637,_7623 )] = (mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->scale * ((*mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->vval)(_7637)));
        }
      }
    }
  }
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,safe_add( d1,mosek::fusion::p_SymmetricMatrix::_get_impl(_7618)->d1 ),_7631,_7630,_7629,_7628,_7627,_7626,1.0);
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7638) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__sub(_7638); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7638) { return __mosek_2fusion_2SymmetricMatrix__sub(_7638); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7638){
  return _pubthis->__mosek_2fusion_2SymmetricMatrix__add(_7638->__mosek_2fusion_2SymmetricMatrix__mul((-1.0)));
}
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix :: __mosek_2fusion_2SymmetricMatrix__mul(double _7639) { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->__mosek_2fusion_2SymmetricMatrix__mul(_7639); }monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::SymmetricMatrix::mul(double _7639) { return __mosek_2fusion_2SymmetricMatrix__mul(_7639); }
monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > mosek::fusion::p_SymmetricMatrix::__mosek_2fusion_2SymmetricMatrix__mul(double _7639){
  return ::mosek::fusion::p_SymmetricMatrix::_new_SymmetricMatrix(d0,d1,usubi,usubj,uval,vsubi,vsubj,vval,(scale * _7639));
}
int mosek::fusion::SymmetricMatrix :: getdim() { return mosek::fusion::p_SymmetricMatrix::_get_impl(this)->getdim(); }int mosek::fusion::p_SymmetricMatrix::getdim(){
  return d0;
}
void mosek::fusion::p_SymmetricMatrix::destroy(){vval.reset();vsubj.reset();vsubi.reset();uval.reset();usubj.reset();usubi.reset();}void mosek::fusion::SymmetricMatrix::destroy() { mosek::fusion::p_SymmetricMatrix::_get_impl(this)->destroy(); }mosek::fusion::NDSparseArray::NDSparseArray(mosek::fusion::p_NDSparseArray *_impl) : _impl(_impl) { /*std::cout << "NDSparseArray() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::NDSparseArray::~NDSparseArray() { delete _impl; _impl = nullptr; }mosek::fusion::p_NDSparseArray::p_NDSparseArray  (::mosek::fusion::NDSparseArray * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _7640,    std::shared_ptr< monty::ndarray< int,2 > > _7641,    std::shared_ptr< monty::ndarray< double,1 > > _7642){ return new mosek::fusion::NDSparseArray(_7640,_7641,_7642); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _7640,    std::shared_ptr< monty::ndarray< int,2 > > _7641,    std::shared_ptr< monty::ndarray< double,1 > > _7642) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_7640,_7641,_7642); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _7640,    std::shared_ptr< monty::ndarray< int,2 > > _7641,    std::shared_ptr< monty::ndarray< double,1 > > _7642){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__7640(_7640 ? _7640->raw() : nullptr, _7640 ? _7640->size(0) : 0);
    _checked_ptr_1<double> _ptr__7642(_7642 ? _7642->raw() : nullptr, _7642 ? _7642->size(0) : 0);
    std::shared_ptr< monty::ndarray< long long,1 > > _7643 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape((int)((_7641)->size(0)))));
    _checked_ptr_1<long long> _ptr__7643(_7643 ? _7643->raw() : nullptr,_7643 ? _7643->size(0) : 0);
    size = (long long)1;
    int _12231 = (int)0;
    int _12232 = (int)((_7640)->size(0));
    for (int _7644 = _12231; _7644 < _12232; ++_7644)
    {
      {
        size = safe_mul( size,_ptr__7640[_7644] );
      }
    }
    int _7645 = (int)((_7640)->size(0));
    if (((int)((_7641)->size(0)) != (int)((_7642)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    if (((int)((_7641)->size(1)) != _7645))
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index key in sub has wrong length"));
      }
    }
    {}
    bool _7646 = false;
    int _12233 = (int)0;
    int _12234 = (int)((_7641)->size(0));
    for (int _7647 = _12233; _7647 < _12234; ++_7647)
    {
      {
        int _12235 = (int)0;
        int _12236 = (int)((_7641)->size(1));
        for (int _7648 = _12235; _7648 < _12236; ++_7648)
        {
          {
            if (((((*_7641)(_7647,_7648)) < (int)0) || (((*_7641)(_7647,_7648)) >= _ptr__7640[_7648])))
            {
              {
                _7646 = true;
              }
            }
            {}
          }
        }
      }
    }
    if (_7646)
    {
      {
        throw ::mosek::fusion::IndexError(std::string ("An index in sub is out of bounds"));
      }
    }
    {}
    int _12237 = (int)0;
    int _12238 = (int)((_7641)->size(0));
    for (int _7649 = _12237; _7649 < _12238; ++_7649)
    {
      {
        long long _7650 = (long long)0;
        int _12239 = (int)0;
        int _12240 = (int)((_7641)->size(1));
        for (int _7651 = _12239; _7651 < _12240; ++_7651)
        {
          {
            _7650 = safe_add( safe_mul( _7650,_ptr__7640[_7651] ),((*_7641)(_7649,_7651)) );
          }
        }
        _ptr__7643[_7649] = _7650;
      }
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_7640);
    bool _7652 = true;
    int _12241 = (int)1;
    int _12242 = (int)((_7643)->size(0));
    for (int _7653 = _12241; _7653 < _12242; ++_7653)
    {
      {
        _7652 = (_7652 && (_ptr__7643[_7653] >= _ptr__7643[(_7653 - (int)1)]));
      }
    }
    if (_7652)
    {
      {
        int _7654 = (int)1;
        int _12243 = (int)1;
        int _12244 = (int)((_7643)->size(0));
        for (int _7655 = _12243; _7655 < _12244; ++_7655)
        {
          {
            if ((_ptr__7643[(_7655 - (int)1)] < _ptr__7643[_7655]))
            {
              {
                ++ _7654;
              }
            }
            {}
          }
        }
        if ((_7654 == (int)((_7643)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_7643);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_7642);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7654)));
            ((*inst)((int)0)) = _ptr__7643[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7654)));
            ((*cof)((int)0)) = _ptr__7642[(int)0];
            int _7656 = (int)0;
            int _12245 = (int)1;
            int _12246 = (int)((_7643)->size(0));
            for (int _7657 = _12245; _7657 < _12246; ++_7657)
            {
              {
                if ((_ptr__7643[_7657] > _ptr__7643[(_7657 - (int)1)]))
                {
                  {
                    ++ _7656;
                    ((*inst)(_7656)) = _ptr__7643[_7657];
                    ((*cof)(_7656)) = _ptr__7642[_7657];
                  }
                }
                else
                {
                  {
                    ((*cof)(_7656)) = (((*cof)(_7656)) + _ptr__7642[_7657]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _7658 = ::mosek::fusion::Utils::Tools::range((long long)((_7643)->size(0)));
        _checked_ptr_1<long long> _ptr__7658(_7658 ? _7658->raw() : nullptr,_7658 ? _7658->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_7658,_7643,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_7643)->size(0)));
        int _7659 = (int)1;
        int _12247 = (int)1;
        int _12248 = (int)((_7643)->size(0));
        for (int _7660 = _12247; _7660 < _12248; ++_7660)
        {
          {
            if ((_ptr__7643[_ptr__7658[(_7660 - (int)1)]] < _ptr__7643[_ptr__7658[_7660]]))
            {
              {
                ++ _7659;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7659)));
        ((*inst)((int)0)) = _ptr__7643[_ptr__7658[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7659)));
        ((*cof)((int)0)) = _ptr__7642[_ptr__7658[(int)0]];
        int _7661 = (int)0;
        int _12249 = (int)1;
        int _12250 = (int)((_7643)->size(0));
        for (int _7662 = _12249; _7662 < _12250; ++_7662)
        {
          {
            if ((_ptr__7643[_ptr__7658[_7662]] > _ptr__7643[_ptr__7658[(_7662 - (int)1)]]))
            {
              {
                ++ _7661;
                ((*inst)(_7661)) = _ptr__7643[_ptr__7658[_7662]];
                ((*cof)(_7661)) = _ptr__7642[_ptr__7658[_7662]];
              }
            }
            else
            {
              {
                ((*cof)(_7661)) = (((*cof)(_7661)) + _ptr__7642[_ptr__7658[_7662]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _7663,    std::shared_ptr< monty::ndarray< long long,1 > > _7664,    std::shared_ptr< monty::ndarray< double,1 > > _7665){ return new mosek::fusion::NDSparseArray(_7663,_7664,_7665); }mosek::fusion::NDSparseArray::NDSparseArray  (std::shared_ptr< monty::ndarray< int,1 > > _7663,    std::shared_ptr< monty::ndarray< long long,1 > > _7664,    std::shared_ptr< monty::ndarray< double,1 > > _7665) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_7663,_7664,_7665); }void mosek::fusion::p_NDSparseArray::_initialize  (std::shared_ptr< monty::ndarray< int,1 > > _7663,    std::shared_ptr< monty::ndarray< long long,1 > > _7664,    std::shared_ptr< monty::ndarray< double,1 > > _7665){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__7663(_7663 ? _7663->raw() : nullptr, _7663 ? _7663->size(0) : 0);
    _checked_ptr_1<long long> _ptr__7664(_7664 ? _7664->raw() : nullptr, _7664 ? _7664->size(0) : 0);
    _checked_ptr_1<double> _ptr__7665(_7665 ? _7665->raw() : nullptr, _7665 ? _7665->size(0) : 0);
    size = (long long)1;
    int _12251 = (int)0;
    int _12252 = (int)((_7663)->size(0));
    for (int _7666 = _12251; _7666 < _12252; ++_7666)
    {
      {
        size = safe_mul( size,_ptr__7663[_7666] );
      }
    }
    int _7667 = (int)((_7664)->size(0));
    if ((_7667 != (int)((_7665)->size(0))))
    {
      {
        throw ::mosek::fusion::LengthError(std::string ("Mismatching data array length"));
      }
    }
    {}
    {
      bool _7668 = false;
      int _12253 = (int)0;
      int _12254 = _7667;
      for (int _7669 = _12253; _7669 < _12254; ++_7669)
      {
        {
          _7668 = (_7668 || ((_ptr__7664[_7669] < (int)0) || (_ptr__7664[_7669] >= size)));
        }
      }
      if (_7668)
      {
        {
          throw ::mosek::fusion::IndexError(std::string ("An index in inst is out of bounds"));
        }
      }
      {}
    }
    dims = ::mosek::fusion::Utils::Tools::arraycopy(_7663);
    bool _7670 = true;
    int _12255 = (int)1;
    int _12256 = (int)((_7664)->size(0));
    for (int _7671 = _12255; _7671 < _12256; ++_7671)
    {
      {
        _7670 = (_7670 && (_ptr__7664[_7671] >= _ptr__7664[(_7671 - (int)1)]));
      }
    }
    if (_7670)
    {
      {
        int _7672 = (int)1;
        int _12257 = (int)1;
        int _12258 = (int)((_7664)->size(0));
        for (int _7673 = _12257; _7673 < _12258; ++_7673)
        {
          {
            if ((_ptr__7664[(_7673 - (int)1)] < _ptr__7664[_7673]))
            {
              {
                ++ _7672;
              }
            }
            {}
          }
        }
        if ((_7672 == (int)((_7664)->size(0))))
        {
          {
            inst = ::mosek::fusion::Utils::Tools::arraycopy(_7664);
            cof = ::mosek::fusion::Utils::Tools::arraycopy(_7665);
          }
        }
        else
        {
          {
            inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7672)));
            ((*inst)((int)0)) = _ptr__7664[(int)0];
            cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7672)));
            ((*cof)((int)0)) = _ptr__7665[(int)0];
            int _7674 = (int)0;
            int _12259 = (int)1;
            int _12260 = (int)((_7664)->size(0));
            for (int _7675 = _12259; _7675 < _12260; ++_7675)
            {
              {
                if ((_ptr__7664[_7675] > _ptr__7664[(_7675 - (int)1)]))
                {
                  {
                    ++ _7674;
                    ((*inst)(_7674)) = _ptr__7664[_7675];
                    ((*cof)(_7674)) = _ptr__7665[_7675];
                  }
                }
                else
                {
                  {
                    ((*cof)(_7674)) = (((*cof)(_7674)) + _ptr__7665[_7675]);
                  }
                }
              }
            }
          }
        }
      }
    }
    else
    {
      {
        std::shared_ptr< monty::ndarray< long long,1 > > _7676 = ::mosek::fusion::Utils::Tools::range((long long)((_7664)->size(0)));
        _checked_ptr_1<long long> _ptr__7676(_7676 ? _7676->raw() : nullptr,_7676 ? _7676->size(0) : 0);
        ::mosek::fusion::p_CommonTools::argQsort(_7676,_7664,std::shared_ptr< monty::ndarray< long long,1 > >(nullptr),(long long)0,(long long)((_7664)->size(0)));
        int _7677 = (int)1;
        int _12261 = (int)1;
        int _12262 = (int)((_7664)->size(0));
        for (int _7678 = _12261; _7678 < _12262; ++_7678)
        {
          {
            if ((_ptr__7664[_ptr__7676[(_7678 - (int)1)]] < _ptr__7664[_ptr__7676[_7678]]))
            {
              {
                ++ _7677;
              }
            }
            {}
          }
        }
        inst = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_7677)));
        ((*inst)((int)0)) = _ptr__7664[_ptr__7676[(int)0]];
        cof = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7677)));
        ((*cof)((int)0)) = _ptr__7665[_ptr__7676[(int)0]];
        int _7679 = (int)0;
        int _12263 = (int)1;
        int _12264 = (int)((_7664)->size(0));
        for (int _7680 = _12263; _7680 < _12264; ++_7680)
        {
          {
            if ((_ptr__7664[_ptr__7676[_7680]] > ((*inst)(_ptr__7676[(_7680 - (int)1)]))))
            {
              {
                ++ _7679;
                ((*inst)(_7679)) = _ptr__7664[_ptr__7676[_7680]];
                ((*cof)(_7679)) = _ptr__7665[_ptr__7676[_7680]];
              }
            }
            else
            {
              {
                ((*cof)(_7679)) = (((*cof)(_7679)) + _ptr__7665[_ptr__7676[_7680]]);
              }
            }
          }
        }
      }
    }
  }
}mosek::fusion::NDSparseArray::t mosek::fusion::p_NDSparseArray::_new_NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _7681){ return new mosek::fusion::NDSparseArray(_7681); }mosek::fusion::NDSparseArray::NDSparseArray  (monty::rc_ptr< ::mosek::fusion::Matrix > _7681) :    NDSparseArray(new mosek::fusion::p_NDSparseArray(this)){ mosek::fusion::p_NDSparseArray::_get_impl(this)->_initialize(_7681); }void mosek::fusion::p_NDSparseArray::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _7681){monty::rc_reserve __reserve_this(_pubthis);   {
    long long _7682 = _7681->numNonzeros();
    int _7683 = _7681->numColumns();
    int _7684 = _7681->numRows();
    std::shared_ptr< monty::ndarray< double,1 > > _7685 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7682)));
    _checked_ptr_1<double> _ptr__7685(_7685 ? _7685->raw() : nullptr,_7685 ? _7685->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _7686 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7682)));
    _checked_ptr_1<int> _ptr__7686(_7686 ? _7686->raw() : nullptr,_7686 ? _7686->size(0) : 0);
    std::shared_ptr< monty::ndarray< int,1 > > _7687 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7682)));
    _checked_ptr_1<int> _ptr__7687(_7687 ? _7687->raw() : nullptr,_7687 ? _7687->size(0) : 0);
    _7681->getDataAsTriplets(_7687,_7686,_7685);
    size = safe_mul( (long long)_7681->numRows(),(long long)_7681->numColumns() );
    dims = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >{(int)(_7684),(int)(_7683)});
    std::vector<long long> _12265;
    for (long long _7688 = (long long)0, _12266 = _7682; _7688 < _12266 ; ++_7688)
    {
      _12265.push_back(safe_add( safe_mul( (long long)_ptr__7687[_7688],_7683 ),(long long)_ptr__7686[_7688] ));
    }
    auto _12267 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(_12265.size()),_12265.begin(),_12265.end()));
    inst = _12267;
    cof = _7685;
  }
}monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7689) { return mosek::fusion::p_NDSparseArray::make(_7689); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(monty::rc_ptr< ::mosek::fusion::Matrix > _7689){
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_7689);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _7690,    std::shared_ptr< monty::ndarray< long long,1 > > _7691,    std::shared_ptr< monty::ndarray< double,1 > > _7692) { return mosek::fusion::p_NDSparseArray::make(_7690,_7691,_7692); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _7690,std::shared_ptr< monty::ndarray< long long,1 > > _7691,std::shared_ptr< monty::ndarray< double,1 > > _7692){
  _checked_ptr_1<int> _ptr__7690(_7690 ? _7690->raw() : nullptr, _7690 ? _7690->size(0) : 0);
  _checked_ptr_1<long long> _ptr__7691(_7691 ? _7691->raw() : nullptr, _7691 ? _7691->size(0) : 0);
  _checked_ptr_1<double> _ptr__7692(_7692 ? _7692->raw() : nullptr, _7692 ? _7692->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_7690,_7691,_7692);
}
monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::NDSparseArray::make  ( std::shared_ptr< monty::ndarray< int,1 > > _7693,    std::shared_ptr< monty::ndarray< int,2 > > _7694,    std::shared_ptr< monty::ndarray< double,1 > > _7695) { return mosek::fusion::p_NDSparseArray::make(_7693,_7694,_7695); }monty::rc_ptr< ::mosek::fusion::NDSparseArray > mosek::fusion::p_NDSparseArray::make(std::shared_ptr< monty::ndarray< int,1 > > _7693,std::shared_ptr< monty::ndarray< int,2 > > _7694,std::shared_ptr< monty::ndarray< double,1 > > _7695){
  _checked_ptr_1<int> _ptr__7693(_7693 ? _7693->raw() : nullptr, _7693 ? _7693->size(0) : 0);
  _checked_ptr_1<double> _ptr__7695(_7695 ? _7695->raw() : nullptr, _7695 ? _7695->size(0) : 0);
  return ::mosek::fusion::p_NDSparseArray::_new_NDSparseArray(_7693,_7694,_7695);
}
void mosek::fusion::p_NDSparseArray::destroy(){cof.reset();inst.reset();dims.reset();}void mosek::fusion::NDSparseArray::destroy() { mosek::fusion::p_NDSparseArray::_get_impl(this)->destroy(); }mosek::fusion::DenseMatrix::DenseMatrix(mosek::fusion::p_DenseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "DenseMatrix()" << this << std::endl; */ }mosek::fusion::DenseMatrix::~DenseMatrix() {  /* std::cout << "~DenseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_DenseMatrix::p_DenseMatrix  (::mosek::fusion::DenseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _7696,    int _7697,    std::shared_ptr< monty::ndarray< double,1 > > _7698){ return new mosek::fusion::DenseMatrix(_7696,_7697,_7698); }mosek::fusion::DenseMatrix::DenseMatrix  (int _7696,    int _7697,    std::shared_ptr< monty::ndarray< double,1 > > _7698) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_7696,_7697,_7698); }void mosek::fusion::p_DenseMatrix::_initialize  (int _7696,    int _7697,    std::shared_ptr< monty::ndarray< double,1 > > _7698){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<double> _ptr__7698(_7698 ? _7698->raw() : nullptr, _7698 ? _7698->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_7696,_7697);
    nnz = (long long)safe_mul( _7696,_7697 );
    data = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( _7696,_7697 ))));
    ::mosek::fusion::Utils::Tools::arraycopy(_7698,(int)0,data,(int)0,safe_mul( _7696,_7697 ));
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _7699){ return new mosek::fusion::DenseMatrix(_7699); }mosek::fusion::DenseMatrix::DenseMatrix  (monty::rc_ptr< ::mosek::fusion::Matrix > _7699) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_7699); }void mosek::fusion::p_DenseMatrix::_initialize  (monty::rc_ptr< ::mosek::fusion::Matrix > _7699){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(mosek::fusion::p_Matrix::_get_impl(_7699)->dimi,mosek::fusion::p_Matrix::_get_impl(_7699)->dimj);
    monty::rc_ptr< ::mosek::fusion::Matrix > _12268 = _7699;
    if (false) {}
    else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_12268.get()))
    {
      ::mosek::fusion::DenseMatrix::t _7700 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_12268.get()));
      {
        data = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_DenseMatrix::_get_impl(_7700)->data);
      }
    }
    else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_12268.get()))
    {
      ::mosek::fusion::SparseMatrix::t _7701 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_12268.get()));
      {
        data = ::mosek::fusion::Utils::Tools::zeros(safe_mul( mosek::fusion::p_Matrix::_get_impl(_7701)->dimi,mosek::fusion::p_Matrix::_get_impl(_7701)->dimj ));
        long long _12269 = (long long)0;
        long long _12270 = mosek::fusion::p_SparseMatrix::_get_impl(_7701)->nnz;
        for (long long _7703 = _12269; _7703 < _12270; ++_7703)
        {
          {
            ((*data)(safe_add( safe_mul( ((*mosek::fusion::p_SparseMatrix::_get_impl(_7701)->subi)(_7703)),dimj ),((*mosek::fusion::p_SparseMatrix::_get_impl(_7701)->subj)(_7703)) ))) = ((*mosek::fusion::p_SparseMatrix::_get_impl(_7701)->val)(_7703));
          }
        }
      }
    }
    else
    {
      mosek::fusion::Matrix::t _7702 = _12268;
      {
        throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
      }
    }
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _7704){ return new mosek::fusion::DenseMatrix(_7704); }mosek::fusion::DenseMatrix::DenseMatrix  (std::shared_ptr< monty::ndarray< double,2 > > _7704) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_7704); }void mosek::fusion::p_DenseMatrix::_initialize  (std::shared_ptr< monty::ndarray< double,2 > > _7704){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize((int)((_7704)->size(0)),(int)((_7704)->size(1)));
    std::vector<double> _12271;
    for (int _7705 = (int)0, _12272 = dimi; _7705 < _12272 ; ++_7705)
    {
      for (int _7706 = (int)0, _12273 = dimj; _7706 < _12273 ; ++_7706)
      {
        _12271.push_back(((*_7704)(_7705,_7706)));
      }
    }
    auto _12274 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12271.size()),_12271.begin(),_12271.end()));
    data = _12274;
    nnz = (long long)safe_mul( dimi,dimj );
  }
}mosek::fusion::DenseMatrix::t mosek::fusion::p_DenseMatrix::_new_DenseMatrix  (int _7707,    int _7708,    double _7709){ return new mosek::fusion::DenseMatrix(_7707,_7708,_7709); }mosek::fusion::DenseMatrix::DenseMatrix  (int _7707,    int _7708,    double _7709) :    DenseMatrix(new mosek::fusion::p_DenseMatrix(this)){ mosek::fusion::p_DenseMatrix::_get_impl(this)->_initialize(_7707,_7708,_7709); }void mosek::fusion::p_DenseMatrix::_initialize  (int _7707,    int _7708,    double _7709){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_Matrix::_initialize(_7707,_7708);
    std::vector<double> _12275;
    for (int _7710 = (int)0, _12276 = _7707; _7710 < _12276 ; ++_7710)
    {
      for (int _7711 = (int)0, _12277 = _7708; _7711 < _12277 ; ++_7711)
      {
        _12275.push_back(_7709);
      }
    }
    auto _12278 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12275.size()),_12275.begin(),_12275.end()));
    data = _12278;
    nnz = (long long)safe_mul( _7707,_7708 );
  }
}std::string mosek::fusion::DenseMatrix :: toString() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_DenseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _7712 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("DenseMatrix("));
  _7712->__mosek_2fusion_2Utils_2StringBuffer__a(dimi);
  _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
  _7712->__mosek_2fusion_2Utils_2StringBuffer__a(dimj);
  _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (": "));
  int _7713 = (int)0;
  {
    int _7714 = (int)0;
    for(;(_7714 < dimi);++ _7714)
    {
      {
        if ((_7714 > (int)0))
        {
          {
            _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
          }
        }
        {}
        _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("[ "));
        _7712->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_7713)));
        ++ _7713;
        {
          int _7715 = (int)1;
          for(;(_7715 < dimj);++ _7715)
          {
            {
              _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","));
              _7712->__mosek_2fusion_2Utils_2StringBuffer__a(((*data)(_7713)));
              ++ _7713;
            }
          }
        }
        _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ]"));
      }
    }
  }
  _7712->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
  return _7712->toString();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix :: __mosek_2fusion_2DenseMatrix__transpose() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->__mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::DenseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_DenseMatrix::__mosek_2fusion_2DenseMatrix__transpose(){
  std::shared_ptr< monty::ndarray< double,1 > > _7716 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__7716(_7716 ? _7716->raw() : nullptr,_7716 ? _7716->size(0) : 0);
  int _7717 = (int)0;
  int _7718 = dimi;
  int _12279 = (int)0;
  int _12280 = dimi;
  for (int _7719 = _12279; _7719 < _12280; ++_7719)
  {
    {
      int _7720 = _7719;
      int _12281 = (int)0;
      int _12282 = dimj;
      for (int _7721 = _12281; _7721 < _12282; ++_7721)
      {
        {
          _ptr__7716[_7720] = ((*data)(_7717));
          _7720 = safe_add( _7720,_7718 );
          ++ _7717;
        }
      }
    }
  }
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(dimj,dimi,_7716)).as<::mosek::fusion::Matrix>();
}
bool mosek::fusion::DenseMatrix :: isSparse() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_DenseMatrix::isSparse(){
  return false;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::DenseMatrix :: getDataAsArray() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_DenseMatrix::getDataAsArray(){
  return ::mosek::fusion::Utils::Tools::arraycopy(data);
}
void mosek::fusion::DenseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _7722,std::shared_ptr< monty::ndarray< int,1 > > _7723,std::shared_ptr< monty::ndarray< double,1 > > _7724) { mosek::fusion::p_DenseMatrix::_get_impl(this)->getDataAsTriplets(_7722,_7723,_7724); }void mosek::fusion::p_DenseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _7722,std::shared_ptr< monty::ndarray< int,1 > > _7723,std::shared_ptr< monty::ndarray< double,1 > > _7724){
  _checked_ptr_1<int> _ptr__7722(_7722 ? _7722->raw() : nullptr, _7722 ? _7722->size(0) : 0);
  _checked_ptr_1<int> _ptr__7723(_7723 ? _7723->raw() : nullptr, _7723 ? _7723->size(0) : 0);
  _checked_ptr_1<double> _ptr__7724(_7724 ? _7724->raw() : nullptr, _7724 ? _7724->size(0) : 0);
  if ((((int)((_7722)->size(0)) < nnz) || (((int)((_7723)->size(0)) < nnz) || ((int)((_7724)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  ::mosek::fusion::Utils::Tools::arraycopy(data,(int)0,_7724,(int)0,(int)((data)->size(0)));
  int _7725 = (int)0;
  int _12283 = (int)0;
  int _12284 = dimi;
  for (int _7726 = _12283; _7726 < _12284; ++_7726)
  {
    {
      int _12285 = (int)0;
      int _12286 = dimj;
      for (int _7727 = _12285; _7727 < _12286; ++_7727)
      {
        {
          _ptr__7722[_7725] = _7726;
          _ptr__7723[_7725] = _7727;
          ++ _7725;
        }
      }
    }
  }
}
double mosek::fusion::DenseMatrix :: get(int _7728,int _7729) { return mosek::fusion::p_DenseMatrix::_get_impl(this)->get(_7728,_7729); }double mosek::fusion::p_DenseMatrix::get(int _7728,int _7729){
  return ((*data)(safe_add( safe_mul( _7728,dimj ),_7729 )));
}
long long mosek::fusion::DenseMatrix :: numNonzeros() { return mosek::fusion::p_DenseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_DenseMatrix::numNonzeros(){
  return (long long)safe_mul( dimi,dimj );
}
void mosek::fusion::p_DenseMatrix::destroy(){data.reset();}void mosek::fusion::DenseMatrix::destroy() { mosek::fusion::p_DenseMatrix::_get_impl(this)->destroy(); }mosek::fusion::SparseMatrix::SparseMatrix(mosek::fusion::p_SparseMatrix *_impl) : mosek::fusion::Matrix(_impl) { /*std::cout << "SparseMatrix()" << this << std::endl; */ }mosek::fusion::SparseMatrix::~SparseMatrix() {  /* std::cout << "~SparseMatrix()" << this << std::endl << std::flush; */ }mosek::fusion::p_SparseMatrix::p_SparseMatrix  (::mosek::fusion::SparseMatrix * _pubthis) :     mosek::fusion::p_Matrix(_pubthis),    _pubthis(_pubthis){}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _7730,    int _7731,    std::shared_ptr< monty::ndarray< int,1 > > _7732,    std::shared_ptr< monty::ndarray< int,1 > > _7733,    std::shared_ptr< monty::ndarray< double,1 > > _7734,    long long _7735){ return new mosek::fusion::SparseMatrix(_7730,_7731,_7732,_7733,_7734,_7735); }mosek::fusion::SparseMatrix::SparseMatrix  (int _7730,    int _7731,    std::shared_ptr< monty::ndarray< int,1 > > _7732,    std::shared_ptr< monty::ndarray< int,1 > > _7733,    std::shared_ptr< monty::ndarray< double,1 > > _7734,    long long _7735) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_7730,_7731,_7732,_7733,_7734,_7735); }void mosek::fusion::p_SparseMatrix::_initialize  (int _7730,    int _7731,    std::shared_ptr< monty::ndarray< int,1 > > _7732,    std::shared_ptr< monty::ndarray< int,1 > > _7733,    std::shared_ptr< monty::ndarray< double,1 > > _7734,    long long _7735){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__7732(_7732 ? _7732->raw() : nullptr, _7732 ? _7732->size(0) : 0);
    _checked_ptr_1<int> _ptr__7733(_7733 ? _7733->raw() : nullptr, _7733 ? _7733->size(0) : 0);
    _checked_ptr_1<double> _ptr__7734(_7734 ? _7734->raw() : nullptr, _7734 ? _7734->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_7730,_7731);
    if ((_7735 > (int)0))
    {
      {
        if ((((int)((_7732)->size(0)) < _7735) || (((int)((_7733)->size(0)) < _7735) || ((int)((_7734)->size(0)) < _7735))))
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Mismatching arrays in sparse data."));
          }
        }
        {}
        bool _7736 = false;
        long long _12287 = (long long)0;
        long long _12288 = _7735;
        for (long long _7737 = _12287; _7737 < _12288; ++_7737)
        {
          {
            if (((_ptr__7732[_7737] < (int)0) || ((_ptr__7732[_7737] >= dimi) || ((_ptr__7733[_7737] < (int)0) || (_ptr__7733[_7737] >= dimj)))))
            {
              {
                _7736 = true;
              }
            }
            {}
          }
        }
        if (_7736)
        {
          {
            throw ::mosek::fusion::SparseFormatError(std::string ("Subscript out of bounds."));
          }
        }
        {}
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _7738 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _7739 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 >(monty::shape((int)1)));
        std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _7740 = std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > >(new monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 >(monty::shape((int)1)));
        ::mosek::fusion::p_CommonTools::tripletSort(_7732,_7733,_7734,_7738,_7739,_7740,_7735,dimi,dimj);
        subi = ((*_7738)((int)0));
        subj = ((*_7739)((int)0));
        val = ((*_7740)((int)0));
        nnz = (long long)((val)->size(0));
      }
    }
    else
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
        nnz = (long long)0;
      }
    }
  }
}mosek::fusion::SparseMatrix::t mosek::fusion::p_SparseMatrix::_new_SparseMatrix  (int _7741,    int _7742,    std::shared_ptr< monty::ndarray< int,1 > > _7743,    std::shared_ptr< monty::ndarray< int,1 > > _7744,    std::shared_ptr< monty::ndarray< double,1 > > _7745){ return new mosek::fusion::SparseMatrix(_7741,_7742,_7743,_7744,_7745); }mosek::fusion::SparseMatrix::SparseMatrix  (int _7741,    int _7742,    std::shared_ptr< monty::ndarray< int,1 > > _7743,    std::shared_ptr< monty::ndarray< int,1 > > _7744,    std::shared_ptr< monty::ndarray< double,1 > > _7745) :    SparseMatrix(new mosek::fusion::p_SparseMatrix(this)){ mosek::fusion::p_SparseMatrix::_get_impl(this)->_initialize(_7741,_7742,_7743,_7744,_7745); }void mosek::fusion::p_SparseMatrix::_initialize  (int _7741,    int _7742,    std::shared_ptr< monty::ndarray< int,1 > > _7743,    std::shared_ptr< monty::ndarray< int,1 > > _7744,    std::shared_ptr< monty::ndarray< double,1 > > _7745){monty::rc_reserve __reserve_this(_pubthis);   {
    _checked_ptr_1<int> _ptr__7743(_7743 ? _7743->raw() : nullptr, _7743 ? _7743->size(0) : 0);
    _checked_ptr_1<int> _ptr__7744(_7744 ? _7744->raw() : nullptr, _7744 ? _7744->size(0) : 0);
    _checked_ptr_1<double> _ptr__7745(_7745 ? _7745->raw() : nullptr, _7745 ? _7745->size(0) : 0);
    mosek::fusion::p_Matrix::_initialize(_7741,_7742);
    int _7746 = (int)0;
    int _12289 = (int)0;
    int _12290 = (int)((_7745)->size(0));
    for (int _7747 = _12289; _7747 < _12290; ++_7747)
    {
      {
        if (((_ptr__7745[_7747] > (int)0) || (_ptr__7745[_7747] < (int)0)))
        {
          {
            ++ _7746;
          }
        }
        {}
      }
    }
    if (((_7746 > (int)0) && (_7746 < (int)((_7743)->size(0)))))
    {
      {
        subi = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7746)));
        subj = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7746)));
        val = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7746)));
        nnz = _7746;
        int _7748 = (int)0;
        int _12291 = (int)0;
        int _12292 = (int)((_7745)->size(0));
        for (int _7749 = _12291; _7749 < _12292; ++_7749)
        {
          {
            if (((_ptr__7745[_7749] < (int)0) || (_ptr__7745[_7749] > (int)0)))
            {
              {
                ((*val)(_7748)) = _ptr__7745[_7749];
                ((*subj)(_7748)) = _ptr__7744[_7749];
                ((*subi)(_7748)) = _ptr__7743[_7749];
                ++ _7748;
              }
            }
            {}
          }
        }
      }
    }
    else
    {
      {
        subi = _7743;
        subj = _7744;
        val = _7745;
        if ((NULL == _7743.get()))
        {
          {
            nnz = (long long)0;
          }
        }
        else
        {
          {
            nnz = (long long)((subi)->size(0));
          }
        }
      }
    }
  }
}std::shared_ptr< monty::ndarray< long long,1 > > mosek::fusion::p_SparseMatrix::formPtrb(){
  std::shared_ptr< monty::ndarray< long long,1 > > _7750 = std::shared_ptr< monty::ndarray< long long,1 > >(new monty::ndarray< long long,1 >(monty::shape(safe_add( dimi,(int)1 ))));
  _checked_ptr_1<long long> _ptr__7750(_7750 ? _7750->raw() : nullptr,_7750 ? _7750->size(0) : 0);
  long long _7751 = (long long)0;
  int _12293 = (int)0;
  int _12294 = dimi;
  for (int _7752 = _12293; _7752 < _12294; ++_7752)
  {
    {
      _ptr__7750[_7752] = _7751;
      {
        for(;((_7751 < nnz) && (((*subi)(_7751)) == _7752));++ _7751)
        {
          {
          }
        }
      }
    }
  }
  _ptr__7750[dimi] = _7751;
  return _7750;
}
std::string mosek::fusion::SparseMatrix :: toString() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_SparseMatrix::toString(){
  monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _7753 = ::mosek::fusion::Utils::p_StringBuffer::_new_StringBuffer();
  _7753->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("SparseMatrix("))->__mosek_2fusion_2Utils_2StringBuffer__a(dimi)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(dimj)->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (", ["));
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      _7753->__mosek_2fusion_2Utils_2StringBuffer__a(std::string ("("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)((int)0)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
      int _12295 = (int)1;
      int _12296 = (int)((subi)->size(0));
      for (int _7754 = _12295; _7754 < _12296; ++_7754)
      {
        {
          _7753->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (",("))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subi)(_7754)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*subj)(_7754)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (","))->__mosek_2fusion_2Utils_2StringBuffer__a(((*val)(_7754)))->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (")"));
        }
      }
    }
  }
  {}
  _7753->__mosek_2fusion_2Utils_2StringBuffer__a(std::string (" ])"));
  return _7753->toString();
}
long long mosek::fusion::SparseMatrix :: numNonzeros() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->numNonzeros(); }long long mosek::fusion::p_SparseMatrix::numNonzeros(){
  return nnz;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix :: __mosek_2fusion_2SparseMatrix__transpose() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->__mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::SparseMatrix::__mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_SparseMatrix::__mosek_2fusion_2SparseMatrix__transpose(){
  return ::mosek::fusion::p_Matrix::sparse(dimj,dimi,subj,subi,val);
}
bool mosek::fusion::SparseMatrix :: isSparse() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->isSparse(); }bool mosek::fusion::p_SparseMatrix::isSparse(){
  return true;
}
std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::SparseMatrix :: getDataAsArray() { return mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsArray(); }std::shared_ptr< monty::ndarray< double,1 > > mosek::fusion::p_SparseMatrix::getDataAsArray(){
  std::shared_ptr< monty::ndarray< double,1 > > _7755 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(safe_mul( dimi,dimj ))));
  _checked_ptr_1<double> _ptr__7755(_7755 ? _7755->raw() : nullptr,_7755 ? _7755->size(0) : 0);
  int _12297 = (int)0;
  int _12298 = (int)((subi)->size(0));
  for (int _7756 = _12297; _7756 < _12298; ++_7756)
  {
    {
      _ptr__7755[safe_add( safe_mul( ((*subi)(_7756)),dimj ),((*subj)(_7756)) )] = ((*val)(_7756));
    }
  }
  return _7755;
}
void mosek::fusion::SparseMatrix :: getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _7757,std::shared_ptr< monty::ndarray< int,1 > > _7758,std::shared_ptr< monty::ndarray< double,1 > > _7759) { mosek::fusion::p_SparseMatrix::_get_impl(this)->getDataAsTriplets(_7757,_7758,_7759); }void mosek::fusion::p_SparseMatrix::getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _7757,std::shared_ptr< monty::ndarray< int,1 > > _7758,std::shared_ptr< monty::ndarray< double,1 > > _7759){
  _checked_ptr_1<int> _ptr__7757(_7757 ? _7757->raw() : nullptr, _7757 ? _7757->size(0) : 0);
  _checked_ptr_1<int> _ptr__7758(_7758 ? _7758->raw() : nullptr, _7758 ? _7758->size(0) : 0);
  _checked_ptr_1<double> _ptr__7759(_7759 ? _7759->raw() : nullptr, _7759 ? _7759->size(0) : 0);
  if ((((long long)((_7757)->size(0)) < nnz) || (((long long)((_7758)->size(0)) < nnz) || ((long long)((_7759)->size(0)) < nnz))))
  {
    {
      throw ::mosek::fusion::LengthError(std::string ("Output arrays are not long enough."));
    }
  }
  {}
  if (((NULL != subi.get()) && ((int)((subi)->size(0)) > (int)0)))
  {
    {
      ::mosek::fusion::Utils::Tools::arraycopy(subi,(long long)0,_7757,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(subj,(long long)0,_7758,(long long)0,nnz);
      ::mosek::fusion::Utils::Tools::arraycopy(val,(long long)0,_7759,(long long)0,nnz);
    }
  }
  {}
}
double mosek::fusion::SparseMatrix :: get(int _7760,int _7761) { return mosek::fusion::p_SparseMatrix::_get_impl(this)->get(_7760,_7761); }double mosek::fusion::p_SparseMatrix::get(int _7760,int _7761){
  if (((_7760 < (int)0) || ((_7760 >= dimi) || ((_7761 < (int)0) || (_7761 >= dimj)))))
  {
    {
      throw ::mosek::fusion::IndexError(std::string ("Index out if bounds"));
    }
  }
  {}
  int _7762 = (int)((subi)->size(0));
  int _7763 = (int)0;
  while ( ((_7762 - _7763) > (int)1) )
  {
    {
      int _7764 = (safe_add( _7763,_7762 ) / (int)2);
      if (((((*subi)(_7764)) < _7760) || ((((*subi)(_7764)) == _7760) && (((*subj)(_7764)) < _7761))))
      {
        {
          _7763 = _7764;
        }
      }
      else if(((((*subi)(_7764)) > _7760) || ((((*subi)(_7764)) == _7760) && (((*subj)(_7764)) > _7761))))
      {
        {
          _7762 = _7764;
        }
      }
      else
      {
        {
          return ((*val)(_7764));
        }
      }
    }
  }
  if (((((*subi)(_7763)) == _7760) && (((*subj)(_7763)) == _7761)))
  {
    {
      return ((*val)(_7763));
    }
  }
  else
  {
    {
      return 0.0;
    }
  }
}
void mosek::fusion::p_SparseMatrix::destroy(){val.reset();subj.reset();subi.reset();}void mosek::fusion::SparseMatrix::destroy() { mosek::fusion::p_SparseMatrix::_get_impl(this)->destroy(); }mosek::fusion::Matrix::Matrix(mosek::fusion::p_Matrix *_impl) : _impl(_impl) { /*std::cout << "Matrix() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Matrix::~Matrix() { delete _impl; _impl = nullptr; }mosek::fusion::p_Matrix::p_Matrix  (::mosek::fusion::Matrix * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::p_Matrix::_initialize  (int _7765,    int _7766){monty::rc_reserve __reserve_this(_pubthis);   {
    if (((_7765 < (int)0) || (_7766 < (int)0)))
    {
      {
        throw ::mosek::fusion::DimensionError(std::string ("Invalid dimensions"));
      }
    }
    {}
    dimi = _7765;
    dimj = _7766;
  }
}std::string mosek::fusion::Matrix :: toString() { return mosek::fusion::p_Matrix::_get_impl(this)->toString(); }std::string mosek::fusion::p_Matrix::toString(){
  return std::string ("");
}
void mosek::fusion::p_Matrix::switchDims(){
  int _7767 = dimi;
  dimi = dimj;
  dimj = _7767;
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _7768,    monty::rc_ptr< ::mosek::fusion::Matrix > _7769) { return mosek::fusion::p_Matrix::diag(_7768,_7769); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _7768,monty::rc_ptr< ::mosek::fusion::Matrix > _7769){
  std::vector<monty::rc_ptr< ::mosek::fusion::Matrix >> _12299;
  for (int _7770 = (int)0, _12300 = _7768; _7770 < _12300 ; ++_7770)
  {
    _12299.push_back(_7769);
  }
  auto _12301 = std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >(new monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 >(monty::shape(_12299.size()),_12299.begin(),_12299.end()));
  return ::mosek::fusion::p_Matrix::diag(_12301);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _7771) { return mosek::fusion::p_Matrix::diag(_7771); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _7771){
  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _7772 = _7771;
  long long _7773 = (long long)0;
  int _7774 = (int)0;
  int _7775 = (int)0;
  int _12302 = (int)0;
  int _12303 = (int)((_7771)->size(0));
  for (int _7776 = _12302; _7776 < _12303; ++_7776)
  {
    {
      _7775 = safe_add( _7775,mosek::fusion::p_Matrix::_get_impl(((*_7771)(_7776)))->dimi );
      _7774 = safe_add( _7774,mosek::fusion::p_Matrix::_get_impl(((*_7771)(_7776)))->dimj );
      _7773 = safe_add( _7773,((*_7771)(_7776))->numNonzeros() );
    }
  }
  std::shared_ptr< monty::ndarray< int,1 > > _7777 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7773)));
  _checked_ptr_1<int> _ptr__7777(_7777 ? _7777->raw() : nullptr,_7777 ? _7777->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7778 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7773)));
  _checked_ptr_1<int> _ptr__7778(_7778 ? _7778->raw() : nullptr,_7778 ? _7778->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7779 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7773)));
  _checked_ptr_1<double> _ptr__7779(_7779 ? _7779->raw() : nullptr,_7779 ? _7779->size(0) : 0);
  {
    int _7780 = (int)0;
    int _7781 = (int)0;
    long long _7782 = (long long)0;
    int _12304 = (int)0;
    int _12305 = (int)((_7771)->size(0));
    for (int _7783 = _12304; _7783 < _12305; ++_7783)
    {
      {
        long long _7784 = ((*_7771)(_7783))->numNonzeros();
        std::shared_ptr< monty::ndarray< double,1 > > _7785 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7784)));
        _checked_ptr_1<double> _ptr__7785(_7785 ? _7785->raw() : nullptr,_7785 ? _7785->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _7786 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7784)));
        _checked_ptr_1<int> _ptr__7786(_7786 ? _7786->raw() : nullptr,_7786 ? _7786->size(0) : 0);
        std::shared_ptr< monty::ndarray< int,1 > > _7787 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7784)));
        _checked_ptr_1<int> _ptr__7787(_7787 ? _7787->raw() : nullptr,_7787 ? _7787->size(0) : 0);
        ((*_7771)(_7783))->getDataAsTriplets(_7787,_7786,_7785);
        ::mosek::fusion::Utils::Tools::arraycopy(_7785,(long long)0,_7779,_7782,_7784);
        long long _12306 = (long long)0;
        long long _12307 = _7784;
        for (long long _7788 = _12306; _7788 < _12307; ++_7788)
        {
          {
            _ptr__7777[safe_add( _7782,_7788 )] = safe_add( _ptr__7787[_7788],_7781 );
            _ptr__7778[safe_add( _7782,_7788 )] = safe_add( _ptr__7787[_7788],_7780 );
          }
        }
        _7782 = safe_add( _7782,_7784 );
        _7781 = safe_add( _7781,mosek::fusion::p_Matrix::_get_impl(((*_7771)(_7783)))->dimi );
        _7780 = safe_add( _7780,mosek::fusion::p_Matrix::_get_impl(((*_7771)(_7783)))->dimj );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7775,_7774,_7777,_7778,_7779)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _7789,    double _7790,    int _7791) { return mosek::fusion::p_Matrix::antidiag(_7789,_7790,_7791); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _7789,double _7790,int _7791){
  if (((_7791 < _7789) && (_7791 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_7790,(_7789 - _7791)),_7791);
    }
  }
  else if(((_7791 > (-_7789)) && (_7791 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_7790,safe_add( _7789,_7791 )),_7791);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( int _7792,    double _7793) { return mosek::fusion::p_Matrix::antidiag(_7792,_7793); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(int _7792,double _7793){
  return ::mosek::fusion::p_Matrix::antidiag(::mosek::fusion::Utils::Tools::makevector(_7793,_7792),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _7794,    double _7795,    int _7796) { return mosek::fusion::p_Matrix::diag(_7794,_7795,_7796); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _7794,double _7795,int _7796){
  if (((_7796 < _7794) && (_7796 >= (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_7795,(_7794 - _7796)),_7796);
    }
  }
  else if(((_7796 > (-_7794)) && (_7796 < (int)0)))
  {
    {
      return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_7795,safe_add( _7794,_7796 )),_7796);
    }
  }
  else
  {
    {
      throw ::mosek::fusion::DimensionError(std::string ("Diagonal index out of bounds"));
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( int _7797,    double _7798) { return mosek::fusion::p_Matrix::diag(_7797,_7798); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(int _7797,double _7798){
  return ::mosek::fusion::p_Matrix::diag(::mosek::fusion::Utils::Tools::makevector(_7798,_7797),(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _7799,    int _7800) { return mosek::fusion::p_Matrix::antidiag(_7799,_7800); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _7799,int _7800){
  _checked_ptr_1<double> _ptr__7799(_7799 ? _7799->raw() : nullptr, _7799 ? _7799->size(0) : 0);
  int _12308;
  bool _12309 = (_7800 > (int)0);
  if (_12309)
  {
    _12308 = _7800;
  }
  else
  {
    _12308 = (-_7800);
  }
  int _7801 = _12308;
  int _7802 = safe_add( (int)((_7799)->size(0)),_7801 );
  int _7803 = (int)((_7799)->size(0));
  if ((_7800 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7804 = ::mosek::fusion::Utils::Tools::range(_7800,safe_add( _7803,_7800 ));
      _checked_ptr_1<int> _ptr__7804(_7804 ? _7804->raw() : nullptr,_7804 ? _7804->size(0) : 0);
      std::vector<int> _12310;
      for (int _7806 = (int)1, _12311 = safe_add( _7803,(int)1 ); _7806 < _12311 ; ++_7806)
      {
        _12310.push_back((safe_add( _7803,_7800 ) - _7806));
      }
      auto _12312 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12310.size()),_12310.begin(),_12310.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _7805 = _12312;
      _checked_ptr_1<int> _ptr__7805(_7805 ? _7805->raw() : nullptr,_7805 ? _7805->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7802,_7802,_7804,_7805,_7799)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7807 = ::mosek::fusion::Utils::Tools::range((int)0,_7803);
      _checked_ptr_1<int> _ptr__7807(_7807 ? _7807->raw() : nullptr,_7807 ? _7807->size(0) : 0);
      std::vector<int> _12313;
      for (int _7809 = (int)1, _12314 = safe_add( _7803,(int)1 ); _7809 < _12314 ; ++_7809)
      {
        _12313.push_back((_7803 - _7809));
      }
      auto _12315 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_12313.size()),_12313.begin(),_12313.end()));
      std::shared_ptr< monty::ndarray< int,1 > > _7808 = _12315;
      _checked_ptr_1<int> _ptr__7808(_7808 ? _7808->raw() : nullptr,_7808 ? _7808->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7802,_7802,_7807,_7808,_7799)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::antidiag  ( std::shared_ptr< monty::ndarray< double,1 > > _7810) { return mosek::fusion::p_Matrix::antidiag(_7810); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::antidiag(std::shared_ptr< monty::ndarray< double,1 > > _7810){
  _checked_ptr_1<double> _ptr__7810(_7810 ? _7810->raw() : nullptr, _7810 ? _7810->size(0) : 0);
  return ::mosek::fusion::p_Matrix::antidiag(_7810,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _7811,    int _7812) { return mosek::fusion::p_Matrix::diag(_7811,_7812); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _7811,int _7812){
  _checked_ptr_1<double> _ptr__7811(_7811 ? _7811->raw() : nullptr, _7811 ? _7811->size(0) : 0);
  int _12316;
  bool _12317 = (_7812 > (int)0);
  if (_12317)
  {
    _12316 = _7812;
  }
  else
  {
    _12316 = (-_7812);
  }
  int _7813 = _12316;
  int _7814 = safe_add( (int)((_7811)->size(0)),_7813 );
  int _7815 = (int)((_7811)->size(0));
  if ((_7812 >= (int)0))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7816 = ::mosek::fusion::Utils::Tools::range((int)0,_7815);
      _checked_ptr_1<int> _ptr__7816(_7816 ? _7816->raw() : nullptr,_7816 ? _7816->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7817 = ::mosek::fusion::Utils::Tools::range(_7813,safe_add( _7815,_7813 ));
      _checked_ptr_1<int> _ptr__7817(_7817 ? _7817->raw() : nullptr,_7817 ? _7817->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7814,_7814,_7816,_7817,_7811)).as<::mosek::fusion::Matrix>();
    }
  }
  else
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7818 = ::mosek::fusion::Utils::Tools::range(_7813,safe_add( _7815,_7813 ));
      _checked_ptr_1<int> _ptr__7818(_7818 ? _7818->raw() : nullptr,_7818 ? _7818->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7819 = ::mosek::fusion::Utils::Tools::range((int)0,_7815);
      _checked_ptr_1<int> _ptr__7819(_7819 ? _7819->raw() : nullptr,_7819 ? _7819->size(0) : 0);
      return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7814,_7814,_7818,_7819,_7811)).as<::mosek::fusion::Matrix>();
    }
  }
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::diag  ( std::shared_ptr< monty::ndarray< double,1 > > _7820) { return mosek::fusion::p_Matrix::diag(_7820); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::diag(std::shared_ptr< monty::ndarray< double,1 > > _7820){
  _checked_ptr_1<double> _ptr__7820(_7820 ? _7820->raw() : nullptr, _7820 ? _7820->size(0) : 0);
  return ::mosek::fusion::p_Matrix::diag(_7820,(int)0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::ones  ( int _7821,    int _7822) { return mosek::fusion::p_Matrix::ones(_7821,_7822); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::ones(int _7821,int _7822){
  return ::mosek::fusion::p_Matrix::dense(_7821,_7822,1.0);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::eye  ( int _7823) { return mosek::fusion::p_Matrix::eye(_7823); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::eye(int _7823){
  std::vector<double> _12318;
  for (int _7824 = (int)0, _12319 = _7823; _7824 < _12319 ; ++_7824)
  {
    _12318.push_back(1.0);
  }
  auto _12320 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_12318.size()),_12318.begin(),_12318.end()));
  return ::mosek::fusion::p_Matrix::diag(_12320);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7825) { return mosek::fusion::p_Matrix::dense(_7825); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(monty::rc_ptr< ::mosek::fusion::Matrix > _7825){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_7825)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _7826,    int _7827,    double _7828) { return mosek::fusion::p_Matrix::dense(_7826,_7827,_7828); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _7826,int _7827,double _7828){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_7826,_7827,_7828)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( int _7829,    int _7830,    std::shared_ptr< monty::ndarray< double,1 > > _7831) { return mosek::fusion::p_Matrix::dense(_7829,_7830,_7831); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(int _7829,int _7830,std::shared_ptr< monty::ndarray< double,1 > > _7831){
  _checked_ptr_1<double> _ptr__7831(_7831 ? _7831->raw() : nullptr, _7831 ? _7831->size(0) : 0);
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_7829,_7830,_7831)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::dense  ( std::shared_ptr< monty::ndarray< double,2 > > _7832) { return mosek::fusion::p_Matrix::dense(_7832); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::dense(std::shared_ptr< monty::ndarray< double,2 > > _7832){
  return (::mosek::fusion::p_DenseMatrix::_new_DenseMatrix(_7832)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( monty::rc_ptr< ::mosek::fusion::Matrix > _7833) { return mosek::fusion::p_Matrix::sparse(_7833); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _7833){
  std::shared_ptr< monty::ndarray< int,1 > > _7834 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7833->numNonzeros())));
  _checked_ptr_1<int> _ptr__7834(_7834 ? _7834->raw() : nullptr,_7834 ? _7834->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7835 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7833->numNonzeros())));
  _checked_ptr_1<int> _ptr__7835(_7835 ? _7835->raw() : nullptr,_7835 ? _7835->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7836 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7833->numNonzeros())));
  _checked_ptr_1<double> _ptr__7836(_7836 ? _7836->raw() : nullptr,_7836 ? _7836->size(0) : 0);
  _7833->getDataAsTriplets(_7834,_7835,_7836);
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7833->numRows(),_7833->numColumns(),_7834,_7835,_7836)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _7837) { return mosek::fusion::p_Matrix::sparse(_7837); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _7837){
  int _7838 = (int)((_7837)->size(0));
  int _7839 = (int)((((*_7837)((int)0)))->size(0));
  std::shared_ptr< monty::ndarray< int,1 > > _7840 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7838)));
  _checked_ptr_1<int> _ptr__7840(_7840 ? _7840->raw() : nullptr,_7840 ? _7840->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7841 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7839)));
  _checked_ptr_1<int> _ptr__7841(_7841 ? _7841->raw() : nullptr,_7841 ? _7841->size(0) : 0);
  long long _7842 = (long long)0;
  int _7843 = (int)0;
  {
    int _7844 = (int)0;
    for(;(_7844 < _7838);++ _7844)
    {
      {
        {
          int _7845 = (int)0;
          for(;(_7845 < _7839);++ _7845)
          {
            {
              monty::rc_ptr< ::mosek::fusion::Matrix > _7846 = ((*((*_7837)(_7844)))(_7845));
              if ((NULL != _7846.get()))
              {
                {
                  if ((_ptr__7841[_7845] == (int)0))
                  {
                    {
                      _ptr__7841[_7845] = mosek::fusion::p_Matrix::_get_impl(_7846)->dimj;
                    }
                  }
                  else if((_ptr__7841[_7845] != mosek::fusion::p_Matrix::_get_impl(_7846)->dimj))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  if ((_ptr__7840[_7844] == (int)0))
                  {
                    {
                      _ptr__7840[_7844] = mosek::fusion::p_Matrix::_get_impl(_7846)->dimi;
                    }
                  }
                  else if((_ptr__7840[_7844] != mosek::fusion::p_Matrix::_get_impl(_7846)->dimi))
                  {
                    {
                      throw ::mosek::fusion::SparseFormatError(std::string ("Sparse matrix construction blocks are not aligned"));
                    }
                  }
                  {}
                  _7842 = safe_add( _7842,_7846->numNonzeros() );
                }
              }
              {}
              ++ _7843;
            }
          }
        }
      }
    }
  }
  std::shared_ptr< monty::ndarray< double,1 > > _7847 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7842)));
  _checked_ptr_1<double> _ptr__7847(_7847 ? _7847->raw() : nullptr,_7847 ? _7847->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7848 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7842)));
  _checked_ptr_1<int> _ptr__7848(_7848 ? _7848->raw() : nullptr,_7848 ? _7848->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7849 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7842)));
  _checked_ptr_1<int> _ptr__7849(_7849 ? _7849->raw() : nullptr,_7849 ? _7849->size(0) : 0);
  int _7850 = (int)0;
  int _7851 = (int)0;
  {
    int _7852 = (int)0;
    for(;(_7852 < _7838);++ _7852)
    {
      {
        std::shared_ptr< monty::ndarray< int,1 > > _7853 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7839)));
        _checked_ptr_1<int> _ptr__7853(_7853 ? _7853->raw() : nullptr,_7853 ? _7853->size(0) : 0);
        {
          int _7854 = (int)0;
          for(;(_7854 < _ptr__7840[_7852]);++ _7854)
          {
            {
              int _7855 = (int)0;
              {
                int _7856 = (int)0;
                for(;(_7856 < _7839);++ _7856)
                {
                  {
                    monty::rc_ptr< ::mosek::fusion::Matrix > _7857 = ((*((*_7837)(_7852)))(_7856));
                    if ((NULL != _7857.get()))
                    {
                      {
                        monty::rc_ptr< ::mosek::fusion::Matrix > _12321 = _7857;
                        if (false) {}
                        else if (nullptr != dynamic_cast<::mosek::fusion::DenseMatrix*>(_12321.get()))
                        {
                          ::mosek::fusion::DenseMatrix::t _7858 (dynamic_cast<::mosek::fusion::DenseMatrix*>(_12321.get()));
                          {
                            int _7861 = _ptr__7853[_7856];
                            {
                              int _7862 = (int)0;
                              for(;(_7862 < mosek::fusion::p_Matrix::_get_impl(_7858)->dimj);++ _7862)
                              {
                                {
                                  _ptr__7847[_7850] = ((*mosek::fusion::p_DenseMatrix::_get_impl(_7858)->data)(_7861));
                                  _ptr__7848[_7850] = safe_add( _7851,_7854 );
                                  _ptr__7849[_7850] = safe_add( _7855,_7862 );
                                  ++ _7861;
                                  ++ _7850;
                                }
                              }
                            }
                            _ptr__7853[_7856] = _7861;
                          }
                        }
                        else if (nullptr != dynamic_cast<::mosek::fusion::SparseMatrix*>(_12321.get()))
                        {
                          ::mosek::fusion::SparseMatrix::t _7859 (dynamic_cast<::mosek::fusion::SparseMatrix*>(_12321.get()));
                          {
                            int _7863;
                            {
                              _7863 = _ptr__7853[_7856];
                              for(;((_7863 < mosek::fusion::p_SparseMatrix::_get_impl(_7859)->nnz) && (((*mosek::fusion::p_SparseMatrix::_get_impl(_7859)->subi)(_7863)) == _7854));++ _7863)
                              {
                                {
                                  _ptr__7847[_7850] = ((*mosek::fusion::p_SparseMatrix::_get_impl(_7859)->val)(_7863));
                                  _ptr__7849[_7850] = safe_add( ((*mosek::fusion::p_SparseMatrix::_get_impl(_7859)->subj)(_7863)),_7855 );
                                  _ptr__7848[_7850] = safe_add( _7851,_7854 );
                                  ++ _7850;
                                }
                              }
                            }
                            _ptr__7853[_7856] = _7863;
                          }
                        }
                        else
                        {
                          mosek::fusion::Matrix::t _7860 = _12321;
                          {
                            throw ::mosek::fusion::MatrixError(std::string ("Unknown matrix type."));
                          }
                        }
                      }
                    }
                    {}
                    _7855 = safe_add( _7855,_ptr__7841[_7856] );
                  }
                }
              }
            }
          }
        }
        _7851 = safe_add( _7851,_ptr__7840[_7852] );
      }
    }
  }
  int _7864 = (int)0;
  int _7865 = (int)0;
  {
    int _7866 = (int)0;
    for(;(_7866 < _7838);++ _7866)
    {
      {
        _7864 = safe_add( _7864,_ptr__7840[_7866] );
      }
    }
  }
  {
    int _7867 = (int)0;
    for(;(_7867 < _7839);++ _7867)
    {
      {
        _7865 = safe_add( _7865,_ptr__7841[_7867] );
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7864,_7865,_7848,_7849,_7847)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< double,2 > > _7868) { return mosek::fusion::p_Matrix::sparse(_7868); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< double,2 > > _7868){
  int _7869 = (int)((_7868)->size(0));
  int _7870 = (int)((_7868)->size(1));
  long long _7871 = (long long)safe_mul( _7869,_7870 );
  int _7872 = (int)0;
  std::shared_ptr< monty::ndarray< int,1 > > _7873 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7871)));
  _checked_ptr_1<int> _ptr__7873(_7873 ? _7873->raw() : nullptr,_7873 ? _7873->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _7874 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7871)));
  _checked_ptr_1<int> _ptr__7874(_7874 ? _7874->raw() : nullptr,_7874 ? _7874->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _7875 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape(_7871)));
  _checked_ptr_1<double> _ptr__7875(_7875 ? _7875->raw() : nullptr,_7875 ? _7875->size(0) : 0);
  {
    int _7876 = (int)0;
    for(;(_7876 < _7869);++ _7876)
    {
      {
        {
          int _7877 = (int)0;
          for(;(_7877 < _7870);++ _7877)
          {
            {
              _ptr__7873[_7872] = _7876;
              _ptr__7874[_7872] = _7877;
              _ptr__7875[_7872] = ((*_7868)(_7876,_7877));
              ++ _7872;
            }
          }
        }
      }
    }
  }
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7869,_7870,_7873,_7874,_7875)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _7878,    int _7879) { return mosek::fusion::p_Matrix::sparse(_7878,_7879); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _7878,int _7879){
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7878,_7879,std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0))),std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0))),(long long)0)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _7880,    int _7881,    std::shared_ptr< monty::ndarray< int,1 > > _7882,    std::shared_ptr< monty::ndarray< int,1 > > _7883,    double _7884) { return mosek::fusion::p_Matrix::sparse(_7880,_7881,_7882,_7883,_7884); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _7880,int _7881,std::shared_ptr< monty::ndarray< int,1 > > _7882,std::shared_ptr< monty::ndarray< int,1 > > _7883,double _7884){
  _checked_ptr_1<int> _ptr__7882(_7882 ? _7882->raw() : nullptr, _7882 ? _7882->size(0) : 0);
  _checked_ptr_1<int> _ptr__7883(_7883 ? _7883->raw() : nullptr, _7883 ? _7883->size(0) : 0);
  int _7885 = (int)0;
  if ((NULL != _7882.get()))
  {
    {
      _7885 = (int)((_7882)->size(0));
    }
  }
  else if((NULL != _7883.get()))
  {
    {
      _7885 = (int)((_7883)->size(0));
    }
  }
  {}
  return ::mosek::fusion::p_Matrix::sparse(_7880,_7881,_7882,_7883,::mosek::fusion::Utils::Tools::makevector(_7884,_7885));
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _7886,    std::shared_ptr< monty::ndarray< int,1 > > _7887,    double _7888) { return mosek::fusion::p_Matrix::sparse(_7886,_7887,_7888); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _7886,std::shared_ptr< monty::ndarray< int,1 > > _7887,double _7888){
  _checked_ptr_1<int> _ptr__7886(_7886 ? _7886->raw() : nullptr, _7886 ? _7886->size(0) : 0);
  _checked_ptr_1<int> _ptr__7887(_7887 ? _7887->raw() : nullptr, _7887 ? _7887->size(0) : 0);
  int _7889 = (int)0;
  int _7890 = (int)0;
  int _7891 = (int)((_7886)->size(0));
  if ((_7891 > (int)((_7887)->size(0))))
  {
    {
      _7891 = (int)((_7887)->size(0));
    }
  }
  {}
  int _12322 = (int)0;
  int _12323 = _7891;
  for (int _7892 = _12322; _7892 < _12323; ++_7892)
  {
    {
      if ((_7890 < _ptr__7886[_7892]))
      {
        {
          _7890 = _ptr__7886[_7892];
        }
      }
      {}
      if ((_7889 < _ptr__7887[_7892]))
      {
        {
          _7889 = _ptr__7887[_7892];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _7890,(int)1 ),safe_add( _7889,(int)1 ),_7886,_7887,_7888);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( std::shared_ptr< monty::ndarray< int,1 > > _7893,    std::shared_ptr< monty::ndarray< int,1 > > _7894,    std::shared_ptr< monty::ndarray< double,1 > > _7895) { return mosek::fusion::p_Matrix::sparse(_7893,_7894,_7895); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(std::shared_ptr< monty::ndarray< int,1 > > _7893,std::shared_ptr< monty::ndarray< int,1 > > _7894,std::shared_ptr< monty::ndarray< double,1 > > _7895){
  _checked_ptr_1<int> _ptr__7893(_7893 ? _7893->raw() : nullptr, _7893 ? _7893->size(0) : 0);
  _checked_ptr_1<int> _ptr__7894(_7894 ? _7894->raw() : nullptr, _7894 ? _7894->size(0) : 0);
  _checked_ptr_1<double> _ptr__7895(_7895 ? _7895->raw() : nullptr, _7895 ? _7895->size(0) : 0);
  int _7896 = (int)0;
  int _7897 = (int)0;
  int _7898 = (int)((_7893)->size(0));
  if ((_7898 > (int)((_7894)->size(0))))
  {
    {
      _7898 = (int)((_7894)->size(0));
    }
  }
  {}
  if ((_7898 > (int)((_7895)->size(0))))
  {
    {
      _7898 = (int)((_7895)->size(0));
    }
  }
  {}
  int _12324 = (int)0;
  int _12325 = _7898;
  for (int _7899 = _12324; _7899 < _12325; ++_7899)
  {
    {
      if ((_7897 < _ptr__7893[_7899]))
      {
        {
          _7897 = _ptr__7893[_7899];
        }
      }
      {}
      if ((_7896 < _ptr__7894[_7899]))
      {
        {
          _7896 = _ptr__7894[_7899];
        }
      }
      {}
    }
  }
  return ::mosek::fusion::p_Matrix::sparse(safe_add( _7897,(int)1 ),safe_add( _7896,(int)1 ),_7893,_7894,_7895);
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix::sparse  ( int _7900,    int _7901,    std::shared_ptr< monty::ndarray< int,1 > > _7902,    std::shared_ptr< monty::ndarray< int,1 > > _7903,    std::shared_ptr< monty::ndarray< double,1 > > _7904) { return mosek::fusion::p_Matrix::sparse(_7900,_7901,_7902,_7903,_7904); }monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::p_Matrix::sparse(int _7900,int _7901,std::shared_ptr< monty::ndarray< int,1 > > _7902,std::shared_ptr< monty::ndarray< int,1 > > _7903,std::shared_ptr< monty::ndarray< double,1 > > _7904){
  _checked_ptr_1<int> _ptr__7902(_7902 ? _7902->raw() : nullptr, _7902 ? _7902->size(0) : 0);
  _checked_ptr_1<int> _ptr__7903(_7903 ? _7903->raw() : nullptr, _7903 ? _7903->size(0) : 0);
  _checked_ptr_1<double> _ptr__7904(_7904 ? _7904->raw() : nullptr, _7904 ? _7904->size(0) : 0);
  std::shared_ptr< monty::ndarray< double,1 > > _12326;
  bool _12327 = (NULL != _7904.get());
  if (_12327)
  {
    _12326 = _7904;
  }
  else
  {
    _12326 = std::shared_ptr< monty::ndarray< double,1 > >(new monty::ndarray< double,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< double,1 > > _7905 = _12326;
  _checked_ptr_1<double> _ptr__7905(_7905 ? _7905->raw() : nullptr,_7905 ? _7905->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _12328;
  bool _12329 = (NULL != _7903.get());
  if (_12329)
  {
    _12328 = _7903;
  }
  else
  {
    _12328 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _7906 = _12328;
  _checked_ptr_1<int> _ptr__7906(_7906 ? _7906->raw() : nullptr,_7906 ? _7906->size(0) : 0);
  std::shared_ptr< monty::ndarray< int,1 > > _12330;
  bool _12331 = (NULL != _7902.get());
  if (_12331)
  {
    _12330 = _7902;
  }
  else
  {
    _12330 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)0)));
  }
  std::shared_ptr< monty::ndarray< int,1 > > _7907 = _12330;
  _checked_ptr_1<int> _ptr__7907(_7907 ? _7907->raw() : nullptr,_7907 ? _7907->size(0) : 0);
  long long _7908 = (long long)((_7907)->size(0));
  if ((((long long)((_7906)->size(0)) != _7908) || ((long long)((_7905)->size(0)) != _7908)))
  {
    {
      throw ::mosek::fusion::SparseFormatError(std::string ("Arrays defining sparse data have different lengths"));
    }
  }
  {}
  return (::mosek::fusion::p_SparseMatrix::_new_SparseMatrix(_7900,_7901,_7907,_7906,_7905,_7908)).as<::mosek::fusion::Matrix>();
}
monty::rc_ptr< ::mosek::fusion::Matrix > mosek::fusion::Matrix :: transpose() { return __mosek_2fusion_2Matrix__transpose(); }
int mosek::fusion::Matrix :: numColumns() { return mosek::fusion::p_Matrix::_get_impl(this)->numColumns(); }int mosek::fusion::p_Matrix::numColumns(){
  return dimj;
}
int mosek::fusion::Matrix :: numRows() { return mosek::fusion::p_Matrix::_get_impl(this)->numRows(); }int mosek::fusion::p_Matrix::numRows(){
  return dimi;
}
void mosek::fusion::p_Matrix::destroy(){}void mosek::fusion::Matrix::destroy() { mosek::fusion::p_Matrix::_get_impl(this)->destroy(); }mosek::fusion::UnimplementedError::UnimplementedError  ( const std::string &  _7914) : RuntimeException(_7914)  {
  }
mosek::fusion::FatalError::FatalError  ( const std::string &  _7915) : RuntimeException(_7915)  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( ::mosek::fusion::FusionException _7916) : RuntimeException(_7916.toString())  {
  }
mosek::fusion::UnexpectedError::UnexpectedError  ( const std::string &  _7917) : RuntimeException(_7917)  {
  }
mosek::fusion::SparseFormatError::SparseFormatError  ( const std::string &  _7918) : mosek::fusion::FusionRuntimeException(_7918)  {
  }
mosek::fusion::SolutionError::SolutionError  ( ) : mosek::fusion::FusionException(std::string ("Solution is invalid or undefined"))  {
  }
mosek::fusion::SolutionError::SolutionError  ( const std::string &  _7919) : mosek::fusion::FusionException(_7919)  {
  }
mosek::fusion::SliceError::SliceError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Invalid slice range"))  {
  }
mosek::fusion::SliceError::SliceError  ( const std::string &  _7920) : mosek::fusion::FusionRuntimeException(_7920)  {
  }
mosek::fusion::UpdateError::UpdateError  ( ) : mosek::fusion::FusionRuntimeException(std::string ("Cannot update parameterized item"))  {
  }
mosek::fusion::UpdateError::UpdateError  ( const std::string &  _7921) : mosek::fusion::FusionRuntimeException(_7921)  {
  }
mosek::fusion::SetDefinitionError::SetDefinitionError  ( const std::string &  _7922) : mosek::fusion::FusionRuntimeException(_7922)  {
  }
mosek::fusion::OptimizeError::OptimizeError  ( const std::string &  _7923) : mosek::fusion::FusionRuntimeException(_7923)  {
  }
mosek::fusion::NameError::NameError  ( const std::string &  _7924) : mosek::fusion::FusionRuntimeException(_7924)  {
  }
mosek::fusion::DeletionError::DeletionError  ( const std::string &  _7925) : mosek::fusion::FusionRuntimeException(_7925)  {
  }
mosek::fusion::ModelError::ModelError  ( const std::string &  _7926) : mosek::fusion::FusionRuntimeException(_7926)  {
  }
mosek::fusion::MatrixError::MatrixError  ( const std::string &  _7927) : mosek::fusion::FusionRuntimeException(_7927)  {
  }
mosek::fusion::DimensionError::DimensionError  ( const std::string &  _7928) : mosek::fusion::FusionRuntimeException(_7928)  {
  }
mosek::fusion::LengthError::LengthError  ( const std::string &  _7929) : mosek::fusion::FusionRuntimeException(_7929)  {
  }
mosek::fusion::RangeError::RangeError  ( const std::string &  _7930) : mosek::fusion::FusionRuntimeException(_7930)  {
  }
mosek::fusion::IndexError::IndexError  ( const std::string &  _7931) : mosek::fusion::FusionRuntimeException(_7931)  {
  }
mosek::fusion::DomainError::DomainError  ( const std::string &  _7932) : mosek::fusion::FusionRuntimeException(_7932)  {
  }
mosek::fusion::ValueConversionError::ValueConversionError  ( const std::string &  _7933) : mosek::fusion::FusionRuntimeException(_7933)  {
  }
mosek::fusion::ParameterError::ParameterError  ( const std::string &  _7934) : mosek::fusion::FusionRuntimeException(_7934)  {
  }
mosek::fusion::ExpressionError::ExpressionError  ( const std::string &  _7935) : mosek::fusion::FusionRuntimeException(_7935)  {
  }
mosek::fusion::IOError::IOError  ( const std::string &  _7936) : mosek::fusion::FusionRuntimeException(_7936)  {
  }
mosek::fusion::FusionRuntimeException::FusionRuntimeException  ( const std::string &  _7937) : RuntimeException(_7937)  {
    msg = _7937;
  }
std::string mosek::fusion::FusionRuntimeException::toString(){
  return msg;
}
mosek::fusion::FusionException::FusionException  ( const std::string &  _7938) : Exception(_7938)  {
    msg = _7938;
  }
std::string mosek::fusion::FusionException::toString(){
  return msg;
}
mosek::fusion::LinkedBlocks::LinkedBlocks(mosek::fusion::p_LinkedBlocks *_impl) : _impl(_impl) { /*std::cout << "LinkedBlocks() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedBlocks::~LinkedBlocks() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedBlocks::p_LinkedBlocks  (::mosek::fusion::LinkedBlocks * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (){ return new mosek::fusion::LinkedBlocks(); }mosek::fusion::LinkedBlocks::LinkedBlocks  () :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedBlocks::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedBlocks::_initialize((int)0);
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (int _7939){ return new mosek::fusion::LinkedBlocks(_7939); }mosek::fusion::LinkedBlocks::LinkedBlocks  (int _7939) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_7939); }void mosek::fusion::p_LinkedBlocks::_initialize  (int _7939){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(_7939);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts((int)128);
    bsize = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
    bfirst = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape((int)128)));
  }
}mosek::fusion::LinkedBlocks::t mosek::fusion::p_LinkedBlocks::_new_LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _7940){ return new mosek::fusion::LinkedBlocks(_7940); }mosek::fusion::LinkedBlocks::LinkedBlocks  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _7940) :    LinkedBlocks(new mosek::fusion::p_LinkedBlocks(this)){ mosek::fusion::p_LinkedBlocks::_get_impl(this)->_initialize(_7940); }void mosek::fusion::p_LinkedBlocks::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _7940){monty::rc_reserve __reserve_this(_pubthis);   {
    ints = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_7940)->ints);
    blocks = ::mosek::fusion::p_LinkedInts::_new_LinkedInts(mosek::fusion::p_LinkedBlocks::_get_impl(_7940)->blocks);
    bsize = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_7940)->bsize);
    bfirst = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedBlocks::_get_impl(_7940)->bfirst);
  }
}void mosek::fusion::LinkedBlocks :: free(int _7941) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->free(_7941); }void mosek::fusion::p_LinkedBlocks::free(int _7941){
  int _7942 = ((*bfirst)(_7941));
  ints->free(_7941,((*bsize)(_7941)));
  ((*bsize)(_7941)) = (-(int)1);
  ((*bfirst)(_7941)) = (-(int)1);
  blocks->free(_7942,(int)1);
}
int mosek::fusion::LinkedBlocks :: alloc(int _7943) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->alloc(_7943); }int mosek::fusion::p_LinkedBlocks::alloc(int _7943){
  int _12332;
  bool _12333 = (_7943 > (int)0);
  if (_12333)
  {
    _12332 = ints->alloc(_7943);
  }
  else
  {
    _12332 = (-(int)1);
  }
  int _7944 = _12332;
  int _7945 = blocks->alloc();
  if ((blocks->capacity() > (int)((bsize)->size(0))))
  {
    {
      std::shared_ptr< monty::ndarray< int,1 > > _7946 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__7946(_7946 ? _7946->raw() : nullptr,_7946 ? _7946->size(0) : 0);
      std::shared_ptr< monty::ndarray< int,1 > > _7947 = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(blocks->capacity())));
      _checked_ptr_1<int> _ptr__7947(_7947 ? _7947->raw() : nullptr,_7947 ? _7947->size(0) : 0);
      ::mosek::fusion::Utils::Tools::arraycopy(bsize,(int)0,_7946,(int)0,(int)((bsize)->size(0)));
      ::mosek::fusion::Utils::Tools::arraycopy(bfirst,(int)0,_7947,(int)0,(int)((bfirst)->size(0)));
      bsize = _7946;
      bfirst = _7947;
    }
  }
  {}
  ((*bfirst)(_7945)) = _7944;
  ((*bsize)(_7945)) = _7943;
  return _7945;
}
int mosek::fusion::LinkedBlocks :: maxidx(int _7948) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->maxidx(_7948); }int mosek::fusion::p_LinkedBlocks::maxidx(int _7948){
  return ints->maxidx(((*bfirst)(_7948)),((*bsize)(_7948)));
}
void mosek::fusion::LinkedBlocks :: get(int _7949,std::shared_ptr< monty::ndarray< int,1 > > _7950,int _7951) { mosek::fusion::p_LinkedBlocks::_get_impl(this)->get(_7949,_7950,_7951); }void mosek::fusion::p_LinkedBlocks::get(int _7949,std::shared_ptr< monty::ndarray< int,1 > > _7950,int _7951){
  _checked_ptr_1<int> _ptr__7950(_7950 ? _7950->raw() : nullptr, _7950 ? _7950->size(0) : 0);
  ints->get(((*bfirst)(_7949)),((*bsize)(_7949)),_7950,_7951);
}
int mosek::fusion::LinkedBlocks :: numblocks() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->numblocks(); }int mosek::fusion::p_LinkedBlocks::numblocks(){
  return (int)((bsize)->size(0));
}
int mosek::fusion::LinkedBlocks :: blocksize(int _7952) { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->blocksize(_7952); }int mosek::fusion::p_LinkedBlocks::blocksize(int _7952){
  return ((*bsize)(_7952));
}
int mosek::fusion::LinkedBlocks :: capacity() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedBlocks::capacity(){
  return ints->capacity();
}
bool mosek::fusion::LinkedBlocks :: validate() { return mosek::fusion::p_LinkedBlocks::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedBlocks::validate(){
  return (ints->validate() && blocks->validate());
}
void mosek::fusion::p_LinkedBlocks::destroy(){bfirst.reset();bsize.reset();blocks.reset();ints.reset();}void mosek::fusion::LinkedBlocks::destroy() { mosek::fusion::p_LinkedBlocks::_get_impl(this)->destroy(); }mosek::fusion::LinkedInts::LinkedInts(mosek::fusion::p_LinkedInts *_impl) : _impl(_impl) { /*std::cout << "LinkedInts() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::LinkedInts::~LinkedInts() { delete _impl; _impl = nullptr; }mosek::fusion::p_LinkedInts::p_LinkedInts  (::mosek::fusion::LinkedInts * _pubthis) :     _pubthis(_pubthis){}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (int _7953){ return new mosek::fusion::LinkedInts(_7953); }mosek::fusion::LinkedInts::LinkedInts  (int _7953) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_7953); }void mosek::fusion::p_LinkedInts::_initialize  (int _7953){monty::rc_reserve __reserve_this(_pubthis);   {
    int _12334;
    bool _12335 = (_7953 > (int)0);
    if (_12335)
    {
      _12334 = _7953;
    }
    else
    {
      _12334 = (int)128;
    }
    int _7954 = _12334;
    next = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7954)));
    prev = std::shared_ptr< monty::ndarray< int,1 > >(new monty::ndarray< int,1 >(monty::shape(_7954)));
    first_used = (-(int)1);
    first_free = (int)0;
    last_free = (_7954 - (int)1);
    int _12336 = (int)1;
    int _12337 = _7954;
    for (int _7955 = _12336; _7955 < _12337; ++_7955)
    {
      {
        ((*prev)(_7955)) = (_7955 - (int)1);
        ((*next)((_7955 - (int)1))) = _7955;
      }
    }
    ((*prev)((int)0)) = (-(int)1);
    ((*next)((_7954 - (int)1))) = (-(int)1);
    nfree = _7954;
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (){ return new mosek::fusion::LinkedInts(); }mosek::fusion::LinkedInts::LinkedInts  () :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(); }void mosek::fusion::p_LinkedInts::_initialize  (){monty::rc_reserve __reserve_this(_pubthis);   {
    mosek::fusion::p_LinkedInts::_initialize((int)128);
  }
}mosek::fusion::LinkedInts::t mosek::fusion::p_LinkedInts::_new_LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _7956){ return new mosek::fusion::LinkedInts(_7956); }mosek::fusion::LinkedInts::LinkedInts  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _7956) :    LinkedInts(new mosek::fusion::p_LinkedInts(this)){ mosek::fusion::p_LinkedInts::_get_impl(this)->_initialize(_7956); }void mosek::fusion::p_LinkedInts::_initialize  (monty::rc_ptr< ::mosek::fusion::LinkedInts > _7956){monty::rc_reserve __reserve_this(_pubthis);   {
    next = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_7956)->next);
    prev = ::mosek::fusion::Utils::Tools::arraycopy(mosek::fusion::p_LinkedInts::_get_impl(_7956)->prev);
    first_used = mosek::fusion::p_LinkedInts::_get_impl(_7956)->first_used;
    first_free = mosek::fusion::p_LinkedInts::_get_impl(_7956)->first_free;
    last_free = mosek::fusion::p_LinkedInts::_get_impl(_7956)->last_free;
    nfree = mosek::fusion::p_LinkedInts::_get_impl(_7956)->nfree;
  }
}void mosek::fusion::LinkedInts :: free(int _7957,int _7958) { mosek::fusion::p_LinkedInts::_get_impl(this)->free(_7957,_7958); }void mosek::fusion::p_LinkedInts::free(int _7957,int _7958){
  int _7959 = _7957;
  int _7960 = _7959;
  int _12338 = (int)0;
  int _12339 = (_7958 - (int)1);
  for (int _7961 = _12338; _7961 < _12339; ++_7961)
  {
    {
      _7960 = ((*next)(_7960));
    }
  }
  int _7962 = ((*prev)(_7959));
  int _7963 = ((*next)(_7960));
  if ((_7962 >= (int)0))
  {
    {
      ((*next)(_7962)) = _7963;
    }
  }
  {}
  if ((_7963 >= (int)0))
  {
    {
      ((*prev)(_7963)) = _7962;
    }
  }
  {}
  ((*prev)(_7959)) = (-(int)1);
  ((*next)(_7960)) = first_free;
  if ((first_free >= (int)0))
  {
    {
      ((*prev)(first_free)) = _7960;
    }
  }
  {}
  first_free = _7959;
  nfree += _7958;
}
int mosek::fusion::LinkedInts :: alloc() { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(); }int mosek::fusion::p_LinkedInts::alloc(){
  return allocblock((int)1);
}
int mosek::fusion::LinkedInts :: alloc(int _7964) { return mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_7964); }int mosek::fusion::p_LinkedInts::alloc(int _7964){
  return allocblock(_7964);
}
void mosek::fusion::LinkedInts :: alloc(int _7965,std::shared_ptr< monty::ndarray< int,1 > > _7966,int _7967) { mosek::fusion::p_LinkedInts::_get_impl(this)->alloc(_7965,_7966,_7967); }void mosek::fusion::p_LinkedInts::alloc(int _7965,std::shared_ptr< monty::ndarray< int,1 > > _7966,int _7967){
  _checked_ptr_1<int> _ptr__7966(_7966 ? _7966->raw() : nullptr, _7966 ? _7966->size(0) : 0);
  int _7968 = allocblock(_7965);
  int _12340 = (int)0;
  int _12341 = _7965;
  for (int _7969 = _12340; _7969 < _12341; ++_7969)
  {
    {
      _ptr__7966[safe_add( _7969,_7967 )] = _7968;
      _7968 = ((*next)(_7968));
    }
  }
}
void mosek::fusion::LinkedInts :: get(int _7970,int _7971,std::shared_ptr< monty::ndarray< int,1 > > _7972,int _7973) { mosek::fusion::p_LinkedInts::_get_impl(this)->get(_7970,_7971,_7972,_7973); }void mosek::fusion::p_LinkedInts::get(int _7970,int _7971,std::shared_ptr< monty::ndarray< int,1 > > _7972,int _7973){
  _checked_ptr_1<int> _ptr__7972(_7972 ? _7972->raw() : nullptr, _7972 ? _7972->size(0) : 0);
  int _7974 = _7970;
  int _12342 = (int)0;
  int _12343 = _7971;
  for (int _7975 = _12342; _7975 < _12343; ++_7975)
  {
    {
      _ptr__7972[safe_add( _7975,_7973 )] = _7974;
      _7974 = ((*next)(_7974));
    }
  }
}
int mosek::fusion::LinkedInts :: maxidx(int _7976,int _7977) { return mosek::fusion::p_LinkedInts::_get_impl(this)->maxidx(_7976,_7977); }int mosek::fusion::p_LinkedInts::maxidx(int _7976,int _7977){
  int _7978 = _7976;
  int _7979 = _7976;
  int _12344 = (int)1;
  int _12345 = _7977;
  for (int _7980 = _12344; _7980 < _12345; ++_7980)
  {
    {
      _7979 = ((*next)(_7979));
      if ((_7978 < _7979))
      {
        {
          _7978 = _7979;
        }
      }
      {}
    }
  }
  return _7978;
}
int mosek::fusion::p_LinkedInts::allocblock(int _7981){
  int _7982 = (int)((next)->size(0));
  if ((nfree < _7981))
  {
    {
      int _7983 = (_7981 - nfree);
      if ((_7983 < _7982))
      {
        {
          _7983 = _7982;
        }
      }
      {}
      recap(safe_add( _7983,_7982 ));
    }
  }
  {}
  int _7984 = first_free;
  int _7985 = _7984;
  int _12346 = (int)0;
  int _12347 = (_7981 - (int)1);
  for (int _7986 = _12346; _7986 < _12347; ++_7986)
  {
    {
      _7985 = ((*next)(_7985));
    }
  }
  first_free = ((*next)(_7985));
  if ((first_free < (int)0))
  {
    {
      last_free = (-(int)1);
    }
  }
  else
  {
    {
      ((*prev)(first_free)) = (-(int)1);
    }
  }
  ((*next)(_7985)) = first_used;
  if ((first_used >= (int)0))
  {
    {
      ((*prev)(first_used)) = _7985;
    }
  }
  {}
  first_used = _7984;
  nfree -= _7981;
  return _7984;
}
void mosek::fusion::p_LinkedInts::recap(int _7987){
  int _7988 = (int)((next)->size(0));
  if ((_7987 > _7988))
  {
    {
      next = ::mosek::fusion::p_CommonTools::resize(next,_7987);
      prev = ::mosek::fusion::p_CommonTools::resize(prev,_7987);
      int _12348 = _7988;
      int _12349 = (_7987 - (int)1);
      for (int _7989 = _12348; _7989 < _12349; ++_7989)
      {
        {
          ((*next)(_7989)) = safe_add( _7989,(int)1 );
          ((*prev)(safe_add( _7989,(int)1 ))) = _7989;
        }
      }
      ((*next)((_7987 - (int)1))) = (-(int)1);
      ((*prev)(_7988)) = last_free;
      if ((last_free < (int)0))
      {
        {
          first_free = _7988;
        }
      }
      else
      {
        {
          ((*next)(last_free)) = _7988;
        }
      }
      last_free = (_7987 - (int)1);
      nfree += (_7987 - _7988);
    }
  }
  {}
}
int mosek::fusion::LinkedInts :: capacity() { return mosek::fusion::p_LinkedInts::_get_impl(this)->capacity(); }int mosek::fusion::p_LinkedInts::capacity(){
  return (int)((next)->size(0));
}
bool mosek::fusion::LinkedInts :: validate() { return mosek::fusion::p_LinkedInts::_get_impl(this)->validate(); }bool mosek::fusion::p_LinkedInts::validate(){
  std::shared_ptr< monty::ndarray< bool,1 > > _7990 = std::shared_ptr< monty::ndarray< bool,1 > >(new monty::ndarray< bool,1 >(monty::shape((int)((next)->size(0)))));
  int _7991 = first_used;
  while ( (_7991 >= (int)0) )
  {
    {
      ((*_7990)(_7991)) = true;
      _7991 = ((*next)(_7991));
      if (((_7991 >= (int)0) && ((*_7990)(_7991))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("used list/next is inconsistent"));
        }
      }
      {}
    }
  }
  _7991 = first_free;
  int _7992 = (int)0;
  while ( (_7991 >= (int)0) )
  {
    {
      ++ _7992;
      ((*_7990)(_7991)) = true;
      _7991 = ((*next)(_7991));
      if (((_7991 >= (int)0) && ((*_7990)(_7991))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("free list/next is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_7992 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free next list did not contain nfree elements"));
    }
  }
  {}
  int _12350 = (int)0;
  int _12351 = (int)((_7990)->size(0));
  for (int _7993 = _12350; _7993 < _12351; ++_7993)
  {
    {
      if ((!((*_7990)(_7991))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("elements missing from used+free list"));
        }
      }
      {}
    }
  }
  int _12352 = (int)0;
  int _12353 = (int)((_7990)->size(0));
  for (int _7994 = _12352; _7994 < _12353; ++_7994)
  {
    {
      ((*_7990)(_7994)) = false;
    }
  }
  _7991 = last_free;
  int _7995 = (int)0;
  while ( (_7991 >= (int)0) )
  {
    {
      ++ _7995;
      ((*_7990)(_7991)) = true;
      _7991 = ((*prev)(_7991));
      if (((_7991 >= (int)0) && ((*_7990)(_7991))))
      {
        {
          throw ::mosek::fusion::UnexpectedError(std::string ("prev list is inconsistent"));
        }
      }
      {}
    }
  }
  if ((_7995 != nfree))
  {
    {
      throw ::mosek::fusion::UnexpectedError(std::string ("free prev list did not contain nfree elements"));
    }
  }
  {}
  return true;
}
void mosek::fusion::p_LinkedInts::destroy(){prev.reset();next.reset();}void mosek::fusion::LinkedInts::destroy() { mosek::fusion::p_LinkedInts::_get_impl(this)->destroy(); }mosek::fusion::Parameters::Parameters(mosek::fusion::p_Parameters *_impl) : _impl(_impl) { /*std::cout << "Parameters() " << this << std::endl;*/ _impl->_pubthis = this; }mosek::fusion::Parameters::~Parameters() { delete _impl; _impl = nullptr; }mosek::fusion::p_Parameters::p_Parameters  (::mosek::fusion::Parameters * _pubthis) :     _pubthis(_pubthis){}void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _7996,    const std::string & _7997,    double _7998) { mosek::fusion::p_Parameters::setParameter(_7996,_7997,_7998); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _7996,const std::string & _7997,double _7998){
  if (false)
  {
    {
    }
  }
  else if((_7997 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_7997 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_7997 == std::string ("numThreads")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _7999 = _7998;
          if (((int)0 <= _7999))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_7999);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_7997 == std::string ("mtSpincount")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8000 = _7998;
          if ((((int)0 <= _8000) && (_8000 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_8000);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_7997 == std::string ("biMaxIterations")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8001 = _7998;
          if (((int)0 <= _8001))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_8001);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8002 = _7998;
          if (((int)0 <= _8002))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_8002);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logCutSecondOpt")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8003 = _7998;
          if (((int)0 <= _8003))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_8003);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logResponse")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8004 = _7998;
          if (((int)0 <= _8004))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_8004);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_7997 == std::string ("logBi")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8005 = _7998;
          if (((int)0 <= _8005))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_8005);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logBiFreq")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8006 = _7998;
          if (((int)0 <= _8006))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_8006);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_7997 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_7997 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_7997 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_7997 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_7997 == std::string ("logIntpnt")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8007 = _7998;
          if (((int)0 <= _8007))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_8007);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntMaxIterations")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8008 = _7998;
          if (((int)0 <= _8008))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_8008);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntOffColTrh")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8009 = _7998;
          if (((int)0 <= _8009))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_8009);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_7997 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8010 = _7998;
          if (((int)0 <= _8010))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_8010);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_7997 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_7997 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_7997 == std::string ("intpntMaxNumCor")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8011 = _7998;
          if (((-(int)1) <= _8011))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_8011);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_7997 == std::string ("presolveLevel")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8012 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_8012);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logPresolve")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8013 = _7998;
          if (((int)0 <= _8013))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_8013);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_7997 == std::string ("presolveMaxNumPass")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8014 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_8014);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8015 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_8015);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8016 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_8016);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("simPrimalCrash")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8017 = _7998;
          if (((int)0 <= _8017))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_8017);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logSim")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8018 = _7998;
          if (((int)0 <= _8018))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_8018);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logSimMinor")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8019 = _7998;
          if (((int)0 <= _8019))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_8019);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logSimFreq")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8020 = _7998;
          if (((int)0 <= _8020))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_8020);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("simPrimalRestrictSelection")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8021 = _7998;
          if ((((int)0 <= _8021) && (_8021 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_8021);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_7997 == std::string ("simDualRestrictSelection")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8022 = _7998;
          if ((((int)0 <= _8022) && (_8022 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_8022);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_7997 == std::string ("simMaxIterations")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8023 = _7998;
          if (((int)0 <= _8023))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_8023);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_7997 == std::string ("simRefactorFreq")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8024 = _7998;
          if (((int)0 <= _8024))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_8024);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("simSeed")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8025 = _7998;
          if ((((int)0 <= _8025) && (_8025 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_8025);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_7997 == std::string ("logMio")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8026 = _7998;
          if (((int)0 <= _8026))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_8026);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logMioFreq")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8027 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_8027);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioMaxNumRelaxs")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8028 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_8028);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioMaxNumBranches")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8029 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_8029);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8030 = _7998;
          if (((int)0 <= _8030))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_8030);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioMaxNumSolutions")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8031 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_8031);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_7997 == std::string ("mioHeuristicLevel")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8032 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_8032);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioProbingLevel")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8033 = _7998;
          if ((((-(int)1) <= _8033) && (_8033 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_8033);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioCutSelectionLevel")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8034 = _7998;
          if ((((-(int)1) <= _8034) && (_8034 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_8034);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioVbDetectionLevel")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8035 = _7998;
          if ((((-(int)1) <= _8035) && (_8035 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_8035);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_7997 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_7997 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_7997 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_7997 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_7997 == std::string ("mioSeed")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8036 = _7998;
          if (((int)0 <= _8036))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_8036);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_7997 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_7997 == std::string ("writeLpLineWidth")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8037 = _7998;
          if (((int)40 <= _8037))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_8037);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("writeLpTermsPerLine")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8038 = _7998;
          if (((int)0 <= _8038))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_8038);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_7997 == std::string ("logInfeasAna")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8039 = _7998;
          if (((int)0 <= _8039))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_8039);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_7997 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_7997 == std::string ("licensePauseTime")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8040 = _7998;
          if ((((int)0 <= _8040) && (_8040 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_8040);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_7997 == std::string ("log")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8041 = _7998;
          if (((int)0 <= _8041))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_8041);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logExpand")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8042 = _7998;
          if (((int)0 <= _8042))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_8042);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logFile")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8043 = _7998;
          if (((int)0 <= _8043))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_8043);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("logOrder")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8044 = _7998;
          if (((int)0 <= _8044))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_8044);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_7997 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_7997 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8045 = _7998;
          if ((((int)0 <= _8045) && (_8045 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_8045);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("simDualPhaseoneMethod")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8046 = _7998;
          if ((((int)0 <= _8046) && (_8046 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_8046);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("simMaxNumSetbacks")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8047 = _7998;
          if (((int)0 <= _8047))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_8047);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_7997 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_7997 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_7997 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_7997 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_7997 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_7997 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_7997 == std::string ("simDualCrash")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8048 = _7998;
          if (((int)0 <= _8048))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_8048);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_7997 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8049 = _7998;
          if ((((-(int)1) <= _8049) && (_8049 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_8049);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_7997 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_7997 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_7997 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_7997 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_7997 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8050 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_8050);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8051 = _7998;
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_8051);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_7997 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_7997 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_7997 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_7997 == std::string ("mioRinsMaxNodes")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8052 = _7998;
          if (((-(int)1) <= _8052))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_8052);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioFeaspumpLevel")))
  {
    {
      if (((_7998 - (int)_7998) == 0.0))
      {
        {
          double _8053 = _7998;
          if ((((-(int)1) <= _8053) && (_8053 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_8053);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("optimizerMaxTime")))
  {
    {
      double _8054 = _7998;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_8054);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("lowerObjCut")))
  {
    {
      double _8055 = _7998;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_8055);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("upperObjCut")))
  {
    {
      double _8056 = _7998;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_8056);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _8057 = _7998;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_8057);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _8058 = _7998;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_8058);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolRelGap")))
  {
    {
      double _8059 = _7998;
      if ((1.000000e-14 <= _8059))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_8059);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolStepSize")))
  {
    {
      double _8060 = _7998;
      if (((0.000000e+00 <= _8060) && (_8060 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_8060);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("simLuTolRelPiv")))
  {
    {
      double _8061 = _7998;
      if (((1.000000e-06 <= _8061) && (_8061 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_8061);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolRelStep")))
  {
    {
      double _8062 = _7998;
      if (((1.000000e-04 <= _8062) && (_8062 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_8062);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolPath")))
  {
    {
      double _8063 = _7998;
      if (((0.000000e+00 <= _8063) && (_8063 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_8063);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolPfeas")))
  {
    {
      double _8064 = _7998;
      if (((0.000000e+00 <= _8064) && (_8064 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_8064);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolDfeas")))
  {
    {
      double _8065 = _7998;
      if (((0.000000e+00 <= _8065) && (_8065 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_8065);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolMuRed")))
  {
    {
      double _8066 = _7998;
      if (((0.000000e+00 <= _8066) && (_8066 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_8066);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolInfeas")))
  {
    {
      double _8067 = _7998;
      if (((0.000000e+00 <= _8067) && (_8067 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_8067);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _8068 = _7998;
      if (((0.000000e+00 <= _8068) && (_8068 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_8068);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _8069 = _7998;
      if (((0.000000e+00 <= _8069) && (_8069 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_8069);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _8070 = _7998;
      if (((0.000000e+00 <= _8070) && (_8070 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_8070);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _8071 = _7998;
      if (((0.000000e+00 <= _8071) && (_8071 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_8071);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _8072 = _7998;
      if ((1.000000e+00 <= _8072))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_8072);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _8073 = _7998;
      if (((0.000000e+00 <= _8073) && (_8073 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_8073);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolPsafe")))
  {
    {
      double _8074 = _7998;
      if ((1.000000e-04 <= _8074))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_8074);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("intpntTolDsafe")))
  {
    {
      double _8075 = _7998;
      if ((1.000000e-04 <= _8075))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_8075);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioMaxTime")))
  {
    {
      double _8076 = _7998;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_8076);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioRelGapConst")))
  {
    {
      double _8077 = _7998;
      if ((1.000000e-15 <= _8077))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_8077);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioTolRelGap")))
  {
    {
      double _8078 = _7998;
      if ((0.000000e+00 <= _8078))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_8078);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioTolAbsGap")))
  {
    {
      double _8079 = _7998;
      if ((0.000000e+00 <= _8079))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_8079);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _8080 = _7998;
      if ((1.000000e-09 <= _8080))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_8080);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("basisTolX")))
  {
    {
      double _8081 = _7998;
      if ((1.000000e-09 <= _8081))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_8081);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("basisTolS")))
  {
    {
      double _8082 = _7998;
      if ((1.000000e-09 <= _8082))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_8082);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("basisRelTolS")))
  {
    {
      double _8083 = _7998;
      if ((0.000000e+00 <= _8083))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_8083);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveTolX")))
  {
    {
      double _8084 = _7998;
      if ((0.000000e+00 <= _8084))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_8084);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveTolS")))
  {
    {
      double _8085 = _7998;
      if ((0.000000e+00 <= _8085))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_8085);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveTolAij")))
  {
    {
      double _8086 = _7998;
      if ((1.000000e-15 <= _8086))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_8086);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _8087 = _7998;
      if ((0.000000e+00 <= _8087))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_8087);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("presolveTolRelLindep")))
  {
    {
      double _8088 = _7998;
      if ((0.000000e+00 <= _8088))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_8088);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _8089 = _7998;
      if ((1.000000e-12 <= _8089))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_8089);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioTolFeas")))
  {
    {
      double _8090 = _7998;
      if (((1.000000e-09 <= _8090) && (_8090 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_8090);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_7997 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _8091 = _7998;
      if (((0.000000e+00 <= _8091) && (_8091 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_7996.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_8091);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_7997 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_7997 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_7997 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_7997 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_7997 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_7997 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _8092,    const std::string & _8093,    int _8094) { mosek::fusion::p_Parameters::setParameter(_8092,_8093,_8094); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _8092,const std::string & _8093,int _8094){
  if (false)
  {
    {
    }
  }
  else if((_8093 == std::string ("autoUpdateSolInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
    }
  }
  else if((_8093 == std::string ("removeUnusedSolutions")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
    }
  }
  {}
  if ((_8093 == std::string ("numThreads")))
  {
    {
      int _8095 = _8094;
      if (((int)0 <= _8095))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_8095);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("intpntMultiThread")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
    }
  }
  {}
  if ((_8093 == std::string ("mtSpincount")))
  {
    {
      int _8096 = _8094;
      if ((((int)0 <= _8096) && (_8096 <= (int)1000000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_8096);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("optimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
    }
  }
  {}
  if ((_8093 == std::string ("biMaxIterations")))
  {
    {
      int _8097 = _8094;
      if (((int)0 <= _8097))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_8097);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      int _8098 = _8094;
      if (((int)0 <= _8098))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_8098);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logCutSecondOpt")))
  {
    {
      int _8099 = _8094;
      if (((int)0 <= _8099))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_8099);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logResponse")))
  {
    {
      int _8100 = _8094;
      if (((int)0 <= _8100))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_8100);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("logLocalInfo")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
    }
  }
  {}
  if ((_8093 == std::string ("logBi")))
  {
    {
      int _8101 = _8094;
      if (((int)0 <= _8101))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_8101);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logBiFreq")))
  {
    {
      int _8102 = _8094;
      if (((int)0 <= _8102))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_8102);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("biCleanOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
    }
  }
  else if((_8093 == std::string ("intpntStartingPoint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
    }
  }
  else if((_8093 == std::string ("intpntDiffStep")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
    }
  }
  else if((_8093 == std::string ("intpntScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
    }
  }
  else if((_8093 == std::string ("intpntSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
    }
  }
  {}
  if ((_8093 == std::string ("logIntpnt")))
  {
    {
      int _8103 = _8094;
      if (((int)0 <= _8103))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_8103);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntMaxIterations")))
  {
    {
      int _8104 = _8094;
      if (((int)0 <= _8104))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_8104);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntOffColTrh")))
  {
    {
      int _8105 = _8094;
      if (((int)0 <= _8105))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_8105);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("intpntOrderMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
    }
  }
  {}
  if ((_8093 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      int _8106 = _8094;
      if (((int)0 <= _8106))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_8106);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("intpntBasis")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
    }
  }
  else if((_8093 == std::string ("biIgnoreMaxIter")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
    }
  }
  else if((_8093 == std::string ("biIgnoreNumError")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
    }
  }
  {}
  if ((_8093 == std::string ("intpntMaxNumCor")))
  {
    {
      int _8107 = _8094;
      if (((-(int)1) <= _8107))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_8107);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("presolveUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
    }
  }
  {}
  if ((_8093 == std::string ("presolveLevel")))
  {
    {
      int _8108 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_8108);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logPresolve")))
  {
    {
      int _8109 = _8094;
      if (((int)0 <= _8109))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_8109);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("presolveLindepUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
    }
  }
  {}
  if ((_8093 == std::string ("presolveMaxNumPass")))
  {
    {
      int _8110 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_8110);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      int _8111 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_8111);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      int _8112 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_8112);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("simPrimalCrash")))
  {
    {
      int _8113 = _8094;
      if (((int)0 <= _8113))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_8113);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logSim")))
  {
    {
      int _8114 = _8094;
      if (((int)0 <= _8114))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_8114);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logSimMinor")))
  {
    {
      int _8115 = _8094;
      if (((int)0 <= _8115))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_8115);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logSimFreq")))
  {
    {
      int _8116 = _8094;
      if (((int)0 <= _8116))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_8116);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("simPrimalRestrictSelection")))
  {
    {
      int _8117 = _8094;
      if ((((int)0 <= _8117) && (_8117 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_8117);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("simPrimalSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
    }
  }
  {}
  if ((_8093 == std::string ("simDualRestrictSelection")))
  {
    {
      int _8118 = _8094;
      if ((((int)0 <= _8118) && (_8118 <= (int)100)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_8118);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("simDualSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
    }
  }
  {}
  if ((_8093 == std::string ("simMaxIterations")))
  {
    {
      int _8119 = _8094;
      if (((int)0 <= _8119))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_8119);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("simHotstartLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
    }
  }
  {}
  if ((_8093 == std::string ("simRefactorFreq")))
  {
    {
      int _8120 = _8094;
      if (((int)0 <= _8120))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_8120);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("simSeed")))
  {
    {
      int _8121 = _8094;
      if ((((int)0 <= _8121) && (_8121 <= (int)32749)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_8121);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("mioMode")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
    }
  }
  {}
  if ((_8093 == std::string ("logMio")))
  {
    {
      int _8122 = _8094;
      if (((int)0 <= _8122))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_8122);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logMioFreq")))
  {
    {
      int _8123 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_8123);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioMaxNumRelaxs")))
  {
    {
      int _8124 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_8124);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioMaxNumBranches")))
  {
    {
      int _8125 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_8125);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      int _8126 = _8094;
      if (((int)0 <= _8126))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_8126);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioMaxNumSolutions")))
  {
    {
      int _8127 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_8127);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("mioNodeSelection")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
    }
  }
  {}
  if ((_8093 == std::string ("mioHeuristicLevel")))
  {
    {
      int _8128 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_8128);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioProbingLevel")))
  {
    {
      int _8129 = _8094;
      if ((((-(int)1) <= _8129) && (_8129 <= (int)3)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_8129);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioCutSelectionLevel")))
  {
    {
      int _8130 = _8094;
      if ((((-(int)1) <= _8130) && (_8130 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_8130);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioVbDetectionLevel")))
  {
    {
      int _8131 = _8094;
      if ((((-(int)1) <= _8131) && (_8131 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_8131);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("mioBranchDir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
    }
  }
  else if((_8093 == std::string ("mioRootOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
    }
  }
  else if((_8093 == std::string ("mioNodeOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
    }
  }
  else if((_8093 == std::string ("mioPerspectiveReformulate")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
    }
  }
  else if((_8093 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
    }
  }
  {}
  if ((_8093 == std::string ("mioSeed")))
  {
    {
      int _8132 = _8094;
      if (((int)0 <= _8132))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_8132);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("mioConicOuterApproximation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
    }
  }
  else if((_8093 == std::string ("writeLpQuotedNames")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
    }
  }
  {}
  if ((_8093 == std::string ("writeLpLineWidth")))
  {
    {
      int _8133 = _8094;
      if (((int)40 <= _8133))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_8133);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("writeLpTermsPerLine")))
  {
    {
      int _8134 = _8094;
      if (((int)0 <= _8134))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_8134);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("writeLpFullObj")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
    }
  }
  {}
  if ((_8093 == std::string ("logInfeasAna")))
  {
    {
      int _8135 = _8094;
      if (((int)0 <= _8135))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_8135);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("licenseWait")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
    }
  }
  else if((_8093 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
    }
  }
  {}
  if ((_8093 == std::string ("licensePauseTime")))
  {
    {
      int _8136 = _8094;
      if ((((int)0 <= _8136) && (_8136 <= (int)1000000)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_8136);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("licenseDebug")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
    }
  }
  {}
  if ((_8093 == std::string ("log")))
  {
    {
      int _8137 = _8094;
      if (((int)0 <= _8137))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_8137);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logExpand")))
  {
    {
      int _8138 = _8094;
      if (((int)0 <= _8138))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_8138);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logFile")))
  {
    {
      int _8139 = _8094;
      if (((int)0 <= _8139))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_8139);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("logOrder")))
  {
    {
      int _8140 = _8094;
      if (((int)0 <= _8140))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_8140);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("simScaling")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
    }
  }
  else if((_8093 == std::string ("simScalingMethod")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
    }
  }
  {}
  if ((_8093 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      int _8141 = _8094;
      if ((((int)0 <= _8141) && (_8141 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_8141);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("simDualPhaseoneMethod")))
  {
    {
      int _8142 = _8094;
      if ((((int)0 <= _8142) && (_8142 <= (int)10)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_8142);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("simMaxNumSetbacks")))
  {
    {
      int _8143 = _8094;
      if (((int)0 <= _8143))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_8143);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("simHotstart")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
    }
  }
  else if((_8093 == std::string ("simBasisFactorUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
    }
  }
  else if((_8093 == std::string ("simDegen")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
    }
  }
  else if((_8093 == std::string ("simReformulation")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
    }
  }
  else if((_8093 == std::string ("simExploitDupvec")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
    }
  }
  else if((_8093 == std::string ("simSaveLu")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
    }
  }
  else if((_8093 == std::string ("simNonSingular")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
    }
  }
  {}
  if ((_8093 == std::string ("simDualCrash")))
  {
    {
      int _8144 = _8094;
      if (((int)0 <= _8144))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_8144);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("infeasPreferPrimal")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
    }
  }
  {}
  if ((_8093 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      int _8145 = _8094;
      if ((((-(int)1) <= _8145) && (_8145 <= (int)1)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_8145);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("mioCutCmir")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
    }
  }
  else if((_8093 == std::string ("mioCutClique")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
    }
  }
  else if((_8093 == std::string ("mioCutImpliedBound")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
    }
  }
  else if((_8093 == std::string ("mioCutKnapsackCover")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
    }
  }
  else if((_8093 == std::string ("mioCutGmi")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
    }
  }
  {}
  if ((_8093 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      int _8146 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_8146);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      int _8147 = _8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_8147);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("cacheLicense")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
    }
  }
  else if((_8093 == std::string ("intpntRegularizationUse")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
    }
  }
  else if((_8093 == std::string ("simSolveForm")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
    }
  }
  else if((_8093 == std::string ("simSwitchOptimizer")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
    }
  }
  {}
  if ((_8093 == std::string ("mioRinsMaxNodes")))
  {
    {
      int _8148 = _8094;
      if (((-(int)1) <= _8148))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_8148);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioFeaspumpLevel")))
  {
    {
      int _8149 = _8094;
      if ((((-(int)1) <= _8149) && (_8149 <= (int)2)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_8149);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("optimizerMaxTime")))
  {
    {
      double _8150 = (double)_8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_8150);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("lowerObjCut")))
  {
    {
      double _8151 = (double)_8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_8151);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("upperObjCut")))
  {
    {
      double _8152 = (double)_8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_8152);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      double _8153 = (double)_8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_8153);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      double _8154 = (double)_8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_8154);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolRelGap")))
  {
    {
      double _8155 = (double)_8094;
      if ((1.000000e-14 <= _8155))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_8155);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolStepSize")))
  {
    {
      double _8156 = (double)_8094;
      if (((0.000000e+00 <= _8156) && (_8156 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_8156);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("simLuTolRelPiv")))
  {
    {
      double _8157 = (double)_8094;
      if (((1.000000e-06 <= _8157) && (_8157 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_8157);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolRelStep")))
  {
    {
      double _8158 = (double)_8094;
      if (((1.000000e-04 <= _8158) && (_8158 <= 9.999990e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_8158);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolPath")))
  {
    {
      double _8159 = (double)_8094;
      if (((0.000000e+00 <= _8159) && (_8159 <= 9.999000e-01)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_8159);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolPfeas")))
  {
    {
      double _8160 = (double)_8094;
      if (((0.000000e+00 <= _8160) && (_8160 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_8160);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolDfeas")))
  {
    {
      double _8161 = (double)_8094;
      if (((0.000000e+00 <= _8161) && (_8161 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_8161);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolMuRed")))
  {
    {
      double _8162 = (double)_8094;
      if (((0.000000e+00 <= _8162) && (_8162 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_8162);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolInfeas")))
  {
    {
      double _8163 = (double)_8094;
      if (((0.000000e+00 <= _8163) && (_8163 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_8163);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntCoTolRelGap")))
  {
    {
      double _8164 = (double)_8094;
      if (((0.000000e+00 <= _8164) && (_8164 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_8164);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntCoTolPfeas")))
  {
    {
      double _8165 = (double)_8094;
      if (((0.000000e+00 <= _8165) && (_8165 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_8165);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntCoTolDfeas")))
  {
    {
      double _8166 = (double)_8094;
      if (((0.000000e+00 <= _8166) && (_8166 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_8166);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntCoTolMuRed")))
  {
    {
      double _8167 = (double)_8094;
      if (((0.000000e+00 <= _8167) && (_8167 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_8167);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntCoTolNearRel")))
  {
    {
      double _8168 = (double)_8094;
      if ((1.000000e+00 <= _8168))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_8168);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntCoTolInfeas")))
  {
    {
      double _8169 = (double)_8094;
      if (((0.000000e+00 <= _8169) && (_8169 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_8169);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolPsafe")))
  {
    {
      double _8170 = (double)_8094;
      if ((1.000000e-04 <= _8170))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_8170);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("intpntTolDsafe")))
  {
    {
      double _8171 = (double)_8094;
      if ((1.000000e-04 <= _8171))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_8171);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioMaxTime")))
  {
    {
      double _8172 = (double)_8094;
      if (true)
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_8172);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioRelGapConst")))
  {
    {
      double _8173 = (double)_8094;
      if ((1.000000e-15 <= _8173))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_8173);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioTolRelGap")))
  {
    {
      double _8174 = (double)_8094;
      if ((0.000000e+00 <= _8174))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_8174);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioTolAbsGap")))
  {
    {
      double _8175 = (double)_8094;
      if ((0.000000e+00 <= _8175))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_8175);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      double _8176 = (double)_8094;
      if ((1.000000e-09 <= _8176))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_8176);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("basisTolX")))
  {
    {
      double _8177 = (double)_8094;
      if ((1.000000e-09 <= _8177))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_8177);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("basisTolS")))
  {
    {
      double _8178 = (double)_8094;
      if ((1.000000e-09 <= _8178))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_8178);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("basisRelTolS")))
  {
    {
      double _8179 = (double)_8094;
      if ((0.000000e+00 <= _8179))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_8179);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveTolX")))
  {
    {
      double _8180 = (double)_8094;
      if ((0.000000e+00 <= _8180))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_8180);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveTolS")))
  {
    {
      double _8181 = (double)_8094;
      if ((0.000000e+00 <= _8181))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_8181);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveTolAij")))
  {
    {
      double _8182 = (double)_8094;
      if ((1.000000e-15 <= _8182))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_8182);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveTolAbsLindep")))
  {
    {
      double _8183 = (double)_8094;
      if ((0.000000e+00 <= _8183))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_8183);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("presolveTolRelLindep")))
  {
    {
      double _8184 = (double)_8094;
      if ((0.000000e+00 <= _8184))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_8184);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("simplexAbsTolPiv")))
  {
    {
      double _8185 = (double)_8094;
      if ((1.000000e-12 <= _8185))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_8185);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioTolFeas")))
  {
    {
      double _8186 = (double)_8094;
      if (((1.000000e-09 <= _8186) && (_8186 <= 1.000000e-03)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_8186);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_8093 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      double _8187 = (double)_8094;
      if (((0.000000e+00 <= _8187) && (_8187 <= 1.000000e+00)))
      {
        {
          mosek::fusion::p_Model::_get_impl(_8092.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_8187);
          return;
        }
      }
      else
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  else if((_8093 == std::string ("dataFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (dataFileName)"));
    }
  }
  else if((_8093 == std::string ("basSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basSolFileName)"));
    }
  }
  else if((_8093 == std::string ("itrSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (itrSolFileName)"));
    }
  }
  else if((_8093 == std::string ("intSolFileName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intSolFileName)"));
    }
  }
  else if((_8093 == std::string ("writeLpGenVarName")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpGenVarName)"));
    }
  }
  else if((_8093 == std::string ("remoteAccessToken")))
  {
    {
      throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (remoteAccessToken)"));
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
void mosek::fusion::Parameters::setParameter  ( monty::rc_ptr< ::mosek::fusion::Model > _8188,    const std::string & _8189,    const std::string & _8190) { mosek::fusion::p_Parameters::setParameter(_8188,_8189,_8190); }void mosek::fusion::p_Parameters::setParameter(monty::rc_ptr< ::mosek::fusion::Model > _8188,const std::string & _8189,const std::string & _8190){
  if (false)
  {
    {
    }
  }
  {}
  if ((_8189 == std::string ("autoUpdateSolInfo")))
  {
    {
      int _8191 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8191 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (autoUpdateSolInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_AUTO_UPDATE_SOL_INFO"),_8191);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("removeUnusedSolutions")))
  {
    {
      int _8192 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8192 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (removeUnusedSolutions)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_REMOVE_UNUSED_SOLUTIONS"),_8192);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("numThreads")))
  {
    {
      try
      {
        {
          int _8194 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8194))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_NUM_THREADS"),_8194);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8193)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (numThreads)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntMultiThread")))
  {
    {
      int _8195 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8195 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMultiThread)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MULTI_THREAD"),_8195);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mtSpincount")))
  {
    {
      try
      {
        {
          int _8197 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((int)0 <= _8197) && (_8197 <= (int)1000000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MT_SPINCOUNT"),_8197);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8196)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mtSpincount)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("optimizer")))
  {
    {
      int _8198 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_8190);
      if ((_8198 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_OPTIMIZER"),_8198);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("biMaxIterations")))
  {
    {
      try
      {
        {
          int _8200 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8200))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_BI_MAX_ITERATIONS"),_8200);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8199)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      try
      {
        {
          int _8202 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8202))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_TRH_EXPIRY_WRN"),_8202);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8201)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseTrhExpiryWrn)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logCutSecondOpt")))
  {
    {
      try
      {
        {
          int _8204 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8204))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_CUT_SECOND_OPT"),_8204);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8203)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logCutSecondOpt)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logResponse")))
  {
    {
      try
      {
        {
          int _8206 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8206))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_RESPONSE"),_8206);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8205)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logResponse)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logLocalInfo")))
  {
    {
      int _8207 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8207 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logLocalInfo)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_LOCAL_INFO"),_8207);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("logBi")))
  {
    {
      try
      {
        {
          int _8209 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8209))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI"),_8209);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8208)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBi)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logBiFreq")))
  {
    {
      try
      {
        {
          int _8211 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8211))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_BI_FREQ"),_8211);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8210)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logBiFreq)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("biCleanOptimizer")))
  {
    {
      int _8212 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_8190);
      if ((_8212 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biCleanOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_BI_CLEAN_OPTIMIZER"),_8212);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intpntStartingPoint")))
  {
    {
      int _8213 = ::mosek::fusion::p_Parameters::string_to_startpointtype_value(_8190);
      if ((_8213 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntStartingPoint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_STARTING_POINT"),_8213);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intpntDiffStep")))
  {
    {
      int _8214 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8214 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntDiffStep)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_DIFF_STEP"),_8214);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intpntScaling")))
  {
    {
      int _8215 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_8190);
      if ((_8215 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SCALING"),_8215);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intpntSolveForm")))
  {
    {
      int _8216 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_8190);
      if ((_8216 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_SOLVE_FORM"),_8216);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("logIntpnt")))
  {
    {
      try
      {
        {
          int _8218 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8218))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_INTPNT"),_8218);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8217)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logIntpnt)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntMaxIterations")))
  {
    {
      try
      {
        {
          int _8220 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8220))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_ITERATIONS"),_8220);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8219)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntOffColTrh")))
  {
    {
      try
      {
        {
          int _8222 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8222))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_OFF_COL_TRH"),_8222);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8221)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOffColTrh)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntOrderMethod")))
  {
    {
      int _8223 = ::mosek::fusion::p_Parameters::string_to_orderingtype_value(_8190);
      if ((_8223 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_METHOD"),_8223);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      try
      {
        {
          int _8225 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8225))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_ORDER_GP_NUM_SEEDS"),_8225);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8224)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntOrderGpNumSeeds)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntBasis")))
  {
    {
      int _8226 = ::mosek::fusion::p_Parameters::string_to_basindtype_value(_8190);
      if ((_8226 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntBasis)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_BASIS"),_8226);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("biIgnoreMaxIter")))
  {
    {
      int _8227 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8227 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreMaxIter)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_MAX_ITER"),_8227);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("biIgnoreNumError")))
  {
    {
      int _8228 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8228 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (biIgnoreNumError)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_BI_IGNORE_NUM_ERROR"),_8228);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intpntMaxNumCor")))
  {
    {
      try
      {
        {
          int _8230 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((-(int)1) <= _8230))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_MAX_NUM_COR"),_8230);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8229)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntMaxNumCor)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveUse")))
  {
    {
      int _8231 = ::mosek::fusion::p_Parameters::string_to_presolvemode_value(_8190);
      if ((_8231 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_USE"),_8231);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("presolveLevel")))
  {
    {
      try
      {
        {
          int _8233 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LEVEL"),_8233);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8232)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logPresolve")))
  {
    {
      try
      {
        {
          int _8235 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8235))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_PRESOLVE"),_8235);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8234)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logPresolve)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveLindepUse")))
  {
    {
      int _8236 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8236 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_USE"),_8236);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("presolveMaxNumPass")))
  {
    {
      try
      {
        {
          int _8238 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_MAX_NUM_PASS"),_8238);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8237)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveMaxNumPass)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      try
      {
        {
          int _8240 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_NUM_TRIES"),_8240);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8239)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxNumTries)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      try
      {
        {
          int _8242 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_ELIMINATOR_MAX_FILL"),_8242);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8241)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveEliminatorMaxFill)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simPrimalCrash")))
  {
    {
      try
      {
        {
          int _8244 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8244))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_CRASH"),_8244);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8243)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalCrash)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logSim")))
  {
    {
      try
      {
        {
          int _8246 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8246))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM"),_8246);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8245)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSim)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logSimMinor")))
  {
    {
      try
      {
        {
          int _8248 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8248))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_MINOR"),_8248);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8247)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimMinor)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logSimFreq")))
  {
    {
      try
      {
        {
          int _8250 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8250))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_SIM_FREQ"),_8250);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8249)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logSimFreq)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simPrimalRestrictSelection")))
  {
    {
      try
      {
        {
          int _8252 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((int)0 <= _8252) && (_8252 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_RESTRICT_SELECTION"),_8252);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8251)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simPrimalSelection")))
  {
    {
      int _8253 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_8190);
      if ((_8253 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_SELECTION"),_8253);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simDualRestrictSelection")))
  {
    {
      try
      {
        {
          int _8255 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((int)0 <= _8255) && (_8255 <= (int)100)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_RESTRICT_SELECTION"),_8255);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8254)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualRestrictSelection)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simDualSelection")))
  {
    {
      int _8256 = ::mosek::fusion::p_Parameters::string_to_simseltype_value(_8190);
      if ((_8256 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_SELECTION"),_8256);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simMaxIterations")))
  {
    {
      try
      {
        {
          int _8258 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8258))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_ITERATIONS"),_8258);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8257)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxIterations)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simHotstartLu")))
  {
    {
      int _8259 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8259 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstartLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART_LU"),_8259);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simRefactorFreq")))
  {
    {
      try
      {
        {
          int _8261 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8261))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFACTOR_FREQ"),_8261);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8260)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simRefactorFreq)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simSeed")))
  {
    {
      try
      {
        {
          int _8263 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((int)0 <= _8263) && (_8263 <= (int)32749)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_SEED"),_8263);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8262)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSeed)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioMode")))
  {
    {
      int _8264 = ::mosek::fusion::p_Parameters::string_to_miomode_value(_8190);
      if ((_8264 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMode)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_MODE"),_8264);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("logMio")))
  {
    {
      try
      {
        {
          int _8266 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8266))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO"),_8266);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8265)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMio)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logMioFreq")))
  {
    {
      try
      {
        {
          int _8268 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_MIO_FREQ"),_8268);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8267)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logMioFreq)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioMaxNumRelaxs")))
  {
    {
      try
      {
        {
          int _8270 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_RELAXS"),_8270);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8269)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRelaxs)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioMaxNumBranches")))
  {
    {
      try
      {
        {
          int _8272 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_BRANCHES"),_8272);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8271)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumBranches)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      try
      {
        {
          int _8274 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8274))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_ROOT_CUT_ROUNDS"),_8274);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8273)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumRootCutRounds)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioMaxNumSolutions")))
  {
    {
      try
      {
        {
          int _8276 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_MAX_NUM_SOLUTIONS"),_8276);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8275)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxNumSolutions)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioNodeSelection")))
  {
    {
      int _8277 = ::mosek::fusion::p_Parameters::string_to_mionodeseltype_value(_8190);
      if ((_8277 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeSelection)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_SELECTION"),_8277);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioHeuristicLevel")))
  {
    {
      try
      {
        {
          int _8279 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_HEURISTIC_LEVEL"),_8279);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8278)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioHeuristicLevel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioProbingLevel")))
  {
    {
      try
      {
        {
          int _8281 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((-(int)1) <= _8281) && (_8281 <= (int)3)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROBING_LEVEL"),_8281);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8280)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioProbingLevel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioCutSelectionLevel")))
  {
    {
      try
      {
        {
          int _8283 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((-(int)1) <= _8283) && (_8283 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_SELECTION_LEVEL"),_8283);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8282)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutSelectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioVbDetectionLevel")))
  {
    {
      try
      {
        {
          int _8285 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((-(int)1) <= _8285) && (_8285 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_VB_DETECTION_LEVEL"),_8285);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8284)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioVbDetectionLevel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioBranchDir")))
  {
    {
      int _8286 = ::mosek::fusion::p_Parameters::string_to_branchdir_value(_8190);
      if ((_8286 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioBranchDir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_BRANCH_DIR"),_8286);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioRootOptimizer")))
  {
    {
      int _8287 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_8190);
      if ((_8287 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_OPTIMIZER"),_8287);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioNodeOptimizer")))
  {
    {
      int _8288 = ::mosek::fusion::p_Parameters::string_to_optimizertype_value(_8190);
      if ((_8288 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioNodeOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_NODE_OPTIMIZER"),_8288);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioPerspectiveReformulate")))
  {
    {
      int _8289 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8289 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPerspectiveReformulate)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_PERSPECTIVE_REFORMULATE"),_8289);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      int _8290 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8290 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioPropagateObjectiveConstraint)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_PROPAGATE_OBJECTIVE_CONSTRAINT"),_8290);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioSeed")))
  {
    {
      try
      {
        {
          int _8292 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8292))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_SEED"),_8292);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8291)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioSeed)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioConicOuterApproximation")))
  {
    {
      int _8293 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8293 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioConicOuterApproximation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_CONIC_OUTER_APPROXIMATION"),_8293);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("writeLpQuotedNames")))
  {
    {
      int _8294 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8294 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpQuotedNames)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_QUOTED_NAMES"),_8294);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("writeLpLineWidth")))
  {
    {
      try
      {
        {
          int _8296 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)40 <= _8296))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_LINE_WIDTH"),_8296);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8295)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpLineWidth)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("writeLpTermsPerLine")))
  {
    {
      try
      {
        {
          int _8298 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8298))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_TERMS_PER_LINE"),_8298);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8297)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpTermsPerLine)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("writeLpFullObj")))
  {
    {
      int _8299 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8299 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (writeLpFullObj)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_WRITE_LP_FULL_OBJ"),_8299);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("logInfeasAna")))
  {
    {
      try
      {
        {
          int _8301 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8301))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_INFEAS_ANA"),_8301);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8300)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logInfeasAna)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("licenseWait")))
  {
    {
      int _8302 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8302 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseWait)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_WAIT"),_8302);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      int _8303 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8303 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseSuppressExpireWrns)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_SUPPRESS_EXPIRE_WRNS"),_8303);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("licensePauseTime")))
  {
    {
      try
      {
        {
          int _8305 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((int)0 <= _8305) && (_8305 <= (int)1000000)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_PAUSE_TIME"),_8305);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8304)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licensePauseTime)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("licenseDebug")))
  {
    {
      int _8306 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8306 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (licenseDebug)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LICENSE_DEBUG"),_8306);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("log")))
  {
    {
      try
      {
        {
          int _8308 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8308))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG"),_8308);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8307)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (log)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logExpand")))
  {
    {
      try
      {
        {
          int _8310 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8310))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_EXPAND"),_8310);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8309)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logExpand)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logFile")))
  {
    {
      try
      {
        {
          int _8312 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8312))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_FILE"),_8312);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8311)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logFile)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("logOrder")))
  {
    {
      try
      {
        {
          int _8314 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8314))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_LOG_ORDER"),_8314);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8313)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (logOrder)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simScaling")))
  {
    {
      int _8315 = ::mosek::fusion::p_Parameters::string_to_scalingtype_value(_8190);
      if ((_8315 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScaling)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING"),_8315);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simScalingMethod")))
  {
    {
      int _8316 = ::mosek::fusion::p_Parameters::string_to_scalingmethod_value(_8190);
      if ((_8316 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simScalingMethod)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_SCALING_METHOD"),_8316);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _8318 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((int)0 <= _8318) && (_8318 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_PRIMAL_PHASEONE_METHOD"),_8318);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8317)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simPrimalPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simDualPhaseoneMethod")))
  {
    {
      try
      {
        {
          int _8320 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((int)0 <= _8320) && (_8320 <= (int)10)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_PHASEONE_METHOD"),_8320);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8319)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualPhaseoneMethod)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simMaxNumSetbacks")))
  {
    {
      try
      {
        {
          int _8322 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8322))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_MAX_NUM_SETBACKS"),_8322);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8321)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simMaxNumSetbacks)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simHotstart")))
  {
    {
      int _8323 = ::mosek::fusion::p_Parameters::string_to_simhotstart_value(_8190);
      if ((_8323 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simHotstart)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_HOTSTART"),_8323);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simBasisFactorUse")))
  {
    {
      int _8324 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8324 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simBasisFactorUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_BASIS_FACTOR_USE"),_8324);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simDegen")))
  {
    {
      int _8325 = ::mosek::fusion::p_Parameters::string_to_simdegen_value(_8190);
      if ((_8325 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDegen)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_DEGEN"),_8325);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simReformulation")))
  {
    {
      int _8326 = ::mosek::fusion::p_Parameters::string_to_simreform_value(_8190);
      if ((_8326 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simReformulation)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_REFORMULATION"),_8326);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simExploitDupvec")))
  {
    {
      int _8327 = ::mosek::fusion::p_Parameters::string_to_simdupvec_value(_8190);
      if ((_8327 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simExploitDupvec)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_EXPLOIT_DUPVEC"),_8327);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simSaveLu")))
  {
    {
      int _8328 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8328 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSaveLu)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_SAVE_LU"),_8328);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simNonSingular")))
  {
    {
      int _8329 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8329 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simNonSingular)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_NON_SINGULAR"),_8329);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simDualCrash")))
  {
    {
      try
      {
        {
          int _8331 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((int)0 <= _8331))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_DUAL_CRASH"),_8331);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8330)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simDualCrash)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("infeasPreferPrimal")))
  {
    {
      int _8332 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8332 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (infeasPreferPrimal)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INFEAS_PREFER_PRIMAL"),_8332);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      try
      {
        {
          int _8334 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((-(int)1) <= _8334) && (_8334 <= (int)1)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_ROOT_REPEAT_PRESOLVE_LEVEL"),_8334);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8333)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRootRepeatPresolveLevel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioCutCmir")))
  {
    {
      int _8335 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8335 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutCmir)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CMIR"),_8335);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioCutClique")))
  {
    {
      int _8336 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8336 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutClique)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_CLIQUE"),_8336);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioCutImpliedBound")))
  {
    {
      int _8337 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8337 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutImpliedBound)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_IMPLIED_BOUND"),_8337);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioCutKnapsackCover")))
  {
    {
      int _8338 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8338 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutKnapsackCover)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_KNAPSACK_COVER"),_8338);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioCutGmi")))
  {
    {
      int _8339 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8339 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioCutGmi)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_CUT_GMI"),_8339);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      try
      {
        {
          int _8341 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_REL_WORK_TRH"),_8341);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8340)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepRelWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      try
      {
        {
          int _8343 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_PRESOLVE_LINDEP_ABS_WORK_TRH"),_8343);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8342)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveLindepAbsWorkTrh)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("cacheLicense")))
  {
    {
      int _8344 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8344 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (cacheLicense)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_CACHE_LICENSE"),_8344);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intpntRegularizationUse")))
  {
    {
      int _8345 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8345 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntRegularizationUse)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_INTPNT_REGULARIZATION_USE"),_8345);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simSolveForm")))
  {
    {
      int _8346 = ::mosek::fusion::p_Parameters::string_to_solveform_value(_8190);
      if ((_8346 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSolveForm)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_SOLVE_FORM"),_8346);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("simSwitchOptimizer")))
  {
    {
      int _8347 = ::mosek::fusion::p_Parameters::string_to_onoffkey_value(_8190);
      if ((_8347 < (int)0))
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simSwitchOptimizer)"));
        }
      }
      {}
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_SIM_SWITCH_OPTIMIZER"),_8347);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("mioRinsMaxNodes")))
  {
    {
      try
      {
        {
          int _8349 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if (((-(int)1) <= _8349))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_RINS_MAX_NODES"),_8349);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8348)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRinsMaxNodes)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioFeaspumpLevel")))
  {
    {
      try
      {
        {
          int _8351 = ::mosek::fusion::Utils::Tools::toInt(_8190);
          if ((((-(int)1) <= _8351) && (_8351 <= (int)2)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_IPAR_MIO_FEASPUMP_LEVEL"),_8351);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8350)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioFeaspumpLevel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("optimizerMaxTime")))
  {
    {
      try
      {
        {
          double _8353 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_OPTIMIZER_MAX_TIME"),_8353);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8352)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (optimizerMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("lowerObjCut")))
  {
    {
      try
      {
        {
          double _8355 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT"),_8355);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8354)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCut)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("upperObjCut")))
  {
    {
      try
      {
        {
          double _8357 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT"),_8357);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8356)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCut)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _8359 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_UPPER_OBJ_CUT_FINITE_TRH"),_8359);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8358)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (upperObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      try
      {
        {
          double _8361 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_LOWER_OBJ_CUT_FINITE_TRH"),_8361);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8360)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (lowerObjCutFiniteTrh)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolRelGap")))
  {
    {
      try
      {
        {
          double _8363 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-14 <= _8363))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_GAP"),_8363);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8362)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolStepSize")))
  {
    {
      try
      {
        {
          double _8365 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8365) && (_8365 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_STEP_SIZE"),_8365);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8364)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolStepSize)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simLuTolRelPiv")))
  {
    {
      try
      {
        {
          double _8367 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((1.000000e-06 <= _8367) && (_8367 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_SIM_LU_TOL_REL_PIV"),_8367);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8366)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simLuTolRelPiv)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolRelStep")))
  {
    {
      try
      {
        {
          double _8369 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((1.000000e-04 <= _8369) && (_8369 <= 9.999990e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_REL_STEP"),_8369);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8368)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolRelStep)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolPath")))
  {
    {
      try
      {
        {
          double _8371 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8371) && (_8371 <= 9.999000e-01)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PATH"),_8371);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8370)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPath)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolPfeas")))
  {
    {
      try
      {
        {
          double _8373 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8373) && (_8373 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PFEAS"),_8373);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8372)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolDfeas")))
  {
    {
      try
      {
        {
          double _8375 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8375) && (_8375 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DFEAS"),_8375);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8374)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolMuRed")))
  {
    {
      try
      {
        {
          double _8377 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8377) && (_8377 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_MU_RED"),_8377);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8376)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolInfeas")))
  {
    {
      try
      {
        {
          double _8379 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8379) && (_8379 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_INFEAS"),_8379);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8378)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntCoTolRelGap")))
  {
    {
      try
      {
        {
          double _8381 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8381) && (_8381 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_REL_GAP"),_8381);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8380)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntCoTolPfeas")))
  {
    {
      try
      {
        {
          double _8383 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8383) && (_8383 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_PFEAS"),_8383);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8382)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolPfeas)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntCoTolDfeas")))
  {
    {
      try
      {
        {
          double _8385 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8385) && (_8385 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_DFEAS"),_8385);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8384)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolDfeas)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntCoTolMuRed")))
  {
    {
      try
      {
        {
          double _8387 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8387) && (_8387 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_MU_RED"),_8387);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8386)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolMuRed)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntCoTolNearRel")))
  {
    {
      try
      {
        {
          double _8389 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e+00 <= _8389))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_NEAR_REL"),_8389);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8388)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolNearRel)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntCoTolInfeas")))
  {
    {
      try
      {
        {
          double _8391 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8391) && (_8391 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_CO_TOL_INFEAS"),_8391);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8390)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntCoTolInfeas)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolPsafe")))
  {
    {
      try
      {
        {
          double _8393 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-04 <= _8393))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_PSAFE"),_8393);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8392)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolPsafe)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("intpntTolDsafe")))
  {
    {
      try
      {
        {
          double _8395 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-04 <= _8395))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_INTPNT_TOL_DSAFE"),_8395);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8394)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (intpntTolDsafe)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioMaxTime")))
  {
    {
      try
      {
        {
          double _8397 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (true)
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_MIO_MAX_TIME"),_8397);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8396)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioMaxTime)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioRelGapConst")))
  {
    {
      try
      {
        {
          double _8399 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-15 <= _8399))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_MIO_REL_GAP_CONST"),_8399);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8398)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioRelGapConst)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioTolRelGap")))
  {
    {
      try
      {
        {
          double _8401 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((0.000000e+00 <= _8401))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_GAP"),_8401);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8400)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelGap)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioTolAbsGap")))
  {
    {
      try
      {
        {
          double _8403 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((0.000000e+00 <= _8403))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_GAP"),_8403);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8402)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsGap)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      try
      {
        {
          double _8405 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-09 <= _8405))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_ABS_RELAX_INT"),_8405);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8404)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolAbsRelaxInt)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("basisTolX")))
  {
    {
      try
      {
        {
          double _8407 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-09 <= _8407))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_X"),_8407);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8406)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolX)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("basisTolS")))
  {
    {
      try
      {
        {
          double _8409 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-09 <= _8409))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_BASIS_TOL_S"),_8409);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8408)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisTolS)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("basisRelTolS")))
  {
    {
      try
      {
        {
          double _8411 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((0.000000e+00 <= _8411))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_BASIS_REL_TOL_S"),_8411);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8410)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (basisRelTolS)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveTolX")))
  {
    {
      try
      {
        {
          double _8413 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((0.000000e+00 <= _8413))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_X"),_8413);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8412)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolX)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveTolS")))
  {
    {
      try
      {
        {
          double _8415 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((0.000000e+00 <= _8415))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_S"),_8415);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8414)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolS)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveTolAij")))
  {
    {
      try
      {
        {
          double _8417 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-15 <= _8417))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_AIJ"),_8417);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8416)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAij)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveTolAbsLindep")))
  {
    {
      try
      {
        {
          double _8419 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((0.000000e+00 <= _8419))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_ABS_LINDEP"),_8419);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8418)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolAbsLindep)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("presolveTolRelLindep")))
  {
    {
      try
      {
        {
          double _8421 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((0.000000e+00 <= _8421))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_PRESOLVE_TOL_REL_LINDEP"),_8421);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8420)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (presolveTolRelLindep)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("simplexAbsTolPiv")))
  {
    {
      try
      {
        {
          double _8423 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if ((1.000000e-12 <= _8423))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_SIMPLEX_ABS_TOL_PIV"),_8423);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8422)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (simplexAbsTolPiv)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioTolFeas")))
  {
    {
      try
      {
        {
          double _8425 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((1.000000e-09 <= _8425) && (_8425 <= 1.000000e-03)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_FEAS"),_8425);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8424)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolFeas)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      try
      {
        {
          double _8427 = ::mosek::fusion::Utils::Tools::toDouble(_8190);
          if (((0.000000e+00 <= _8427) && (_8427 <= 1.000000e+00)))
          {
            {
              mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_DPAR_MIO_TOL_REL_DUAL_BOUND_IMPROVEMENT"),_8427);
              return;
            }
          }
          else
          {
            {
              throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
            }
          }
        }
      }
      catch (mosek::fusion::ValueConversionError _8426)
      {
        {
          throw ::mosek::fusion::ParameterError(std::string ("Invalid value for parameter (mioTolRelDualBoundImprovement)"));
        }
      }
    }
  }
  {}
  if ((_8189 == std::string ("dataFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_SPAR_DATA_FILE_NAME"),_8190);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("basSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_SPAR_BAS_SOL_FILE_NAME"),_8190);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("itrSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_SPAR_ITR_SOL_FILE_NAME"),_8190);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("intSolFileName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_SPAR_INT_SOL_FILE_NAME"),_8190);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("writeLpGenVarName")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_SPAR_WRITE_LP_GEN_VAR_NAME"),_8190);
      return;
    }
  }
  {}
  if ((_8189 == std::string ("remoteAccessToken")))
  {
    {
      mosek::fusion::p_Model::_get_impl(_8188.get())->task_put_param(std::string ("MSK_SPAR_REMOTE_ACCESS_TOKEN"),_8190);
      return;
    }
  }
  {}
  throw ::mosek::fusion::ParameterError(std::string ("Unknown parameter"));
}
int mosek::fusion::p_Parameters::string_to_variabletype_value(const std::string & _8428){
  if ((_8428 == std::string ("typeCont")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8428 == std::string ("typeInt")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_value_value(const std::string & _8429){
  if ((_8429 == std::string ("maxStrLen")))
  {
    {
      return (int)1024;
    }
  }
  {}
  if ((_8429 == std::string ("licenseBufferLength")))
  {
    {
      return (int)21;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_streamtype_value(const std::string & _8430){
  if ((_8430 == std::string ("log")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8430 == std::string ("msg")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8430 == std::string ("err")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8430 == std::string ("wrn")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_startpointtype_value(const std::string & _8431){
  if ((_8431 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8431 == std::string ("guess")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8431 == std::string ("constant")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8431 == std::string ("satisfyBounds")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_stakey_value(const std::string & _8432){
  if ((_8432 == std::string ("unk")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8432 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8432 == std::string ("supbas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8432 == std::string ("low")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8432 == std::string ("upr")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8432 == std::string ("fix")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8432 == std::string ("inf")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sparam_value(const std::string & _8433){
  if ((_8433 == std::string ("dataFileName")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8433 == std::string ("paramReadFileName")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8433 == std::string ("paramWriteFileName")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8433 == std::string ("paramCommentSign")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8433 == std::string ("debugFileName")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8433 == std::string ("basSolFileName")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8433 == std::string ("itrSolFileName")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8433 == std::string ("intSolFileName")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8433 == std::string ("solFilterXcLow")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8433 == std::string ("solFilterXcUpr")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8433 == std::string ("solFilterXxLow")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8433 == std::string ("solFilterXxUpr")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8433 == std::string ("readMpsObjName")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8433 == std::string ("readMpsRanName")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8433 == std::string ("readMpsRhsName")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8433 == std::string ("readMpsBouName")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8433 == std::string ("statFileName")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8433 == std::string ("statName")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8433 == std::string ("statKey")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8433 == std::string ("writeLpGenVarName")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8433 == std::string ("sensitivityResFileName")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8433 == std::string ("sensitivityFileName")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8433 == std::string ("mioDebugString")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8433 == std::string ("remoteAccessToken")))
  {
    {
      return (int)13;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solveform_value(const std::string & _8434){
  if ((_8434 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8434 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8434 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_soltype_value(const std::string & _8435){
  if ((_8435 == std::string ("bas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8435 == std::string ("itr")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8435 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solsta_value(const std::string & _8436){
  if ((_8436 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8436 == std::string ("optimal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8436 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8436 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8436 == std::string ("primAndDualFeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8436 == std::string ("primInfeasCer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8436 == std::string ("dualInfeasCer")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8436 == std::string ("primIllposedCer")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8436 == std::string ("dualIllposedCer")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8436 == std::string ("integerOptimal")))
  {
    {
      return (int)9;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_solitem_value(const std::string & _8437){
  if ((_8437 == std::string ("xc")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8437 == std::string ("xx")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8437 == std::string ("y")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8437 == std::string ("slc")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8437 == std::string ("suc")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8437 == std::string ("slx")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8437 == std::string ("sux")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8437 == std::string ("snx")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simseltype_value(const std::string & _8438){
  if ((_8438 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8438 == std::string ("full")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8438 == std::string ("ase")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8438 == std::string ("devex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8438 == std::string ("se")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8438 == std::string ("partial")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_sensitivitytype_value(const std::string & _8439){
  if ((_8439 == std::string ("basis")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingmethod_value(const std::string & _8440){
  if ((_8440 == std::string ("pow2")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8440 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scalingtype_value(const std::string & _8441){
  if ((_8441 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8441 == std::string ("none")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8441 == std::string ("moderate")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8441 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescodetype_value(const std::string & _8442){
  if ((_8442 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8442 == std::string ("wrn")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8442 == std::string ("trm")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8442 == std::string ("err")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8442 == std::string ("unk")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_rescode_value(const std::string & _8443){
  if ((_8443 == std::string ("ok")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8443 == std::string ("wrnOpenParamFile")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLargeBound")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLargeLoBound")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLargeUpBound")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLargeConFx")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLargeCj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLargeAij")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_8443 == std::string ("wrnZeroAij")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_8443 == std::string ("wrnNameMaxLen")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_8443 == std::string ("wrnSparMaxLen")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_8443 == std::string ("wrnMpsSplitRhsVector")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_8443 == std::string ("wrnMpsSplitRanVector")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_8443 == std::string ("wrnMpsSplitBouVector")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLpOldQuadFormat")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLpDropVariable")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_8443 == std::string ("wrnNzInUprTri")))
  {
    {
      return (int)200;
    }
  }
  {}
  if ((_8443 == std::string ("wrnDroppedNzQobj")))
  {
    {
      return (int)201;
    }
  }
  {}
  if ((_8443 == std::string ("wrnIgnoreInteger")))
  {
    {
      return (int)250;
    }
  }
  {}
  if ((_8443 == std::string ("wrnNoGlobalOptimizer")))
  {
    {
      return (int)251;
    }
  }
  {}
  if ((_8443 == std::string ("wrnMioInfeasibleFinal")))
  {
    {
      return (int)270;
    }
  }
  {}
  if ((_8443 == std::string ("wrnSolFilter")))
  {
    {
      return (int)300;
    }
  }
  {}
  if ((_8443 == std::string ("wrnUndefSolFileName")))
  {
    {
      return (int)350;
    }
  }
  {}
  if ((_8443 == std::string ("wrnSolFileIgnoredCon")))
  {
    {
      return (int)351;
    }
  }
  {}
  if ((_8443 == std::string ("wrnSolFileIgnoredVar")))
  {
    {
      return (int)352;
    }
  }
  {}
  if ((_8443 == std::string ("wrnTooFewBasisVars")))
  {
    {
      return (int)400;
    }
  }
  {}
  if ((_8443 == std::string ("wrnTooManyBasisVars")))
  {
    {
      return (int)405;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLicenseExpire")))
  {
    {
      return (int)500;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLicenseServer")))
  {
    {
      return (int)501;
    }
  }
  {}
  if ((_8443 == std::string ("wrnEmptyName")))
  {
    {
      return (int)502;
    }
  }
  {}
  if ((_8443 == std::string ("wrnUsingGenericNames")))
  {
    {
      return (int)503;
    }
  }
  {}
  if ((_8443 == std::string ("wrnLicenseFeatureExpire")))
  {
    {
      return (int)505;
    }
  }
  {}
  if ((_8443 == std::string ("wrnParamNameDou")))
  {
    {
      return (int)510;
    }
  }
  {}
  if ((_8443 == std::string ("wrnParamNameInt")))
  {
    {
      return (int)511;
    }
  }
  {}
  if ((_8443 == std::string ("wrnParamNameStr")))
  {
    {
      return (int)512;
    }
  }
  {}
  if ((_8443 == std::string ("wrnParamStrValue")))
  {
    {
      return (int)515;
    }
  }
  {}
  if ((_8443 == std::string ("wrnParamIgnoredCmio")))
  {
    {
      return (int)516;
    }
  }
  {}
  if ((_8443 == std::string ("wrnZerosInSparseRow")))
  {
    {
      return (int)705;
    }
  }
  {}
  if ((_8443 == std::string ("wrnZerosInSparseCol")))
  {
    {
      return (int)710;
    }
  }
  {}
  if ((_8443 == std::string ("wrnIncompleteLinearDependencyCheck")))
  {
    {
      return (int)800;
    }
  }
  {}
  if ((_8443 == std::string ("wrnEliminatorSpace")))
  {
    {
      return (int)801;
    }
  }
  {}
  if ((_8443 == std::string ("wrnPresolveOutofspace")))
  {
    {
      return (int)802;
    }
  }
  {}
  if ((_8443 == std::string ("wrnWriteChangedNames")))
  {
    {
      return (int)803;
    }
  }
  {}
  if ((_8443 == std::string ("wrnWriteDiscardedCfix")))
  {
    {
      return (int)804;
    }
  }
  {}
  if ((_8443 == std::string ("wrnDuplicateConstraintNames")))
  {
    {
      return (int)850;
    }
  }
  {}
  if ((_8443 == std::string ("wrnDuplicateVariableNames")))
  {
    {
      return (int)851;
    }
  }
  {}
  if ((_8443 == std::string ("wrnDuplicateBarvariableNames")))
  {
    {
      return (int)852;
    }
  }
  {}
  if ((_8443 == std::string ("wrnDuplicateConeNames")))
  {
    {
      return (int)853;
    }
  }
  {}
  if ((_8443 == std::string ("wrnAnaLargeBounds")))
  {
    {
      return (int)900;
    }
  }
  {}
  if ((_8443 == std::string ("wrnAnaCZero")))
  {
    {
      return (int)901;
    }
  }
  {}
  if ((_8443 == std::string ("wrnAnaEmptyCols")))
  {
    {
      return (int)902;
    }
  }
  {}
  if ((_8443 == std::string ("wrnAnaCloseBounds")))
  {
    {
      return (int)903;
    }
  }
  {}
  if ((_8443 == std::string ("wrnAnaAlmostIntBounds")))
  {
    {
      return (int)904;
    }
  }
  {}
  if ((_8443 == std::string ("wrnQuadConesWithRootFixedAtZero")))
  {
    {
      return (int)930;
    }
  }
  {}
  if ((_8443 == std::string ("wrnRquadConesWithRootFixedAtZero")))
  {
    {
      return (int)931;
    }
  }
  {}
  if ((_8443 == std::string ("wrnExpConesWithVariablesFixedAtZero")))
  {
    {
      return (int)932;
    }
  }
  {}
  if ((_8443 == std::string ("wrnPowConesWithRootFixedAtZero")))
  {
    {
      return (int)933;
    }
  }
  {}
  if ((_8443 == std::string ("wrnNoDualizer")))
  {
    {
      return (int)950;
    }
  }
  {}
  if ((_8443 == std::string ("wrnSymMatLarge")))
  {
    {
      return (int)960;
    }
  }
  {}
  if ((_8443 == std::string ("errLicense")))
  {
    {
      return (int)1000;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseExpired")))
  {
    {
      return (int)1001;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseVersion")))
  {
    {
      return (int)1002;
    }
  }
  {}
  if ((_8443 == std::string ("errSizeLicense")))
  {
    {
      return (int)1005;
    }
  }
  {}
  if ((_8443 == std::string ("errProbLicense")))
  {
    {
      return (int)1006;
    }
  }
  {}
  if ((_8443 == std::string ("errFileLicense")))
  {
    {
      return (int)1007;
    }
  }
  {}
  if ((_8443 == std::string ("errMissingLicenseFile")))
  {
    {
      return (int)1008;
    }
  }
  {}
  if ((_8443 == std::string ("errSizeLicenseCon")))
  {
    {
      return (int)1010;
    }
  }
  {}
  if ((_8443 == std::string ("errSizeLicenseVar")))
  {
    {
      return (int)1011;
    }
  }
  {}
  if ((_8443 == std::string ("errSizeLicenseIntvar")))
  {
    {
      return (int)1012;
    }
  }
  {}
  if ((_8443 == std::string ("errOptimizerLicense")))
  {
    {
      return (int)1013;
    }
  }
  {}
  if ((_8443 == std::string ("errFlexlm")))
  {
    {
      return (int)1014;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseServer")))
  {
    {
      return (int)1015;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseMax")))
  {
    {
      return (int)1016;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseMoseklmDaemon")))
  {
    {
      return (int)1017;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseFeature")))
  {
    {
      return (int)1018;
    }
  }
  {}
  if ((_8443 == std::string ("errPlatformNotLicensed")))
  {
    {
      return (int)1019;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseCannotAllocate")))
  {
    {
      return (int)1020;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseCannotConnect")))
  {
    {
      return (int)1021;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseInvalidHostid")))
  {
    {
      return (int)1025;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseServerVersion")))
  {
    {
      return (int)1026;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseNoServerSupport")))
  {
    {
      return (int)1027;
    }
  }
  {}
  if ((_8443 == std::string ("errLicenseNoServerLine")))
  {
    {
      return (int)1028;
    }
  }
  {}
  if ((_8443 == std::string ("errOlderDll")))
  {
    {
      return (int)1035;
    }
  }
  {}
  if ((_8443 == std::string ("errNewerDll")))
  {
    {
      return (int)1036;
    }
  }
  {}
  if ((_8443 == std::string ("errLinkFileDll")))
  {
    {
      return (int)1040;
    }
  }
  {}
  if ((_8443 == std::string ("errThreadMutexInit")))
  {
    {
      return (int)1045;
    }
  }
  {}
  if ((_8443 == std::string ("errThreadMutexLock")))
  {
    {
      return (int)1046;
    }
  }
  {}
  if ((_8443 == std::string ("errThreadMutexUnlock")))
  {
    {
      return (int)1047;
    }
  }
  {}
  if ((_8443 == std::string ("errThreadCreate")))
  {
    {
      return (int)1048;
    }
  }
  {}
  if ((_8443 == std::string ("errThreadCondInit")))
  {
    {
      return (int)1049;
    }
  }
  {}
  if ((_8443 == std::string ("errUnknown")))
  {
    {
      return (int)1050;
    }
  }
  {}
  if ((_8443 == std::string ("errSpace")))
  {
    {
      return (int)1051;
    }
  }
  {}
  if ((_8443 == std::string ("errFileOpen")))
  {
    {
      return (int)1052;
    }
  }
  {}
  if ((_8443 == std::string ("errFileRead")))
  {
    {
      return (int)1053;
    }
  }
  {}
  if ((_8443 == std::string ("errFileWrite")))
  {
    {
      return (int)1054;
    }
  }
  {}
  if ((_8443 == std::string ("errDataFileExt")))
  {
    {
      return (int)1055;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFileName")))
  {
    {
      return (int)1056;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidSolFileName")))
  {
    {
      return (int)1057;
    }
  }
  {}
  if ((_8443 == std::string ("errEndOfFile")))
  {
    {
      return (int)1059;
    }
  }
  {}
  if ((_8443 == std::string ("errNullEnv")))
  {
    {
      return (int)1060;
    }
  }
  {}
  if ((_8443 == std::string ("errNullTask")))
  {
    {
      return (int)1061;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidStream")))
  {
    {
      return (int)1062;
    }
  }
  {}
  if ((_8443 == std::string ("errNoInitEnv")))
  {
    {
      return (int)1063;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidTask")))
  {
    {
      return (int)1064;
    }
  }
  {}
  if ((_8443 == std::string ("errNullPointer")))
  {
    {
      return (int)1065;
    }
  }
  {}
  if ((_8443 == std::string ("errLivingTasks")))
  {
    {
      return (int)1066;
    }
  }
  {}
  if ((_8443 == std::string ("errBlankName")))
  {
    {
      return (int)1070;
    }
  }
  {}
  if ((_8443 == std::string ("errDupName")))
  {
    {
      return (int)1071;
    }
  }
  {}
  if ((_8443 == std::string ("errFormatString")))
  {
    {
      return (int)1072;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidObjName")))
  {
    {
      return (int)1075;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidConName")))
  {
    {
      return (int)1076;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidVarName")))
  {
    {
      return (int)1077;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidConeName")))
  {
    {
      return (int)1078;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidBarvarName")))
  {
    {
      return (int)1079;
    }
  }
  {}
  if ((_8443 == std::string ("errSpaceLeaking")))
  {
    {
      return (int)1080;
    }
  }
  {}
  if ((_8443 == std::string ("errSpaceNoInfo")))
  {
    {
      return (int)1081;
    }
  }
  {}
  if ((_8443 == std::string ("errReadFormat")))
  {
    {
      return (int)1090;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsFile")))
  {
    {
      return (int)1100;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvField")))
  {
    {
      return (int)1101;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvMarker")))
  {
    {
      return (int)1102;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsNullConName")))
  {
    {
      return (int)1103;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsNullVarName")))
  {
    {
      return (int)1104;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsUndefConName")))
  {
    {
      return (int)1105;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsUndefVarName")))
  {
    {
      return (int)1106;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvConKey")))
  {
    {
      return (int)1107;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvBoundKey")))
  {
    {
      return (int)1108;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvSecName")))
  {
    {
      return (int)1109;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsNoObjective")))
  {
    {
      return (int)1110;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsSplittedVar")))
  {
    {
      return (int)1111;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsMulConName")))
  {
    {
      return (int)1112;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsMulQsec")))
  {
    {
      return (int)1113;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsMulQobj")))
  {
    {
      return (int)1114;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvSecOrder")))
  {
    {
      return (int)1115;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsMulCsec")))
  {
    {
      return (int)1116;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsConeType")))
  {
    {
      return (int)1117;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsConeOverlap")))
  {
    {
      return (int)1118;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsConeRepeat")))
  {
    {
      return (int)1119;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsNonSymmetricQ")))
  {
    {
      return (int)1120;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsDuplicateQElement")))
  {
    {
      return (int)1121;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvalidObjsense")))
  {
    {
      return (int)1122;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsTabInField2")))
  {
    {
      return (int)1125;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsTabInField3")))
  {
    {
      return (int)1126;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsTabInField5")))
  {
    {
      return (int)1127;
    }
  }
  {}
  if ((_8443 == std::string ("errMpsInvalidObjName")))
  {
    {
      return (int)1128;
    }
  }
  {}
  if ((_8443 == std::string ("errLpIncompatible")))
  {
    {
      return (int)1150;
    }
  }
  {}
  if ((_8443 == std::string ("errLpEmpty")))
  {
    {
      return (int)1151;
    }
  }
  {}
  if ((_8443 == std::string ("errLpDupSlackName")))
  {
    {
      return (int)1152;
    }
  }
  {}
  if ((_8443 == std::string ("errWriteMpsInvalidName")))
  {
    {
      return (int)1153;
    }
  }
  {}
  if ((_8443 == std::string ("errLpInvalidVarName")))
  {
    {
      return (int)1154;
    }
  }
  {}
  if ((_8443 == std::string ("errLpFreeConstraint")))
  {
    {
      return (int)1155;
    }
  }
  {}
  if ((_8443 == std::string ("errWriteOpfInvalidVarName")))
  {
    {
      return (int)1156;
    }
  }
  {}
  if ((_8443 == std::string ("errLpFileFormat")))
  {
    {
      return (int)1157;
    }
  }
  {}
  if ((_8443 == std::string ("errWriteLpFormat")))
  {
    {
      return (int)1158;
    }
  }
  {}
  if ((_8443 == std::string ("errReadLpMissingEndTag")))
  {
    {
      return (int)1159;
    }
  }
  {}
  if ((_8443 == std::string ("errLpFormat")))
  {
    {
      return (int)1160;
    }
  }
  {}
  if ((_8443 == std::string ("errWriteLpNonUniqueName")))
  {
    {
      return (int)1161;
    }
  }
  {}
  if ((_8443 == std::string ("errReadLpNonexistingName")))
  {
    {
      return (int)1162;
    }
  }
  {}
  if ((_8443 == std::string ("errLpWriteConicProblem")))
  {
    {
      return (int)1163;
    }
  }
  {}
  if ((_8443 == std::string ("errLpWriteGecoProblem")))
  {
    {
      return (int)1164;
    }
  }
  {}
  if ((_8443 == std::string ("errWritingFile")))
  {
    {
      return (int)1166;
    }
  }
  {}
  if ((_8443 == std::string ("errPtfFormat")))
  {
    {
      return (int)1167;
    }
  }
  {}
  if ((_8443 == std::string ("errOpfFormat")))
  {
    {
      return (int)1168;
    }
  }
  {}
  if ((_8443 == std::string ("errOpfNewVariable")))
  {
    {
      return (int)1169;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidNameInSolFile")))
  {
    {
      return (int)1170;
    }
  }
  {}
  if ((_8443 == std::string ("errLpInvalidConName")))
  {
    {
      return (int)1171;
    }
  }
  {}
  if ((_8443 == std::string ("errOpfPrematureEof")))
  {
    {
      return (int)1172;
    }
  }
  {}
  if ((_8443 == std::string ("errJsonSyntax")))
  {
    {
      return (int)1175;
    }
  }
  {}
  if ((_8443 == std::string ("errJsonString")))
  {
    {
      return (int)1176;
    }
  }
  {}
  if ((_8443 == std::string ("errJsonNumberOverflow")))
  {
    {
      return (int)1177;
    }
  }
  {}
  if ((_8443 == std::string ("errJsonFormat")))
  {
    {
      return (int)1178;
    }
  }
  {}
  if ((_8443 == std::string ("errJsonData")))
  {
    {
      return (int)1179;
    }
  }
  {}
  if ((_8443 == std::string ("errJsonMissingData")))
  {
    {
      return (int)1180;
    }
  }
  {}
  if ((_8443 == std::string ("errArgumentLenneq")))
  {
    {
      return (int)1197;
    }
  }
  {}
  if ((_8443 == std::string ("errArgumentType")))
  {
    {
      return (int)1198;
    }
  }
  {}
  if ((_8443 == std::string ("errNumArguments")))
  {
    {
      return (int)1199;
    }
  }
  {}
  if ((_8443 == std::string ("errInArgument")))
  {
    {
      return (int)1200;
    }
  }
  {}
  if ((_8443 == std::string ("errArgumentDimension")))
  {
    {
      return (int)1201;
    }
  }
  {}
  if ((_8443 == std::string ("errShapeIsTooLarge")))
  {
    {
      return (int)1202;
    }
  }
  {}
  if ((_8443 == std::string ("errIndexIsTooSmall")))
  {
    {
      return (int)1203;
    }
  }
  {}
  if ((_8443 == std::string ("errIndexIsTooLarge")))
  {
    {
      return (int)1204;
    }
  }
  {}
  if ((_8443 == std::string ("errParamName")))
  {
    {
      return (int)1205;
    }
  }
  {}
  if ((_8443 == std::string ("errParamNameDou")))
  {
    {
      return (int)1206;
    }
  }
  {}
  if ((_8443 == std::string ("errParamNameInt")))
  {
    {
      return (int)1207;
    }
  }
  {}
  if ((_8443 == std::string ("errParamNameStr")))
  {
    {
      return (int)1208;
    }
  }
  {}
  if ((_8443 == std::string ("errParamIndex")))
  {
    {
      return (int)1210;
    }
  }
  {}
  if ((_8443 == std::string ("errParamIsTooLarge")))
  {
    {
      return (int)1215;
    }
  }
  {}
  if ((_8443 == std::string ("errParamIsTooSmall")))
  {
    {
      return (int)1216;
    }
  }
  {}
  if ((_8443 == std::string ("errParamValueStr")))
  {
    {
      return (int)1217;
    }
  }
  {}
  if ((_8443 == std::string ("errParamType")))
  {
    {
      return (int)1218;
    }
  }
  {}
  if ((_8443 == std::string ("errInfDouIndex")))
  {
    {
      return (int)1219;
    }
  }
  {}
  if ((_8443 == std::string ("errInfIntIndex")))
  {
    {
      return (int)1220;
    }
  }
  {}
  if ((_8443 == std::string ("errIndexArrIsTooSmall")))
  {
    {
      return (int)1221;
    }
  }
  {}
  if ((_8443 == std::string ("errIndexArrIsTooLarge")))
  {
    {
      return (int)1222;
    }
  }
  {}
  if ((_8443 == std::string ("errInfLintIndex")))
  {
    {
      return (int)1225;
    }
  }
  {}
  if ((_8443 == std::string ("errArgIsTooSmall")))
  {
    {
      return (int)1226;
    }
  }
  {}
  if ((_8443 == std::string ("errArgIsTooLarge")))
  {
    {
      return (int)1227;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidWhichsol")))
  {
    {
      return (int)1228;
    }
  }
  {}
  if ((_8443 == std::string ("errInfDouName")))
  {
    {
      return (int)1230;
    }
  }
  {}
  if ((_8443 == std::string ("errInfIntName")))
  {
    {
      return (int)1231;
    }
  }
  {}
  if ((_8443 == std::string ("errInfType")))
  {
    {
      return (int)1232;
    }
  }
  {}
  if ((_8443 == std::string ("errInfLintName")))
  {
    {
      return (int)1234;
    }
  }
  {}
  if ((_8443 == std::string ("errIndex")))
  {
    {
      return (int)1235;
    }
  }
  {}
  if ((_8443 == std::string ("errWhichsol")))
  {
    {
      return (int)1236;
    }
  }
  {}
  if ((_8443 == std::string ("errSolitem")))
  {
    {
      return (int)1237;
    }
  }
  {}
  if ((_8443 == std::string ("errWhichitemNotAllowed")))
  {
    {
      return (int)1238;
    }
  }
  {}
  if ((_8443 == std::string ("errMaxnumcon")))
  {
    {
      return (int)1240;
    }
  }
  {}
  if ((_8443 == std::string ("errMaxnumvar")))
  {
    {
      return (int)1241;
    }
  }
  {}
  if ((_8443 == std::string ("errMaxnumbarvar")))
  {
    {
      return (int)1242;
    }
  }
  {}
  if ((_8443 == std::string ("errMaxnumqnz")))
  {
    {
      return (int)1243;
    }
  }
  {}
  if ((_8443 == std::string ("errTooSmallMaxNumNz")))
  {
    {
      return (int)1245;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidIdx")))
  {
    {
      return (int)1246;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidMaxNum")))
  {
    {
      return (int)1247;
    }
  }
  {}
  if ((_8443 == std::string ("errNumconlim")))
  {
    {
      return (int)1250;
    }
  }
  {}
  if ((_8443 == std::string ("errNumvarlim")))
  {
    {
      return (int)1251;
    }
  }
  {}
  if ((_8443 == std::string ("errTooSmallMaxnumanz")))
  {
    {
      return (int)1252;
    }
  }
  {}
  if ((_8443 == std::string ("errInvAptre")))
  {
    {
      return (int)1253;
    }
  }
  {}
  if ((_8443 == std::string ("errMulAElement")))
  {
    {
      return (int)1254;
    }
  }
  {}
  if ((_8443 == std::string ("errInvBk")))
  {
    {
      return (int)1255;
    }
  }
  {}
  if ((_8443 == std::string ("errInvBkc")))
  {
    {
      return (int)1256;
    }
  }
  {}
  if ((_8443 == std::string ("errInvBkx")))
  {
    {
      return (int)1257;
    }
  }
  {}
  if ((_8443 == std::string ("errInvVarType")))
  {
    {
      return (int)1258;
    }
  }
  {}
  if ((_8443 == std::string ("errSolverProbtype")))
  {
    {
      return (int)1259;
    }
  }
  {}
  if ((_8443 == std::string ("errObjectiveRange")))
  {
    {
      return (int)1260;
    }
  }
  {}
  if ((_8443 == std::string ("errUndefSolution")))
  {
    {
      return (int)1265;
    }
  }
  {}
  if ((_8443 == std::string ("errBasis")))
  {
    {
      return (int)1266;
    }
  }
  {}
  if ((_8443 == std::string ("errInvSkc")))
  {
    {
      return (int)1267;
    }
  }
  {}
  if ((_8443 == std::string ("errInvSkx")))
  {
    {
      return (int)1268;
    }
  }
  {}
  if ((_8443 == std::string ("errInvSkn")))
  {
    {
      return (int)1274;
    }
  }
  {}
  if ((_8443 == std::string ("errInvSkStr")))
  {
    {
      return (int)1269;
    }
  }
  {}
  if ((_8443 == std::string ("errInvSk")))
  {
    {
      return (int)1270;
    }
  }
  {}
  if ((_8443 == std::string ("errInvConeTypeStr")))
  {
    {
      return (int)1271;
    }
  }
  {}
  if ((_8443 == std::string ("errInvConeType")))
  {
    {
      return (int)1272;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidSurplus")))
  {
    {
      return (int)1275;
    }
  }
  {}
  if ((_8443 == std::string ("errInvNameItem")))
  {
    {
      return (int)1280;
    }
  }
  {}
  if ((_8443 == std::string ("errProItem")))
  {
    {
      return (int)1281;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFormatType")))
  {
    {
      return (int)1283;
    }
  }
  {}
  if ((_8443 == std::string ("errFirsti")))
  {
    {
      return (int)1285;
    }
  }
  {}
  if ((_8443 == std::string ("errLasti")))
  {
    {
      return (int)1286;
    }
  }
  {}
  if ((_8443 == std::string ("errFirstj")))
  {
    {
      return (int)1287;
    }
  }
  {}
  if ((_8443 == std::string ("errLastj")))
  {
    {
      return (int)1288;
    }
  }
  {}
  if ((_8443 == std::string ("errMaxLenIsTooSmall")))
  {
    {
      return (int)1289;
    }
  }
  {}
  if ((_8443 == std::string ("errNonlinearEquality")))
  {
    {
      return (int)1290;
    }
  }
  {}
  if ((_8443 == std::string ("errNonconvex")))
  {
    {
      return (int)1291;
    }
  }
  {}
  if ((_8443 == std::string ("errNonlinearRanged")))
  {
    {
      return (int)1292;
    }
  }
  {}
  if ((_8443 == std::string ("errConQNotPsd")))
  {
    {
      return (int)1293;
    }
  }
  {}
  if ((_8443 == std::string ("errConQNotNsd")))
  {
    {
      return (int)1294;
    }
  }
  {}
  if ((_8443 == std::string ("errObjQNotPsd")))
  {
    {
      return (int)1295;
    }
  }
  {}
  if ((_8443 == std::string ("errObjQNotNsd")))
  {
    {
      return (int)1296;
    }
  }
  {}
  if ((_8443 == std::string ("errArgumentPermArray")))
  {
    {
      return (int)1299;
    }
  }
  {}
  if ((_8443 == std::string ("errConeIndex")))
  {
    {
      return (int)1300;
    }
  }
  {}
  if ((_8443 == std::string ("errConeSize")))
  {
    {
      return (int)1301;
    }
  }
  {}
  if ((_8443 == std::string ("errConeOverlap")))
  {
    {
      return (int)1302;
    }
  }
  {}
  if ((_8443 == std::string ("errConeRepVar")))
  {
    {
      return (int)1303;
    }
  }
  {}
  if ((_8443 == std::string ("errMaxnumcone")))
  {
    {
      return (int)1304;
    }
  }
  {}
  if ((_8443 == std::string ("errConeType")))
  {
    {
      return (int)1305;
    }
  }
  {}
  if ((_8443 == std::string ("errConeTypeStr")))
  {
    {
      return (int)1306;
    }
  }
  {}
  if ((_8443 == std::string ("errConeOverlapAppend")))
  {
    {
      return (int)1307;
    }
  }
  {}
  if ((_8443 == std::string ("errRemoveConeVariable")))
  {
    {
      return (int)1310;
    }
  }
  {}
  if ((_8443 == std::string ("errAppendingTooBigCone")))
  {
    {
      return (int)1311;
    }
  }
  {}
  if ((_8443 == std::string ("errConeParameter")))
  {
    {
      return (int)1320;
    }
  }
  {}
  if ((_8443 == std::string ("errSolFileInvalidNumber")))
  {
    {
      return (int)1350;
    }
  }
  {}
  if ((_8443 == std::string ("errHugeC")))
  {
    {
      return (int)1375;
    }
  }
  {}
  if ((_8443 == std::string ("errHugeAij")))
  {
    {
      return (int)1380;
    }
  }
  {}
  if ((_8443 == std::string ("errDuplicateAij")))
  {
    {
      return (int)1385;
    }
  }
  {}
  if ((_8443 == std::string ("errLowerBoundIsANan")))
  {
    {
      return (int)1390;
    }
  }
  {}
  if ((_8443 == std::string ("errUpperBoundIsANan")))
  {
    {
      return (int)1391;
    }
  }
  {}
  if ((_8443 == std::string ("errInfiniteBound")))
  {
    {
      return (int)1400;
    }
  }
  {}
  if ((_8443 == std::string ("errInvQobjSubi")))
  {
    {
      return (int)1401;
    }
  }
  {}
  if ((_8443 == std::string ("errInvQobjSubj")))
  {
    {
      return (int)1402;
    }
  }
  {}
  if ((_8443 == std::string ("errInvQobjVal")))
  {
    {
      return (int)1403;
    }
  }
  {}
  if ((_8443 == std::string ("errInvQconSubk")))
  {
    {
      return (int)1404;
    }
  }
  {}
  if ((_8443 == std::string ("errInvQconSubi")))
  {
    {
      return (int)1405;
    }
  }
  {}
  if ((_8443 == std::string ("errInvQconSubj")))
  {
    {
      return (int)1406;
    }
  }
  {}
  if ((_8443 == std::string ("errInvQconVal")))
  {
    {
      return (int)1407;
    }
  }
  {}
  if ((_8443 == std::string ("errQconSubiTooSmall")))
  {
    {
      return (int)1408;
    }
  }
  {}
  if ((_8443 == std::string ("errQconSubiTooLarge")))
  {
    {
      return (int)1409;
    }
  }
  {}
  if ((_8443 == std::string ("errQobjUpperTriangle")))
  {
    {
      return (int)1415;
    }
  }
  {}
  if ((_8443 == std::string ("errQconUpperTriangle")))
  {
    {
      return (int)1417;
    }
  }
  {}
  if ((_8443 == std::string ("errFixedBoundValues")))
  {
    {
      return (int)1420;
    }
  }
  {}
  if ((_8443 == std::string ("errTooSmallATruncationValue")))
  {
    {
      return (int)1421;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidObjectiveSense")))
  {
    {
      return (int)1445;
    }
  }
  {}
  if ((_8443 == std::string ("errUndefinedObjectiveSense")))
  {
    {
      return (int)1446;
    }
  }
  {}
  if ((_8443 == std::string ("errYIsUndefined")))
  {
    {
      return (int)1449;
    }
  }
  {}
  if ((_8443 == std::string ("errNanInDoubleData")))
  {
    {
      return (int)1450;
    }
  }
  {}
  if ((_8443 == std::string ("errNanInBlc")))
  {
    {
      return (int)1461;
    }
  }
  {}
  if ((_8443 == std::string ("errNanInBuc")))
  {
    {
      return (int)1462;
    }
  }
  {}
  if ((_8443 == std::string ("errNanInC")))
  {
    {
      return (int)1470;
    }
  }
  {}
  if ((_8443 == std::string ("errNanInBlx")))
  {
    {
      return (int)1471;
    }
  }
  {}
  if ((_8443 == std::string ("errNanInBux")))
  {
    {
      return (int)1472;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidAij")))
  {
    {
      return (int)1473;
    }
  }
  {}
  if ((_8443 == std::string ("errSymMatInvalid")))
  {
    {
      return (int)1480;
    }
  }
  {}
  if ((_8443 == std::string ("errSymMatHuge")))
  {
    {
      return (int)1482;
    }
  }
  {}
  if ((_8443 == std::string ("errInvProblem")))
  {
    {
      return (int)1500;
    }
  }
  {}
  if ((_8443 == std::string ("errMixedConicAndNl")))
  {
    {
      return (int)1501;
    }
  }
  {}
  if ((_8443 == std::string ("errGlobalInvConicProblem")))
  {
    {
      return (int)1503;
    }
  }
  {}
  if ((_8443 == std::string ("errInvOptimizer")))
  {
    {
      return (int)1550;
    }
  }
  {}
  if ((_8443 == std::string ("errMioNoOptimizer")))
  {
    {
      return (int)1551;
    }
  }
  {}
  if ((_8443 == std::string ("errNoOptimizerVarType")))
  {
    {
      return (int)1552;
    }
  }
  {}
  if ((_8443 == std::string ("errFinalSolution")))
  {
    {
      return (int)1560;
    }
  }
  {}
  if ((_8443 == std::string ("errFirst")))
  {
    {
      return (int)1570;
    }
  }
  {}
  if ((_8443 == std::string ("errLast")))
  {
    {
      return (int)1571;
    }
  }
  {}
  if ((_8443 == std::string ("errSliceSize")))
  {
    {
      return (int)1572;
    }
  }
  {}
  if ((_8443 == std::string ("errNegativeSurplus")))
  {
    {
      return (int)1573;
    }
  }
  {}
  if ((_8443 == std::string ("errNegativeAppend")))
  {
    {
      return (int)1578;
    }
  }
  {}
  if ((_8443 == std::string ("errPostsolve")))
  {
    {
      return (int)1580;
    }
  }
  {}
  if ((_8443 == std::string ("errOverflow")))
  {
    {
      return (int)1590;
    }
  }
  {}
  if ((_8443 == std::string ("errNoBasisSol")))
  {
    {
      return (int)1600;
    }
  }
  {}
  if ((_8443 == std::string ("errBasisFactor")))
  {
    {
      return (int)1610;
    }
  }
  {}
  if ((_8443 == std::string ("errBasisSingular")))
  {
    {
      return (int)1615;
    }
  }
  {}
  if ((_8443 == std::string ("errFactor")))
  {
    {
      return (int)1650;
    }
  }
  {}
  if ((_8443 == std::string ("errFeasrepairCannotRelax")))
  {
    {
      return (int)1700;
    }
  }
  {}
  if ((_8443 == std::string ("errFeasrepairSolvingRelaxed")))
  {
    {
      return (int)1701;
    }
  }
  {}
  if ((_8443 == std::string ("errFeasrepairInconsistentBound")))
  {
    {
      return (int)1702;
    }
  }
  {}
  if ((_8443 == std::string ("errRepairInvalidProblem")))
  {
    {
      return (int)1710;
    }
  }
  {}
  if ((_8443 == std::string ("errRepairOptimizationFailed")))
  {
    {
      return (int)1711;
    }
  }
  {}
  if ((_8443 == std::string ("errNameMaxLen")))
  {
    {
      return (int)1750;
    }
  }
  {}
  if ((_8443 == std::string ("errNameIsNull")))
  {
    {
      return (int)1760;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidCompression")))
  {
    {
      return (int)1800;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidIomode")))
  {
    {
      return (int)1801;
    }
  }
  {}
  if ((_8443 == std::string ("errNoPrimalInfeasCer")))
  {
    {
      return (int)2000;
    }
  }
  {}
  if ((_8443 == std::string ("errNoDualInfeasCer")))
  {
    {
      return (int)2001;
    }
  }
  {}
  if ((_8443 == std::string ("errNoSolutionInCallback")))
  {
    {
      return (int)2500;
    }
  }
  {}
  if ((_8443 == std::string ("errInvMarki")))
  {
    {
      return (int)2501;
    }
  }
  {}
  if ((_8443 == std::string ("errInvMarkj")))
  {
    {
      return (int)2502;
    }
  }
  {}
  if ((_8443 == std::string ("errInvNumi")))
  {
    {
      return (int)2503;
    }
  }
  {}
  if ((_8443 == std::string ("errInvNumj")))
  {
    {
      return (int)2504;
    }
  }
  {}
  if ((_8443 == std::string ("errTaskIncompatible")))
  {
    {
      return (int)2560;
    }
  }
  {}
  if ((_8443 == std::string ("errTaskInvalid")))
  {
    {
      return (int)2561;
    }
  }
  {}
  if ((_8443 == std::string ("errTaskWrite")))
  {
    {
      return (int)2562;
    }
  }
  {}
  if ((_8443 == std::string ("errLuMaxNumTries")))
  {
    {
      return (int)2800;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidUtf8")))
  {
    {
      return (int)2900;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidWchar")))
  {
    {
      return (int)2901;
    }
  }
  {}
  if ((_8443 == std::string ("errNoDualForItgSol")))
  {
    {
      return (int)2950;
    }
  }
  {}
  if ((_8443 == std::string ("errNoSnxForBasSol")))
  {
    {
      return (int)2953;
    }
  }
  {}
  if ((_8443 == std::string ("errInternal")))
  {
    {
      return (int)3000;
    }
  }
  {}
  if ((_8443 == std::string ("errApiArrayTooSmall")))
  {
    {
      return (int)3001;
    }
  }
  {}
  if ((_8443 == std::string ("errApiCbConnect")))
  {
    {
      return (int)3002;
    }
  }
  {}
  if ((_8443 == std::string ("errApiFatalError")))
  {
    {
      return (int)3005;
    }
  }
  {}
  if ((_8443 == std::string ("errApiInternal")))
  {
    {
      return (int)3999;
    }
  }
  {}
  if ((_8443 == std::string ("errSenFormat")))
  {
    {
      return (int)3050;
    }
  }
  {}
  if ((_8443 == std::string ("errSenUndefName")))
  {
    {
      return (int)3051;
    }
  }
  {}
  if ((_8443 == std::string ("errSenIndexRange")))
  {
    {
      return (int)3052;
    }
  }
  {}
  if ((_8443 == std::string ("errSenBoundInvalidUp")))
  {
    {
      return (int)3053;
    }
  }
  {}
  if ((_8443 == std::string ("errSenBoundInvalidLo")))
  {
    {
      return (int)3054;
    }
  }
  {}
  if ((_8443 == std::string ("errSenIndexInvalid")))
  {
    {
      return (int)3055;
    }
  }
  {}
  if ((_8443 == std::string ("errSenInvalidRegexp")))
  {
    {
      return (int)3056;
    }
  }
  {}
  if ((_8443 == std::string ("errSenSolutionStatus")))
  {
    {
      return (int)3057;
    }
  }
  {}
  if ((_8443 == std::string ("errSenNumerical")))
  {
    {
      return (int)3058;
    }
  }
  {}
  if ((_8443 == std::string ("errSenUnhandledProblemType")))
  {
    {
      return (int)3080;
    }
  }
  {}
  if ((_8443 == std::string ("errUnbStepSize")))
  {
    {
      return (int)3100;
    }
  }
  {}
  if ((_8443 == std::string ("errIdenticalTasks")))
  {
    {
      return (int)3101;
    }
  }
  {}
  if ((_8443 == std::string ("errAdInvalidCodelist")))
  {
    {
      return (int)3102;
    }
  }
  {}
  if ((_8443 == std::string ("errInternalTestFailed")))
  {
    {
      return (int)3500;
    }
  }
  {}
  if ((_8443 == std::string ("errXmlInvalidProblemType")))
  {
    {
      return (int)3600;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidAmplStub")))
  {
    {
      return (int)3700;
    }
  }
  {}
  if ((_8443 == std::string ("errInt64ToInt32Cast")))
  {
    {
      return (int)3800;
    }
  }
  {}
  if ((_8443 == std::string ("errSizeLicenseNumcores")))
  {
    {
      return (int)3900;
    }
  }
  {}
  if ((_8443 == std::string ("errInfeasUndefined")))
  {
    {
      return (int)3910;
    }
  }
  {}
  if ((_8443 == std::string ("errNoBarxForSolution")))
  {
    {
      return (int)3915;
    }
  }
  {}
  if ((_8443 == std::string ("errNoBarsForSolution")))
  {
    {
      return (int)3916;
    }
  }
  {}
  if ((_8443 == std::string ("errBarVarDim")))
  {
    {
      return (int)3920;
    }
  }
  {}
  if ((_8443 == std::string ("errSymMatInvalidRowIndex")))
  {
    {
      return (int)3940;
    }
  }
  {}
  if ((_8443 == std::string ("errSymMatInvalidColIndex")))
  {
    {
      return (int)3941;
    }
  }
  {}
  if ((_8443 == std::string ("errSymMatNotLowerTringular")))
  {
    {
      return (int)3942;
    }
  }
  {}
  if ((_8443 == std::string ("errSymMatInvalidValue")))
  {
    {
      return (int)3943;
    }
  }
  {}
  if ((_8443 == std::string ("errSymMatDuplicate")))
  {
    {
      return (int)3944;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidSymMatDim")))
  {
    {
      return (int)3950;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFileFormatForSymMat")))
  {
    {
      return (int)4000;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFileFormatForCfix")))
  {
    {
      return (int)4001;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFileFormatForRangedConstraints")))
  {
    {
      return (int)4002;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFileFormatForFreeConstraints")))
  {
    {
      return (int)4003;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFileFormatForCones")))
  {
    {
      return (int)4005;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidFileFormatForNonlinear")))
  {
    {
      return (int)4010;
    }
  }
  {}
  if ((_8443 == std::string ("errDuplicateConstraintNames")))
  {
    {
      return (int)4500;
    }
  }
  {}
  if ((_8443 == std::string ("errDuplicateVariableNames")))
  {
    {
      return (int)4501;
    }
  }
  {}
  if ((_8443 == std::string ("errDuplicateBarvariableNames")))
  {
    {
      return (int)4502;
    }
  }
  {}
  if ((_8443 == std::string ("errDuplicateConeNames")))
  {
    {
      return (int)4503;
    }
  }
  {}
  if ((_8443 == std::string ("errNonUniqueArray")))
  {
    {
      return (int)5000;
    }
  }
  {}
  if ((_8443 == std::string ("errArgumentIsTooLarge")))
  {
    {
      return (int)5005;
    }
  }
  {}
  if ((_8443 == std::string ("errMioInternal")))
  {
    {
      return (int)5010;
    }
  }
  {}
  if ((_8443 == std::string ("errInvalidProblemType")))
  {
    {
      return (int)6000;
    }
  }
  {}
  if ((_8443 == std::string ("errUnhandledSolutionStatus")))
  {
    {
      return (int)6010;
    }
  }
  {}
  if ((_8443 == std::string ("errUpperTriangle")))
  {
    {
      return (int)6020;
    }
  }
  {}
  if ((_8443 == std::string ("errLauSingularMatrix")))
  {
    {
      return (int)7000;
    }
  }
  {}
  if ((_8443 == std::string ("errLauNotPositiveDefinite")))
  {
    {
      return (int)7001;
    }
  }
  {}
  if ((_8443 == std::string ("errLauInvalidLowerTriangularMatrix")))
  {
    {
      return (int)7002;
    }
  }
  {}
  if ((_8443 == std::string ("errLauUnknown")))
  {
    {
      return (int)7005;
    }
  }
  {}
  if ((_8443 == std::string ("errLauArgM")))
  {
    {
      return (int)7010;
    }
  }
  {}
  if ((_8443 == std::string ("errLauArgN")))
  {
    {
      return (int)7011;
    }
  }
  {}
  if ((_8443 == std::string ("errLauArgK")))
  {
    {
      return (int)7012;
    }
  }
  {}
  if ((_8443 == std::string ("errLauArgTransa")))
  {
    {
      return (int)7015;
    }
  }
  {}
  if ((_8443 == std::string ("errLauArgTransb")))
  {
    {
      return (int)7016;
    }
  }
  {}
  if ((_8443 == std::string ("errLauArgUplo")))
  {
    {
      return (int)7017;
    }
  }
  {}
  if ((_8443 == std::string ("errLauArgTrans")))
  {
    {
      return (int)7018;
    }
  }
  {}
  if ((_8443 == std::string ("errLauInvalidSparseSymmetricMatrix")))
  {
    {
      return (int)7019;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfParse")))
  {
    {
      return (int)7100;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfObjSense")))
  {
    {
      return (int)7101;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfNoVariables")))
  {
    {
      return (int)7102;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfTooManyConstraints")))
  {
    {
      return (int)7103;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfTooManyVariables")))
  {
    {
      return (int)7104;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfNoVersionSpecified")))
  {
    {
      return (int)7105;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfSyntax")))
  {
    {
      return (int)7106;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicateObj")))
  {
    {
      return (int)7107;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicateCon")))
  {
    {
      return (int)7108;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicateVar")))
  {
    {
      return (int)7109;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicateInt")))
  {
    {
      return (int)7110;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidVarType")))
  {
    {
      return (int)7111;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidConType")))
  {
    {
      return (int)7112;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidDomainDimension")))
  {
    {
      return (int)7113;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicateObjacoord")))
  {
    {
      return (int)7114;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicateBcoord")))
  {
    {
      return (int)7115;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicateAcoord")))
  {
    {
      return (int)7116;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfTooFewVariables")))
  {
    {
      return (int)7117;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfTooFewConstraints")))
  {
    {
      return (int)7118;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfTooFewInts")))
  {
    {
      return (int)7119;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfTooManyInts")))
  {
    {
      return (int)7120;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidIntIndex")))
  {
    {
      return (int)7121;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfUnsupported")))
  {
    {
      return (int)7122;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicatePsdvar")))
  {
    {
      return (int)7123;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidPsdvarDimension")))
  {
    {
      return (int)7124;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfTooFewPsdvar")))
  {
    {
      return (int)7125;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidExpDimension")))
  {
    {
      return (int)7126;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicatePowCones")))
  {
    {
      return (int)7130;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfDuplicatePowStarCones")))
  {
    {
      return (int)7131;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidPower")))
  {
    {
      return (int)7132;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfPowerConeIsTooLong")))
  {
    {
      return (int)7133;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidPowerConeIndex")))
  {
    {
      return (int)7134;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidPowerStarConeIndex")))
  {
    {
      return (int)7135;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfUnhandledPowerConeType")))
  {
    {
      return (int)7136;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfUnhandledPowerStarConeType")))
  {
    {
      return (int)7137;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfPowerConeMismatch")))
  {
    {
      return (int)7138;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfPowerStarConeMismatch")))
  {
    {
      return (int)7139;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidNumberOfCones")))
  {
    {
      return (int)7740;
    }
  }
  {}
  if ((_8443 == std::string ("errCbfInvalidDimensionOfCones")))
  {
    {
      return (int)7741;
    }
  }
  {}
  if ((_8443 == std::string ("errMioInvalidRootOptimizer")))
  {
    {
      return (int)7700;
    }
  }
  {}
  if ((_8443 == std::string ("errMioInvalidNodeOptimizer")))
  {
    {
      return (int)7701;
    }
  }
  {}
  if ((_8443 == std::string ("errToconicConstrQNotPsd")))
  {
    {
      return (int)7800;
    }
  }
  {}
  if ((_8443 == std::string ("errToconicConstraintFx")))
  {
    {
      return (int)7801;
    }
  }
  {}
  if ((_8443 == std::string ("errToconicConstraintRa")))
  {
    {
      return (int)7802;
    }
  }
  {}
  if ((_8443 == std::string ("errToconicConstrNotConic")))
  {
    {
      return (int)7803;
    }
  }
  {}
  if ((_8443 == std::string ("errToconicObjectiveNotPsd")))
  {
    {
      return (int)7804;
    }
  }
  {}
  if ((_8443 == std::string ("errServerConnect")))
  {
    {
      return (int)8000;
    }
  }
  {}
  if ((_8443 == std::string ("errServerProtocol")))
  {
    {
      return (int)8001;
    }
  }
  {}
  if ((_8443 == std::string ("errServerStatus")))
  {
    {
      return (int)8002;
    }
  }
  {}
  if ((_8443 == std::string ("errServerToken")))
  {
    {
      return (int)8003;
    }
  }
  {}
  if ((_8443 == std::string ("errServerProblemSize")))
  {
    {
      return (int)8008;
    }
  }
  {}
  if ((_8443 == std::string ("trmMaxIterations")))
  {
    {
      return (int)10000;
    }
  }
  {}
  if ((_8443 == std::string ("trmMaxTime")))
  {
    {
      return (int)10001;
    }
  }
  {}
  if ((_8443 == std::string ("trmObjectiveRange")))
  {
    {
      return (int)10002;
    }
  }
  {}
  if ((_8443 == std::string ("trmMioNumRelaxs")))
  {
    {
      return (int)10008;
    }
  }
  {}
  if ((_8443 == std::string ("trmMioNumBranches")))
  {
    {
      return (int)10009;
    }
  }
  {}
  if ((_8443 == std::string ("trmNumMaxNumIntSolutions")))
  {
    {
      return (int)10015;
    }
  }
  {}
  if ((_8443 == std::string ("trmStall")))
  {
    {
      return (int)10006;
    }
  }
  {}
  if ((_8443 == std::string ("trmUserCallback")))
  {
    {
      return (int)10007;
    }
  }
  {}
  if ((_8443 == std::string ("trmMaxNumSetbacks")))
  {
    {
      return (int)10020;
    }
  }
  {}
  if ((_8443 == std::string ("trmNumericalProblem")))
  {
    {
      return (int)10025;
    }
  }
  {}
  if ((_8443 == std::string ("trmInternal")))
  {
    {
      return (int)10030;
    }
  }
  {}
  if ((_8443 == std::string ("trmInternalStop")))
  {
    {
      return (int)10031;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_xmlwriteroutputtype_value(const std::string & _8444){
  if ((_8444 == std::string ("row")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8444 == std::string ("col")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_prosta_value(const std::string & _8445){
  if ((_8445 == std::string ("unknown")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8445 == std::string ("primAndDualFeas")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8445 == std::string ("primFeas")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8445 == std::string ("dualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8445 == std::string ("primInfeas")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8445 == std::string ("dualInfeas")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8445 == std::string ("primAndDualInfeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8445 == std::string ("illPosed")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8445 == std::string ("primInfeasOrUnbounded")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemtype_value(const std::string & _8446){
  if ((_8446 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8446 == std::string ("qo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8446 == std::string ("qcqo")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8446 == std::string ("conic")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8446 == std::string ("mixed")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_problemitem_value(const std::string & _8447){
  if ((_8447 == std::string ("var")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8447 == std::string ("con")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8447 == std::string ("cone")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_parametertype_value(const std::string & _8448){
  if ((_8448 == std::string ("invalidType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8448 == std::string ("douType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8448 == std::string ("intType")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8448 == std::string ("strType")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_presolvemode_value(const std::string & _8449){
  if ((_8449 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8449 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8449 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_orderingtype_value(const std::string & _8450){
  if ((_8450 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8450 == std::string ("appminloc")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8450 == std::string ("experimental")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8450 == std::string ("tryGraphpar")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8450 == std::string ("forceGraphpar")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8450 == std::string ("none")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_optimizertype_value(const std::string & _8451){
  if ((_8451 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8451 == std::string ("intpnt")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8451 == std::string ("conic")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8451 == std::string ("primalSimplex")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8451 == std::string ("dualSimplex")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8451 == std::string ("freeSimplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8451 == std::string ("mixedInt")))
  {
    {
      return (int)5;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_onoffkey_value(const std::string & _8452){
  if ((_8452 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8452 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_objsense_value(const std::string & _8453){
  if ((_8453 == std::string ("minimize")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8453 == std::string ("maximize")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mpsformat_value(const std::string & _8454){
  if ((_8454 == std::string ("strict")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8454 == std::string ("relaxed")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8454 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8454 == std::string ("cplex")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mionodeseltype_value(const std::string & _8455){
  if ((_8455 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8455 == std::string ("first")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8455 == std::string ("best")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8455 == std::string ("pseudo")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miomode_value(const std::string & _8456){
  if ((_8456 == std::string ("ignored")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8456 == std::string ("satisfied")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_miocontsoltype_value(const std::string & _8457){
  if ((_8457 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8457 == std::string ("root")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8457 == std::string ("itg")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8457 == std::string ("itgRel")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_branchdir_value(const std::string & _8458){
  if ((_8458 == std::string ("free")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8458 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8458 == std::string ("down")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8458 == std::string ("near")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8458 == std::string ("far")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8458 == std::string ("rootLp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8458 == std::string ("guided")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8458 == std::string ("pseudocost")))
  {
    {
      return (int)7;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iparam_value(const std::string & _8459){
  if ((_8459 == std::string ("autoUpdateSolInfo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8459 == std::string ("removeUnusedSolutions")))
  {
    {
      return (int)118;
    }
  }
  {}
  if ((_8459 == std::string ("intpntHotstart")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8459 == std::string ("intpntPurify")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_8459 == std::string ("numThreads")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_8459 == std::string ("intpntMultiThread")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8459 == std::string ("timingLevel")))
  {
    {
      return (int)152;
    }
  }
  {}
  if ((_8459 == std::string ("mtSpincount")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_8459 == std::string ("maxNumWarnings")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_8459 == std::string ("optimizer")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_8459 == std::string ("biMaxIterations")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8459 == std::string ("licenseTrhExpiryWrn")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_8459 == std::string ("logIncludeSummary")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_8459 == std::string ("logCutSecondOpt")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_8459 == std::string ("logAnaPro")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_8459 == std::string ("logResponse")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8459 == std::string ("logLocalInfo")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_8459 == std::string ("logBi")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_8459 == std::string ("logBiFreq")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_8459 == std::string ("biCleanOptimizer")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8459 == std::string ("intpntMaxNumRefinementSteps")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8459 == std::string ("intpntStartingPoint")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_8459 == std::string ("intpntDiffStep")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8459 == std::string ("intpntScaling")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_8459 == std::string ("intpntSolveForm")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_8459 == std::string ("logIntpnt")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_8459 == std::string ("intpntMaxIterations")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8459 == std::string ("intpntOffColTrh")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8459 == std::string ("intpntOrderMethod")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_8459 == std::string ("intpntOrderGpNumSeeds")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_8459 == std::string ("intpntBasis")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8459 == std::string ("biIgnoreMaxIter")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8459 == std::string ("biIgnoreNumError")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8459 == std::string ("intpntMaxNumCor")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8459 == std::string ("presolveUse")))
  {
    {
      return (int)108;
    }
  }
  {}
  if ((_8459 == std::string ("presolveLevel")))
  {
    {
      return (int)102;
    }
  }
  {}
  if ((_8459 == std::string ("logPresolve")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8459 == std::string ("presolveLindepUse")))
  {
    {
      return (int)105;
    }
  }
  {}
  if ((_8459 == std::string ("presolveMaxNumPass")))
  {
    {
      return (int)106;
    }
  }
  {}
  if ((_8459 == std::string ("presolveEliminatorMaxNumTries")))
  {
    {
      return (int)101;
    }
  }
  {}
  if ((_8459 == std::string ("presolveEliminatorMaxFill")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_8459 == std::string ("presolveMaxNumReductions")))
  {
    {
      return (int)107;
    }
  }
  {}
  if ((_8459 == std::string ("simStabilityPriority")))
  {
    {
      return (int)145;
    }
  }
  {}
  if ((_8459 == std::string ("simPrimalCrash")))
  {
    {
      return (int)134;
    }
  }
  {}
  if ((_8459 == std::string ("logSim")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_8459 == std::string ("logSimMinor")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_8459 == std::string ("logSimFreq")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_8459 == std::string ("simPrimalRestrictSelection")))
  {
    {
      return (int)136;
    }
  }
  {}
  if ((_8459 == std::string ("simPrimalSelection")))
  {
    {
      return (int)137;
    }
  }
  {}
  if ((_8459 == std::string ("simDualRestrictSelection")))
  {
    {
      return (int)126;
    }
  }
  {}
  if ((_8459 == std::string ("simDualSelection")))
  {
    {
      return (int)127;
    }
  }
  {}
  if ((_8459 == std::string ("simMaxIterations")))
  {
    {
      return (int)131;
    }
  }
  {}
  if ((_8459 == std::string ("simHotstartLu")))
  {
    {
      return (int)130;
    }
  }
  {}
  if ((_8459 == std::string ("simRefactorFreq")))
  {
    {
      return (int)138;
    }
  }
  {}
  if ((_8459 == std::string ("simSeed")))
  {
    {
      return (int)143;
    }
  }
  {}
  if ((_8459 == std::string ("mioMode")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_8459 == std::string ("logMio")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_8459 == std::string ("logMioFreq")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8459 == std::string ("mioMaxNumRelaxs")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_8459 == std::string ("mioMaxNumBranches")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_8459 == std::string ("mioMaxNumRootCutRounds")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_8459 == std::string ("mioMaxNumSolutions")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_8459 == std::string ("mioNodeSelection")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_8459 == std::string ("mioHeuristicLevel")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_8459 == std::string ("mioProbingLevel")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_8459 == std::string ("mioCutSelectionLevel")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_8459 == std::string ("mioVbDetectionLevel")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_8459 == std::string ("mioBranchDir")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_8459 == std::string ("mioRootOptimizer")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_8459 == std::string ("mioNodeOptimizer")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_8459 == std::string ("mioPerspectiveReformulate")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_8459 == std::string ("mioPropagateObjectiveConstraint")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_8459 == std::string ("mioSeed")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_8459 == std::string ("mioConicOuterApproximation")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_8459 == std::string ("readKeepFreeCon")))
  {
    {
      return (int)112;
    }
  }
  {}
  if ((_8459 == std::string ("readMpsFormat")))
  {
    {
      return (int)115;
    }
  }
  {}
  if ((_8459 == std::string ("writeMpsFormat")))
  {
    {
      return (int)170;
    }
  }
  {}
  if ((_8459 == std::string ("readMpsWidth")))
  {
    {
      return (int)116;
    }
  }
  {}
  if ((_8459 == std::string ("readDebug")))
  {
    {
      return (int)111;
    }
  }
  {}
  if ((_8459 == std::string ("readLpQuotedNames")))
  {
    {
      return (int)114;
    }
  }
  {}
  if ((_8459 == std::string ("writeDataParam")))
  {
    {
      return (int)157;
    }
  }
  {}
  if ((_8459 == std::string ("writeFreeCon")))
  {
    {
      return (int)158;
    }
  }
  {}
  if ((_8459 == std::string ("writeGenericNames")))
  {
    {
      return (int)159;
    }
  }
  {}
  if ((_8459 == std::string ("writeGenericNamesIo")))
  {
    {
      return (int)160;
    }
  }
  {}
  if ((_8459 == std::string ("writeCompression")))
  {
    {
      return (int)156;
    }
  }
  {}
  if ((_8459 == std::string ("writeMpsInt")))
  {
    {
      return (int)171;
    }
  }
  {}
  if ((_8459 == std::string ("writeLpStrictFormat")))
  {
    {
      return (int)168;
    }
  }
  {}
  if ((_8459 == std::string ("writeLpQuotedNames")))
  {
    {
      return (int)167;
    }
  }
  {}
  if ((_8459 == std::string ("writeLpLineWidth")))
  {
    {
      return (int)166;
    }
  }
  {}
  if ((_8459 == std::string ("writeLpTermsPerLine")))
  {
    {
      return (int)169;
    }
  }
  {}
  if ((_8459 == std::string ("writeLpFullObj")))
  {
    {
      return (int)165;
    }
  }
  {}
  if ((_8459 == std::string ("writePrecision")))
  {
    {
      return (int)172;
    }
  }
  {}
  if ((_8459 == std::string ("writeSolIgnoreInvalidNames")))
  {
    {
      return (int)176;
    }
  }
  {}
  if ((_8459 == std::string ("writeSolHead")))
  {
    {
      return (int)175;
    }
  }
  {}
  if ((_8459 == std::string ("writeSolConstraints")))
  {
    {
      return (int)174;
    }
  }
  {}
  if ((_8459 == std::string ("writeSolVariables")))
  {
    {
      return (int)177;
    }
  }
  {}
  if ((_8459 == std::string ("writeSolBarvariables")))
  {
    {
      return (int)173;
    }
  }
  {}
  if ((_8459 == std::string ("writeBasHead")))
  {
    {
      return (int)154;
    }
  }
  {}
  if ((_8459 == std::string ("writeBasConstraints")))
  {
    {
      return (int)153;
    }
  }
  {}
  if ((_8459 == std::string ("writeBasVariables")))
  {
    {
      return (int)155;
    }
  }
  {}
  if ((_8459 == std::string ("writeIntHead")))
  {
    {
      return (int)163;
    }
  }
  {}
  if ((_8459 == std::string ("writeIntConstraints")))
  {
    {
      return (int)162;
    }
  }
  {}
  if ((_8459 == std::string ("writeIntVariables")))
  {
    {
      return (int)164;
    }
  }
  {}
  if ((_8459 == std::string ("solReadNameWidth")))
  {
    {
      return (int)149;
    }
  }
  {}
  if ((_8459 == std::string ("solReadWidth")))
  {
    {
      return (int)150;
    }
  }
  {}
  if ((_8459 == std::string ("infeasReportAuto")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8459 == std::string ("infeasReportLevel")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8459 == std::string ("infeasGenericNames")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8459 == std::string ("logInfeasAna")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_8459 == std::string ("licenseWait")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_8459 == std::string ("licenseSuppressExpireWrns")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_8459 == std::string ("licensePauseTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_8459 == std::string ("licenseDebug")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_8459 == std::string ("solFilterKeepBasic")))
  {
    {
      return (int)147;
    }
  }
  {}
  if ((_8459 == std::string ("solFilterKeepRanged")))
  {
    {
      return (int)148;
    }
  }
  {}
  if ((_8459 == std::string ("log")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_8459 == std::string ("logExpand")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_8459 == std::string ("logFile")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_8459 == std::string ("logOrder")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8459 == std::string ("logSensitivity")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8459 == std::string ("logSensitivityOpt")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_8459 == std::string ("readTaskIgnoreParam")))
  {
    {
      return (int)117;
    }
  }
  {}
  if ((_8459 == std::string ("writeTaskIncSol")))
  {
    {
      return (int)178;
    }
  }
  {}
  if ((_8459 == std::string ("paramReadCaseName")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_8459 == std::string ("paramReadIgnError")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_8459 == std::string ("solutionCallback")))
  {
    {
      return (int)151;
    }
  }
  {}
  if ((_8459 == std::string ("simScaling")))
  {
    {
      return (int)141;
    }
  }
  {}
  if ((_8459 == std::string ("simScalingMethod")))
  {
    {
      return (int)142;
    }
  }
  {}
  if ((_8459 == std::string ("simPrimalPhaseoneMethod")))
  {
    {
      return (int)135;
    }
  }
  {}
  if ((_8459 == std::string ("simDualPhaseoneMethod")))
  {
    {
      return (int)125;
    }
  }
  {}
  if ((_8459 == std::string ("simMaxNumSetbacks")))
  {
    {
      return (int)132;
    }
  }
  {}
  if ((_8459 == std::string ("simHotstart")))
  {
    {
      return (int)129;
    }
  }
  {}
  if ((_8459 == std::string ("simBasisFactorUse")))
  {
    {
      return (int)122;
    }
  }
  {}
  if ((_8459 == std::string ("simDegen")))
  {
    {
      return (int)123;
    }
  }
  {}
  if ((_8459 == std::string ("simReformulation")))
  {
    {
      return (int)139;
    }
  }
  {}
  if ((_8459 == std::string ("simExploitDupvec")))
  {
    {
      return (int)128;
    }
  }
  {}
  if ((_8459 == std::string ("simSaveLu")))
  {
    {
      return (int)140;
    }
  }
  {}
  if ((_8459 == std::string ("simNonSingular")))
  {
    {
      return (int)133;
    }
  }
  {}
  if ((_8459 == std::string ("simDualCrash")))
  {
    {
      return (int)124;
    }
  }
  {}
  if ((_8459 == std::string ("logStorage")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_8459 == std::string ("infeasPreferPrimal")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_8459 == std::string ("readLpDropNewVarsInBou")))
  {
    {
      return (int)113;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteLineLength")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteHints")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteParameters")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteProblem")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteHeader")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteSolutions")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteSolBas")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteSolItg")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_8459 == std::string ("opfWriteSolItr")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_8459 == std::string ("ptfWriteTransform")))
  {
    {
      return (int)110;
    }
  }
  {}
  if ((_8459 == std::string ("primalRepairOptimizer")))
  {
    {
      return (int)109;
    }
  }
  {}
  if ((_8459 == std::string ("mioRootRepeatPresolveLevel")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_8459 == std::string ("mioCutCmir")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_8459 == std::string ("mioCutClique")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_8459 == std::string ("mioCutImpliedBound")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_8459 == std::string ("mioCutKnapsackCover")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_8459 == std::string ("mioCutGmi")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_8459 == std::string ("sensitivityType")))
  {
    {
      return (int)121;
    }
  }
  {}
  if ((_8459 == std::string ("presolveLindepRelWorkTrh")))
  {
    {
      return (int)104;
    }
  }
  {}
  if ((_8459 == std::string ("presolveLindepAbsWorkTrh")))
  {
    {
      return (int)103;
    }
  }
  {}
  if ((_8459 == std::string ("sensitivityAll")))
  {
    {
      return (int)119;
    }
  }
  {}
  if ((_8459 == std::string ("logFeasRepair")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_8459 == std::string ("cacheLicense")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8459 == std::string ("intpntRegularizationUse")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_8459 == std::string ("simSolveForm")))
  {
    {
      return (int)144;
    }
  }
  {}
  if ((_8459 == std::string ("simSwitchOptimizer")))
  {
    {
      return (int)146;
    }
  }
  {}
  if ((_8459 == std::string ("writeIgnoreIncompatibleItems")))
  {
    {
      return (int)161;
    }
  }
  {}
  if ((_8459 == std::string ("checkConvexity")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8459 == std::string ("logCheckConvexity")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_8459 == std::string ("autoSortABeforeOpt")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8459 == std::string ("sensitivityOptimizer")))
  {
    {
      return (int)120;
    }
  }
  {}
  if ((_8459 == std::string ("writeXmlMode")))
  {
    {
      return (int)179;
    }
  }
  {}
  if ((_8459 == std::string ("anaSolBasis")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8459 == std::string ("anaSolPrintViolated")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8459 == std::string ("basisSolveUsePlusOne")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8459 == std::string ("compressStatfile")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8459 == std::string ("mioRinsMaxNodes")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_8459 == std::string ("mioFeaspumpLevel")))
  {
    {
      return (int)69;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iomode_value(const std::string & _8460){
  if ((_8460 == std::string ("read")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8460 == std::string ("write")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8460 == std::string ("readwrite")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_iinf_value(const std::string & _8461){
  if ((_8461 == std::string ("versionMajor")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_8461 == std::string ("versionMinor")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_8461 == std::string ("versionRevision")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_8461 == std::string ("presolveLindepWork")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_8461 == std::string ("presolveLindepPivots")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_8461 == std::string ("presolveLindepSkipped")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_8461 == std::string ("presolveOutofspace")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_8461 == std::string ("presolveBadPrecision")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_8461 == std::string ("optObjectiveSense")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_8461 == std::string ("optimizer")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFirRefIter")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumRefSteps")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFactorDim")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFactorSchurNumSingular")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFactorNumDenseA")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFactorNumDenseADup")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFactorNumDenseW")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumcon")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumvar")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumbarvar")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumblo")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumbup")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumbfr")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumbfx")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumcone")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumconevar")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumbndcone")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumrqcones")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumqcones")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumpexpcones")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_8461 == std::string ("intpntNumppowcones")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_8461 == std::string ("intpntMinconedim")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_8461 == std::string ("intpntMaxconedim")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8461 == std::string ("intpntMaxbarvardim")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumcfr")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumcfx")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumclo")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumcup")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumcra")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumcnl")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumvfr")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumvfx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumvlo")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumvup")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumvra")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumvnl")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumnza")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumcon")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumcfr")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumcfx")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumclo")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumcup")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumcra")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumcnl")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumvar")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumvfr")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumvfx")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumvlo")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumvup")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumvra")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumvnl")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_8461 == std::string ("presolveFnumnza")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumElimns")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_8461 == std::string ("presolveEliNumTries")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_8461 == std::string ("presolveEliNumFreedCon")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_8461 == std::string ("presolveEliNumFreedConTotal")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_8461 == std::string ("presolveLindepNumTries")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_8461 == std::string ("presolveLindepNum")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_8461 == std::string ("presolveForceConNum")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8461 == std::string ("presolveForceConNumVar")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8461 == std::string ("presolveForceVarNum")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8461 == std::string ("presolveForceVarNumCon")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8461 == std::string ("presolvePivOnConNum")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumDouBlocks")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumSimplifiedDouBlocks")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_8461 == std::string ("presolveSizeSimplifiedDouBlocks")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_8461 == std::string ("presolveNumQuadConeOrthoTrans")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFactorNum")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8461 == std::string ("intpntFactorNumSolve")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8461 == std::string ("simPrimalHotstartNumBasics")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_8461 == std::string ("simPrimalHotstartBasisRank")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_8461 == std::string ("simDualHotstartNumBasics")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_8461 == std::string ("simDualHotstartBasisRank")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_8461 == std::string ("intpntGpOrderEmployed")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8461 == std::string ("numLuFactorizations")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_8461 == std::string ("simPrimalTrust")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_8461 == std::string ("simDualTrust")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_8461 == std::string ("simPrimalNumSetbacks")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_8461 == std::string ("simDualNumSetbacks")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_8461 == std::string ("simNumDupvec")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_8461 == std::string ("simNumPrimalBoundswaps")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_8461 == std::string ("simNumDualBoundswaps")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_8461 == std::string ("simNumDualIntegerPivots")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_8461 == std::string ("biPrimalInfo")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8461 == std::string ("biDualInfo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8461 == std::string ("presolveLindepNumTruncTries")))
  {
    {
      return (int)57;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_dinf_value(const std::string & _8462){
  if ((_8462 == std::string ("sensitivityPrimalTime")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_8462 == std::string ("sensitivityDualTime")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_8462 == std::string ("intpntGfeas")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_8462 == std::string ("intpntMu")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_8462 == std::string ("intpntInitIterTime")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorTime")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8462 == std::string ("intpntInitSearchTime")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFormSearchTime")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8462 == std::string ("intpntUpdateTime")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSetupTime")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSchurTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorHatSchurTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorHatSchurPushTime")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorHatSchurPullTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorBarSchurTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorBarSchurDeTabTime")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorBarSchurSpTabTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSparseLTime")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSparseLUpdateLastTime")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSparseLFactorLastTime")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseLTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseTime")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotaTime")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotaSolveTime")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotatdotaTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotlInitTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotlFactorTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_8462 == std::string ("intpntIterNonCorrectorFlops")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_8462 == std::string ("intpntIterOneCorrectorFlops")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_8462 == std::string ("intpntSolveTime")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_8462 == std::string ("intpntIterRefTime")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_8462 == std::string ("intpntSolveSparseLTime")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_8462 == std::string ("intpntSolveDenseLTime")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSetupFlops")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSetupHatSchurFlops")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSchurFlops")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorHatSchurFlops")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorHatSchurPushFlops")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorHatSchurPullFlops")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorBarSchurFlops")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSparseLFlops")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorMlOrderSparseLFlops")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorGpOrderSparseLFlops")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSparseLUpdateLastFlops")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSparseLFactorLastFlops")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseLFlops")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseFlops")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotaFlops")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotatdotaFlops")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotlFactor_initFlops")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotlFactorFlops")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotl11FactorFlops")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotl21FactorFlops")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorDenseDotl22FactorFlops")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8462 == std::string ("presolveAcoltTime")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_8462 == std::string ("presolveSetupTime")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_8462 == std::string ("presolveCheckproTime")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_8462 == std::string ("presolveDupconTime")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_8462 == std::string ("presolveDupvarTime")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_8462 == std::string ("presolveFinalTime")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_8462 == std::string ("presolveSubDomvarTime")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_8462 == std::string ("presolveSubRelaxTime")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_8462 == std::string ("primalSimplexInftime")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_8462 == std::string ("dualSimplexInftime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8462 == std::string ("intpntGpOrderSavedFlops")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSetupDetectDenseTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSetupMlOrderTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_8462 == std::string ("intpntFactorSetupGpOrderTime")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_8462 == std::string ("biCrashTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8462 == std::string ("biCrashLuTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8462 == std::string ("biFactorTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8462 == std::string ("biFactorWork")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8462 == std::string ("biPrimalDone")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8462 == std::string ("biDualDone")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8462 == std::string ("simPrimalObj")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_8462 == std::string ("simPrimalFeas")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_8462 == std::string ("simDualObj")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_8462 == std::string ("simDualFeas")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_8462 == std::string ("biPrimalObj")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8462 == std::string ("biDualObj")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8462 == std::string ("biPrimalFeas")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8462 == std::string ("biDualFeas")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8462 == std::string ("intpntPurifyTime")))
  {
    {
      return (int)63;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_inftype_value(const std::string & _8463){
  if ((_8463 == std::string ("douType")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8463 == std::string ("intType")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8463 == std::string ("lintType")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_iinfitem_value(const std::string & _8464){
  if ((_8464 == std::string ("anaProNumCon")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumConLo")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumConUp")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumConRa")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumConEq")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumConFr")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarLo")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarUp")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarRa")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarEq")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarFr")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarCont")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarBin")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8464 == std::string ("anaProNumVarInt")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8464 == std::string ("optimizeResponse")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_8464 == std::string ("intpntIter")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8464 == std::string ("intpntFactorDimDense")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8464 == std::string ("intpntSolveDual")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8464 == std::string ("mioNodeDepth")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumbin")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumint")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumcont")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumcon")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumcone")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumqcones")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumrqcones")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumpexpcones")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumdexpcones")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumppowcones")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumdpowcones")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumconevar")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumbinconevar")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumintconevar")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumcontconevar")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumvar")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumbin")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumint")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumcont")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumcon")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumcone")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumqcones")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumrqcones")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumpexpcones")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumdexpcones")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumppowcones")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumdpowcones")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumconevar")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumbinconevar")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumintconevar")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_8464 == std::string ("mioPresolvedNumcontconevar")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_8464 == std::string ("mioCliqueTableSize")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8464 == std::string ("mioConstructSolution")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumIntSolutions")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_8464 == std::string ("mioObjBoundDefined")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumActiveNodes")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumRelax")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumBranch")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_8464 == std::string ("mioTotalNumCuts")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumCmirCuts")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumCliqueCuts")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumImpliedBoundCuts")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumKnapsackCoverCuts")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumGomoryCuts")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_8464 == std::string ("mioNumRepeatedPresolve")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_8464 == std::string ("mioUserObjCut")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_8464 == std::string ("mioRelgapSatisfied")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_8464 == std::string ("mioAbsgapSatisfied")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8464 == std::string ("rdProtype")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_8464 == std::string ("rdNumcon")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_8464 == std::string ("rdNumvar")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_8464 == std::string ("rdNumbarvar")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_8464 == std::string ("rdNumintvar")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_8464 == std::string ("rdNumq")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_8464 == std::string ("simDualDegIter")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_8464 == std::string ("simDualInfIter")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_8464 == std::string ("simDualHotstartLu")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_8464 == std::string ("simPrimalIter")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_8464 == std::string ("simDualIter")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_8464 == std::string ("intpntNumThreads")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8464 == std::string ("simPrimalInfIter")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_8464 == std::string ("simPrimalDegIter")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_8464 == std::string ("simPrimalHotstart")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_8464 == std::string ("simPrimalHotstartLu")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_8464 == std::string ("simDualHotstart")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_8464 == std::string ("solItrProsta")))
  {
    {
      return (int)98;
    }
  }
  {}
  if ((_8464 == std::string ("solItrSolsta")))
  {
    {
      return (int)99;
    }
  }
  {}
  if ((_8464 == std::string ("solBasProsta")))
  {
    {
      return (int)94;
    }
  }
  {}
  if ((_8464 == std::string ("solBasSolsta")))
  {
    {
      return (int)95;
    }
  }
  {}
  if ((_8464 == std::string ("solItgProsta")))
  {
    {
      return (int)96;
    }
  }
  {}
  if ((_8464 == std::string ("solItgSolsta")))
  {
    {
      return (int)97;
    }
  }
  {}
  if ((_8464 == std::string ("simNumcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_8464 == std::string ("simNumvar")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_8464 == std::string ("optNumcon")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_8464 == std::string ("optNumvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_8464 == std::string ("stoNumARealloc")))
  {
    {
      return (int)100;
    }
  }
  {}
  if ((_8464 == std::string ("rdNumcone")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_8464 == std::string ("simSolveDual")))
  {
    {
      return (int)93;
    }
  }
  {}
  if ((_8464 == std::string ("purifyPrimalSuccess")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_8464 == std::string ("purifyDualSuccess")))
  {
    {
      return (int)72;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_internal_liinf_value(const std::string & _8465){
  if ((_8465 == std::string ("intpntLenbarvar")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8465 == std::string ("intpntFactorNumNzBefore")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8465 == std::string ("intpntFactorNumNzAfter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8465 == std::string ("intpntFactorMlOrderSparseLNz")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8465 == std::string ("intpntFactorGpOrderSparseLNz")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8465 == std::string ("presolveStackSize")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8465 == std::string ("intpntFactorVNz")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8465 == std::string ("intpntFactorUpdatedVNz")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_liinfitem_value(const std::string & _8466){
  if ((_8466 == std::string ("mioAnz")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8466 == std::string ("mioPresolvedAnz")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8466 == std::string ("mioSimplexIter")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8466 == std::string ("mioIntpntIter")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8466 == std::string ("biPrimalIter")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8466 == std::string ("biDualIter")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8466 == std::string ("biCleanPrimalIter")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8466 == std::string ("biCleanDualIter")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8466 == std::string ("biCleanPrimalDegIter")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8466 == std::string ("biCleanDualDegIter")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8466 == std::string ("intpntFactorNumNz")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8466 == std::string ("rdNumanz")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8466 == std::string ("rdNumqnz")))
  {
    {
      return (int)12;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dparam_value(const std::string & _8467){
  if ((_8467 == std::string ("dataTolCjLarge")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_8467 == std::string ("dataTolCHuge")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8467 == std::string ("dataTolAijLarge")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8467 == std::string ("dataTolAijHuge")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8467 == std::string ("dataSymMatTol")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8467 == std::string ("dataSymMatTolLarge")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8467 == std::string ("dataSymMatTolHuge")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8467 == std::string ("dataTolBoundInf")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8467 == std::string ("dataTolBoundWrn")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8467 == std::string ("dataTolQij")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8467 == std::string ("dataTolX")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8467 == std::string ("semidefiniteTolApprox")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8467 == std::string ("optimizerMaxTime")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_8467 == std::string ("lowerObjCut")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_8467 == std::string ("upperObjCut")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_8467 == std::string ("upperObjCutFiniteTrh")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_8467 == std::string ("lowerObjCutFiniteTrh")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolRelGap")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolStepSize")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_8467 == std::string ("simLuTolRelPiv")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolRelStep")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolPath")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolPfeas")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolDfeas")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolMuRed")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolInfeas")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_8467 == std::string ("intpntCoTolRelGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8467 == std::string ("intpntCoTolPfeas")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8467 == std::string ("intpntCoTolDfeas")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8467 == std::string ("intpntCoTolMuRed")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8467 == std::string ("intpntCoTolNearRel")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8467 == std::string ("intpntCoTolInfeas")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8467 == std::string ("intpntQoTolRelGap")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_8467 == std::string ("intpntQoTolPfeas")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_8467 == std::string ("intpntQoTolDfeas")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8467 == std::string ("intpntQoTolMuRed")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_8467 == std::string ("intpntQoTolNearRel")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_8467 == std::string ("intpntQoTolInfeas")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolPsafe")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_8467 == std::string ("intpntTolDsafe")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_8467 == std::string ("mioMaxTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_8467 == std::string ("mioRelGapConst")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_8467 == std::string ("mioTolRelGap")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_8467 == std::string ("mioTolAbsGap")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_8467 == std::string ("mioTolAbsRelaxInt")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_8467 == std::string ("basisTolX")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8467 == std::string ("basisTolS")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8467 == std::string ("basisRelTolS")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8467 == std::string ("presolveTolX")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8467 == std::string ("presolveTolS")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8467 == std::string ("presolveTolAij")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_8467 == std::string ("presolveTolAbsLindep")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_8467 == std::string ("presolveTolRelLindep")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8467 == std::string ("simplexAbsTolPiv")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_8467 == std::string ("mioTolFeas")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_8467 == std::string ("anaSolInfeasTol")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8467 == std::string ("checkConvexityRelTol")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8467 == std::string ("qcqoReformulateRelDropTol")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8467 == std::string ("mioTolRelDualBoundImprovement")))
  {
    {
      return (int)45;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_feature_value(const std::string & _8468){
  if ((_8468 == std::string ("pts")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8468 == std::string ("pton")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dinfitem_value(const std::string & _8469){
  if ((_8469 == std::string ("biTime")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8469 == std::string ("biPrimalTime")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8469 == std::string ("biDualTime")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8469 == std::string ("biCleanTime")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8469 == std::string ("biCleanPrimalTime")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8469 == std::string ("biCleanDualTime")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8469 == std::string ("intpntTime")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_8469 == std::string ("intpntOrderTime")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8469 == std::string ("intpntPrimalObj")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8469 == std::string ("intpntDualObj")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8469 == std::string ("intpntPrimalFeas")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8469 == std::string ("intpntDualFeas")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8469 == std::string ("intpntOptStatus")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8469 == std::string ("simTime")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_8469 == std::string ("simPrimalTime")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_8469 == std::string ("simDualTime")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_8469 == std::string ("simObj")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_8469 == std::string ("simFeas")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_8469 == std::string ("mioTime")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_8469 == std::string ("mioRootPresolveTime")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_8469 == std::string ("mioRootOptimizerTime")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_8469 == std::string ("toConicTime")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_8469 == std::string ("mioConstructSolutionObj")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8469 == std::string ("mioObjInt")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8469 == std::string ("mioObjBound")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8469 == std::string ("mioObjRelGap")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_8469 == std::string ("mioObjAbsGap")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8469 == std::string ("mioUserObjCut")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_8469 == std::string ("mioCmirSeparationTime")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8469 == std::string ("mioCliqueSeparationTime")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8469 == std::string ("mioKnapsackCoverSeparationTime")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8469 == std::string ("mioGmiSeparationTime")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8469 == std::string ("mioImpliedBoundTime")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8469 == std::string ("mioRootCutgenTime")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_8469 == std::string ("mioProbingTime")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_8469 == std::string ("optimizerTime")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_8469 == std::string ("presolveTime")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_8469 == std::string ("mioDualBoundAfterPresolve")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8469 == std::string ("presolveEliTime")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_8469 == std::string ("presolveLindepTime")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_8469 == std::string ("rdTime")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_8469 == std::string ("solItrPrimalObj")))
  {
    {
      return (int)84;
    }
  }
  {}
  if ((_8469 == std::string ("solItrPviolcon")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_8469 == std::string ("solItrPviolvar")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_8469 == std::string ("solItrPviolbarvar")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_8469 == std::string ("solItrPviolcones")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_8469 == std::string ("solItrDualObj")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_8469 == std::string ("solItrDviolcon")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_8469 == std::string ("solItrDviolvar")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_8469 == std::string ("solItrDviolbarvar")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_8469 == std::string ("solItrDviolcones")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmXc")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmXx")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmBarx")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmY")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmSlc")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmSuc")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmSlx")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmSux")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmSnx")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_8469 == std::string ("solItrNrmBars")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_8469 == std::string ("solBasPrimalObj")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_8469 == std::string ("solBasPviolcon")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_8469 == std::string ("solBasPviolvar")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_8469 == std::string ("solBasDualObj")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_8469 == std::string ("solBasDviolcon")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_8469 == std::string ("solBasDviolvar")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmXc")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmXx")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmBarx")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmY")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmSlc")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmSuc")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmSlx")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8469 == std::string ("solBasNrmSux")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8469 == std::string ("solItgPrimalObj")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_8469 == std::string ("solItgPviolcon")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_8469 == std::string ("solItgPviolvar")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_8469 == std::string ("solItgPviolbarvar")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_8469 == std::string ("solItgPviolcones")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_8469 == std::string ("solItgPviolitg")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_8469 == std::string ("solItgNrmXc")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_8469 == std::string ("solItgNrmXx")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_8469 == std::string ("solItgNrmBarx")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_8469 == std::string ("intpntFactorNumFlops")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8469 == std::string ("qcqoReformulateTime")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_8469 == std::string ("qcqoReformulateMaxPerturbation")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_8469 == std::string ("qcqoReformulateWorstCholeskyDiagScaling")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_8469 == std::string ("qcqoReformulateWorstCholeskyColumnScaling")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_8469 == std::string ("primalRepairPenaltyObj")))
  {
    {
      return (int)35;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_dataformat_value(const std::string & _8470){
  if ((_8470 == std::string ("extension")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8470 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8470 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8470 == std::string ("op")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8470 == std::string ("freeMps")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8470 == std::string ("task")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8470 == std::string ("ptf")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8470 == std::string ("cb")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8470 == std::string ("jsonTask")))
  {
    {
      return (int)8;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_symmattype_value(const std::string & _8471){
  if ((_8471 == std::string ("sparse")))
  {
    {
      return (int)0;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_scopr_value(const std::string & _8472){
  if ((_8472 == std::string ("ent")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8472 == std::string ("exp")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8472 == std::string ("log")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8472 == std::string ("pow")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8472 == std::string ("sqrt")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_nametype_value(const std::string & _8473){
  if ((_8473 == std::string ("gen")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8473 == std::string ("mps")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8473 == std::string ("lp")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_conetype_value(const std::string & _8474){
  if ((_8474 == std::string ("quad")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8474 == std::string ("rquad")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8474 == std::string ("pexp")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8474 == std::string ("dexp")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8474 == std::string ("ppow")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8474 == std::string ("dpow")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8474 == std::string ("zero")))
  {
    {
      return (int)6;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_compresstype_value(const std::string & _8475){
  if ((_8475 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8475 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8475 == std::string ("gzip")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8475 == std::string ("zstd")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_checkconvexitytype_value(const std::string & _8476){
  if ((_8476 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8476 == std::string ("simple")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8476 == std::string ("full")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_callbackcode_value(const std::string & _8477){
  if ((_8477 == std::string ("beginRootCutgen")))
  {
    {
      return (int)22;
    }
  }
  {}
  if ((_8477 == std::string ("imRootCutgen")))
  {
    {
      return (int)76;
    }
  }
  {}
  if ((_8477 == std::string ("endRootCutgen")))
  {
    {
      return (int)51;
    }
  }
  {}
  if ((_8477 == std::string ("beginOptimizer")))
  {
    {
      return (int)12;
    }
  }
  {}
  if ((_8477 == std::string ("endOptimizer")))
  {
    {
      return (int)41;
    }
  }
  {}
  if ((_8477 == std::string ("beginPresolve")))
  {
    {
      return (int)13;
    }
  }
  {}
  if ((_8477 == std::string ("updatePresolve")))
  {
    {
      return (int)88;
    }
  }
  {}
  if ((_8477 == std::string ("imPresolve")))
  {
    {
      return (int)70;
    }
  }
  {}
  if ((_8477 == std::string ("endPresolve")))
  {
    {
      return (int)42;
    }
  }
  {}
  if ((_8477 == std::string ("beginIntpnt")))
  {
    {
      return (int)9;
    }
  }
  {}
  if ((_8477 == std::string ("intpnt")))
  {
    {
      return (int)79;
    }
  }
  {}
  if ((_8477 == std::string ("imIntpnt")))
  {
    {
      return (int)62;
    }
  }
  {}
  if ((_8477 == std::string ("endIntpnt")))
  {
    {
      return (int)38;
    }
  }
  {}
  if ((_8477 == std::string ("beginConic")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8477 == std::string ("conic")))
  {
    {
      return (int)27;
    }
  }
  {}
  if ((_8477 == std::string ("imConic")))
  {
    {
      return (int)57;
    }
  }
  {}
  if ((_8477 == std::string ("endConic")))
  {
    {
      return (int)30;
    }
  }
  {}
  if ((_8477 == std::string ("primalSimplex")))
  {
    {
      return (int)81;
    }
  }
  {}
  if ((_8477 == std::string ("dualSimplex")))
  {
    {
      return (int)28;
    }
  }
  {}
  if ((_8477 == std::string ("beginBi")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8477 == std::string ("imBi")))
  {
    {
      return (int)56;
    }
  }
  {}
  if ((_8477 == std::string ("endBi")))
  {
    {
      return (int)29;
    }
  }
  {}
  if ((_8477 == std::string ("beginPrimalBi")))
  {
    {
      return (int)14;
    }
  }
  {}
  if ((_8477 == std::string ("imPrimalBi")))
  {
    {
      return (int)71;
    }
  }
  {}
  if ((_8477 == std::string ("updatePrimalBi")))
  {
    {
      return (int)89;
    }
  }
  {}
  if ((_8477 == std::string ("endPrimalBi")))
  {
    {
      return (int)43;
    }
  }
  {}
  if ((_8477 == std::string ("beginDualBi")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8477 == std::string ("imDualBi")))
  {
    {
      return (int)58;
    }
  }
  {}
  if ((_8477 == std::string ("updateDualBi")))
  {
    {
      return (int)85;
    }
  }
  {}
  if ((_8477 == std::string ("endDualBi")))
  {
    {
      return (int)31;
    }
  }
  {}
  if ((_8477 == std::string ("beginSimplexBi")))
  {
    {
      return (int)24;
    }
  }
  {}
  if ((_8477 == std::string ("imSimplexBi")))
  {
    {
      return (int)78;
    }
  }
  {}
  if ((_8477 == std::string ("beginPrimalSimplexBi")))
  {
    {
      return (int)19;
    }
  }
  {}
  if ((_8477 == std::string ("updatePrimalSimplexBi")))
  {
    {
      return (int)91;
    }
  }
  {}
  if ((_8477 == std::string ("endPrimalSimplexBi")))
  {
    {
      return (int)48;
    }
  }
  {}
  if ((_8477 == std::string ("beginDualSimplexBi")))
  {
    {
      return (int)6;
    }
  }
  {}
  if ((_8477 == std::string ("updateDualSimplexBi")))
  {
    {
      return (int)87;
    }
  }
  {}
  if ((_8477 == std::string ("endDualSimplexBi")))
  {
    {
      return (int)35;
    }
  }
  {}
  if ((_8477 == std::string ("endSimplexBi")))
  {
    {
      return (int)53;
    }
  }
  {}
  if ((_8477 == std::string ("beginMio")))
  {
    {
      return (int)11;
    }
  }
  {}
  if ((_8477 == std::string ("imMio")))
  {
    {
      return (int)65;
    }
  }
  {}
  if ((_8477 == std::string ("newIntMio")))
  {
    {
      return (int)80;
    }
  }
  {}
  if ((_8477 == std::string ("endMio")))
  {
    {
      return (int)40;
    }
  }
  {}
  if ((_8477 == std::string ("beginSimplex")))
  {
    {
      return (int)23;
    }
  }
  {}
  if ((_8477 == std::string ("beginDualSimplex")))
  {
    {
      return (int)5;
    }
  }
  {}
  if ((_8477 == std::string ("imDualSimplex")))
  {
    {
      return (int)60;
    }
  }
  {}
  if ((_8477 == std::string ("updateDualSimplex")))
  {
    {
      return (int)86;
    }
  }
  {}
  if ((_8477 == std::string ("endDualSimplex")))
  {
    {
      return (int)34;
    }
  }
  {}
  if ((_8477 == std::string ("beginPrimalSimplex")))
  {
    {
      return (int)18;
    }
  }
  {}
  if ((_8477 == std::string ("imPrimalSimplex")))
  {
    {
      return (int)73;
    }
  }
  {}
  if ((_8477 == std::string ("updatePrimalSimplex")))
  {
    {
      return (int)90;
    }
  }
  {}
  if ((_8477 == std::string ("endPrimalSimplex")))
  {
    {
      return (int)47;
    }
  }
  {}
  if ((_8477 == std::string ("endSimplex")))
  {
    {
      return (int)52;
    }
  }
  {}
  if ((_8477 == std::string ("beginInfeasAna")))
  {
    {
      return (int)8;
    }
  }
  {}
  if ((_8477 == std::string ("endInfeasAna")))
  {
    {
      return (int)37;
    }
  }
  {}
  if ((_8477 == std::string ("imPrimalSensivity")))
  {
    {
      return (int)72;
    }
  }
  {}
  if ((_8477 == std::string ("imDualSensivity")))
  {
    {
      return (int)59;
    }
  }
  {}
  if ((_8477 == std::string ("imMioIntpnt")))
  {
    {
      return (int)67;
    }
  }
  {}
  if ((_8477 == std::string ("imMioPrimalSimplex")))
  {
    {
      return (int)68;
    }
  }
  {}
  if ((_8477 == std::string ("imMioDualSimplex")))
  {
    {
      return (int)66;
    }
  }
  {}
  if ((_8477 == std::string ("beginPrimalSetupBi")))
  {
    {
      return (int)17;
    }
  }
  {}
  if ((_8477 == std::string ("endPrimalSetupBi")))
  {
    {
      return (int)46;
    }
  }
  {}
  if ((_8477 == std::string ("beginDualSetupBi")))
  {
    {
      return (int)4;
    }
  }
  {}
  if ((_8477 == std::string ("endDualSetupBi")))
  {
    {
      return (int)33;
    }
  }
  {}
  if ((_8477 == std::string ("beginPrimalSensitivity")))
  {
    {
      return (int)16;
    }
  }
  {}
  if ((_8477 == std::string ("endPrimalSensitivity")))
  {
    {
      return (int)45;
    }
  }
  {}
  if ((_8477 == std::string ("beginDualSensitivity")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8477 == std::string ("endDualSensitivity")))
  {
    {
      return (int)32;
    }
  }
  {}
  if ((_8477 == std::string ("beginLicenseWait")))
  {
    {
      return (int)10;
    }
  }
  {}
  if ((_8477 == std::string ("endLicenseWait")))
  {
    {
      return (int)39;
    }
  }
  {}
  if ((_8477 == std::string ("imLicenseWait")))
  {
    {
      return (int)63;
    }
  }
  {}
  if ((_8477 == std::string ("beginQcqoReformulate")))
  {
    {
      return (int)20;
    }
  }
  {}
  if ((_8477 == std::string ("endQcqoReformulate")))
  {
    {
      return (int)49;
    }
  }
  {}
  if ((_8477 == std::string ("imQoReformulate")))
  {
    {
      return (int)74;
    }
  }
  {}
  if ((_8477 == std::string ("beginToConic")))
  {
    {
      return (int)25;
    }
  }
  {}
  if ((_8477 == std::string ("endToConic")))
  {
    {
      return (int)54;
    }
  }
  {}
  if ((_8477 == std::string ("beginFullConvexityCheck")))
  {
    {
      return (int)7;
    }
  }
  {}
  if ((_8477 == std::string ("endFullConvexityCheck")))
  {
    {
      return (int)36;
    }
  }
  {}
  if ((_8477 == std::string ("imFullConvexityCheck")))
  {
    {
      return (int)61;
    }
  }
  {}
  if ((_8477 == std::string ("beginPrimalRepair")))
  {
    {
      return (int)15;
    }
  }
  {}
  if ((_8477 == std::string ("endPrimalRepair")))
  {
    {
      return (int)44;
    }
  }
  {}
  if ((_8477 == std::string ("beginRead")))
  {
    {
      return (int)21;
    }
  }
  {}
  if ((_8477 == std::string ("imRead")))
  {
    {
      return (int)75;
    }
  }
  {}
  if ((_8477 == std::string ("endRead")))
  {
    {
      return (int)50;
    }
  }
  {}
  if ((_8477 == std::string ("beginWrite")))
  {
    {
      return (int)26;
    }
  }
  {}
  if ((_8477 == std::string ("endWrite")))
  {
    {
      return (int)55;
    }
  }
  {}
  if ((_8477 == std::string ("readOpfSection")))
  {
    {
      return (int)83;
    }
  }
  {}
  if ((_8477 == std::string ("imLu")))
  {
    {
      return (int)64;
    }
  }
  {}
  if ((_8477 == std::string ("imOrder")))
  {
    {
      return (int)69;
    }
  }
  {}
  if ((_8477 == std::string ("imSimplex")))
  {
    {
      return (int)77;
    }
  }
  {}
  if ((_8477 == std::string ("readOpf")))
  {
    {
      return (int)82;
    }
  }
  {}
  if ((_8477 == std::string ("writeOpf")))
  {
    {
      return (int)92;
    }
  }
  {}
  if ((_8477 == std::string ("solvingRemote")))
  {
    {
      return (int)84;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_purify_value(const std::string & _8478){
  if ((_8478 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8478 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8478 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8478 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8478 == std::string ("auto")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_intpnthotstart_value(const std::string & _8479){
  if ((_8479 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8479 == std::string ("primal")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8479 == std::string ("dual")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8479 == std::string ("primalDual")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simhotstart_value(const std::string & _8480){
  if ((_8480 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8480 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8480 == std::string ("statusKeys")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdupvec_value(const std::string & _8481){
  if ((_8481 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8481 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8481 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simreform_value(const std::string & _8482){
  if ((_8482 == std::string ("on")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8482 == std::string ("off")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8482 == std::string ("free")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8482 == std::string ("aggressive")))
  {
    {
      return (int)3;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_uplo_value(const std::string & _8483){
  if ((_8483 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8483 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_transpose_value(const std::string & _8484){
  if ((_8484 == std::string ("no")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8484 == std::string ("yes")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_simdegen_value(const std::string & _8485){
  if ((_8485 == std::string ("none")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8485 == std::string ("free")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8485 == std::string ("aggressive")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8485 == std::string ("moderate")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8485 == std::string ("minimum")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_mark_value(const std::string & _8486){
  if ((_8486 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8486 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_boundkey_value(const std::string & _8487){
  if ((_8487 == std::string ("lo")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8487 == std::string ("up")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8487 == std::string ("fx")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8487 == std::string ("fr")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8487 == std::string ("ra")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_basindtype_value(const std::string & _8488){
  if ((_8488 == std::string ("never")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8488 == std::string ("always")))
  {
    {
      return (int)1;
    }
  }
  {}
  if ((_8488 == std::string ("noError")))
  {
    {
      return (int)2;
    }
  }
  {}
  if ((_8488 == std::string ("ifFeasible")))
  {
    {
      return (int)3;
    }
  }
  {}
  if ((_8488 == std::string ("reservered")))
  {
    {
      return (int)4;
    }
  }
  {}
  return (-(int)1);
}
int mosek::fusion::p_Parameters::string_to_language_value(const std::string & _8489){
  if ((_8489 == std::string ("eng")))
  {
    {
      return (int)0;
    }
  }
  {}
  if ((_8489 == std::string ("dan")))
  {
    {
      return (int)1;
    }
  }
  {}
  return (-(int)1);
}
void mosek::fusion::p_Parameters::destroy(){}void mosek::fusion::Parameters::destroy() { mosek::fusion::p_Parameters::_get_impl(this)->destroy(); }