#ifndef __FUSION_P_H__
#define __FUSION_P_H__
#include "monty.h"
#include "mosektask_p.h"
#include "list"
#include "vector"
#include "unordered_map"
#include "fusion.h"
namespace mosek
{
namespace fusion
{
// mosek.fusion.BaseModel from file 'src/fusion/cxx/BaseModel_p.h'
// namespace mosek::fusion
struct p_BaseModel
{
  p_BaseModel(BaseModel * _pubthis);

  void _initialize( monty::rc_ptr<BaseModel> m);
  void _initialize( const std::string & name,
                    const std::string & licpath);

  virtual ~p_BaseModel() { /* std::cout << "~p_BaseModel()" << std::endl;*/  }

  static p_BaseModel * _get_impl(Model * _inst) { return _inst->_impl; }

  //----------------------

  bool synched;
  std::string taskname;

  monty::rc_ptr<SolutionStruct> sol_itr;
  monty::rc_ptr<SolutionStruct> sol_itg;
  monty::rc_ptr<SolutionStruct> sol_bas;

  //---------------------

  std::unique_ptr<Task> task;

  //---------------------
  void task_setLogHandler (const msghandler_t & handler);
  void task_setDataCallbackHandler (const datacbhandler_t & handler);
  void task_setCallbackHandler (const cbhandler_t & handler);

  int task_append_barvar(int size, int num);

  void task_var_name   (int index, const std::string & name);
  void task_con_name   (int index, const std::string & name);
  void task_cone_name  (int index, const std::string & name);
  void task_barvar_name(int index, const std::string & name);
  void task_objectivename(         const std::string & name);

  void task_format_var_names(const std::shared_ptr<monty::ndarray<int,1>> subj, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_con_names(const std::shared_ptr<monty::ndarray<int,1>> subi, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);
  void task_format_cone_names(const std::shared_ptr<monty::ndarray<int,1>> subk, const std::string & format,const std::shared_ptr<monty::ndarray<int,1>> dims, const std::shared_ptr<monty::ndarray<long long,1>> sp);

  void task_break_solve();

  //--------------------------

  int task_numvar();
  int task_numcon();
  int task_numcone();
  int task_numbarvar();

  //--------------------------

  void task_put_param(const std::string & name, const std::string & value);
  void task_put_param(const std::string & name, int    value);
  void task_put_param(const std::string & name, double value);
  
  double    task_get_dinf (const std::string & name);
  int       task_get_iinf (const std::string & name);
  long long task_get_liinf(const std::string & name);
  
  //--------------------------

  void task_con_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_con_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_con_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );

  void task_var_putboundlist_fr(const std::shared_ptr<monty::ndarray<int,1>> idxs);
  void task_var_putboundlist_lo(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_up(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_fx(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & rhs);
  void task_var_putboundlist_ra(const std::shared_ptr<monty::ndarray<int,1>> idxs, const std::shared_ptr<monty::ndarray<double,1>> & lb , 
                                const std::shared_ptr<monty::ndarray<double,1>> & ub );
  
  void task_var_putintlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs);
  void task_var_putcontlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs); 
 
  //--------------------------

  void task_putbararowlist(const std::shared_ptr<monty::ndarray<int,1>>       subi,
                           const std::shared_ptr<monty::ndarray<long long,1>> ptr,
                           const std::shared_ptr<monty::ndarray<int,1>>       subj,
                           const std::shared_ptr<monty::ndarray<long long,1>> matidx);

  void task_putbaraijlist(const std::shared_ptr<monty::ndarray<int,1>> subi,
                          const std::shared_ptr<monty::ndarray<int,1>> subj,
                          std::shared_ptr<monty::ndarray<long long,1>> matidx);
  
  void task_putbarc(const std::shared_ptr<monty::ndarray<int,1>> subj,
                    const std::shared_ptr<monty::ndarray<int,1>> subl,
                    const std::shared_ptr<monty::ndarray<int,1>> subk,
                    const std::shared_ptr<monty::ndarray<double,1>> val);
  
  std::shared_ptr<monty::ndarray<long long,1>> task_appendsymmatlist (const std::shared_ptr<monty::ndarray<int,1>>       & dim, 
                                                                      const std::shared_ptr<monty::ndarray<long long,1>> & nz, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subk, 
                                                                      const std::shared_ptr<monty::ndarray<int,1>>       & subl, 
                                                                      const std::shared_ptr<monty::ndarray<double,1>>    & val);
  int  task_barvar_dim(int j);
  void task_putbaraij (int i, int j, int k);
  void task_putbaraij (int i, int j, const std::shared_ptr<monty::ndarray<int,1>> & k);
  void task_putbarcj  (int j, int k);
  void task_putbarcj  (int j,        const std::shared_ptr<monty::ndarray<int,1>> & k);
  int  task_barvardim (int index);

  int task_append_var(int num);
  int task_append_con(int num);

  void task_append_zerocones (int numcone);
  void task_clear_cones   ( const std::shared_ptr<monty::ndarray<int,1>> & idxs );
  void task_put_zerocones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_quadcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_rquadcones( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_pexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_ppowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );
  void task_put_dexpcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs );
  void task_put_dpowcones ( const std::shared_ptr<monty::ndarray<int,1>> & idxs, int conesize, int numcone,  const std::shared_ptr<monty::ndarray<int,1>> & membs, const std::shared_ptr<monty::ndarray<double,1>> & alpha );

  void task_cleararowlist(const std::shared_ptr<monty::ndarray<int,1>> & idxs);
  void task_clearacollist(const std::shared_ptr<monty::ndarray<int,1>> & idxs);

  void task_putarowlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & idxs, 
    const std::shared_ptr<monty::ndarray<long long,1>> & ptrb, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof);
  void task_putaijlist(
    const std::shared_ptr<monty::ndarray<int,1>>       & subi, 
    const std::shared_ptr<monty::ndarray<int,1>>       & subj, 
    const std::shared_ptr<monty::ndarray<double,1>>    & cof, 
    long long                           num);

  void task_setnumvar(int num);
  void task_cleanup(int oldnum, int oldnumcon, int oldnumcone, int oldnumbarvar);
  void task_putoptserver_host(const std::string & addr);
  void task_solve(bool remote, const std::string & server, const std::string & port);

  void task_putobjective( 
    bool                             maximize,
    const std::shared_ptr<monty::ndarray<int,1>>    & subj    ,
    const std::shared_ptr<monty::ndarray<double,1>> & cof     ,
    double                           cfix    );

  void task_putclist(   
    const std::shared_ptr<monty::ndarray<int,1>>    & subj,
    const std::shared_ptr<monty::ndarray<double,1>> & cof);


  void task_putobjectivename(const std::string & name);

  void task_write(const std::string & filename);
  void task_dump (const std::string & filename);

  MSKtask_t task_get();
  MSKtask_t __mosek_2fusion_2BaseModel__task_get();
  
  void dispose();

  void task_putxx_slice(SolutionType which, int first, int last, std::shared_ptr<monty::ndarray<double,1>> & xx);

  static void env_syeig (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);
  static void env_potrf (int n, std::shared_ptr<monty::ndarray<double,1>> & a);                        
  static void env_syevd (int n, std::shared_ptr<monty::ndarray<double,1>> & a, std::shared_ptr<monty::ndarray<double,1>> & w);

  static void env_putlicensecode(std::shared_ptr<monty::ndarray<int,1>> code);
  static void env_putlicensepath(const std::string &licfile);
  static void env_putlicensewait(int wait);

  static std::string env_getversion();

  void convertSolutionStatus(MSKsoltypee soltype, p_SolutionStruct * sol, MSKsolstae status, MSKprostae prosta);


};

// End of file 'src/fusion/cxx/BaseModel_p.h'
struct p_Model : public ::mosek::fusion::p_BaseModel
{
Model * _pubthis;
static mosek::fusion::p_Model* _get_impl(mosek::fusion::Model * _inst){ return static_cast< mosek::fusion::p_Model* >(mosek::fusion::p_BaseModel::_get_impl(_inst)); }
static mosek::fusion::p_Model * _get_impl(mosek::fusion::Model::t _inst) { return _get_impl(_inst.get()); }
p_Model(Model * _pubthis);
virtual ~p_Model() { /* std::cout << "~p_Model" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::WorkStack > xs{};monty::rc_ptr< ::mosek::fusion::WorkStack > ws{};monty::rc_ptr< ::mosek::fusion::WorkStack > rs{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > con_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelConstraint >,1 > > cons{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_objcconst{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_objcode{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_objcodeptr{};std::shared_ptr< monty::ndarray< long long,1 > > natconmap_objcodenidx{};std::shared_ptr< monty::ndarray< double,1 > > natconmap_cconst{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_code{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_codeptr{};std::shared_ptr< monty::ndarray< long long,1 > > natconmap_codenidx{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_coderowptre{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_coderowptrb{};int natconmap_codeatomtop{};int natconmap_codenztop{};int natconmap_numparameterized{};std::shared_ptr< monty::ndarray< double,1 > > param_value{};int param_num{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > par_map{};int numparameter{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > parameters{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_type{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_idx{};std::shared_ptr< monty::ndarray< long long,1 > > natconmap_slackidx{};std::shared_ptr< monty::ndarray< int,1 > > natconmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconmap{};std::shared_ptr< monty::ndarray< bool,1 > > initsol_xx_flag{};std::shared_ptr< monty::ndarray< double,1 > > initsol_xx{};monty::rc_ptr< ::mosek::fusion::Utils::StringIntMap > var_map{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > barvars{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_ptr{};std::shared_ptr< monty::ndarray< int,1 > > natbarvarmap_num{};int natbarvarmap_nblock{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_dim{};std::shared_ptr< monty::ndarray< long long,1 > > natbarvar_ptr{};int natbarvar_numbarvarelm{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_j{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_i{};std::shared_ptr< monty::ndarray< int,1 > > natbarvar_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_type{};std::shared_ptr< monty::ndarray< int,1 > > natconemap_dim{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natconemap{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::ModelVariable >,1 > > vars{};int bfixidx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_idx{};std::shared_ptr< monty::ndarray< int,1 > > natvarmap_blockid{};monty::rc_ptr< ::mosek::fusion::LinkedBlocks > natvarmap{};mosek::fusion::SolutionType solutionptr{};mosek::fusion::AccSolutionStatus acceptable_sol{};std::string model_name{};virtual void destroy();
static Model::t _new_Model(monty::rc_ptr< ::mosek::fusion::Model > _470);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _470);
static Model::t _new_Model(const std::string &  _476);
void _initialize(const std::string &  _476);
static Model::t _new_Model();
void _initialize();
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2Model__formstConstr(monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _479,std::shared_ptr< monty::ndarray< int,1 > > _480,std::shared_ptr< monty::ndarray< int,1 > > _481) ;
virtual void connames(std::shared_ptr< monty::ndarray< int,1 > > _482,const std::string &  _483,std::shared_ptr< monty::ndarray< int,1 > > _484,std::shared_ptr< monty::ndarray< long long,1 > > _485) ;
virtual void varnames(std::shared_ptr< monty::ndarray< int,1 > > _486,const std::string &  _487,std::shared_ptr< monty::ndarray< int,1 > > _488,std::shared_ptr< monty::ndarray< long long,1 > > _489) ;
virtual void varname(int _490,const std::string &  _491) ;
virtual void natbarvarmap_get(int _492,std::shared_ptr< monty::ndarray< int,1 > > _493) ;
virtual void natbarvar_get(int _497,std::shared_ptr< monty::ndarray< long long,1 > > _498) ;
virtual int natbarvarmap_alloc(int _505,int _506) ;
virtual int natvarmap_alloc(int _524) ;
virtual void natconmap_codealloc(int _534,int _535) ;
virtual int natconmap_alloc(int _542) ;
virtual int natconemap_alloc(int _552) ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _555) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _561) ;
static  void putlicensewait(bool _567);
static  void putlicensepath(const std::string &  _568);
static  void putlicensecode(std::shared_ptr< monty::ndarray< int,1 > > _569);
virtual /* override */ void dispose() ;
virtual void nativeVarToStr(int _572,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _573) ;
virtual MSKtask_t __mosek_2fusion_2Model__getTask() ;
virtual void getConstraintDuals(bool _574,std::shared_ptr< monty::ndarray< int,1 > > _575,std::shared_ptr< monty::ndarray< double,1 > > _576,int _577) ;
virtual void getConstraintValues(bool _587,std::shared_ptr< monty::ndarray< int,1 > > _588,std::shared_ptr< monty::ndarray< double,1 > > _589,int _590) ;
virtual void getVariableDuals(bool _598,std::shared_ptr< monty::ndarray< long long,1 > > _599,std::shared_ptr< monty::ndarray< double,1 > > _600,int _601) ;
virtual void getVariableValues(bool _607,std::shared_ptr< monty::ndarray< long long,1 > > _608,std::shared_ptr< monty::ndarray< double,1 > > _609,int _610) ;
virtual void setVariableValues(bool _616,std::shared_ptr< monty::ndarray< long long,1 > > _617,std::shared_ptr< monty::ndarray< double,1 > > _618) ;
virtual void flushNames() ;
virtual void writeTaskNoFlush(const std::string &  _628) ;
virtual void writeTask(const std::string &  _629) ;
virtual long long getSolverLIntInfo(const std::string &  _630) ;
virtual int getSolverIntInfo(const std::string &  _631) ;
virtual double getSolverDoubleInfo(const std::string &  _632) ;
virtual void setCallbackHandler(mosek::cbhandler_t  _633) ;
virtual void setDataCallbackHandler(mosek::datacbhandler_t  _634) ;
virtual void setLogHandler(mosek::msghandler_t  _635) ;
virtual void setSolverParam(const std::string &  _636,double _637) ;
virtual void setSolverParam(const std::string &  _638,int _639) ;
virtual void setSolverParam(const std::string &  _640,const std::string &  _641) ;
virtual void breakSolver() ;
virtual void optserverHost(const std::string &  _642) ;
virtual void solve(const std::string &  _643,const std::string &  _644) ;
virtual void solve() ;
virtual void flush_parameters() ;
virtual void flushParameters() ;
virtual void evaluate_parameterized(monty::rc_ptr< ::mosek::fusion::WorkStack > _658,int _659,std::shared_ptr< monty::ndarray< int,1 > > _660,std::shared_ptr< monty::ndarray< int,1 > > _661,std::shared_ptr< monty::ndarray< long long,1 > > _662,std::shared_ptr< monty::ndarray< int,1 > > _663,std::shared_ptr< monty::ndarray< int,1 > > _664,std::shared_ptr< monty::ndarray< double,1 > > _665,std::shared_ptr< monty::ndarray< int,1 > > _666,std::shared_ptr< monty::ndarray< double,1 > > _667) ;
virtual void flushSolutions() ;
virtual void flush_initsol(mosek::fusion::SolutionType _677) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus() ;
virtual mosek::fusion::ProblemStatus getProblemStatus() ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus() ;
virtual double dualObjValue() ;
virtual double primalObjValue() ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _684,bool _685,bool _686) ;
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2Model__get_sol_cache(mosek::fusion::SolutionType _692,bool _693) ;
virtual void setSolution_xx(std::shared_ptr< monty::ndarray< int,1 > > _694,std::shared_ptr< monty::ndarray< double,1 > > _695) ;
virtual void ensure_initsol_xx() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_bars(mosek::fusion::SolutionType _702) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_barx(mosek::fusion::SolutionType _703) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_y(mosek::fusion::SolutionType _704) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xc(mosek::fusion::SolutionType _705) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_snx(mosek::fusion::SolutionType _706) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_suc(mosek::fusion::SolutionType _707) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slc(mosek::fusion::SolutionType _708) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_sux(mosek::fusion::SolutionType _709) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_slx(mosek::fusion::SolutionType _710) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_yx(mosek::fusion::SolutionType _711) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getSolution_xx(mosek::fusion::SolutionType _712) ;
virtual void selectedSolution(mosek::fusion::SolutionType _713) ;
virtual mosek::fusion::AccSolutionStatus getAcceptedSolutionStatus() ;
virtual void acceptedSolutionStatus(mosek::fusion::AccSolutionStatus _714) ;
virtual mosek::fusion::ProblemStatus getProblemStatus(mosek::fusion::SolutionType _715) ;
virtual mosek::fusion::SolutionStatus getDualSolutionStatus(mosek::fusion::SolutionType _717) ;
virtual mosek::fusion::SolutionStatus getPrimalSolutionStatus(mosek::fusion::SolutionType _718) ;
virtual mosek::fusion::SolutionStatus getSolutionStatus(mosek::fusion::SolutionType _719,bool _720) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _723,monty::rc_ptr< ::mosek::fusion::Expression > _724) ;
virtual void update(std::shared_ptr< monty::ndarray< int,1 > > _768,monty::rc_ptr< ::mosek::fusion::Expression > _769,std::shared_ptr< monty::ndarray< int,1 > > _770) ;
virtual void updateObjective(monty::rc_ptr< ::mosek::fusion::Expression > _815,monty::rc_ptr< ::mosek::fusion::Variable > _816) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter_unchecked(const std::string &  _853,std::shared_ptr< monty::ndarray< int,1 > > _854,std::shared_ptr< monty::ndarray< long long,1 > > _855) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter_(const std::string &  _865,std::shared_ptr< monty::ndarray< int,1 > > _866,std::shared_ptr< monty::ndarray< long long,1 > > _867) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter_(const std::string &  _872,std::shared_ptr< monty::ndarray< int,1 > > _873,std::shared_ptr< monty::ndarray< int,2 > > _874) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(const std::string &  _882) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(const std::string &  _884,int _885,int _886,int _887) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(const std::string &  _889,int _890,int _891) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(const std::string &  _893,int _894) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(const std::string &  _896,std::shared_ptr< monty::ndarray< int,1 > > _897) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(const std::string &  _899,std::shared_ptr< monty::ndarray< int,1 > > _900,std::shared_ptr< monty::ndarray< long long,1 > > _901) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(const std::string &  _902,std::shared_ptr< monty::ndarray< int,1 > > _903,std::shared_ptr< monty::ndarray< int,2 > > _904) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter() ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(int _906,int _907,int _908) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(int _910,int _911) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(int _913) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _915) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _917,std::shared_ptr< monty::ndarray< long long,1 > > _918) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__parameter(std::shared_ptr< monty::ndarray< int,1 > > _919,std::shared_ptr< monty::ndarray< int,2 > > _920) ;
virtual void objective_(const std::string &  _921,mosek::fusion::ObjectiveSense _922,monty::rc_ptr< ::mosek::fusion::Expression > _923) ;
virtual void objective(double _970) ;
virtual void objective(mosek::fusion::ObjectiveSense _971,double _972) ;
virtual void objective(mosek::fusion::ObjectiveSense _973,monty::rc_ptr< ::mosek::fusion::Expression > _974) ;
virtual void objective(const std::string &  _975,double _976) ;
virtual void objective(const std::string &  _977,mosek::fusion::ObjectiveSense _978,double _979) ;
virtual void objective(const std::string &  _980,mosek::fusion::ObjectiveSense _981,monty::rc_ptr< ::mosek::fusion::Expression > _982) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _983,monty::rc_ptr< ::mosek::fusion::ConeDomain > _984) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _985,monty::rc_ptr< ::mosek::fusion::Expression > _986,monty::rc_ptr< ::mosek::fusion::ConeDomain > _987) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedConstraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _988,monty::rc_ptr< ::mosek::fusion::RangeDomain > _989) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedConstraint > __mosek_2fusion_2Model__constraint(const std::string &  _990,monty::rc_ptr< ::mosek::fusion::Expression > _991,monty::rc_ptr< ::mosek::fusion::RangeDomain > _992) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _993,monty::rc_ptr< ::mosek::fusion::LinearDomain > _994) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _995,monty::rc_ptr< ::mosek::fusion::Expression > _996,monty::rc_ptr< ::mosek::fusion::LinearDomain > _997) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _998,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _999) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _1000,monty::rc_ptr< ::mosek::fusion::Expression > _1001,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1002) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(monty::rc_ptr< ::mosek::fusion::Expression > _1003,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1004) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint(const std::string &  _1005,monty::rc_ptr< ::mosek::fusion::Expression > _1006,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1007) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1008) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _1009,int _1010,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1011) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _1012,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1013) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1014,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1015) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1016,int _1017,int _1018,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1019) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1020,int _1021,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1022) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1023,std::shared_ptr< monty::ndarray< int,1 > > _1024,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1025) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::PSDDomain > _1026) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _1027,int _1028,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1029) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _1030,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1031) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1032,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1033) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1034,int _1035,int _1036,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1037) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1038,int _1039,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1040) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1041,std::shared_ptr< monty::ndarray< int,1 > > _1042,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1043) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::ConeDomain > _1044) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedVariable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::RangeDomain > _1045) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(monty::rc_ptr< ::mosek::fusion::LinearDomain > _1046) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1047,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1048) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedVariable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1049,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1050) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1051,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1052) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(std::shared_ptr< monty::ndarray< int,1 > > _1053) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _1054,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1055) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedVariable > __mosek_2fusion_2Model__variable(int _1056,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1057) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _1058,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1059) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(int _1060) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1061,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1062) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedVariable > __mosek_2fusion_2Model__variable(const std::string &  _1063,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1064) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1065,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1066) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1067,std::shared_ptr< monty::ndarray< int,1 > > _1068,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1069) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedVariable > __mosek_2fusion_2Model__variable(const std::string &  _1070,std::shared_ptr< monty::ndarray< int,1 > > _1071,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1072) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1073,std::shared_ptr< monty::ndarray< int,1 > > _1074,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1075) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1076,std::shared_ptr< monty::ndarray< int,1 > > _1077) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1078,int _1079,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1080) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedVariable > __mosek_2fusion_2Model__variable(const std::string &  _1081,int _1082,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1083) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1084,int _1085,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1086) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1087,int _1088) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable(const std::string &  _1089) ;
virtual void removeConstraintBlock(int _1090) ;
virtual void removeVariableBlock(long long _1095) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedVariable > __mosek_2fusion_2Model__ranged_variable(const std::string &  _1103,std::shared_ptr< monty::ndarray< int,1 > > _1104,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1105) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _1126,std::shared_ptr< monty::ndarray< int,1 > > _1127,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1128) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _1156,std::shared_ptr< monty::ndarray< int,1 > > _1157,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1158) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__variable_(const std::string &  _1200,std::shared_ptr< monty::ndarray< int,1 > > _1201,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1202) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricVariable > __mosek_2fusion_2Model__variable_(const std::string &  _1223,std::shared_ptr< monty::ndarray< int,1 > > _1224,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1225) ;
virtual void replace_row_code(monty::rc_ptr< ::mosek::fusion::WorkStack > _1240,std::shared_ptr< monty::ndarray< int,1 > > _1241,int _1242,int _1243,int _1244,int _1245,int _1246) ;
virtual monty::rc_ptr< ::mosek::fusion::RangedConstraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1261,monty::rc_ptr< ::mosek::fusion::Expression > _1262,monty::rc_ptr< ::mosek::fusion::RangeDomain > _1263) ;
virtual void putarows(std::shared_ptr< monty::ndarray< int,1 > > _1315,monty::rc_ptr< ::mosek::fusion::WorkStack > _1316,int _1317,int _1318,int _1319,int _1320,int _1321,std::shared_ptr< monty::ndarray< int,1 > > _1322) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1363,monty::rc_ptr< ::mosek::fusion::Expression > _1364,monty::rc_ptr< ::mosek::fusion::PSDDomain > _1365) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1446,monty::rc_ptr< ::mosek::fusion::Expression > _1447,monty::rc_ptr< ::mosek::fusion::LinPSDDomain > _1448) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1513,monty::rc_ptr< ::mosek::fusion::Expression > _1514,monty::rc_ptr< ::mosek::fusion::ConeDomain > _1515) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__constraint_(const std::string &  _1575,monty::rc_ptr< ::mosek::fusion::Expression > _1576,monty::rc_ptr< ::mosek::fusion::LinearDomain > _1577) ;
static  std::string getVersion();
virtual bool hasParameter(const std::string &  _1618) ;
virtual bool hasConstraint(const std::string &  _1619) ;
virtual bool hasVariable(const std::string &  _1620) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Model__getParameter(const std::string &  _1621) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(int _1622) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Model__getConstraint(const std::string &  _1623) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(int _1624) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Model__getVariable(const std::string &  _1625) ;
virtual std::string getName() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getParameterValue(std::shared_ptr< monty::ndarray< int,1 > > _1627) ;
virtual void setParameterValue(std::shared_ptr< monty::ndarray< int,1 > > _1630,std::shared_ptr< monty::ndarray< double,1 > > _1631) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Model__clone() ;
}; // struct Model;

// mosek.fusion.Debug from file 'src/fusion/cxx/Debug_p.h'
// namespace mosek::fusion
struct p_Debug
{
  Debug * _pubthis;

  p_Debug(Debug * _pubthis) : _pubthis(_pubthis) {}

  static Debug::t o ()                 { return monty::rc_ptr<Debug>(new Debug()); }
  Debug::t p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (      int val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (long long val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (   double val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t p (     bool val)           { std::cout << val; return Debug::t(_pubthis); }
  Debug::t lf()                        { std::cout << std::endl; return Debug::t(_pubthis); }

  static p_Debug * _get_impl(Debug * _inst) { return _inst->ptr; }

  template<typename T>
  Debug::t p(const std::shared_ptr<monty::ndarray<T,1>> & val)
  {
    if (val->size() > 0)
    {
      std::cout << (*val)[0];
      for (int i = 1; i < val->size(); ++i)
        std::cout << "," << (*val)[i];
    }
    return Debug::t(_pubthis);
  }

  Debug::t __mosek_2fusion_2Debug__p (const std::string & val) { std::cout << val; return Debug::t(_pubthis); }

  template<class C>
  Debug::t __mosek_2fusion_2Debug__p (C val) { std::cout << val; return Debug::t(_pubthis); }
  Debug::t __mosek_2fusion_2Debug__lf()      { std::cout << std::endl; return Debug::t(_pubthis); }
  
};
// End of file 'src/fusion/cxx/Debug_p.h'
struct p_Sort
{
Sort * _pubthis;
static mosek::fusion::p_Sort* _get_impl(mosek::fusion::Sort * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Sort * _get_impl(mosek::fusion::Sort::t _inst) { return _get_impl(_inst.get()); }
p_Sort(Sort * _pubthis);
virtual ~p_Sort() { /* std::cout << "~p_Sort" << std::endl;*/ };
virtual void destroy();
static  void argTransposeSort(std::shared_ptr< monty::ndarray< long long,1 > > _157,std::shared_ptr< monty::ndarray< long long,1 > > _158,int _159,int _160,int _161,std::shared_ptr< monty::ndarray< long long,1 > > _162);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _170,std::shared_ptr< monty::ndarray< long long,1 > > _171);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _172,std::shared_ptr< monty::ndarray< int,1 > > _173);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _174,std::shared_ptr< monty::ndarray< long long,1 > > _175,std::shared_ptr< monty::ndarray< long long,1 > > _176);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _177,std::shared_ptr< monty::ndarray< int,1 > > _178,std::shared_ptr< monty::ndarray< int,1 > > _179);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _180,std::shared_ptr< monty::ndarray< long long,1 > > _181,long long _182,long long _183);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _184,std::shared_ptr< monty::ndarray< int,1 > > _185,long long _186,long long _187);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _188,std::shared_ptr< monty::ndarray< long long,1 > > _189,std::shared_ptr< monty::ndarray< long long,1 > > _190,long long _191,long long _192);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _193,std::shared_ptr< monty::ndarray< int,1 > > _194,std::shared_ptr< monty::ndarray< int,1 > > _195,long long _196,long long _197);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _198,std::shared_ptr< monty::ndarray< long long,1 > > _199,long long _200,long long _201,bool _202);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _205,std::shared_ptr< monty::ndarray< int,1 > > _206,long long _207,long long _208,bool _209);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _212,std::shared_ptr< monty::ndarray< long long,1 > > _213,std::shared_ptr< monty::ndarray< long long,1 > > _214,long long _215,long long _216,bool _217);
static  void argsort(std::shared_ptr< monty::ndarray< long long,1 > > _220,std::shared_ptr< monty::ndarray< int,1 > > _221,std::shared_ptr< monty::ndarray< int,1 > > _222,long long _223,long long _224,bool _225);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _228,std::shared_ptr< monty::ndarray< long long,1 > > _229,long long _230,long long _231,long long _232,long long _233);
static  void argbucketsort(std::shared_ptr< monty::ndarray< long long,1 > > _234,std::shared_ptr< monty::ndarray< int,1 > > _235,long long _236,long long _237,int _238,int _239);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _240,std::shared_ptr< monty::ndarray< long long,1 > > _241,std::shared_ptr< monty::ndarray< long long,1 > > _242,long long _243,long long _244,std::shared_ptr< monty::ndarray< long long,1 > > _245);
static  void getminmax(std::shared_ptr< monty::ndarray< long long,1 > > _248,std::shared_ptr< monty::ndarray< int,1 > > _249,std::shared_ptr< monty::ndarray< int,1 > > _250,long long _251,long long _252,std::shared_ptr< monty::ndarray< int,1 > > _253);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _256,std::shared_ptr< monty::ndarray< long long,1 > > _257,long long _258,long long _259,bool _260);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _262,std::shared_ptr< monty::ndarray< int,1 > > _263,long long _264,long long _265,bool _266);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _268,std::shared_ptr< monty::ndarray< long long,1 > > _269,std::shared_ptr< monty::ndarray< long long,1 > > _270,long long _271,long long _272,bool _273);
static  bool issorted(std::shared_ptr< monty::ndarray< long long,1 > > _275,std::shared_ptr< monty::ndarray< int,1 > > _276,std::shared_ptr< monty::ndarray< int,1 > > _277,long long _278,long long _279,bool _280);
}; // struct Sort;

struct p_IndexCounter
{
IndexCounter * _pubthis;
static mosek::fusion::p_IndexCounter* _get_impl(mosek::fusion::IndexCounter * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_IndexCounter * _get_impl(mosek::fusion::IndexCounter::t _inst) { return _get_impl(_inst.get()); }
p_IndexCounter(IndexCounter * _pubthis);
virtual ~p_IndexCounter() { /* std::cout << "~p_IndexCounter" << std::endl;*/ };
long long start{};std::shared_ptr< monty::ndarray< int,1 > > dims{};std::shared_ptr< monty::ndarray< long long,1 > > strides{};std::shared_ptr< monty::ndarray< long long,1 > > st{};std::shared_ptr< monty::ndarray< int,1 > > ii{};int n{};virtual void destroy();
static IndexCounter::t _new_IndexCounter(std::shared_ptr< monty::ndarray< int,1 > > _282);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _282);
static IndexCounter::t _new_IndexCounter(long long _284,std::shared_ptr< monty::ndarray< int,1 > > _285,std::shared_ptr< monty::ndarray< int,1 > > _286);
void _initialize(long long _284,std::shared_ptr< monty::ndarray< int,1 > > _285,std::shared_ptr< monty::ndarray< int,1 > > _286);
static IndexCounter::t _new_IndexCounter(long long _289,std::shared_ptr< monty::ndarray< int,1 > > _290,std::shared_ptr< monty::ndarray< long long,1 > > _291);
void _initialize(long long _289,std::shared_ptr< monty::ndarray< int,1 > > _290,std::shared_ptr< monty::ndarray< long long,1 > > _291);
virtual bool atEnd() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getIndex() ;
virtual long long next() ;
virtual long long get() ;
virtual void inc() ;
virtual void reset() ;
}; // struct IndexCounter;

struct p_CommonTools
{
CommonTools * _pubthis;
static mosek::fusion::p_CommonTools* _get_impl(mosek::fusion::CommonTools * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_CommonTools * _get_impl(mosek::fusion::CommonTools::t _inst) { return _get_impl(_inst.get()); }
p_CommonTools(CommonTools * _pubthis);
virtual ~p_CommonTools() { /* std::cout << "~p_CommonTools" << std::endl;*/ };
virtual void destroy();
static  std::shared_ptr< monty::ndarray< long long,1 > > resize(std::shared_ptr< monty::ndarray< long long,1 > > _297,int _298);
static  std::shared_ptr< monty::ndarray< int,1 > > resize(std::shared_ptr< monty::ndarray< int,1 > > _300,int _301);
static  std::shared_ptr< monty::ndarray< double,1 > > resize(std::shared_ptr< monty::ndarray< double,1 > > _303,int _304);
static  int binarySearch(std::shared_ptr< monty::ndarray< int,1 > > _306,int _307);
static  int binarySearch(std::shared_ptr< monty::ndarray< long long,1 > > _311,long long _312);
static  int binarySearchR(std::shared_ptr< monty::ndarray< long long,1 > > _314,long long _315);
static  int binarySearchL(std::shared_ptr< monty::ndarray< long long,1 > > _319,long long _320);
static  void ndIncr(std::shared_ptr< monty::ndarray< int,1 > > _324,std::shared_ptr< monty::ndarray< int,1 > > _325,std::shared_ptr< monty::ndarray< int,1 > > _326);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _328,std::shared_ptr< monty::ndarray< int,1 > > _329,std::shared_ptr< monty::ndarray< double,1 > > _330,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _331,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< long long,1 > >,1 > > _332,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _333,long long _334,int _335,int _336);
static  void transposeTriplets(std::shared_ptr< monty::ndarray< int,1 > > _349,std::shared_ptr< monty::ndarray< int,1 > > _350,std::shared_ptr< monty::ndarray< double,1 > > _351,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _352,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _353,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _354,long long _355,int _356,int _357);
static  void tripletSort(std::shared_ptr< monty::ndarray< int,1 > > _370,std::shared_ptr< monty::ndarray< int,1 > > _371,std::shared_ptr< monty::ndarray< double,1 > > _372,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _373,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< int,1 > >,1 > > _374,std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< double,1 > >,1 > > _375,long long _376,int _377,int _378);
static  void argMSort(std::shared_ptr< monty::ndarray< int,1 > > _404,std::shared_ptr< monty::ndarray< int,1 > > _405);
static  void mergeInto(std::shared_ptr< monty::ndarray< int,1 > > _410,std::shared_ptr< monty::ndarray< int,1 > > _411,std::shared_ptr< monty::ndarray< int,1 > > _412,int _413,int _414,int _415);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _421,std::shared_ptr< monty::ndarray< long long,1 > > _422,std::shared_ptr< monty::ndarray< long long,1 > > _423,long long _424,long long _425);
static  void argQsort(std::shared_ptr< monty::ndarray< long long,1 > > _426,std::shared_ptr< monty::ndarray< int,1 > > _427,std::shared_ptr< monty::ndarray< int,1 > > _428,long long _429,long long _430);
}; // struct CommonTools;

struct p_SolutionStruct
{
SolutionStruct * _pubthis;
static mosek::fusion::p_SolutionStruct* _get_impl(mosek::fusion::SolutionStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SolutionStruct * _get_impl(mosek::fusion::SolutionStruct::t _inst) { return _get_impl(_inst.get()); }
p_SolutionStruct(SolutionStruct * _pubthis);
virtual ~p_SolutionStruct() { /* std::cout << "~p_SolutionStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > yx{};std::shared_ptr< monty::ndarray< double,1 > > snx{};std::shared_ptr< monty::ndarray< double,1 > > sux{};std::shared_ptr< monty::ndarray< double,1 > > slx{};std::shared_ptr< monty::ndarray< double,1 > > bars{};std::shared_ptr< monty::ndarray< double,1 > > barx{};std::shared_ptr< monty::ndarray< double,1 > > y{};std::shared_ptr< monty::ndarray< double,1 > > suc{};std::shared_ptr< monty::ndarray< double,1 > > slc{};std::shared_ptr< monty::ndarray< double,1 > > xx{};std::shared_ptr< monty::ndarray< double,1 > > xc{};double dobj{};double pobj{};mosek::fusion::ProblemStatus probstatus{};mosek::fusion::SolutionStatus dstatus{};mosek::fusion::SolutionStatus pstatus{};int sol_numbarvar{};int sol_numcone{};int sol_numvar{};int sol_numcon{};virtual void destroy();
static SolutionStruct::t _new_SolutionStruct(int _431,int _432,int _433,int _434);
void _initialize(int _431,int _432,int _433,int _434);
static SolutionStruct::t _new_SolutionStruct(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _435);
void _initialize(monty::rc_ptr< ::mosek::fusion::SolutionStruct > _435);
virtual monty::rc_ptr< ::mosek::fusion::SolutionStruct > __mosek_2fusion_2SolutionStruct__clone() ;
virtual void resize(int _436,int _437,int _438,int _439) ;
virtual bool isDualAcceptable(mosek::fusion::AccSolutionStatus _459) ;
virtual bool isPrimalAcceptable(mosek::fusion::AccSolutionStatus _460) ;
virtual bool isAcceptable(mosek::fusion::SolutionStatus _461,mosek::fusion::AccSolutionStatus _462) ;
}; // struct SolutionStruct;

struct p_ConNZStruct
{
ConNZStruct * _pubthis;
static mosek::fusion::p_ConNZStruct* _get_impl(mosek::fusion::ConNZStruct * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConNZStruct * _get_impl(mosek::fusion::ConNZStruct::t _inst) { return _get_impl(_inst.get()); }
p_ConNZStruct(ConNZStruct * _pubthis);
virtual ~p_ConNZStruct() { /* std::cout << "~p_ConNZStruct" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};virtual void destroy();
static ConNZStruct::t _new_ConNZStruct(std::shared_ptr< monty::ndarray< long long,1 > > _463,std::shared_ptr< monty::ndarray< int,1 > > _464,std::shared_ptr< monty::ndarray< double,1 > > _465,std::shared_ptr< monty::ndarray< double,1 > > _466,std::shared_ptr< monty::ndarray< int,1 > > _467,std::shared_ptr< monty::ndarray< int,1 > > _468,std::shared_ptr< monty::ndarray< int,1 > > _469);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _463,std::shared_ptr< monty::ndarray< int,1 > > _464,std::shared_ptr< monty::ndarray< double,1 > > _465,std::shared_ptr< monty::ndarray< double,1 > > _466,std::shared_ptr< monty::ndarray< int,1 > > _467,std::shared_ptr< monty::ndarray< int,1 > > _468,std::shared_ptr< monty::ndarray< int,1 > > _469);
}; // struct ConNZStruct;

struct p_BaseVariable : public /*implements*/ virtual ::mosek::fusion::Variable
{
BaseVariable * _pubthis;
static mosek::fusion::p_BaseVariable* _get_impl(mosek::fusion::BaseVariable * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseVariable * _get_impl(mosek::fusion::BaseVariable::t _inst) { return _get_impl(_inst.get()); }
p_BaseVariable(BaseVariable * _pubthis);
virtual ~p_BaseVariable() { /* std::cout << "~p_BaseVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};monty::rc_ptr< ::mosek::fusion::Model > model{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1902,monty::rc_ptr< ::mosek::fusion::Model > _1903);
void _initialize(monty::rc_ptr< ::mosek::fusion::BaseVariable > _1902,monty::rc_ptr< ::mosek::fusion::Model > _1903);
static BaseVariable::t _new_BaseVariable(monty::rc_ptr< ::mosek::fusion::Model > _1904,std::shared_ptr< monty::ndarray< int,1 > > _1905,std::shared_ptr< monty::ndarray< long long,1 > > _1906,std::shared_ptr< monty::ndarray< long long,1 > > _1907);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1904,std::shared_ptr< monty::ndarray< int,1 > > _1905,std::shared_ptr< monty::ndarray< long long,1 > > _1906,std::shared_ptr< monty::ndarray< long long,1 > > _1907);
virtual /* override */ std::string toString() ;
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _1910,monty::rc_ptr< ::mosek::fusion::WorkStack > _1911,monty::rc_ptr< ::mosek::fusion::WorkStack > _1912) ;
virtual void remove() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__fromTril(int _1930,int _1931) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__fromTril(int _1964) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__fromTril(int _1964) { return __mosek_2fusion_2BaseVariable__fromTril(_1964); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__tril(int _1965,int _1966) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__tril() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__tril() { return __mosek_2fusion_2BaseVariable__tril(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(int _2020,int _2021,int _2022) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(int _2020,int _2021,int _2022) { return __mosek_2fusion_2BaseVariable__reshape(_2020,_2021,_2022); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(int _2023,int _2024) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(int _2023,int _2024) { return __mosek_2fusion_2BaseVariable__reshape(_2023,_2024); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(int _2025) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(int _2025) { return __mosek_2fusion_2BaseVariable__reshape(_2025); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _2026) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__reshape(std::shared_ptr< monty::ndarray< int,1 > > _2026) { return __mosek_2fusion_2BaseVariable__reshape(_2026); }
virtual void setLevel(std::shared_ptr< monty::ndarray< double,1 > > _2030) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2BaseVariable__getModel() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Variable__getModel() { return __mosek_2fusion_2BaseVariable__getModel(); }
virtual int getND() ;
virtual int getDim(int _2033) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual long long getSize() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void makeContinuous() ;
virtual void makeInteger() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__transpose() { return __mosek_2fusion_2BaseVariable__transpose(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _2054,int _2055,int _2056) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _2054,int _2055,int _2056) { return __mosek_2fusion_2BaseVariable__index(_2054,_2055,_2056); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _2057,int _2058) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _2057,int _2058) { return __mosek_2fusion_2BaseVariable__index(_2057,_2058); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _2059) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _2059) { return __mosek_2fusion_2BaseVariable__index(_2059); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _2062) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _2062) { return __mosek_2fusion_2BaseVariable__index(_2062); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2063,std::shared_ptr< monty::ndarray< int,1 > > _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2063,std::shared_ptr< monty::ndarray< int,1 > > _2064,std::shared_ptr< monty::ndarray< int,1 > > _2065) { return __mosek_2fusion_2BaseVariable__pick(_2063,_2064,_2065); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2068,std::shared_ptr< monty::ndarray< int,1 > > _2069) { return __mosek_2fusion_2BaseVariable__pick(_2068,_2069); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _2072) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,2 > > _2072) { return __mosek_2fusion_2BaseVariable__pick(_2072); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2094) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__pick(std::shared_ptr< monty::ndarray< int,1 > > _2094) { return __mosek_2fusion_2BaseVariable__pick(_2094); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag(int _2105) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag(int _2105) { return __mosek_2fusion_2BaseVariable__antidiag(_2105); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__antidiag() { return __mosek_2fusion_2BaseVariable__antidiag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag(int _2106) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag(int _2106) { return __mosek_2fusion_2BaseVariable__diag(_2106); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__diag() { return __mosek_2fusion_2BaseVariable__diag(); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__general_diag(std::shared_ptr< monty::ndarray< int,1 > > _2107,std::shared_ptr< monty::ndarray< int,1 > > _2108,int _2109) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _2130,std::shared_ptr< monty::ndarray< int,1 > > _2131) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _2130,std::shared_ptr< monty::ndarray< int,1 > > _2131) { return __mosek_2fusion_2BaseVariable__slice(_2130,_2131); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _2165,int _2166) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _2165,int _2166) { return __mosek_2fusion_2BaseVariable__slice(_2165,_2166); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseVariable__asExpr() ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Variable__asExpr() { return __mosek_2fusion_2BaseVariable__asExpr(); }
virtual int inst(int _2175,std::shared_ptr< monty::ndarray< long long,1 > > _2176,int _2177,std::shared_ptr< monty::ndarray< long long,1 > > _2178) ;
virtual int numInst() ;
virtual void inst(int _2183,std::shared_ptr< monty::ndarray< long long,1 > > _2184) ;
virtual void set_values(std::shared_ptr< monty::ndarray< double,1 > > _2191,bool _2192) ;
virtual void dual_lu(int _2197,std::shared_ptr< monty::ndarray< double,1 > > _2198,bool _2199) ;
virtual void values(int _2202,std::shared_ptr< monty::ndarray< double,1 > > _2203,bool _2204) ;
virtual void make_continuous() ;
virtual void make_integer() ;
}; // struct BaseVariable;

struct p_SliceVariable : public ::mosek::fusion::p_BaseVariable
{
SliceVariable * _pubthis;
static mosek::fusion::p_SliceVariable* _get_impl(mosek::fusion::SliceVariable * _inst){ return static_cast< mosek::fusion::p_SliceVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_SliceVariable * _get_impl(mosek::fusion::SliceVariable::t _inst) { return _get_impl(_inst.get()); }
p_SliceVariable(SliceVariable * _pubthis);
virtual ~p_SliceVariable() { /* std::cout << "~p_SliceVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};virtual void destroy();
static SliceVariable::t _new_SliceVariable(monty::rc_ptr< ::mosek::fusion::Model > _1633,std::shared_ptr< monty::ndarray< int,1 > > _1634,std::shared_ptr< monty::ndarray< long long,1 > > _1635,std::shared_ptr< monty::ndarray< long long,1 > > _1636);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1633,std::shared_ptr< monty::ndarray< int,1 > > _1634,std::shared_ptr< monty::ndarray< long long,1 > > _1635,std::shared_ptr< monty::ndarray< long long,1 > > _1636);
static SliceVariable::t _new_SliceVariable(monty::rc_ptr< ::mosek::fusion::SliceVariable > _1637);
void _initialize(monty::rc_ptr< ::mosek::fusion::SliceVariable > _1637);
}; // struct SliceVariable;

struct p_BoundInterfaceVariable : public ::mosek::fusion::p_SliceVariable
{
BoundInterfaceVariable * _pubthis;
static mosek::fusion::p_BoundInterfaceVariable* _get_impl(mosek::fusion::BoundInterfaceVariable * _inst){ return static_cast< mosek::fusion::p_BoundInterfaceVariable* >(mosek::fusion::p_SliceVariable::_get_impl(_inst)); }
static mosek::fusion::p_BoundInterfaceVariable * _get_impl(mosek::fusion::BoundInterfaceVariable::t _inst) { return _get_impl(_inst.get()); }
p_BoundInterfaceVariable(BoundInterfaceVariable * _pubthis);
virtual ~p_BoundInterfaceVariable() { /* std::cout << "~p_BoundInterfaceVariable" << std::endl;*/ };
bool islower{};virtual void destroy();
static BoundInterfaceVariable::t _new_BoundInterfaceVariable(monty::rc_ptr< ::mosek::fusion::Model > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685,std::shared_ptr< monty::ndarray< long long,1 > > _1686,std::shared_ptr< monty::ndarray< long long,1 > > _1687,bool _1688);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1684,std::shared_ptr< monty::ndarray< int,1 > > _1685,std::shared_ptr< monty::ndarray< long long,1 > > _1686,std::shared_ptr< monty::ndarray< long long,1 > > _1687,bool _1688);
static BoundInterfaceVariable::t _new_BoundInterfaceVariable(monty::rc_ptr< ::mosek::fusion::SliceVariable > _1689,bool _1690);
void _initialize(monty::rc_ptr< ::mosek::fusion::SliceVariable > _1689,bool _1690);
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__transpose() { return __mosek_2fusion_2BoundInterfaceVariable__transpose(); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1692,std::shared_ptr< monty::ndarray< int,1 > > _1693,std::shared_ptr< monty::ndarray< int,1 > > _1694) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1692,std::shared_ptr< monty::ndarray< int,1 > > _1693,std::shared_ptr< monty::ndarray< int,1 > > _1694) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1692,_1693,_1694); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1695,std::shared_ptr< monty::ndarray< int,1 > > _1696) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1695,std::shared_ptr< monty::ndarray< int,1 > > _1696) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1695,_1696); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1697) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,2 > > _1697) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1697); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__pick(std::shared_ptr< monty::ndarray< int,1 > > _1698) { return __mosek_2fusion_2BoundInterfaceVariable__pick(_1698); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__antidiag(int _1699) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag(int _1699) { return __mosek_2fusion_2BoundInterfaceVariable__antidiag(_1699); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__antidiag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__antidiag() { return __mosek_2fusion_2BoundInterfaceVariable__antidiag(); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__diag(int _1700) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag(int _1700) { return __mosek_2fusion_2BoundInterfaceVariable__diag(_1700); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__diag() ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__diag() { return __mosek_2fusion_2BoundInterfaceVariable__diag(); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1701,std::shared_ptr< monty::ndarray< int,1 > > _1702) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1701,std::shared_ptr< monty::ndarray< int,1 > > _1702) { return __mosek_2fusion_2BoundInterfaceVariable__slice(_1701,_1702); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BoundInterfaceVariable__slice(int _1703,int _1704) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1703,int _1704) { return __mosek_2fusion_2BoundInterfaceVariable__slice(_1703,_1704); }
virtual monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > __mosek_2fusion_2BoundInterfaceVariable__from_(monty::rc_ptr< ::mosek::fusion::Variable > _1705) ;
}; // struct BoundInterfaceVariable;

struct p_ModelVariable : public ::mosek::fusion::p_BaseVariable
{
ModelVariable * _pubthis;
static mosek::fusion::p_ModelVariable* _get_impl(mosek::fusion::ModelVariable * _inst){ return static_cast< mosek::fusion::p_ModelVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_ModelVariable * _get_impl(mosek::fusion::ModelVariable::t _inst) { return _get_impl(_inst.get()); }
p_ModelVariable(ModelVariable * _pubthis);
virtual ~p_ModelVariable() { /* std::cout << "~p_ModelVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};long long varid{};std::string name{};virtual void destroy();
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1865,monty::rc_ptr< ::mosek::fusion::Model > _1866);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelVariable > _1865,monty::rc_ptr< ::mosek::fusion::Model > _1866);
static ModelVariable::t _new_ModelVariable(monty::rc_ptr< ::mosek::fusion::Model > _1867,const std::string &  _1868,std::shared_ptr< monty::ndarray< int,1 > > _1869,long long _1870,std::shared_ptr< monty::ndarray< long long,1 > > _1871,std::shared_ptr< monty::ndarray< long long,1 > > _1872);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1867,const std::string &  _1868,std::shared_ptr< monty::ndarray< int,1 > > _1869,long long _1870,std::shared_ptr< monty::ndarray< long long,1 > > _1871,std::shared_ptr< monty::ndarray< long long,1 > > _1872);
virtual void flushNames() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void elementName(long long _1873,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1874) ;
virtual /* override */ void remove() ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1875) { throw monty::AbstractClassError("Call to abstract method"); }
}; // struct ModelVariable;

struct p_SymRangedVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymRangedVariable * _pubthis;
static mosek::fusion::p_SymRangedVariable* _get_impl(mosek::fusion::SymRangedVariable * _inst){ return static_cast< mosek::fusion::p_SymRangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymRangedVariable * _get_impl(mosek::fusion::SymRangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymRangedVariable(SymRangedVariable * _pubthis);
virtual ~p_SymRangedVariable() { /* std::cout << "~p_SymRangedVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1638,monty::rc_ptr< ::mosek::fusion::Model > _1639);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymRangedVariable > _1638,monty::rc_ptr< ::mosek::fusion::Model > _1639);
static SymRangedVariable::t _new_SymRangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1640,const std::string &  _1641,long long _1642,int _1643,std::shared_ptr< monty::ndarray< long long,1 > > _1644,std::shared_ptr< monty::ndarray< int,1 > > _1645);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1640,const std::string &  _1641,long long _1642,int _1643,std::shared_ptr< monty::ndarray< long long,1 > > _1644,std::shared_ptr< monty::ndarray< int,1 > > _1645);
virtual void dual_u(int _1646,std::shared_ptr< monty::ndarray< double,1 > > _1647) ;
virtual void dual_l(int _1648,std::shared_ptr< monty::ndarray< double,1 > > _1649) ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymRangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1653) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1653) { return __mosek_2fusion_2SymRangedVariable__clone(_1653); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1654,std::shared_ptr< monty::ndarray< long long,1 > > _1655,std::shared_ptr< monty::ndarray< int,1 > > _1656);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1672,std::shared_ptr< monty::ndarray< long long,1 > > _1673);
}; // struct SymRangedVariable;

struct p_RangedVariable : public ::mosek::fusion::p_ModelVariable
{
RangedVariable * _pubthis;
static mosek::fusion::p_RangedVariable* _get_impl(mosek::fusion::RangedVariable * _inst){ return static_cast< mosek::fusion::p_RangedVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_RangedVariable * _get_impl(mosek::fusion::RangedVariable::t _inst) { return _get_impl(_inst.get()); }
p_RangedVariable(RangedVariable * _pubthis);
virtual ~p_RangedVariable() { /* std::cout << "~p_RangedVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};virtual void destroy();
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1710,monty::rc_ptr< ::mosek::fusion::Model > _1711);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedVariable > _1710,monty::rc_ptr< ::mosek::fusion::Model > _1711);
static RangedVariable::t _new_RangedVariable(monty::rc_ptr< ::mosek::fusion::Model > _1712,const std::string &  _1713,long long _1714,std::shared_ptr< monty::ndarray< int,1 > > _1715,std::shared_ptr< monty::ndarray< long long,1 > > _1716,std::shared_ptr< monty::ndarray< int,1 > > _1717);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1712,const std::string &  _1713,long long _1714,std::shared_ptr< monty::ndarray< int,1 > > _1715,std::shared_ptr< monty::ndarray< long long,1 > > _1716,std::shared_ptr< monty::ndarray< int,1 > > _1717);
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2RangedVariable__elementDesc(long long _1718,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1719) ;
virtual /* override */ void flushNames() ;
virtual void dual_u(int _1723,std::shared_ptr< monty::ndarray< double,1 > > _1724) ;
virtual void dual_l(int _1725,std::shared_ptr< monty::ndarray< double,1 > > _1726) ;
virtual monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > __mosek_2fusion_2RangedVariable__upperBoundVar() ;
virtual monty::rc_ptr< ::mosek::fusion::BoundInterfaceVariable > __mosek_2fusion_2RangedVariable__lowerBoundVar() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2RangedVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1729) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1729) { return __mosek_2fusion_2RangedVariable__clone(_1729); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1730);
}; // struct RangedVariable;

struct p_LinearPSDVariable : public ::mosek::fusion::p_ModelVariable
{
LinearPSDVariable * _pubthis;
static mosek::fusion::p_LinearPSDVariable* _get_impl(mosek::fusion::LinearPSDVariable * _inst){ return static_cast< mosek::fusion::p_LinearPSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDVariable * _get_impl(mosek::fusion::LinearPSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDVariable(LinearPSDVariable * _pubthis);
virtual ~p_LinearPSDVariable() { /* std::cout << "~p_LinearPSDVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};int varid{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int conedim{};virtual void destroy();
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1733,monty::rc_ptr< ::mosek::fusion::Model > _1734);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDVariable > _1733,monty::rc_ptr< ::mosek::fusion::Model > _1734);
static LinearPSDVariable::t _new_LinearPSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1735,const std::string &  _1736,int _1737,std::shared_ptr< monty::ndarray< int,1 > > _1738,int _1739,std::shared_ptr< monty::ndarray< long long,1 > > _1740);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1735,const std::string &  _1736,int _1737,std::shared_ptr< monty::ndarray< int,1 > > _1738,int _1739,std::shared_ptr< monty::ndarray< long long,1 > > _1740);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void make_continuous(std::shared_ptr< monty::ndarray< long long,1 > > _1743) ;
virtual void make_integer(std::shared_ptr< monty::ndarray< long long,1 > > _1744) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearPSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1745) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1745) { return __mosek_2fusion_2LinearPSDVariable__clone(_1745); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< long long,1 > > _1746);
}; // struct LinearPSDVariable;

struct p_PSDVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
PSDVariable * _pubthis;
static mosek::fusion::p_PSDVariable* _get_impl(mosek::fusion::PSDVariable * _inst){ return static_cast< mosek::fusion::p_PSDVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_PSDVariable * _get_impl(mosek::fusion::PSDVariable::t _inst) { return _get_impl(_inst.get()); }
p_PSDVariable(PSDVariable * _pubthis);
virtual ~p_PSDVariable() { /* std::cout << "~p_PSDVariable" << std::endl;*/ };
int conedim2{};int conedim1{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > nativeidxs{};int varid{};virtual void destroy();
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1748,monty::rc_ptr< ::mosek::fusion::Model > _1749);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDVariable > _1748,monty::rc_ptr< ::mosek::fusion::Model > _1749);
static PSDVariable::t _new_PSDVariable(monty::rc_ptr< ::mosek::fusion::Model > _1750,const std::string &  _1751,int _1752,std::shared_ptr< monty::ndarray< int,1 > > _1753,int _1754,int _1755,std::shared_ptr< monty::ndarray< long long,1 > > _1756);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1750,const std::string &  _1751,int _1752,std::shared_ptr< monty::ndarray< int,1 > > _1753,int _1754,int _1755,std::shared_ptr< monty::ndarray< long long,1 > > _1756);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2PSDVariable__elementDesc(long long _1759,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1760) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2PSDVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1761) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1761) { return __mosek_2fusion_2PSDVariable__clone(_1761); }
static  std::shared_ptr< monty::ndarray< long long,1 > > fullnativeidxs(std::shared_ptr< monty::ndarray< int,1 > > _1762,int _1763,int _1764,std::shared_ptr< monty::ndarray< long long,1 > > _1765);
}; // struct PSDVariable;

struct p_SymLinearVariable : public ::mosek::fusion::p_ModelVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
SymLinearVariable * _pubthis;
static mosek::fusion::p_SymLinearVariable* _get_impl(mosek::fusion::SymLinearVariable * _inst){ return static_cast< mosek::fusion::p_SymLinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_SymLinearVariable * _get_impl(mosek::fusion::SymLinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_SymLinearVariable(SymLinearVariable * _pubthis);
virtual ~p_SymLinearVariable() { /* std::cout << "~p_SymLinearVariable" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1790,monty::rc_ptr< ::mosek::fusion::Model > _1791);
void _initialize(monty::rc_ptr< ::mosek::fusion::SymLinearVariable > _1790,monty::rc_ptr< ::mosek::fusion::Model > _1791);
static SymLinearVariable::t _new_SymLinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1792,const std::string &  _1793,long long _1794,int _1795,std::shared_ptr< monty::ndarray< long long,1 > > _1796,std::shared_ptr< monty::ndarray< int,1 > > _1797);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1792,const std::string &  _1793,long long _1794,int _1795,std::shared_ptr< monty::ndarray< long long,1 > > _1796,std::shared_ptr< monty::ndarray< int,1 > > _1797);
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2SymLinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1801) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1801) { return __mosek_2fusion_2SymLinearVariable__clone(_1801); }
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_idxs(int _1802,std::shared_ptr< monty::ndarray< long long,1 > > _1803,std::shared_ptr< monty::ndarray< int,1 > > _1804);
static  std::shared_ptr< monty::ndarray< long long,1 > > mirror_sp(int _1820,std::shared_ptr< monty::ndarray< long long,1 > > _1821);
}; // struct SymLinearVariable;

struct p_LinearVariable : public ::mosek::fusion::p_ModelVariable
{
LinearVariable * _pubthis;
static mosek::fusion::p_LinearVariable* _get_impl(mosek::fusion::LinearVariable * _inst){ return static_cast< mosek::fusion::p_LinearVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_LinearVariable * _get_impl(mosek::fusion::LinearVariable::t _inst) { return _get_impl(_inst.get()); }
p_LinearVariable(LinearVariable * _pubthis);
virtual ~p_LinearVariable() { /* std::cout << "~p_LinearVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1832,monty::rc_ptr< ::mosek::fusion::Model > _1833);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearVariable > _1832,monty::rc_ptr< ::mosek::fusion::Model > _1833);
static LinearVariable::t _new_LinearVariable(monty::rc_ptr< ::mosek::fusion::Model > _1834,const std::string &  _1835,long long _1836,std::shared_ptr< monty::ndarray< int,1 > > _1837,std::shared_ptr< monty::ndarray< long long,1 > > _1838,std::shared_ptr< monty::ndarray< int,1 > > _1839);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1834,const std::string &  _1835,long long _1836,std::shared_ptr< monty::ndarray< int,1 > > _1837,std::shared_ptr< monty::ndarray< long long,1 > > _1838,std::shared_ptr< monty::ndarray< int,1 > > _1839);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2LinearVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1845) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1845) { return __mosek_2fusion_2LinearVariable__clone(_1845); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1846);
}; // struct LinearVariable;

struct p_ConicVariable : public ::mosek::fusion::p_ModelVariable
{
ConicVariable * _pubthis;
static mosek::fusion::p_ConicVariable* _get_impl(mosek::fusion::ConicVariable * _inst){ return static_cast< mosek::fusion::p_ConicVariable* >(mosek::fusion::p_ModelVariable::_get_impl(_inst)); }
static mosek::fusion::p_ConicVariable * _get_impl(mosek::fusion::ConicVariable::t _inst) { return _get_impl(_inst.get()); }
p_ConicVariable(ConicVariable * _pubthis);
virtual ~p_ConicVariable() { /* std::cout << "~p_ConicVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};bool names_flushed{};int varid{};virtual void destroy();
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1849,monty::rc_ptr< ::mosek::fusion::Model > _1850);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicVariable > _1849,monty::rc_ptr< ::mosek::fusion::Model > _1850);
static ConicVariable::t _new_ConicVariable(monty::rc_ptr< ::mosek::fusion::Model > _1851,const std::string &  _1852,int _1853,std::shared_ptr< monty::ndarray< int,1 > > _1854,std::shared_ptr< monty::ndarray< int,1 > > _1855);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _1851,const std::string &  _1852,int _1853,std::shared_ptr< monty::ndarray< int,1 > > _1854,std::shared_ptr< monty::ndarray< int,1 > > _1855);
virtual /* override */ std::string toString() ;
virtual /* override */ void flushNames() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ConicVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1861) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelVariable > __mosek_2fusion_2ModelVariable__clone(monty::rc_ptr< ::mosek::fusion::Model > _1861) { return __mosek_2fusion_2ConicVariable__clone(_1861); }
static  std::shared_ptr< monty::ndarray< long long,1 > > globalNativeIndexes(std::shared_ptr< monty::ndarray< int,1 > > _1862);
}; // struct ConicVariable;

struct p_NilVariable : public ::mosek::fusion::p_BaseVariable, public /*implements*/ virtual ::mosek::fusion::SymmetricVariable
{
NilVariable * _pubthis;
static mosek::fusion::p_NilVariable* _get_impl(mosek::fusion::NilVariable * _inst){ return static_cast< mosek::fusion::p_NilVariable* >(mosek::fusion::p_BaseVariable::_get_impl(_inst)); }
static mosek::fusion::p_NilVariable * _get_impl(mosek::fusion::NilVariable::t _inst) { return _get_impl(_inst.get()); }
p_NilVariable(NilVariable * _pubthis);
virtual ~p_NilVariable() { /* std::cout << "~p_NilVariable" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static NilVariable::t _new_NilVariable(std::shared_ptr< monty::ndarray< int,1 > > _1876);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _1876);
static NilVariable::t _new_NilVariable();
void _initialize();
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > __mosek_2fusion_2NilVariable__elementDesc(long long _1878,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1879) ;
virtual void elementName(long long _1880,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _1881) ;
virtual /* override */ int numInst() ;
virtual int inst(int _1882,std::shared_ptr< monty::ndarray< long long,1 > > _1883,std::shared_ptr< monty::ndarray< long long,1 > > _1884) ;
virtual /* override */ void inst(int _1885,std::shared_ptr< monty::ndarray< long long,1 > > _1886) ;
virtual /* override */ void set_values(std::shared_ptr< monty::ndarray< double,1 > > _1887,bool _1888) ;
virtual /* override */ void values(int _1889,std::shared_ptr< monty::ndarray< double,1 > > _1890,bool _1891) ;
virtual /* override */ void make_continuous() ;
virtual /* override */ void make_integer() ;
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1892) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(std::shared_ptr< monty::ndarray< int,1 > > _1892) { return __mosek_2fusion_2NilVariable__index(_1892); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(std::shared_ptr< monty::ndarray< int,1 > > _1892) { return __mosek_2fusion_2NilVariable__index(_1892); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__index(int _1894) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__index(int _1894) { return __mosek_2fusion_2NilVariable__index(_1894); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__index(int _1894) { return __mosek_2fusion_2NilVariable__index(_1894); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897) { return __mosek_2fusion_2NilVariable__slice(_1896,_1897); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(std::shared_ptr< monty::ndarray< int,1 > > _1896,std::shared_ptr< monty::ndarray< int,1 > > _1897) { return __mosek_2fusion_2NilVariable__slice(_1896,_1897); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2NilVariable__slice(int _1900,int _1901) ;
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2BaseVariable__slice(int _1900,int _1901) { return __mosek_2fusion_2NilVariable__slice(_1900,_1901); }
virtual monty::rc_ptr< ::mosek::fusion::Variable > __mosek_2fusion_2Variable__slice(int _1900,int _1901) { return __mosek_2fusion_2NilVariable__slice(_1900,_1901); }
}; // struct NilVariable;

struct p_Var
{
Var * _pubthis;
static mosek::fusion::p_Var* _get_impl(mosek::fusion::Var * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Var * _get_impl(mosek::fusion::Var::t _inst) { return _get_impl(_inst.get()); }
p_Var(Var * _pubthis);
virtual ~p_Var() { /* std::cout << "~p_Var" << std::endl;*/ };
virtual void destroy();
static  monty::rc_ptr< ::mosek::fusion::Variable > empty(std::shared_ptr< monty::ndarray< int,1 > > _2247);
static  monty::rc_ptr< ::mosek::fusion::Variable > compress(monty::rc_ptr< ::mosek::fusion::Variable > _2249);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _2257,int _2258);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _2259,int _2260,int _2261);
static  monty::rc_ptr< ::mosek::fusion::Variable > flatten(monty::rc_ptr< ::mosek::fusion::Variable > _2262);
static  monty::rc_ptr< ::mosek::fusion::Variable > reshape(monty::rc_ptr< ::mosek::fusion::Variable > _2263,std::shared_ptr< monty::ndarray< int,1 > > _2264);
static  monty::rc_ptr< ::mosek::fusion::Variable > index_permute_(monty::rc_ptr< ::mosek::fusion::Variable > _2265,std::shared_ptr< monty::ndarray< int,1 > > _2266);
static  monty::rc_ptr< ::mosek::fusion::Variable > hrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _2295,int _2296);
static  monty::rc_ptr< ::mosek::fusion::Variable > vrepeat(monty::rc_ptr< ::mosek::fusion::Variable > _2297,int _2298);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _2299,int _2300);
static  monty::rc_ptr< ::mosek::fusion::Variable > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _2301,int _2302,int _2303);
static  monty::rc_ptr< ::mosek::fusion::Variable > drepeat(monty::rc_ptr< ::mosek::fusion::Variable > _2304,int _2305,int _2306);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _2370);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _2372,monty::rc_ptr< ::mosek::fusion::Variable > _2373,monty::rc_ptr< ::mosek::fusion::Variable > _2374);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(monty::rc_ptr< ::mosek::fusion::Variable > _2375,monty::rc_ptr< ::mosek::fusion::Variable > _2376);
static  monty::rc_ptr< ::mosek::fusion::Variable > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2377);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _2378,monty::rc_ptr< ::mosek::fusion::Variable > _2379,monty::rc_ptr< ::mosek::fusion::Variable > _2380);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(monty::rc_ptr< ::mosek::fusion::Variable > _2381,monty::rc_ptr< ::mosek::fusion::Variable > _2382);
static  monty::rc_ptr< ::mosek::fusion::Variable > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2383);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _2384,monty::rc_ptr< ::mosek::fusion::Variable > _2385,monty::rc_ptr< ::mosek::fusion::Variable > _2386,int _2387);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(monty::rc_ptr< ::mosek::fusion::Variable > _2388,monty::rc_ptr< ::mosek::fusion::Variable > _2389,int _2390);
static  monty::rc_ptr< ::mosek::fusion::Variable > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2391,int _2392);
static  monty::rc_ptr< ::mosek::fusion::Variable > promote(monty::rc_ptr< ::mosek::fusion::Variable > _2395,int _2396);
static  monty::rc_ptr< ::mosek::fusion::Variable > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _2401,int _2402);
}; // struct Var;

struct p_ConstraintCache
{
ConstraintCache * _pubthis;
static mosek::fusion::p_ConstraintCache* _get_impl(mosek::fusion::ConstraintCache * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConstraintCache * _get_impl(mosek::fusion::ConstraintCache::t _inst) { return _get_impl(_inst.get()); }
p_ConstraintCache(ConstraintCache * _pubthis);
virtual ~p_ConstraintCache() { /* std::cout << "~p_ConstraintCache" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > barmatidx{};std::shared_ptr< monty::ndarray< int,1 > > barsubj{};std::shared_ptr< monty::ndarray< int,1 > > barsubi{};long long nbarnz{};long long nunordered{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subi{};std::shared_ptr< monty::ndarray< int,1 > > buffer_subj{};std::shared_ptr< monty::ndarray< double,1 > > buffer_cof{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< int,1 > > subi{};std::shared_ptr< monty::ndarray< int,1 > > subj{};long long nnz{};int nrows{};virtual void destroy();
static ConstraintCache::t _new_ConstraintCache(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2525);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConstraintCache > _2525);
static ConstraintCache::t _new_ConstraintCache(std::shared_ptr< monty::ndarray< long long,1 > > _2526,std::shared_ptr< monty::ndarray< double,1 > > _2527,std::shared_ptr< monty::ndarray< int,1 > > _2528,std::shared_ptr< monty::ndarray< double,1 > > _2529,std::shared_ptr< monty::ndarray< int,1 > > _2530,std::shared_ptr< monty::ndarray< int,1 > > _2531,std::shared_ptr< monty::ndarray< int,1 > > _2532);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _2526,std::shared_ptr< monty::ndarray< double,1 > > _2527,std::shared_ptr< monty::ndarray< int,1 > > _2528,std::shared_ptr< monty::ndarray< double,1 > > _2529,std::shared_ptr< monty::ndarray< int,1 > > _2530,std::shared_ptr< monty::ndarray< int,1 > > _2531,std::shared_ptr< monty::ndarray< int,1 > > _2532);
virtual void unchecked_add_fx(std::shared_ptr< monty::ndarray< double,1 > > _2535) ;
virtual long long order_barentries() ;
virtual void add_bar(std::shared_ptr< monty::ndarray< int,1 > > _2545,std::shared_ptr< monty::ndarray< int,1 > > _2546,std::shared_ptr< monty::ndarray< int,1 > > _2547) ;
virtual void unchecked_add_l(std::shared_ptr< monty::ndarray< long long,1 > > _2553,std::shared_ptr< monty::ndarray< int,1 > > _2554,std::shared_ptr< monty::ndarray< double,1 > > _2555,std::shared_ptr< monty::ndarray< double,1 > > _2556) ;
virtual void add(std::shared_ptr< monty::ndarray< long long,1 > > _2565,std::shared_ptr< monty::ndarray< int,1 > > _2566,std::shared_ptr< monty::ndarray< double,1 > > _2567,std::shared_ptr< monty::ndarray< double,1 > > _2568) ;
virtual long long flush(std::shared_ptr< monty::ndarray< int,1 > > _2569,std::shared_ptr< monty::ndarray< int,1 > > _2570,std::shared_ptr< monty::ndarray< double,1 > > _2571,std::shared_ptr< monty::ndarray< double,1 > > _2572) ;
virtual long long numUnsorted() ;
virtual monty::rc_ptr< ::mosek::fusion::ConstraintCache > __mosek_2fusion_2ConstraintCache__clone() ;
}; // struct ConstraintCache;

struct p_Constraint
{
Constraint * _pubthis;
static mosek::fusion::p_Constraint* _get_impl(mosek::fusion::Constraint * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Constraint * _get_impl(mosek::fusion::Constraint::t _inst) { return _get_impl(_inst.get()); }
p_Constraint(Constraint * _pubthis);
virtual ~p_Constraint() { /* std::cout << "~p_Constraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::Model > model{};virtual void destroy();
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Constraint > _2669,monty::rc_ptr< ::mosek::fusion::Model > _2670);
void _initialize(monty::rc_ptr< ::mosek::fusion::Constraint > _2669,monty::rc_ptr< ::mosek::fusion::Model > _2670);
static Constraint::t _new_Constraint(monty::rc_ptr< ::mosek::fusion::Model > _2671,std::shared_ptr< monty::ndarray< int,1 > > _2672,std::shared_ptr< monty::ndarray< int,1 > > _2673);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2671,std::shared_ptr< monty::ndarray< int,1 > > _2672,std::shared_ptr< monty::ndarray< int,1 > > _2673);
virtual /* override */ std::string toString() ;
virtual void toStringArray(std::shared_ptr< monty::ndarray< long long,1 > > _2674,long long _2675,std::shared_ptr< monty::ndarray< std::string,1 > > _2676) ;
virtual void dual_lu(int _2677,std::shared_ptr< monty::ndarray< double,1 > > _2678,bool _2679) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual std::shared_ptr< monty::ndarray< double,1 > > level() ;
virtual void values(bool _2682,int _2683,std::shared_ptr< monty::ndarray< double,1 > > _2684) ;
virtual void remove() ;
virtual void update(std::shared_ptr< monty::ndarray< double,1 > > _2685) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2686) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2690,monty::rc_ptr< ::mosek::fusion::Variable > _2691,bool _2692) ;
virtual void update(monty::rc_ptr< ::mosek::fusion::Expression > _2712,monty::rc_ptr< ::mosek::fusion::Variable > _2713) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__get_model() ;
virtual int get_nd() ;
virtual long long size() ;
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2716,int _2717);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2718,monty::rc_ptr< ::mosek::fusion::Constraint > _2719,monty::rc_ptr< ::mosek::fusion::Constraint > _2720,int _2721);
static  monty::rc_ptr< ::mosek::fusion::Constraint > stack(monty::rc_ptr< ::mosek::fusion::Constraint > _2722,monty::rc_ptr< ::mosek::fusion::Constraint > _2723,int _2724);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2725);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2726);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2727,monty::rc_ptr< ::mosek::fusion::Constraint > _2728,monty::rc_ptr< ::mosek::fusion::Constraint > _2729);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2730,monty::rc_ptr< ::mosek::fusion::Constraint > _2731,monty::rc_ptr< ::mosek::fusion::Constraint > _2732);
static  monty::rc_ptr< ::mosek::fusion::Constraint > hstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2733,monty::rc_ptr< ::mosek::fusion::Constraint > _2734);
static  monty::rc_ptr< ::mosek::fusion::Constraint > vstack(monty::rc_ptr< ::mosek::fusion::Constraint > _2735,monty::rc_ptr< ::mosek::fusion::Constraint > _2736);
static  monty::rc_ptr< ::mosek::fusion::Constraint > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Constraint >,1 > > _2737,int _2738);
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2789) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(int _2796) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2797,std::shared_ptr< monty::ndarray< int,1 > > _2798) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(int _2817,int _2818) ;
virtual int getND() ;
virtual int getSize() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Constraint__getModel() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getNativeidxs() ;
}; // struct Constraint;

struct p_SliceConstraint : public ::mosek::fusion::p_Constraint
{
SliceConstraint * _pubthis;
static mosek::fusion::p_SliceConstraint* _get_impl(mosek::fusion::SliceConstraint * _inst){ return static_cast< mosek::fusion::p_SliceConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_SliceConstraint * _get_impl(mosek::fusion::SliceConstraint::t _inst) { return _get_impl(_inst.get()); }
p_SliceConstraint(SliceConstraint * _pubthis);
virtual ~p_SliceConstraint() { /* std::cout << "~p_SliceConstraint" << std::endl;*/ };
virtual void destroy();
static SliceConstraint::t _new_SliceConstraint(monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2615);
void _initialize(monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2615);
static SliceConstraint::t _new_SliceConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2616,std::shared_ptr< monty::ndarray< int,1 > > _2617,std::shared_ptr< monty::ndarray< int,1 > > _2618);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2616,std::shared_ptr< monty::ndarray< int,1 > > _2617,std::shared_ptr< monty::ndarray< int,1 > > _2618);
virtual /* override */ std::string toString() ;
}; // struct SliceConstraint;

struct p_BoundInterfaceConstraint : public ::mosek::fusion::p_SliceConstraint
{
BoundInterfaceConstraint * _pubthis;
static mosek::fusion::p_BoundInterfaceConstraint* _get_impl(mosek::fusion::BoundInterfaceConstraint * _inst){ return static_cast< mosek::fusion::p_BoundInterfaceConstraint* >(mosek::fusion::p_SliceConstraint::_get_impl(_inst)); }
static mosek::fusion::p_BoundInterfaceConstraint * _get_impl(mosek::fusion::BoundInterfaceConstraint::t _inst) { return _get_impl(_inst.get()); }
p_BoundInterfaceConstraint(BoundInterfaceConstraint * _pubthis);
virtual ~p_BoundInterfaceConstraint() { /* std::cout << "~p_BoundInterfaceConstraint" << std::endl;*/ };
bool islower{};virtual void destroy();
static BoundInterfaceConstraint::t _new_BoundInterfaceConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2595,std::shared_ptr< monty::ndarray< int,1 > > _2596,std::shared_ptr< monty::ndarray< int,1 > > _2597,bool _2598);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2595,std::shared_ptr< monty::ndarray< int,1 > > _2596,std::shared_ptr< monty::ndarray< int,1 > > _2597,bool _2598);
static BoundInterfaceConstraint::t _new_BoundInterfaceConstraint(monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2599,bool _2600);
void _initialize(monty::rc_ptr< ::mosek::fusion::SliceConstraint > _2599,bool _2600);
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > dual() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2BoundInterfaceConstraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(std::shared_ptr< monty::ndarray< int,1 > > _2602,std::shared_ptr< monty::ndarray< int,1 > > _2603) { return __mosek_2fusion_2BoundInterfaceConstraint__slice(_2602,_2603); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2BoundInterfaceConstraint__slice(int _2605,int _2606) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__slice(int _2605,int _2606) { return __mosek_2fusion_2BoundInterfaceConstraint__slice(_2605,_2606); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2BoundInterfaceConstraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2608) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(std::shared_ptr< monty::ndarray< int,1 > > _2608) { return __mosek_2fusion_2BoundInterfaceConstraint__index(_2608); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2BoundInterfaceConstraint__index(int _2610) ;
virtual monty::rc_ptr< ::mosek::fusion::Constraint > __mosek_2fusion_2Constraint__index(int _2610) { return __mosek_2fusion_2BoundInterfaceConstraint__index(_2610); }
virtual monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > __mosek_2fusion_2BoundInterfaceConstraint__from_(monty::rc_ptr< ::mosek::fusion::Constraint > _2612) ;
}; // struct BoundInterfaceConstraint;

struct p_ModelConstraint : public ::mosek::fusion::p_Constraint
{
ModelConstraint * _pubthis;
static mosek::fusion::p_ModelConstraint* _get_impl(mosek::fusion::ModelConstraint * _inst){ return static_cast< mosek::fusion::p_ModelConstraint* >(mosek::fusion::p_Constraint::_get_impl(_inst)); }
static mosek::fusion::p_ModelConstraint * _get_impl(mosek::fusion::ModelConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ModelConstraint(ModelConstraint * _pubthis);
virtual ~p_ModelConstraint() { /* std::cout << "~p_ModelConstraint" << std::endl;*/ };
int conid{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};virtual void destroy();
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2657,monty::rc_ptr< ::mosek::fusion::Model > _2658);
void _initialize(monty::rc_ptr< ::mosek::fusion::ModelConstraint > _2657,monty::rc_ptr< ::mosek::fusion::Model > _2658);
static ModelConstraint::t _new_ModelConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2659,const std::string &  _2660,std::shared_ptr< monty::ndarray< int,1 > > _2661,std::shared_ptr< monty::ndarray< int,1 > > _2662,int _2663);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2659,const std::string &  _2660,std::shared_ptr< monty::ndarray< int,1 > > _2661,std::shared_ptr< monty::ndarray< int,1 > > _2662,int _2663);
virtual /* override */ std::string toString() ;
virtual void flushNames() ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2668) { throw monty::AbstractClassError("Call to abstract method"); }
virtual /* override */ void remove() ;
}; // struct ModelConstraint;

struct p_LinearPSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearPSDConstraint * _pubthis;
static mosek::fusion::p_LinearPSDConstraint* _get_impl(mosek::fusion::LinearPSDConstraint * _inst){ return static_cast< mosek::fusion::p_LinearPSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearPSDConstraint * _get_impl(mosek::fusion::LinearPSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearPSDConstraint(LinearPSDConstraint * _pubthis);
virtual ~p_LinearPSDConstraint() { /* std::cout << "~p_LinearPSDConstraint" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};int conid{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};virtual void destroy();
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2471,monty::rc_ptr< ::mosek::fusion::Model > _2472);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearPSDConstraint > _2471,monty::rc_ptr< ::mosek::fusion::Model > _2472);
static LinearPSDConstraint::t _new_LinearPSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2473,const std::string &  _2474,int _2475,std::shared_ptr< monty::ndarray< int,1 > > _2476,int _2477,std::shared_ptr< monty::ndarray< int,1 > > _2478,std::shared_ptr< monty::ndarray< long long,1 > > _2479);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2473,const std::string &  _2474,int _2475,std::shared_ptr< monty::ndarray< int,1 > > _2476,int _2477,std::shared_ptr< monty::ndarray< int,1 > > _2478,std::shared_ptr< monty::ndarray< long long,1 > > _2479);
virtual void domainToString(long long _2480,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2481) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearPSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2485) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2485) { return __mosek_2fusion_2LinearPSDConstraint__clone(_2485); }
}; // struct LinearPSDConstraint;

struct p_PSDConstraint : public ::mosek::fusion::p_ModelConstraint
{
PSDConstraint * _pubthis;
static mosek::fusion::p_PSDConstraint* _get_impl(mosek::fusion::PSDConstraint * _inst){ return static_cast< mosek::fusion::p_PSDConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_PSDConstraint * _get_impl(mosek::fusion::PSDConstraint::t _inst) { return _get_impl(_inst.get()); }
p_PSDConstraint(PSDConstraint * _pubthis);
virtual ~p_PSDConstraint() { /* std::cout << "~p_PSDConstraint" << std::endl;*/ };
bool names_flushed{};int conedim1{};int conedim0{};std::shared_ptr< monty::ndarray< int,1 > > shape{};std::string name{};std::shared_ptr< monty::ndarray< long long,1 > > slackidxs{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};int conid{};virtual void destroy();
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2486,monty::rc_ptr< ::mosek::fusion::Model > _2487);
void _initialize(monty::rc_ptr< ::mosek::fusion::PSDConstraint > _2486,monty::rc_ptr< ::mosek::fusion::Model > _2487);
static PSDConstraint::t _new_PSDConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2488,const std::string &  _2489,int _2490,std::shared_ptr< monty::ndarray< int,1 > > _2491,int _2492,int _2493,std::shared_ptr< monty::ndarray< long long,1 > > _2494,std::shared_ptr< monty::ndarray< int,1 > > _2495);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2488,const std::string &  _2489,int _2490,std::shared_ptr< monty::ndarray< int,1 > > _2491,int _2492,int _2493,std::shared_ptr< monty::ndarray< long long,1 > > _2494,std::shared_ptr< monty::ndarray< int,1 > > _2495);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2PSDConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2496) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2496) { return __mosek_2fusion_2PSDConstraint__clone(_2496); }
static  std::shared_ptr< monty::ndarray< int,1 > > computenidxs(std::shared_ptr< monty::ndarray< int,1 > > _2497,int _2498,int _2499,std::shared_ptr< monty::ndarray< int,1 > > _2500);
}; // struct PSDConstraint;

struct p_RangedConstraint : public ::mosek::fusion::p_ModelConstraint
{
RangedConstraint * _pubthis;
static mosek::fusion::p_RangedConstraint* _get_impl(mosek::fusion::RangedConstraint * _inst){ return static_cast< mosek::fusion::p_RangedConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_RangedConstraint * _get_impl(mosek::fusion::RangedConstraint::t _inst) { return _get_impl(_inst.get()); }
p_RangedConstraint(RangedConstraint * _pubthis);
virtual ~p_RangedConstraint() { /* std::cout << "~p_RangedConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2620,monty::rc_ptr< ::mosek::fusion::Model > _2621);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangedConstraint > _2620,monty::rc_ptr< ::mosek::fusion::Model > _2621);
static RangedConstraint::t _new_RangedConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2622,const std::string &  _2623,std::shared_ptr< monty::ndarray< int,1 > > _2624,std::shared_ptr< monty::ndarray< int,1 > > _2625,int _2626);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2622,const std::string &  _2623,std::shared_ptr< monty::ndarray< int,1 > > _2624,std::shared_ptr< monty::ndarray< int,1 > > _2625,int _2626);
virtual monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > __mosek_2fusion_2RangedConstraint__upperBoundCon() ;
virtual monty::rc_ptr< ::mosek::fusion::BoundInterfaceConstraint > __mosek_2fusion_2RangedConstraint__lowerBoundCon() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2RangedConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2627) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2627) { return __mosek_2fusion_2RangedConstraint__clone(_2627); }
}; // struct RangedConstraint;

struct p_ConicConstraint : public ::mosek::fusion::p_ModelConstraint
{
ConicConstraint * _pubthis;
static mosek::fusion::p_ConicConstraint* _get_impl(mosek::fusion::ConicConstraint * _inst){ return static_cast< mosek::fusion::p_ConicConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_ConicConstraint * _get_impl(mosek::fusion::ConicConstraint::t _inst) { return _get_impl(_inst.get()); }
p_ConicConstraint(ConicConstraint * _pubthis);
virtual ~p_ConicConstraint() { /* std::cout << "~p_ConicConstraint" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > nativeslack{};std::shared_ptr< monty::ndarray< int,1 > > nativeidxs{};bool names_flushed{};std::string name{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::ConeDomain > dom{};int conid{};virtual void destroy();
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2628,monty::rc_ptr< ::mosek::fusion::Model > _2629);
void _initialize(monty::rc_ptr< ::mosek::fusion::ConicConstraint > _2628,monty::rc_ptr< ::mosek::fusion::Model > _2629);
static ConicConstraint::t _new_ConicConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2630,const std::string &  _2631,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2632,std::shared_ptr< monty::ndarray< int,1 > > _2633,int _2634,std::shared_ptr< monty::ndarray< int,1 > > _2635,std::shared_ptr< monty::ndarray< int,1 > > _2636);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2630,const std::string &  _2631,monty::rc_ptr< ::mosek::fusion::ConeDomain > _2632,std::shared_ptr< monty::ndarray< int,1 > > _2633,int _2634,std::shared_ptr< monty::ndarray< int,1 > > _2635,std::shared_ptr< monty::ndarray< int,1 > > _2636);
virtual /* override */ void flushNames() ;
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2643,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2644) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ConicConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2645) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2645) { return __mosek_2fusion_2ConicConstraint__clone(_2645); }
}; // struct ConicConstraint;

struct p_LinearConstraint : public ::mosek::fusion::p_ModelConstraint
{
LinearConstraint * _pubthis;
static mosek::fusion::p_LinearConstraint* _get_impl(mosek::fusion::LinearConstraint * _inst){ return static_cast< mosek::fusion::p_LinearConstraint* >(mosek::fusion::p_ModelConstraint::_get_impl(_inst)); }
static mosek::fusion::p_LinearConstraint * _get_impl(mosek::fusion::LinearConstraint::t _inst) { return _get_impl(_inst.get()); }
p_LinearConstraint(LinearConstraint * _pubthis);
virtual ~p_LinearConstraint() { /* std::cout << "~p_LinearConstraint" << std::endl;*/ };
std::string name{};int conid{};virtual void destroy();
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2646,monty::rc_ptr< ::mosek::fusion::Model > _2647);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearConstraint > _2646,monty::rc_ptr< ::mosek::fusion::Model > _2647);
static LinearConstraint::t _new_LinearConstraint(monty::rc_ptr< ::mosek::fusion::Model > _2648,const std::string &  _2649,int _2650,std::shared_ptr< monty::ndarray< int,1 > > _2651,std::shared_ptr< monty::ndarray< int,1 > > _2652);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _2648,const std::string &  _2649,int _2650,std::shared_ptr< monty::ndarray< int,1 > > _2651,std::shared_ptr< monty::ndarray< int,1 > > _2652);
virtual /* override */ std::string toString() ;
virtual void domainToString(long long _2654,monty::rc_ptr< ::mosek::fusion::Utils::StringBuffer > _2655) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2LinearConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2656) ;
virtual monty::rc_ptr< ::mosek::fusion::ModelConstraint > __mosek_2fusion_2ModelConstraint__clone(monty::rc_ptr< ::mosek::fusion::Model > _2656) { return __mosek_2fusion_2LinearConstraint__clone(_2656); }
}; // struct LinearConstraint;

struct p_Set
{
Set * _pubthis;
static mosek::fusion::p_Set* _get_impl(mosek::fusion::Set * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Set * _get_impl(mosek::fusion::Set::t _inst) { return _get_impl(_inst.get()); }
p_Set(Set * _pubthis);
virtual ~p_Set() { /* std::cout << "~p_Set" << std::endl;*/ };
virtual void destroy();
static  long long size(std::shared_ptr< monty::ndarray< int,1 > > _2823);
static  bool match(std::shared_ptr< monty::ndarray< int,1 > > _2826,std::shared_ptr< monty::ndarray< int,1 > > _2827);
static  long long linearidx(std::shared_ptr< monty::ndarray< int,1 > > _2829,std::shared_ptr< monty::ndarray< int,1 > > _2830);
static  std::shared_ptr< monty::ndarray< int,1 > > idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2833,long long _2834);
static  void idxtokey(std::shared_ptr< monty::ndarray< int,1 > > _2836,long long _2837,std::shared_ptr< monty::ndarray< int,1 > > _2838);
static  std::string indexToString(std::shared_ptr< monty::ndarray< int,1 > > _2842,long long _2843);
static  std::string keyToString(std::shared_ptr< monty::ndarray< int,1 > > _2850);
static  void indexToKey(std::shared_ptr< monty::ndarray< int,1 > > _2853,long long _2854,std::shared_ptr< monty::ndarray< int,1 > > _2855);
static  std::shared_ptr< monty::ndarray< long long,1 > > strides(std::shared_ptr< monty::ndarray< int,1 > > _2859);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2863,std::shared_ptr< monty::ndarray< int,1 > > _2864);
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< int,1 > > _2868);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2870,int _2871,int _2872);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2873,int _2874);
static  std::shared_ptr< monty::ndarray< int,1 > > make(int _2875);
static  std::shared_ptr< monty::ndarray< int,1 > > scalar();
static  std::shared_ptr< monty::ndarray< int,1 > > make(std::shared_ptr< monty::ndarray< std::string,1 > > _2876);
}; // struct Set;

struct p_ConeDomain
{
ConeDomain * _pubthis;
static mosek::fusion::p_ConeDomain* _get_impl(mosek::fusion::ConeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ConeDomain * _get_impl(mosek::fusion::ConeDomain::t _inst) { return _get_impl(_inst.get()); }
p_ConeDomain(ConeDomain * _pubthis);
virtual ~p_ConeDomain() { /* std::cout << "~p_ConeDomain" << std::endl;*/ };
double alpha{};std::shared_ptr< monty::ndarray< int,1 > > shape{};bool int_flag{};bool axisset{};int axisidx{};mosek::fusion::QConeKey key{};virtual void destroy();
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2877,double _2878,std::shared_ptr< monty::ndarray< int,1 > > _2879);
void _initialize(mosek::fusion::QConeKey _2877,double _2878,std::shared_ptr< monty::ndarray< int,1 > > _2879);
static ConeDomain::t _new_ConeDomain(mosek::fusion::QConeKey _2880,std::shared_ptr< monty::ndarray< int,1 > > _2881);
void _initialize(mosek::fusion::QConeKey _2880,std::shared_ptr< monty::ndarray< int,1 > > _2881);
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2882) ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__integral() ;
virtual bool axisIsSet() ;
virtual int getAxis() ;
virtual monty::rc_ptr< ::mosek::fusion::ConeDomain > __mosek_2fusion_2ConeDomain__axis(int _2883) ;
}; // struct ConeDomain;

struct p_LinPSDDomain
{
LinPSDDomain * _pubthis;
static mosek::fusion::p_LinPSDDomain* _get_impl(mosek::fusion::LinPSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinPSDDomain * _get_impl(mosek::fusion::LinPSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinPSDDomain(LinPSDDomain * _pubthis);
virtual ~p_LinPSDDomain() { /* std::cout << "~p_LinPSDDomain" << std::endl;*/ };
int conedim{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2884,int _2885);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2884,int _2885);
static LinPSDDomain::t _new_LinPSDDomain(std::shared_ptr< monty::ndarray< int,1 > > _2886);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _2886);
static LinPSDDomain::t _new_LinPSDDomain();
void _initialize();
}; // struct LinPSDDomain;

struct p_PSDDomain
{
PSDDomain * _pubthis;
static mosek::fusion::p_PSDDomain* _get_impl(mosek::fusion::PSDDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_PSDDomain * _get_impl(mosek::fusion::PSDDomain::t _inst) { return _get_impl(_inst.get()); }
p_PSDDomain(PSDDomain * _pubthis);
virtual ~p_PSDDomain() { /* std::cout << "~p_PSDDomain" << std::endl;*/ };
bool axisIsSet{};int conedim2{};int conedim1{};mosek::fusion::PSDKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2887,std::shared_ptr< monty::ndarray< int,1 > > _2888,int _2889,int _2890);
void _initialize(mosek::fusion::PSDKey _2887,std::shared_ptr< monty::ndarray< int,1 > > _2888,int _2889,int _2890);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2892,std::shared_ptr< monty::ndarray< int,1 > > _2893);
void _initialize(mosek::fusion::PSDKey _2892,std::shared_ptr< monty::ndarray< int,1 > > _2893);
static PSDDomain::t _new_PSDDomain(mosek::fusion::PSDKey _2894);
void _initialize(mosek::fusion::PSDKey _2894);
virtual monty::rc_ptr< ::mosek::fusion::PSDDomain > __mosek_2fusion_2PSDDomain__axis(int _2895,int _2896) ;
}; // struct PSDDomain;

struct p_RangeDomain
{
RangeDomain * _pubthis;
static mosek::fusion::p_RangeDomain* _get_impl(mosek::fusion::RangeDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_RangeDomain * _get_impl(mosek::fusion::RangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_RangeDomain(RangeDomain * _pubthis);
virtual ~p_RangeDomain() { /* std::cout << "~p_RangeDomain" << std::endl;*/ };
bool cardinal_flag{};bool scalable{};std::shared_ptr< monty::ndarray< double,1 > > ub{};std::shared_ptr< monty::ndarray< double,1 > > lb{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool empty{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static RangeDomain::t _new_RangeDomain(bool _2898,std::shared_ptr< monty::ndarray< double,1 > > _2899,std::shared_ptr< monty::ndarray< double,1 > > _2900,std::shared_ptr< monty::ndarray< int,1 > > _2901);
void _initialize(bool _2898,std::shared_ptr< monty::ndarray< double,1 > > _2899,std::shared_ptr< monty::ndarray< double,1 > > _2900,std::shared_ptr< monty::ndarray< int,1 > > _2901);
static RangeDomain::t _new_RangeDomain(bool _2902,std::shared_ptr< monty::ndarray< double,1 > > _2903,std::shared_ptr< monty::ndarray< double,1 > > _2904,std::shared_ptr< monty::ndarray< int,1 > > _2905,std::shared_ptr< monty::ndarray< int,2 > > _2906);
void _initialize(bool _2902,std::shared_ptr< monty::ndarray< double,1 > > _2903,std::shared_ptr< monty::ndarray< double,1 > > _2904,std::shared_ptr< monty::ndarray< int,1 > > _2905,std::shared_ptr< monty::ndarray< int,2 > > _2906);
static RangeDomain::t _new_RangeDomain(bool _2907,std::shared_ptr< monty::ndarray< double,1 > > _2908,std::shared_ptr< monty::ndarray< double,1 > > _2909,std::shared_ptr< monty::ndarray< int,1 > > _2910,std::shared_ptr< monty::ndarray< int,2 > > _2911,int _2912);
void _initialize(bool _2907,std::shared_ptr< monty::ndarray< double,1 > > _2908,std::shared_ptr< monty::ndarray< double,1 > > _2909,std::shared_ptr< monty::ndarray< int,1 > > _2910,std::shared_ptr< monty::ndarray< int,2 > > _2911,int _2912);
static RangeDomain::t _new_RangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2913);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2913);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > __mosek_2fusion_2RangeDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2914) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2917) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(int _2919,int _2920,int _2921) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(int _2922,int _2923) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(int _2924) ;
virtual monty::rc_ptr< ::mosek::fusion::RangeDomain > __mosek_2fusion_2RangeDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2925) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2926) ;
}; // struct RangeDomain;

struct p_SymmetricRangeDomain : public ::mosek::fusion::p_RangeDomain
{
SymmetricRangeDomain * _pubthis;
static mosek::fusion::p_SymmetricRangeDomain* _get_impl(mosek::fusion::SymmetricRangeDomain * _inst){ return static_cast< mosek::fusion::p_SymmetricRangeDomain* >(mosek::fusion::p_RangeDomain::_get_impl(_inst)); }
static mosek::fusion::p_SymmetricRangeDomain * _get_impl(mosek::fusion::SymmetricRangeDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricRangeDomain(SymmetricRangeDomain * _pubthis);
virtual ~p_SymmetricRangeDomain() { /* std::cout << "~p_SymmetricRangeDomain" << std::endl;*/ };
int dim{};virtual void destroy();
static SymmetricRangeDomain::t _new_SymmetricRangeDomain(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2897);
void _initialize(monty::rc_ptr< ::mosek::fusion::RangeDomain > _2897);
}; // struct SymmetricRangeDomain;

struct p_SymmetricLinearDomain
{
SymmetricLinearDomain * _pubthis;
static mosek::fusion::p_SymmetricLinearDomain* _get_impl(mosek::fusion::SymmetricLinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricLinearDomain * _get_impl(mosek::fusion::SymmetricLinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricLinearDomain(SymmetricLinearDomain * _pubthis);
virtual ~p_SymmetricLinearDomain() { /* std::cout << "~p_SymmetricLinearDomain" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::LinearDomain > dom{};int dim{};virtual void destroy();
static SymmetricLinearDomain::t _new_SymmetricLinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2928);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2928);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2929) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2932) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2SymmetricLinearDomain__integral() ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2934) ;
}; // struct SymmetricLinearDomain;

struct p_LinearDomain
{
LinearDomain * _pubthis;
static mosek::fusion::p_LinearDomain* _get_impl(mosek::fusion::LinearDomain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinearDomain * _get_impl(mosek::fusion::LinearDomain::t _inst) { return _get_impl(_inst.get()); }
p_LinearDomain(LinearDomain * _pubthis);
virtual ~p_LinearDomain() { /* std::cout << "~p_LinearDomain" << std::endl;*/ };
bool empty{};bool scalable{};std::shared_ptr< monty::ndarray< int,2 > > sparsity{};bool cardinal_flag{};mosek::fusion::RelationKey key{};std::shared_ptr< monty::ndarray< double,1 > > bnd{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2936,bool _2937,std::shared_ptr< monty::ndarray< double,1 > > _2938,std::shared_ptr< monty::ndarray< int,1 > > _2939);
void _initialize(mosek::fusion::RelationKey _2936,bool _2937,std::shared_ptr< monty::ndarray< double,1 > > _2938,std::shared_ptr< monty::ndarray< int,1 > > _2939);
static LinearDomain::t _new_LinearDomain(mosek::fusion::RelationKey _2940,bool _2941,std::shared_ptr< monty::ndarray< double,1 > > _2942,std::shared_ptr< monty::ndarray< int,1 > > _2943,std::shared_ptr< monty::ndarray< int,2 > > _2944,int _2945);
void _initialize(mosek::fusion::RelationKey _2940,bool _2941,std::shared_ptr< monty::ndarray< double,1 > > _2942,std::shared_ptr< monty::ndarray< int,1 > > _2943,std::shared_ptr< monty::ndarray< int,2 > > _2944,int _2945);
static LinearDomain::t _new_LinearDomain(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2946);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinearDomain > _2946);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > __mosek_2fusion_2LinearDomain__symmetric() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,2 > > _2947) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse(std::shared_ptr< monty::ndarray< int,1 > > _2950) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__sparse() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__integral() ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(int _2952,int _2953,int _2954) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(int _2955,int _2956) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(int _2957) ;
virtual monty::rc_ptr< ::mosek::fusion::LinearDomain > __mosek_2fusion_2LinearDomain__withShape(std::shared_ptr< monty::ndarray< int,1 > > _2958) ;
virtual bool match_shape(std::shared_ptr< monty::ndarray< int,1 > > _2959) ;
}; // struct LinearDomain;

struct p_Domain
{
Domain * _pubthis;
static mosek::fusion::p_Domain* _get_impl(mosek::fusion::Domain * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Domain * _get_impl(mosek::fusion::Domain::t _inst) { return _get_impl(_inst.get()); }
p_Domain(Domain * _pubthis);
virtual ~p_Domain() { /* std::cout << "~p_Domain" << std::endl;*/ };
virtual void destroy();
static  long long dimsize(std::shared_ptr< monty::ndarray< int,1 > > _2961);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > mkRangedDomain(monty::rc_ptr< ::mosek::fusion::Matrix > _2964,monty::rc_ptr< ::mosek::fusion::Matrix > _2965);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > mkRangedDomain(std::shared_ptr< monty::ndarray< double,2 > > _2994,std::shared_ptr< monty::ndarray< double,2 > > _2995);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > mkLinearDomain(mosek::fusion::RelationKey _3004,monty::rc_ptr< ::mosek::fusion::Matrix > _3005);
static  long long prod(std::shared_ptr< monty::ndarray< int,1 > > _3011);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(bool _3014,std::shared_ptr< monty::ndarray< double,1 > > _3015,std::shared_ptr< monty::ndarray< double,1 > > _3016,std::shared_ptr< monty::ndarray< int,2 > > _3017,std::shared_ptr< monty::ndarray< int,1 > > _3018);
static  monty::rc_ptr< ::mosek::fusion::SymmetricRangeDomain > symmetric(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3020);
static  monty::rc_ptr< ::mosek::fusion::SymmetricLinearDomain > symmetric(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3021);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3022,std::shared_ptr< monty::ndarray< int,2 > > _3023);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > sparse(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3024,std::shared_ptr< monty::ndarray< int,1 > > _3025);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3026,std::shared_ptr< monty::ndarray< int,2 > > _3027);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > sparse(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3028,std::shared_ptr< monty::ndarray< int,1 > > _3029);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > integral(monty::rc_ptr< ::mosek::fusion::RangeDomain > _3030);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > integral(monty::rc_ptr< ::mosek::fusion::LinearDomain > _3031);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > integral(monty::rc_ptr< ::mosek::fusion::ConeDomain > _3032);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > axis(monty::rc_ptr< ::mosek::fusion::ConeDomain > _3033,int _3034);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _3035,std::shared_ptr< monty::ndarray< int,1 > > _3036);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _3038,int _3039);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDPowerCone(double _3040);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _3041,std::shared_ptr< monty::ndarray< int,1 > > _3042);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _3044,int _3045);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPPowerCone(double _3046);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(std::shared_ptr< monty::ndarray< int,1 > > _3047);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone(int _3049);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inDExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(std::shared_ptr< monty::ndarray< int,1 > > _3050);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone(int _3052);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inPExpCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(std::shared_ptr< monty::ndarray< int,1 > > _3053);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _3055,int _3056);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone(int _3057);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inRotatedQCone();
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(std::shared_ptr< monty::ndarray< int,1 > > _3058);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _3060,int _3061);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone(int _3062);
static  monty::rc_ptr< ::mosek::fusion::ConeDomain > inQCone();
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _3063,int _3064);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD(int _3065);
static  monty::rc_ptr< ::mosek::fusion::LinPSDDomain > isLinPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _3066,int _3067);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD(int _3068);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > isTrilPSD();
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _3069,int _3070);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone(int _3071);
static  monty::rc_ptr< ::mosek::fusion::PSDDomain > inPSDCone();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary();
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(std::shared_ptr< monty::ndarray< int,1 > > _3072);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _3073,int _3074);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > binary(int _3075);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(monty::rc_ptr< ::mosek::fusion::Matrix > _3076,monty::rc_ptr< ::mosek::fusion::Matrix > _3077);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,2 > > _3078,std::shared_ptr< monty::ndarray< double,2 > > _3079);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _3080,std::shared_ptr< monty::ndarray< double,1 > > _3081,std::shared_ptr< monty::ndarray< int,1 > > _3082);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _3083,double _3084,std::shared_ptr< monty::ndarray< int,1 > > _3085);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _3087,std::shared_ptr< monty::ndarray< double,1 > > _3088,std::shared_ptr< monty::ndarray< int,1 > > _3089);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _3091,double _3092,std::shared_ptr< monty::ndarray< int,1 > > _3093);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _3094,std::shared_ptr< monty::ndarray< double,1 > > _3095);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(std::shared_ptr< monty::ndarray< double,1 > > _3096,double _3097);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _3099,std::shared_ptr< monty::ndarray< double,1 > > _3100);
static  monty::rc_ptr< ::mosek::fusion::RangeDomain > inRange(double _3102,double _3103);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(monty::rc_ptr< ::mosek::fusion::Matrix > _3104);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _3105,std::shared_ptr< monty::ndarray< int,1 > > _3106);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,2 > > _3107);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(std::shared_ptr< monty::ndarray< double,1 > > _3110);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _3111,std::shared_ptr< monty::ndarray< int,1 > > _3112);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _3114,int _3115,int _3116);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _3118,int _3119);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > greaterThan(double _3121);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(monty::rc_ptr< ::mosek::fusion::Matrix > _3122);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _3123,std::shared_ptr< monty::ndarray< int,1 > > _3124);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,2 > > _3125);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(std::shared_ptr< monty::ndarray< double,1 > > _3128);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _3129,std::shared_ptr< monty::ndarray< int,1 > > _3130);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _3131,int _3132,int _3133);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _3134,int _3135);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > lessThan(double _3136);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(monty::rc_ptr< ::mosek::fusion::Matrix > _3137);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _3138,std::shared_ptr< monty::ndarray< int,1 > > _3139);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,2 > > _3140);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(std::shared_ptr< monty::ndarray< double,1 > > _3143);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _3144,std::shared_ptr< monty::ndarray< int,1 > > _3145);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _3146,int _3147,int _3148);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _3149,int _3150);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > equalsTo(double _3151);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(std::shared_ptr< monty::ndarray< int,1 > > _3152);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _3154,int _3155);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded(int _3156);
static  monty::rc_ptr< ::mosek::fusion::LinearDomain > unbounded();
}; // struct Domain;

struct p_ExprCode
{
ExprCode * _pubthis;
static mosek::fusion::p_ExprCode* _get_impl(mosek::fusion::ExprCode * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ExprCode * _get_impl(mosek::fusion::ExprCode::t _inst) { return _get_impl(_inst.get()); }
p_ExprCode(ExprCode * _pubthis);
virtual ~p_ExprCode() { /* std::cout << "~p_ExprCode" << std::endl;*/ };
virtual void destroy();
static  void inplace_relocate(std::shared_ptr< monty::ndarray< int,1 > > _3157,int _3158,int _3159,int _3160);
static  std::string op2str(int _3162);
static  void eval_add_list(std::shared_ptr< monty::ndarray< int,1 > > _3163,std::shared_ptr< monty::ndarray< int,1 > > _3164,std::shared_ptr< monty::ndarray< double,1 > > _3165,int _3166,std::shared_ptr< monty::ndarray< double,1 > > _3167,std::shared_ptr< monty::ndarray< double,1 > > _3168,monty::rc_ptr< ::mosek::fusion::WorkStack > _3169);
static  void eval_add_list(std::shared_ptr< monty::ndarray< int,1 > > _3177,std::shared_ptr< monty::ndarray< int,1 > > _3178,std::shared_ptr< monty::ndarray< double,1 > > _3179,std::shared_ptr< monty::ndarray< double,1 > > _3180,std::shared_ptr< monty::ndarray< double,1 > > _3181,monty::rc_ptr< ::mosek::fusion::WorkStack > _3182);
static  int emit_sum(std::shared_ptr< monty::ndarray< int,1 > > _3183,int _3184,int _3185);
static  int emit_inv(std::shared_ptr< monty::ndarray< int,1 > > _3186,int _3187);
static  int emit_mul(std::shared_ptr< monty::ndarray< int,1 > > _3188,int _3189);
static  int emit_neg(std::shared_ptr< monty::ndarray< int,1 > > _3190,int _3191);
static  int emit_add(std::shared_ptr< monty::ndarray< int,1 > > _3192,int _3193);
static  int emit_constref(std::shared_ptr< monty::ndarray< int,1 > > _3194,int _3195,int _3196);
static  int emit_paramref(std::shared_ptr< monty::ndarray< int,1 > > _3197,int _3198,int _3199);
static  int emit_nop(std::shared_ptr< monty::ndarray< int,1 > > _3200,int _3201);
}; // struct ExprCode;

struct p_Param
{
Param * _pubthis;
static mosek::fusion::p_Param* _get_impl(mosek::fusion::Param * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Param * _get_impl(mosek::fusion::Param::t _inst) { return _get_impl(_inst.get()); }
p_Param(Param * _pubthis);
virtual ~p_Param() { /* std::cout << "~p_Param" << std::endl;*/ };
virtual void destroy();
static  monty::rc_ptr< ::mosek::fusion::Parameter > repeat(monty::rc_ptr< ::mosek::fusion::Parameter > _3210,int _3211,int _3212);
static  monty::rc_ptr< ::mosek::fusion::Parameter > stack(int _3214,monty::rc_ptr< ::mosek::fusion::Parameter > _3215,monty::rc_ptr< ::mosek::fusion::Parameter > _3216,monty::rc_ptr< ::mosek::fusion::Parameter > _3217);
static  monty::rc_ptr< ::mosek::fusion::Parameter > stack(int _3218,monty::rc_ptr< ::mosek::fusion::Parameter > _3219,monty::rc_ptr< ::mosek::fusion::Parameter > _3220);
static  monty::rc_ptr< ::mosek::fusion::Parameter > stack(int _3221,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3222);
static  monty::rc_ptr< ::mosek::fusion::Parameter > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > >,1 > > _3223);
static  monty::rc_ptr< ::mosek::fusion::Parameter > hstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3225,monty::rc_ptr< ::mosek::fusion::Parameter > _3226,monty::rc_ptr< ::mosek::fusion::Parameter > _3227);
static  monty::rc_ptr< ::mosek::fusion::Parameter > hstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3228,monty::rc_ptr< ::mosek::fusion::Parameter > _3229);
static  monty::rc_ptr< ::mosek::fusion::Parameter > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3230);
static  monty::rc_ptr< ::mosek::fusion::Parameter > vstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3231,monty::rc_ptr< ::mosek::fusion::Parameter > _3232,monty::rc_ptr< ::mosek::fusion::Parameter > _3233);
static  monty::rc_ptr< ::mosek::fusion::Parameter > vstack(monty::rc_ptr< ::mosek::fusion::Parameter > _3234,monty::rc_ptr< ::mosek::fusion::Parameter > _3235);
static  monty::rc_ptr< ::mosek::fusion::Parameter > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3236);
static  monty::rc_ptr< ::mosek::fusion::Parameter > dstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Parameter >,1 > > _3237,int _3238);
}; // struct Param;

struct p_ParameterImpl : public /*implements*/ virtual ::mosek::fusion::Parameter
{
ParameterImpl * _pubthis;
static mosek::fusion::p_ParameterImpl* _get_impl(mosek::fusion::ParameterImpl * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_ParameterImpl * _get_impl(mosek::fusion::ParameterImpl::t _inst) { return _get_impl(_inst.get()); }
p_ParameterImpl(ParameterImpl * _pubthis);
virtual ~p_ParameterImpl() { /* std::cout << "~p_ParameterImpl" << std::endl;*/ };
long long size{};std::shared_ptr< monty::ndarray< int,1 > > nidxs{};std::shared_ptr< monty::ndarray< long long,1 > > sp{};std::shared_ptr< monty::ndarray< int,1 > > shape{};monty::rc_ptr< ::mosek::fusion::Model > model{};virtual void destroy();
static ParameterImpl::t _new_ParameterImpl(monty::rc_ptr< ::mosek::fusion::ParameterImpl > _4027,monty::rc_ptr< ::mosek::fusion::Model > _4028);
void _initialize(monty::rc_ptr< ::mosek::fusion::ParameterImpl > _4027,monty::rc_ptr< ::mosek::fusion::Model > _4028);
static ParameterImpl::t _new_ParameterImpl(monty::rc_ptr< ::mosek::fusion::Model > _4029,std::shared_ptr< monty::ndarray< int,1 > > _4030,std::shared_ptr< monty::ndarray< long long,1 > > _4031,std::shared_ptr< monty::ndarray< int,1 > > _4032);
void _initialize(monty::rc_ptr< ::mosek::fusion::Model > _4029,std::shared_ptr< monty::ndarray< int,1 > > _4030,std::shared_ptr< monty::ndarray< long long,1 > > _4031,std::shared_ptr< monty::ndarray< int,1 > > _4032);
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2ParameterImpl__clone(monty::rc_ptr< ::mosek::fusion::Model > _4033) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Parameter__clone(monty::rc_ptr< ::mosek::fusion::Model > _4033) { return __mosek_2fusion_2ParameterImpl__clone(_4033); }
virtual /* override */ std::string toString() ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2ParameterImpl__pick(std::shared_ptr< monty::ndarray< int,2 > > _4036) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _4036) { return __mosek_2fusion_2ParameterImpl__pick(_4036); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2ParameterImpl__pick(std::shared_ptr< monty::ndarray< int,1 > > _4037) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _4037) { return __mosek_2fusion_2ParameterImpl__pick(_4037); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2ParameterImpl__index(std::shared_ptr< monty::ndarray< int,1 > > _4038) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _4038) { return __mosek_2fusion_2ParameterImpl__index(_4038); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2ParameterImpl__index(int _4047) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(int _4047) { return __mosek_2fusion_2ParameterImpl__index(_4047); }
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4049,monty::rc_ptr< ::mosek::fusion::WorkStack > _4050,monty::rc_ptr< ::mosek::fusion::WorkStack > _4051) ;
virtual void getSp(std::shared_ptr< monty::ndarray< long long,1 > > _4073,int _4074) ;
virtual bool isSparse() ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2ParameterImpl__slice(std::shared_ptr< monty::ndarray< int,1 > > _4077,std::shared_ptr< monty::ndarray< int,1 > > _4078) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Parameter__slice(std::shared_ptr< monty::ndarray< int,1 > > _4077,std::shared_ptr< monty::ndarray< int,1 > > _4078) { return __mosek_2fusion_2ParameterImpl__slice(_4077,_4078); }
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2ParameterImpl__slice(int _4110,int _4111) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Parameter__slice(int _4110,int _4111) { return __mosek_2fusion_2ParameterImpl__slice(_4110,_4111); }
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2ParameterImpl__reshape(std::shared_ptr< monty::ndarray< int,1 > > _4119) ;
virtual monty::rc_ptr< ::mosek::fusion::Parameter > __mosek_2fusion_2Parameter__reshape(std::shared_ptr< monty::ndarray< int,1 > > _4119) { return __mosek_2fusion_2ParameterImpl__reshape(_4119); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2ParameterImpl__asExpr() ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Parameter__asExpr() { return __mosek_2fusion_2ParameterImpl__asExpr(); }
virtual long long getSize() ;
virtual int getNumNonzero() ;
virtual int getND() ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual int getDim(int _4120) ;
virtual void getAllIndexes(std::shared_ptr< monty::ndarray< int,1 > > _4121,int _4122) ;
virtual int getIndex(int _4124) ;
virtual std::shared_ptr< monty::ndarray< double,1 > > getValue() ;
virtual void setValue(std::shared_ptr< monty::ndarray< double,2 > > _4125) ;
virtual void setValue(std::shared_ptr< monty::ndarray< double,1 > > _4131) ;
virtual void setValue(double _4134) ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2ParameterImpl__getModel() ;
virtual monty::rc_ptr< ::mosek::fusion::Model > __mosek_2fusion_2Parameter__getModel() { return __mosek_2fusion_2ParameterImpl__getModel(); }
}; // struct ParameterImpl;

struct p_BaseExpression : public /*implements*/ virtual ::mosek::fusion::Expression
{
BaseExpression * _pubthis;
static mosek::fusion::p_BaseExpression* _get_impl(mosek::fusion::BaseExpression * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_BaseExpression * _get_impl(mosek::fusion::BaseExpression::t _inst) { return _get_impl(_inst.get()); }
p_BaseExpression(BaseExpression * _pubthis);
virtual ~p_BaseExpression() { /* std::cout << "~p_BaseExpression" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static BaseExpression::t _new_BaseExpression(std::shared_ptr< monty::ndarray< int,1 > > _6754);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _6754);
virtual /* override */ std::string toString() ;
virtual void printStack(monty::rc_ptr< ::mosek::fusion::WorkStack > _6755) ;
virtual void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6781,monty::rc_ptr< ::mosek::fusion::WorkStack > _6782,monty::rc_ptr< ::mosek::fusion::WorkStack > _6783) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,2 > > _6784) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,2 > > _6784) { return __mosek_2fusion_2BaseExpression__pick(_6784); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__pick(std::shared_ptr< monty::ndarray< int,1 > > _6785) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__pick(std::shared_ptr< monty::ndarray< int,1 > > _6785) { return __mosek_2fusion_2BaseExpression__pick(_6785); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(std::shared_ptr< monty::ndarray< int,1 > > _6788) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(std::shared_ptr< monty::ndarray< int,1 > > _6788) { return __mosek_2fusion_2BaseExpression__index(_6788); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__index(int _6791) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__index(int _6791) { return __mosek_2fusion_2BaseExpression__index(_6791); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _6793,std::shared_ptr< monty::ndarray< int,1 > > _6794) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(std::shared_ptr< monty::ndarray< int,1 > > _6793,std::shared_ptr< monty::ndarray< int,1 > > _6794) { return __mosek_2fusion_2BaseExpression__slice(_6793,_6794); }
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(int _6795,int _6796) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2Expression__slice(int _6795,int _6796) { return __mosek_2fusion_2BaseExpression__slice(_6795,_6796); }
virtual long long getSize() ;
virtual int getND() ;
virtual int getDim(int _6797) ;
virtual std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
}; // struct BaseExpression;

struct p_ExprParameter : public ::mosek::fusion::p_BaseExpression
{
ExprParameter * _pubthis;
static mosek::fusion::p_ExprParameter* _get_impl(mosek::fusion::ExprParameter * _inst){ return static_cast< mosek::fusion::p_ExprParameter* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprParameter * _get_impl(mosek::fusion::ExprParameter::t _inst) { return _get_impl(_inst.get()); }
p_ExprParameter(ExprParameter * _pubthis);
virtual ~p_ExprParameter() { /* std::cout << "~p_ExprParameter" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprParameter::t _new_ExprParameter(monty::rc_ptr< ::mosek::fusion::Parameter > _3202);
void _initialize(monty::rc_ptr< ::mosek::fusion::Parameter > _3202);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3203,monty::rc_ptr< ::mosek::fusion::WorkStack > _3204,monty::rc_ptr< ::mosek::fusion::WorkStack > _3205) ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2ExprParameter__slice(std::shared_ptr< monty::ndarray< int,1 > > _3206,std::shared_ptr< monty::ndarray< int,1 > > _3207) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(std::shared_ptr< monty::ndarray< int,1 > > _3206,std::shared_ptr< monty::ndarray< int,1 > > _3207) { return __mosek_2fusion_2ExprParameter__slice(_3206,_3207); }
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2ExprParameter__slice(int _3208,int _3209) ;
virtual monty::rc_ptr< ::mosek::fusion::Expression > __mosek_2fusion_2BaseExpression__slice(int _3208,int _3209) { return __mosek_2fusion_2ExprParameter__slice(_3208,_3209); }
virtual /* override */ std::string toString() ;
}; // struct ExprParameter;

struct p_ExprMulParamScalarExpr : public ::mosek::fusion::p_BaseExpression
{
ExprMulParamScalarExpr * _pubthis;
static mosek::fusion::p_ExprMulParamScalarExpr* _get_impl(mosek::fusion::ExprMulParamScalarExpr * _inst){ return static_cast< mosek::fusion::p_ExprMulParamScalarExpr* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulParamScalarExpr * _get_impl(mosek::fusion::ExprMulParamScalarExpr::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulParamScalarExpr(ExprMulParamScalarExpr * _pubthis);
virtual ~p_ExprMulParamScalarExpr() { /* std::cout << "~p_ExprMulParamScalarExpr" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprMulParamScalarExpr::t _new_ExprMulParamScalarExpr(monty::rc_ptr< ::mosek::fusion::Parameter > _3297,monty::rc_ptr< ::mosek::fusion::Expression > _3298);
void _initialize(monty::rc_ptr< ::mosek::fusion::Parameter > _3297,monty::rc_ptr< ::mosek::fusion::Expression > _3298);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3299,monty::rc_ptr< ::mosek::fusion::WorkStack > _3300,monty::rc_ptr< ::mosek::fusion::WorkStack > _3301) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulParamScalarExpr;

struct p_ExprMulParamScalar : public ::mosek::fusion::p_BaseExpression
{
ExprMulParamScalar * _pubthis;
static mosek::fusion::p_ExprMulParamScalar* _get_impl(mosek::fusion::ExprMulParamScalar * _inst){ return static_cast< mosek::fusion::p_ExprMulParamScalar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulParamScalar * _get_impl(mosek::fusion::ExprMulParamScalar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulParamScalar(ExprMulParamScalar * _pubthis);
virtual ~p_ExprMulParamScalar() { /* std::cout << "~p_ExprMulParamScalar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprMulParamScalar::t _new_ExprMulParamScalar(monty::rc_ptr< ::mosek::fusion::Parameter > _3352,monty::rc_ptr< ::mosek::fusion::Expression > _3353);
void _initialize(monty::rc_ptr< ::mosek::fusion::Parameter > _3352,monty::rc_ptr< ::mosek::fusion::Expression > _3353);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3354,monty::rc_ptr< ::mosek::fusion::WorkStack > _3355,monty::rc_ptr< ::mosek::fusion::WorkStack > _3356) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulParamScalar;

struct p_ExprMulParamDiagLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulParamDiagLeft * _pubthis;
static mosek::fusion::p_ExprMulParamDiagLeft* _get_impl(mosek::fusion::ExprMulParamDiagLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulParamDiagLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulParamDiagLeft * _get_impl(mosek::fusion::ExprMulParamDiagLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulParamDiagLeft(ExprMulParamDiagLeft * _pubthis);
virtual ~p_ExprMulParamDiagLeft() { /* std::cout << "~p_ExprMulParamDiagLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprMulParamDiagLeft::t _new_ExprMulParamDiagLeft(monty::rc_ptr< ::mosek::fusion::Parameter > _3399,monty::rc_ptr< ::mosek::fusion::Expression > _3400);
void _initialize(monty::rc_ptr< ::mosek::fusion::Parameter > _3399,monty::rc_ptr< ::mosek::fusion::Expression > _3400);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3401,monty::rc_ptr< ::mosek::fusion::WorkStack > _3402,monty::rc_ptr< ::mosek::fusion::WorkStack > _3403) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulParamDiagLeft;

struct p_ExprMulParamDiagRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulParamDiagRight * _pubthis;
static mosek::fusion::p_ExprMulParamDiagRight* _get_impl(mosek::fusion::ExprMulParamDiagRight * _inst){ return static_cast< mosek::fusion::p_ExprMulParamDiagRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulParamDiagRight * _get_impl(mosek::fusion::ExprMulParamDiagRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulParamDiagRight(ExprMulParamDiagRight * _pubthis);
virtual ~p_ExprMulParamDiagRight() { /* std::cout << "~p_ExprMulParamDiagRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprMulParamDiagRight::t _new_ExprMulParamDiagRight(monty::rc_ptr< ::mosek::fusion::Expression > _3518,monty::rc_ptr< ::mosek::fusion::Parameter > _3519);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3518,monty::rc_ptr< ::mosek::fusion::Parameter > _3519);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3520,monty::rc_ptr< ::mosek::fusion::WorkStack > _3521,monty::rc_ptr< ::mosek::fusion::WorkStack > _3522) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulParamDiagRight;

struct p_ExprDotParam : public ::mosek::fusion::p_BaseExpression
{
ExprDotParam * _pubthis;
static mosek::fusion::p_ExprDotParam* _get_impl(mosek::fusion::ExprDotParam * _inst){ return static_cast< mosek::fusion::p_ExprDotParam* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDotParam * _get_impl(mosek::fusion::ExprDotParam::t _inst) { return _get_impl(_inst.get()); }
p_ExprDotParam(ExprDotParam * _pubthis);
virtual ~p_ExprDotParam() { /* std::cout << "~p_ExprDotParam" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprDotParam::t _new_ExprDotParam(monty::rc_ptr< ::mosek::fusion::Parameter > _3636,monty::rc_ptr< ::mosek::fusion::Expression > _3637);
void _initialize(monty::rc_ptr< ::mosek::fusion::Parameter > _3636,monty::rc_ptr< ::mosek::fusion::Expression > _3637);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3639,monty::rc_ptr< ::mosek::fusion::WorkStack > _3640,monty::rc_ptr< ::mosek::fusion::WorkStack > _3641) ;
virtual /* override */ std::string toString() ;
}; // struct ExprDotParam;

struct p_ExprMulParamElem : public ::mosek::fusion::p_BaseExpression
{
ExprMulParamElem * _pubthis;
static mosek::fusion::p_ExprMulParamElem* _get_impl(mosek::fusion::ExprMulParamElem * _inst){ return static_cast< mosek::fusion::p_ExprMulParamElem* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulParamElem * _get_impl(mosek::fusion::ExprMulParamElem::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulParamElem(ExprMulParamElem * _pubthis);
virtual ~p_ExprMulParamElem() { /* std::cout << "~p_ExprMulParamElem" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprMulParamElem::t _new_ExprMulParamElem(monty::rc_ptr< ::mosek::fusion::Parameter > _3699,monty::rc_ptr< ::mosek::fusion::Expression > _3700);
void _initialize(monty::rc_ptr< ::mosek::fusion::Parameter > _3699,monty::rc_ptr< ::mosek::fusion::Expression > _3700);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3702,monty::rc_ptr< ::mosek::fusion::WorkStack > _3703,monty::rc_ptr< ::mosek::fusion::WorkStack > _3704) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulParamElem;

struct p_ExprMulParamRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulParamRight * _pubthis;
static mosek::fusion::p_ExprMulParamRight* _get_impl(mosek::fusion::ExprMulParamRight * _inst){ return static_cast< mosek::fusion::p_ExprMulParamRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulParamRight * _get_impl(mosek::fusion::ExprMulParamRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulParamRight(ExprMulParamRight * _pubthis);
virtual ~p_ExprMulParamRight() { /* std::cout << "~p_ExprMulParamRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprMulParamRight::t _new_ExprMulParamRight(monty::rc_ptr< ::mosek::fusion::Expression > _3766,monty::rc_ptr< ::mosek::fusion::Parameter > _3767);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _3766,monty::rc_ptr< ::mosek::fusion::Parameter > _3767);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3768,monty::rc_ptr< ::mosek::fusion::WorkStack > _3769,monty::rc_ptr< ::mosek::fusion::WorkStack > _3770) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulParamRight;

struct p_ExprMulParamLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulParamLeft * _pubthis;
static mosek::fusion::p_ExprMulParamLeft* _get_impl(mosek::fusion::ExprMulParamLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulParamLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulParamLeft * _get_impl(mosek::fusion::ExprMulParamLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulParamLeft(ExprMulParamLeft * _pubthis);
virtual ~p_ExprMulParamLeft() { /* std::cout << "~p_ExprMulParamLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};monty::rc_ptr< ::mosek::fusion::Parameter > p{};virtual void destroy();
static ExprMulParamLeft::t _new_ExprMulParamLeft(monty::rc_ptr< ::mosek::fusion::Parameter > _3870,monty::rc_ptr< ::mosek::fusion::Expression > _3871);
void _initialize(monty::rc_ptr< ::mosek::fusion::Parameter > _3870,monty::rc_ptr< ::mosek::fusion::Expression > _3871);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _3872,monty::rc_ptr< ::mosek::fusion::WorkStack > _3873,monty::rc_ptr< ::mosek::fusion::WorkStack > _3874) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulParamLeft;

struct p_ExprOptimizeCode : public ::mosek::fusion::p_BaseExpression
{
ExprOptimizeCode * _pubthis;
static mosek::fusion::p_ExprOptimizeCode* _get_impl(mosek::fusion::ExprOptimizeCode * _inst){ return static_cast< mosek::fusion::p_ExprOptimizeCode* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprOptimizeCode * _get_impl(mosek::fusion::ExprOptimizeCode::t _inst) { return _get_impl(_inst.get()); }
p_ExprOptimizeCode(ExprOptimizeCode * _pubthis);
virtual ~p_ExprOptimizeCode() { /* std::cout << "~p_ExprOptimizeCode" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprOptimizeCode::t _new_ExprOptimizeCode(monty::rc_ptr< ::mosek::fusion::Expression > _4151);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4151);
static  void compress_code(monty::rc_ptr< ::mosek::fusion::WorkStack > _4152,int _4153,std::shared_ptr< monty::ndarray< int,1 > > _4154,int _4155,std::shared_ptr< monty::ndarray< int,1 > > _4156,int _4157,std::shared_ptr< monty::ndarray< double,1 > > _4158,int _4159,std::shared_ptr< monty::ndarray< double,1 > > _4160,int _4161,int _4162,int _4163,int _4164);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4217,monty::rc_ptr< ::mosek::fusion::WorkStack > _4218,monty::rc_ptr< ::mosek::fusion::WorkStack > _4219) ;
virtual /* override */ std::string toString() ;
}; // struct ExprOptimizeCode;

struct p_ExprCompress : public ::mosek::fusion::p_BaseExpression
{
ExprCompress * _pubthis;
static mosek::fusion::p_ExprCompress* _get_impl(mosek::fusion::ExprCompress * _inst){ return static_cast< mosek::fusion::p_ExprCompress* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCompress * _get_impl(mosek::fusion::ExprCompress::t _inst) { return _get_impl(_inst.get()); }
p_ExprCompress(ExprCompress * _pubthis);
virtual ~p_ExprCompress() { /* std::cout << "~p_ExprCompress" << std::endl;*/ };
double eps{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4286);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4286);
static ExprCompress::t _new_ExprCompress(monty::rc_ptr< ::mosek::fusion::Expression > _4287,double _4288);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4287,double _4288);
static  void arg_sort(monty::rc_ptr< ::mosek::fusion::WorkStack > _4289,monty::rc_ptr< ::mosek::fusion::WorkStack > _4290,int _4291,int _4292,int _4293,int _4294,int _4295);
static  void merge_sort(int _4331,int _4332,int _4333,int _4334,int _4335,int _4336,std::shared_ptr< monty::ndarray< int,1 > > _4337,std::shared_ptr< monty::ndarray< long long,1 > > _4338);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4361,monty::rc_ptr< ::mosek::fusion::WorkStack > _4362,monty::rc_ptr< ::mosek::fusion::WorkStack > _4363) ;
virtual /* override */ std::string toString() ;
}; // struct ExprCompress;

struct p_ExprConst : public ::mosek::fusion::p_BaseExpression
{
ExprConst * _pubthis;
static mosek::fusion::p_ExprConst* _get_impl(mosek::fusion::ExprConst * _inst){ return static_cast< mosek::fusion::p_ExprConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprConst * _get_impl(mosek::fusion::ExprConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprConst(ExprConst * _pubthis);
virtual ~p_ExprConst() { /* std::cout << "~p_ExprConst" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > sparsity{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};virtual void destroy();
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _4445,std::shared_ptr< monty::ndarray< long long,1 > > _4446,std::shared_ptr< monty::ndarray< double,1 > > _4447);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4445,std::shared_ptr< monty::ndarray< long long,1 > > _4446,std::shared_ptr< monty::ndarray< double,1 > > _4447);
static ExprConst::t _new_ExprConst(std::shared_ptr< monty::ndarray< int,1 > > _4448,std::shared_ptr< monty::ndarray< long long,1 > > _4449,double _4450);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4448,std::shared_ptr< monty::ndarray< long long,1 > > _4449,double _4450);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4453,monty::rc_ptr< ::mosek::fusion::WorkStack > _4454,monty::rc_ptr< ::mosek::fusion::WorkStack > _4455) ;
static  void validate(std::shared_ptr< monty::ndarray< int,1 > > _4474,std::shared_ptr< monty::ndarray< double,1 > > _4475,std::shared_ptr< monty::ndarray< long long,1 > > _4476);
virtual /* override */ std::string toString() ;
}; // struct ExprConst;

struct p_ExprPick : public ::mosek::fusion::p_BaseExpression
{
ExprPick * _pubthis;
static mosek::fusion::p_ExprPick* _get_impl(mosek::fusion::ExprPick * _inst){ return static_cast< mosek::fusion::p_ExprPick* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPick * _get_impl(mosek::fusion::ExprPick::t _inst) { return _get_impl(_inst.get()); }
p_ExprPick(ExprPick * _pubthis);
virtual ~p_ExprPick() { /* std::cout << "~p_ExprPick" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > idxs{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _4480,std::shared_ptr< monty::ndarray< int,2 > > _4481);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4480,std::shared_ptr< monty::ndarray< int,2 > > _4481);
static ExprPick::t _new_ExprPick(monty::rc_ptr< ::mosek::fusion::Expression > _4493,std::shared_ptr< monty::ndarray< long long,1 > > _4494);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4493,std::shared_ptr< monty::ndarray< long long,1 > > _4494);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4499,monty::rc_ptr< ::mosek::fusion::WorkStack > _4500,monty::rc_ptr< ::mosek::fusion::WorkStack > _4501) ;
virtual /* override */ std::string toString() ;
}; // struct ExprPick;

struct p_ExprSlice : public ::mosek::fusion::p_BaseExpression
{
ExprSlice * _pubthis;
static mosek::fusion::p_ExprSlice* _get_impl(mosek::fusion::ExprSlice * _inst){ return static_cast< mosek::fusion::p_ExprSlice* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSlice * _get_impl(mosek::fusion::ExprSlice::t _inst) { return _get_impl(_inst.get()); }
p_ExprSlice(ExprSlice * _pubthis);
virtual ~p_ExprSlice() { /* std::cout << "~p_ExprSlice" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > last{};std::shared_ptr< monty::ndarray< int,1 > > first{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSlice::t _new_ExprSlice(monty::rc_ptr< ::mosek::fusion::Expression > _4566,std::shared_ptr< monty::ndarray< int,1 > > _4567,std::shared_ptr< monty::ndarray< int,1 > > _4568);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4566,std::shared_ptr< monty::ndarray< int,1 > > _4567,std::shared_ptr< monty::ndarray< int,1 > > _4568);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4569,monty::rc_ptr< ::mosek::fusion::WorkStack > _4570,monty::rc_ptr< ::mosek::fusion::WorkStack > _4571) ;
static  std::shared_ptr< monty::ndarray< int,1 > > makeShape(std::shared_ptr< monty::ndarray< int,1 > > _4636,std::shared_ptr< monty::ndarray< int,1 > > _4637,std::shared_ptr< monty::ndarray< int,1 > > _4638);
virtual /* override */ std::string toString() ;
}; // struct ExprSlice;

struct p_ExprPermuteDims : public ::mosek::fusion::p_BaseExpression
{
ExprPermuteDims * _pubthis;
static mosek::fusion::p_ExprPermuteDims* _get_impl(mosek::fusion::ExprPermuteDims * _inst){ return static_cast< mosek::fusion::p_ExprPermuteDims* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprPermuteDims * _get_impl(mosek::fusion::ExprPermuteDims::t _inst) { return _get_impl(_inst.get()); }
p_ExprPermuteDims(ExprPermuteDims * _pubthis);
virtual ~p_ExprPermuteDims() { /* std::cout << "~p_ExprPermuteDims" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > dperm{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _4643,monty::rc_ptr< ::mosek::fusion::Expression > _4644);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4643,monty::rc_ptr< ::mosek::fusion::Expression > _4644);
static ExprPermuteDims::t _new_ExprPermuteDims(std::shared_ptr< monty::ndarray< int,1 > > _4650,monty::rc_ptr< ::mosek::fusion::Expression > _4651,int _4652);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _4650,monty::rc_ptr< ::mosek::fusion::Expression > _4651,int _4652);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4653,monty::rc_ptr< ::mosek::fusion::WorkStack > _4654,monty::rc_ptr< ::mosek::fusion::WorkStack > _4655) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(std::shared_ptr< monty::ndarray< int,1 > > _4709,std::shared_ptr< monty::ndarray< int,1 > > _4710);
}; // struct ExprPermuteDims;

struct p_ExprTranspose : public ::mosek::fusion::p_BaseExpression
{
ExprTranspose * _pubthis;
static mosek::fusion::p_ExprTranspose* _get_impl(mosek::fusion::ExprTranspose * _inst){ return static_cast< mosek::fusion::p_ExprTranspose* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprTranspose * _get_impl(mosek::fusion::ExprTranspose::t _inst) { return _get_impl(_inst.get()); }
p_ExprTranspose(ExprTranspose * _pubthis);
virtual ~p_ExprTranspose() { /* std::cout << "~p_ExprTranspose" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprTranspose::t _new_ExprTranspose(monty::rc_ptr< ::mosek::fusion::Expression > _4712);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4712);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4713,monty::rc_ptr< ::mosek::fusion::WorkStack > _4714,monty::rc_ptr< ::mosek::fusion::WorkStack > _4715) ;
virtual /* override */ std::string toString() ;
static  std::shared_ptr< monty::ndarray< int,1 > > transposeShape(std::shared_ptr< monty::ndarray< int,1 > > _4768);
}; // struct ExprTranspose;

struct p_ExprRepeat : public ::mosek::fusion::p_BaseExpression
{
ExprRepeat * _pubthis;
static mosek::fusion::p_ExprRepeat* _get_impl(mosek::fusion::ExprRepeat * _inst){ return static_cast< mosek::fusion::p_ExprRepeat* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprRepeat * _get_impl(mosek::fusion::ExprRepeat::t _inst) { return _get_impl(_inst.get()); }
p_ExprRepeat(ExprRepeat * _pubthis);
virtual ~p_ExprRepeat() { /* std::cout << "~p_ExprRepeat" << std::endl;*/ };
int n{};int dim{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprRepeat::t _new_ExprRepeat(monty::rc_ptr< ::mosek::fusion::Expression > _4769,int _4770,int _4771);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _4769,int _4770,int _4771);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4772,monty::rc_ptr< ::mosek::fusion::WorkStack > _4773,monty::rc_ptr< ::mosek::fusion::WorkStack > _4774) ;
static  std::shared_ptr< monty::ndarray< int,1 > > getshape(monty::rc_ptr< ::mosek::fusion::Expression > _4839,int _4840,int _4841);
virtual /* override */ std::string toString() ;
}; // struct ExprRepeat;

struct p_ExprStack : public ::mosek::fusion::p_BaseExpression
{
ExprStack * _pubthis;
static mosek::fusion::p_ExprStack* _get_impl(mosek::fusion::ExprStack * _inst){ return static_cast< mosek::fusion::p_ExprStack* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprStack * _get_impl(mosek::fusion::ExprStack::t _inst) { return _get_impl(_inst.get()); }
p_ExprStack(ExprStack * _pubthis);
virtual ~p_ExprStack() { /* std::cout << "~p_ExprStack" << std::endl;*/ };
int dim{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > exprs{};virtual void destroy();
static ExprStack::t _new_ExprStack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4846,int _4847);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4846,int _4847);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _4849,monty::rc_ptr< ::mosek::fusion::WorkStack > _4850,monty::rc_ptr< ::mosek::fusion::WorkStack > _4851) ;
static  std::shared_ptr< monty::ndarray< int,1 > > getshape(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _4995,int _4996);
virtual /* override */ std::string toString() ;
}; // struct ExprStack;

struct p_ExprInner : public ::mosek::fusion::p_BaseExpression
{
ExprInner * _pubthis;
static mosek::fusion::p_ExprInner* _get_impl(mosek::fusion::ExprInner * _inst){ return static_cast< mosek::fusion::p_ExprInner* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprInner * _get_impl(mosek::fusion::ExprInner::t _inst) { return _get_impl(_inst.get()); }
p_ExprInner(ExprInner * _pubthis);
virtual ~p_ExprInner() { /* std::cout << "~p_ExprInner" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > vcof{};std::shared_ptr< monty::ndarray< long long,1 > > vsub{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _5010,std::shared_ptr< monty::ndarray< long long,1 > > _5011,std::shared_ptr< monty::ndarray< double,1 > > _5012);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _5010,std::shared_ptr< monty::ndarray< long long,1 > > _5011,std::shared_ptr< monty::ndarray< double,1 > > _5012);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _5018,std::shared_ptr< monty::ndarray< double,1 > > _5019);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _5018,std::shared_ptr< monty::ndarray< double,1 > > _5019);
static ExprInner::t _new_ExprInner(monty::rc_ptr< ::mosek::fusion::Expression > _5021,std::shared_ptr< monty::ndarray< int,2 > > _5022,std::shared_ptr< monty::ndarray< double,1 > > _5023);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _5021,std::shared_ptr< monty::ndarray< int,2 > > _5022,std::shared_ptr< monty::ndarray< double,1 > > _5023);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5024,monty::rc_ptr< ::mosek::fusion::WorkStack > _5025,monty::rc_ptr< ::mosek::fusion::WorkStack > _5026) ;
static  std::shared_ptr< monty::ndarray< long long,1 > > range(int _5070);
static  std::shared_ptr< monty::ndarray< long long,1 > > convert(std::shared_ptr< monty::ndarray< int,1 > > _5072,std::shared_ptr< monty::ndarray< int,2 > > _5073);
virtual /* override */ std::string toString() ;
}; // struct ExprInner;

struct p_ExprMulDiagRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagRight * _pubthis;
static mosek::fusion::p_ExprMulDiagRight* _get_impl(mosek::fusion::ExprMulDiagRight * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagRight * _get_impl(mosek::fusion::ExprMulDiagRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagRight(ExprMulDiagRight * _pubthis);
virtual ~p_ExprMulDiagRight() { /* std::cout << "~p_ExprMulDiagRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _5080,int _5081,std::shared_ptr< monty::ndarray< int,1 > > _5082,std::shared_ptr< monty::ndarray< int,1 > > _5083,std::shared_ptr< monty::ndarray< double,1 > > _5084,monty::rc_ptr< ::mosek::fusion::Expression > _5085,int _5086);
void _initialize(int _5080,int _5081,std::shared_ptr< monty::ndarray< int,1 > > _5082,std::shared_ptr< monty::ndarray< int,1 > > _5083,std::shared_ptr< monty::ndarray< double,1 > > _5084,monty::rc_ptr< ::mosek::fusion::Expression > _5085,int _5086);
static ExprMulDiagRight::t _new_ExprMulDiagRight(int _5087,int _5088,std::shared_ptr< monty::ndarray< int,1 > > _5089,std::shared_ptr< monty::ndarray< int,1 > > _5090,std::shared_ptr< monty::ndarray< double,1 > > _5091,monty::rc_ptr< ::mosek::fusion::Expression > _5092);
void _initialize(int _5087,int _5088,std::shared_ptr< monty::ndarray< int,1 > > _5089,std::shared_ptr< monty::ndarray< int,1 > > _5090,std::shared_ptr< monty::ndarray< double,1 > > _5091,monty::rc_ptr< ::mosek::fusion::Expression > _5092);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5093,monty::rc_ptr< ::mosek::fusion::WorkStack > _5094,monty::rc_ptr< ::mosek::fusion::WorkStack > _5095) ;
static  int validate(int _5174,int _5175,std::shared_ptr< monty::ndarray< int,1 > > _5176,std::shared_ptr< monty::ndarray< int,1 > > _5177,std::shared_ptr< monty::ndarray< double,1 > > _5178,monty::rc_ptr< ::mosek::fusion::Expression > _5179);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagRight;

struct p_ExprMulDiagLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulDiagLeft * _pubthis;
static mosek::fusion::p_ExprMulDiagLeft* _get_impl(mosek::fusion::ExprMulDiagLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulDiagLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulDiagLeft * _get_impl(mosek::fusion::ExprMulDiagLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulDiagLeft(ExprMulDiagLeft * _pubthis);
virtual ~p_ExprMulDiagLeft() { /* std::cout << "~p_ExprMulDiagLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _5188,int _5189,std::shared_ptr< monty::ndarray< int,1 > > _5190,std::shared_ptr< monty::ndarray< int,1 > > _5191,std::shared_ptr< monty::ndarray< double,1 > > _5192,monty::rc_ptr< ::mosek::fusion::Expression > _5193,int _5194);
void _initialize(int _5188,int _5189,std::shared_ptr< monty::ndarray< int,1 > > _5190,std::shared_ptr< monty::ndarray< int,1 > > _5191,std::shared_ptr< monty::ndarray< double,1 > > _5192,monty::rc_ptr< ::mosek::fusion::Expression > _5193,int _5194);
static ExprMulDiagLeft::t _new_ExprMulDiagLeft(int _5195,int _5196,std::shared_ptr< monty::ndarray< int,1 > > _5197,std::shared_ptr< monty::ndarray< int,1 > > _5198,std::shared_ptr< monty::ndarray< double,1 > > _5199,monty::rc_ptr< ::mosek::fusion::Expression > _5200);
void _initialize(int _5195,int _5196,std::shared_ptr< monty::ndarray< int,1 > > _5197,std::shared_ptr< monty::ndarray< int,1 > > _5198,std::shared_ptr< monty::ndarray< double,1 > > _5199,monty::rc_ptr< ::mosek::fusion::Expression > _5200);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5201,monty::rc_ptr< ::mosek::fusion::WorkStack > _5202,monty::rc_ptr< ::mosek::fusion::WorkStack > _5203) ;
static  int validate(int _5301,int _5302,std::shared_ptr< monty::ndarray< int,1 > > _5303,std::shared_ptr< monty::ndarray< int,1 > > _5304,std::shared_ptr< monty::ndarray< double,1 > > _5305,monty::rc_ptr< ::mosek::fusion::Expression > _5306);
virtual /* override */ std::string toString() ;
}; // struct ExprMulDiagLeft;

struct p_ExprMulElement : public ::mosek::fusion::p_BaseExpression
{
ExprMulElement * _pubthis;
static mosek::fusion::p_ExprMulElement* _get_impl(mosek::fusion::ExprMulElement * _inst){ return static_cast< mosek::fusion::p_ExprMulElement* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulElement * _get_impl(mosek::fusion::ExprMulElement::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulElement(ExprMulElement * _pubthis);
virtual ~p_ExprMulElement() { /* std::cout << "~p_ExprMulElement" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< long long,1 > > msp{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};virtual void destroy();
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _5315,std::shared_ptr< monty::ndarray< long long,1 > > _5316,monty::rc_ptr< ::mosek::fusion::Expression > _5317);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _5315,std::shared_ptr< monty::ndarray< long long,1 > > _5316,monty::rc_ptr< ::mosek::fusion::Expression > _5317);
static ExprMulElement::t _new_ExprMulElement(std::shared_ptr< monty::ndarray< double,1 > > _5324,std::shared_ptr< monty::ndarray< long long,1 > > _5325,monty::rc_ptr< ::mosek::fusion::Expression > _5326,int _5327);
void _initialize(std::shared_ptr< monty::ndarray< double,1 > > _5324,std::shared_ptr< monty::ndarray< long long,1 > > _5325,monty::rc_ptr< ::mosek::fusion::Expression > _5326,int _5327);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5328,monty::rc_ptr< ::mosek::fusion::WorkStack > _5329,monty::rc_ptr< ::mosek::fusion::WorkStack > _5330) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulElement;

struct p_ExprMulScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarConst * _pubthis;
static mosek::fusion::p_ExprMulScalarConst* _get_impl(mosek::fusion::ExprMulScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarConst * _get_impl(mosek::fusion::ExprMulScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarConst(ExprMulScalarConst * _pubthis);
virtual ~p_ExprMulScalarConst() { /* std::cout << "~p_ExprMulScalarConst" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};double c{};virtual void destroy();
static ExprMulScalarConst::t _new_ExprMulScalarConst(double _5388,monty::rc_ptr< ::mosek::fusion::Expression > _5389);
void _initialize(double _5388,monty::rc_ptr< ::mosek::fusion::Expression > _5389);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5390,monty::rc_ptr< ::mosek::fusion::WorkStack > _5391,monty::rc_ptr< ::mosek::fusion::WorkStack > _5392) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarConst;

struct p_ExprScalarMul : public ::mosek::fusion::p_BaseExpression
{
ExprScalarMul * _pubthis;
static mosek::fusion::p_ExprScalarMul* _get_impl(mosek::fusion::ExprScalarMul * _inst){ return static_cast< mosek::fusion::p_ExprScalarMul* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprScalarMul * _get_impl(mosek::fusion::ExprScalarMul::t _inst) { return _get_impl(_inst.get()); }
p_ExprScalarMul(ExprScalarMul * _pubthis);
virtual ~p_ExprScalarMul() { /* std::cout << "~p_ExprScalarMul" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprScalarMul::t _new_ExprScalarMul(int _5429,int _5430,std::shared_ptr< monty::ndarray< int,1 > > _5431,std::shared_ptr< monty::ndarray< int,1 > > _5432,std::shared_ptr< monty::ndarray< double,1 > > _5433,monty::rc_ptr< ::mosek::fusion::Expression > _5434,int _5435);
void _initialize(int _5429,int _5430,std::shared_ptr< monty::ndarray< int,1 > > _5431,std::shared_ptr< monty::ndarray< int,1 > > _5432,std::shared_ptr< monty::ndarray< double,1 > > _5433,monty::rc_ptr< ::mosek::fusion::Expression > _5434,int _5435);
static ExprScalarMul::t _new_ExprScalarMul(int _5436,int _5437,std::shared_ptr< monty::ndarray< int,1 > > _5438,std::shared_ptr< monty::ndarray< int,1 > > _5439,std::shared_ptr< monty::ndarray< double,1 > > _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441);
void _initialize(int _5436,int _5437,std::shared_ptr< monty::ndarray< int,1 > > _5438,std::shared_ptr< monty::ndarray< int,1 > > _5439,std::shared_ptr< monty::ndarray< double,1 > > _5440,monty::rc_ptr< ::mosek::fusion::Expression > _5441);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5442,monty::rc_ptr< ::mosek::fusion::WorkStack > _5443,monty::rc_ptr< ::mosek::fusion::WorkStack > _5444) ;
static  int validate(int _5480,int _5481,std::shared_ptr< monty::ndarray< int,1 > > _5482,std::shared_ptr< monty::ndarray< int,1 > > _5483,std::shared_ptr< monty::ndarray< double,1 > > _5484,monty::rc_ptr< ::mosek::fusion::Expression > _5485);
virtual /* override */ std::string toString() ;
}; // struct ExprScalarMul;

struct p_ExprMulRight : public ::mosek::fusion::p_BaseExpression
{
ExprMulRight * _pubthis;
static mosek::fusion::p_ExprMulRight* _get_impl(mosek::fusion::ExprMulRight * _inst){ return static_cast< mosek::fusion::p_ExprMulRight* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulRight * _get_impl(mosek::fusion::ExprMulRight::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulRight(ExprMulRight * _pubthis);
virtual ~p_ExprMulRight() { /* std::cout << "~p_ExprMulRight" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulRight::t _new_ExprMulRight(int _5492,int _5493,std::shared_ptr< monty::ndarray< int,1 > > _5494,std::shared_ptr< monty::ndarray< int,1 > > _5495,std::shared_ptr< monty::ndarray< double,1 > > _5496,monty::rc_ptr< ::mosek::fusion::Expression > _5497,int _5498);
void _initialize(int _5492,int _5493,std::shared_ptr< monty::ndarray< int,1 > > _5494,std::shared_ptr< monty::ndarray< int,1 > > _5495,std::shared_ptr< monty::ndarray< double,1 > > _5496,monty::rc_ptr< ::mosek::fusion::Expression > _5497,int _5498);
static ExprMulRight::t _new_ExprMulRight(int _5499,int _5500,std::shared_ptr< monty::ndarray< int,1 > > _5501,std::shared_ptr< monty::ndarray< int,1 > > _5502,std::shared_ptr< monty::ndarray< double,1 > > _5503,monty::rc_ptr< ::mosek::fusion::Expression > _5504);
void _initialize(int _5499,int _5500,std::shared_ptr< monty::ndarray< int,1 > > _5501,std::shared_ptr< monty::ndarray< int,1 > > _5502,std::shared_ptr< monty::ndarray< double,1 > > _5503,monty::rc_ptr< ::mosek::fusion::Expression > _5504);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5505,monty::rc_ptr< ::mosek::fusion::WorkStack > _5506,monty::rc_ptr< ::mosek::fusion::WorkStack > _5507) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _5651,std::shared_ptr< monty::ndarray< int,1 > > _5652);
static  int validate(int _5653,int _5654,std::shared_ptr< monty::ndarray< int,1 > > _5655,std::shared_ptr< monty::ndarray< int,1 > > _5656,std::shared_ptr< monty::ndarray< double,1 > > _5657,monty::rc_ptr< ::mosek::fusion::Expression > _5658);
virtual /* override */ std::string toString() ;
}; // struct ExprMulRight;

struct p_ExprMulLeft : public ::mosek::fusion::p_BaseExpression
{
ExprMulLeft * _pubthis;
static mosek::fusion::p_ExprMulLeft* _get_impl(mosek::fusion::ExprMulLeft * _inst){ return static_cast< mosek::fusion::p_ExprMulLeft* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulLeft * _get_impl(mosek::fusion::ExprMulLeft::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulLeft(ExprMulLeft * _pubthis);
virtual ~p_ExprMulLeft() { /* std::cout << "~p_ExprMulLeft" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};std::shared_ptr< monty::ndarray< double,1 > > mval{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdim1{};int mdim0{};virtual void destroy();
static ExprMulLeft::t _new_ExprMulLeft(int _5667,int _5668,std::shared_ptr< monty::ndarray< int,1 > > _5669,std::shared_ptr< monty::ndarray< int,1 > > _5670,std::shared_ptr< monty::ndarray< double,1 > > _5671,monty::rc_ptr< ::mosek::fusion::Expression > _5672,int _5673);
void _initialize(int _5667,int _5668,std::shared_ptr< monty::ndarray< int,1 > > _5669,std::shared_ptr< monty::ndarray< int,1 > > _5670,std::shared_ptr< monty::ndarray< double,1 > > _5671,monty::rc_ptr< ::mosek::fusion::Expression > _5672,int _5673);
static ExprMulLeft::t _new_ExprMulLeft(int _5674,int _5675,std::shared_ptr< monty::ndarray< int,1 > > _5676,std::shared_ptr< monty::ndarray< int,1 > > _5677,std::shared_ptr< monty::ndarray< double,1 > > _5678,monty::rc_ptr< ::mosek::fusion::Expression > _5679);
void _initialize(int _5674,int _5675,std::shared_ptr< monty::ndarray< int,1 > > _5676,std::shared_ptr< monty::ndarray< int,1 > > _5677,std::shared_ptr< monty::ndarray< double,1 > > _5678,monty::rc_ptr< ::mosek::fusion::Expression > _5679);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5680,monty::rc_ptr< ::mosek::fusion::WorkStack > _5681,monty::rc_ptr< ::mosek::fusion::WorkStack > _5682) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeshape(int _5784,int _5785,std::shared_ptr< monty::ndarray< int,1 > > _5786);
static  int validate(int _5787,int _5788,std::shared_ptr< monty::ndarray< int,1 > > _5789,std::shared_ptr< monty::ndarray< int,1 > > _5790,std::shared_ptr< monty::ndarray< double,1 > > _5791,monty::rc_ptr< ::mosek::fusion::Expression > _5792);
virtual /* override */ std::string toString() ;
}; // struct ExprMulLeft;

struct p_ExprMulVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulVar * _pubthis;
static mosek::fusion::p_ExprMulVar* _get_impl(mosek::fusion::ExprMulVar * _inst){ return static_cast< mosek::fusion::p_ExprMulVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVar * _get_impl(mosek::fusion::ExprMulVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVar(ExprMulVar * _pubthis);
virtual ~p_ExprMulVar() { /* std::cout << "~p_ExprMulVar" << std::endl;*/ };
bool left{};monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulVar::t _new_ExprMulVar(bool _5800,int _5801,int _5802,std::shared_ptr< monty::ndarray< int,1 > > _5803,std::shared_ptr< monty::ndarray< int,1 > > _5804,std::shared_ptr< monty::ndarray< double,1 > > _5805,monty::rc_ptr< ::mosek::fusion::Variable > _5806);
void _initialize(bool _5800,int _5801,int _5802,std::shared_ptr< monty::ndarray< int,1 > > _5803,std::shared_ptr< monty::ndarray< int,1 > > _5804,std::shared_ptr< monty::ndarray< double,1 > > _5805,monty::rc_ptr< ::mosek::fusion::Variable > _5806);
static ExprMulVar::t _new_ExprMulVar(bool _5809,int _5810,int _5811,std::shared_ptr< monty::ndarray< int,1 > > _5812,std::shared_ptr< monty::ndarray< int,1 > > _5813,std::shared_ptr< monty::ndarray< double,1 > > _5814,monty::rc_ptr< ::mosek::fusion::Variable > _5815,int _5816);
void _initialize(bool _5809,int _5810,int _5811,std::shared_ptr< monty::ndarray< int,1 > > _5812,std::shared_ptr< monty::ndarray< int,1 > > _5813,std::shared_ptr< monty::ndarray< double,1 > > _5814,monty::rc_ptr< ::mosek::fusion::Variable > _5815,int _5816);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _5817,monty::rc_ptr< ::mosek::fusion::WorkStack > _5818,monty::rc_ptr< ::mosek::fusion::WorkStack > _5819) ;
virtual void eval_right(monty::rc_ptr< ::mosek::fusion::WorkStack > _5820,monty::rc_ptr< ::mosek::fusion::WorkStack > _5821,monty::rc_ptr< ::mosek::fusion::WorkStack > _5822) ;
virtual void eval_left(monty::rc_ptr< ::mosek::fusion::WorkStack > _5927,monty::rc_ptr< ::mosek::fusion::WorkStack > _5928,monty::rc_ptr< ::mosek::fusion::WorkStack > _5929) ;
virtual void validate(int _6002,int _6003,std::shared_ptr< monty::ndarray< int,1 > > _6004,std::shared_ptr< monty::ndarray< int,1 > > _6005,std::shared_ptr< monty::ndarray< double,1 > > _6006) ;
static  std::shared_ptr< monty::ndarray< int,1 > > resshape(int _6010,int _6011,std::shared_ptr< monty::ndarray< int,1 > > _6012,bool _6013);
virtual /* override */ std::string toString() ;
}; // struct ExprMulVar;

struct p_ExprMulScalarVar : public ::mosek::fusion::p_BaseExpression
{
ExprMulScalarVar * _pubthis;
static mosek::fusion::p_ExprMulScalarVar* _get_impl(mosek::fusion::ExprMulScalarVar * _inst){ return static_cast< mosek::fusion::p_ExprMulScalarVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulScalarVar * _get_impl(mosek::fusion::ExprMulScalarVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulScalarVar(ExprMulScalarVar * _pubthis);
virtual ~p_ExprMulScalarVar() { /* std::cout << "~p_ExprMulScalarVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};std::shared_ptr< monty::ndarray< double,1 > > mcof{};std::shared_ptr< monty::ndarray< int,1 > > msubj{};std::shared_ptr< monty::ndarray< int,1 > > msubi{};int mdimj{};int mdimi{};virtual void destroy();
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _6014,int _6015,std::shared_ptr< monty::ndarray< int,1 > > _6016,std::shared_ptr< monty::ndarray< int,1 > > _6017,std::shared_ptr< monty::ndarray< double,1 > > _6018,monty::rc_ptr< ::mosek::fusion::Variable > _6019);
void _initialize(int _6014,int _6015,std::shared_ptr< monty::ndarray< int,1 > > _6016,std::shared_ptr< monty::ndarray< int,1 > > _6017,std::shared_ptr< monty::ndarray< double,1 > > _6018,monty::rc_ptr< ::mosek::fusion::Variable > _6019);
static ExprMulScalarVar::t _new_ExprMulScalarVar(int _6024,int _6025,std::shared_ptr< monty::ndarray< int,1 > > _6026,std::shared_ptr< monty::ndarray< int,1 > > _6027,std::shared_ptr< monty::ndarray< double,1 > > _6028,monty::rc_ptr< ::mosek::fusion::Variable > _6029,int _6030);
void _initialize(int _6024,int _6025,std::shared_ptr< monty::ndarray< int,1 > > _6026,std::shared_ptr< monty::ndarray< int,1 > > _6027,std::shared_ptr< monty::ndarray< double,1 > > _6028,monty::rc_ptr< ::mosek::fusion::Variable > _6029,int _6030);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6031,monty::rc_ptr< ::mosek::fusion::WorkStack > _6032,monty::rc_ptr< ::mosek::fusion::WorkStack > _6033) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulScalarVar;

struct p_ExprMulVarScalarConst : public ::mosek::fusion::p_BaseExpression
{
ExprMulVarScalarConst * _pubthis;
static mosek::fusion::p_ExprMulVarScalarConst* _get_impl(mosek::fusion::ExprMulVarScalarConst * _inst){ return static_cast< mosek::fusion::p_ExprMulVarScalarConst* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprMulVarScalarConst * _get_impl(mosek::fusion::ExprMulVarScalarConst::t _inst) { return _get_impl(_inst.get()); }
p_ExprMulVarScalarConst(ExprMulVarScalarConst * _pubthis);
virtual ~p_ExprMulVarScalarConst() { /* std::cout << "~p_ExprMulVarScalarConst" << std::endl;*/ };
double c{};monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprMulVarScalarConst::t _new_ExprMulVarScalarConst(monty::rc_ptr< ::mosek::fusion::Variable > _6050,double _6051);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _6050,double _6051);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6052,monty::rc_ptr< ::mosek::fusion::WorkStack > _6053,monty::rc_ptr< ::mosek::fusion::WorkStack > _6054) ;
virtual /* override */ std::string toString() ;
}; // struct ExprMulVarScalarConst;

struct p_ExprAdd : public ::mosek::fusion::p_BaseExpression
{
ExprAdd * _pubthis;
static mosek::fusion::p_ExprAdd* _get_impl(mosek::fusion::ExprAdd * _inst){ return static_cast< mosek::fusion::p_ExprAdd* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprAdd * _get_impl(mosek::fusion::ExprAdd::t _inst) { return _get_impl(_inst.get()); }
p_ExprAdd(ExprAdd * _pubthis);
virtual ~p_ExprAdd() { /* std::cout << "~p_ExprAdd" << std::endl;*/ };
double m2{};double m1{};monty::rc_ptr< ::mosek::fusion::Expression > e2{};monty::rc_ptr< ::mosek::fusion::Expression > e1{};virtual void destroy();
static ExprAdd::t _new_ExprAdd(monty::rc_ptr< ::mosek::fusion::Expression > _6071,monty::rc_ptr< ::mosek::fusion::Expression > _6072,double _6073,double _6074);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _6071,monty::rc_ptr< ::mosek::fusion::Expression > _6072,double _6073,double _6074);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6076,monty::rc_ptr< ::mosek::fusion::WorkStack > _6077,monty::rc_ptr< ::mosek::fusion::WorkStack > _6078) ;
virtual /* override */ std::string toString() ;
}; // struct ExprAdd;

struct p_ExprWSum : public ::mosek::fusion::p_BaseExpression
{
ExprWSum * _pubthis;
static mosek::fusion::p_ExprWSum* _get_impl(mosek::fusion::ExprWSum * _inst){ return static_cast< mosek::fusion::p_ExprWSum* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprWSum * _get_impl(mosek::fusion::ExprWSum::t _inst) { return _get_impl(_inst.get()); }
p_ExprWSum(ExprWSum * _pubthis);
virtual ~p_ExprWSum() { /* std::cout << "~p_ExprWSum" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > w{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > es{};virtual void destroy();
static ExprWSum::t _new_ExprWSum(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _6212,std::shared_ptr< monty::ndarray< double,1 > > _6213);
void _initialize(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _6212,std::shared_ptr< monty::ndarray< double,1 > > _6213);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6220,monty::rc_ptr< ::mosek::fusion::WorkStack > _6221,monty::rc_ptr< ::mosek::fusion::WorkStack > _6222) ;
virtual /* override */ std::string toString() ;
}; // struct ExprWSum;

struct p_ExprSumReduce : public ::mosek::fusion::p_BaseExpression
{
ExprSumReduce * _pubthis;
static mosek::fusion::p_ExprSumReduce* _get_impl(mosek::fusion::ExprSumReduce * _inst){ return static_cast< mosek::fusion::p_ExprSumReduce* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSumReduce * _get_impl(mosek::fusion::ExprSumReduce::t _inst) { return _get_impl(_inst.get()); }
p_ExprSumReduce(ExprSumReduce * _pubthis);
virtual ~p_ExprSumReduce() { /* std::cout << "~p_ExprSumReduce" << std::endl;*/ };
int dim{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSumReduce::t _new_ExprSumReduce(int _6316,monty::rc_ptr< ::mosek::fusion::Expression > _6317);
void _initialize(int _6316,monty::rc_ptr< ::mosek::fusion::Expression > _6317);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6319,monty::rc_ptr< ::mosek::fusion::WorkStack > _6320,monty::rc_ptr< ::mosek::fusion::WorkStack > _6321) ;
static  std::shared_ptr< monty::ndarray< int,1 > > computeShape(int _6437,std::shared_ptr< monty::ndarray< int,1 > > _6438);
virtual /* override */ std::string toString() ;
}; // struct ExprSumReduce;

struct p_ExprDenseTril : public ::mosek::fusion::p_BaseExpression
{
ExprDenseTril * _pubthis;
static mosek::fusion::p_ExprDenseTril* _get_impl(mosek::fusion::ExprDenseTril * _inst){ return static_cast< mosek::fusion::p_ExprDenseTril* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDenseTril * _get_impl(mosek::fusion::ExprDenseTril::t _inst) { return _get_impl(_inst.get()); }
p_ExprDenseTril(ExprDenseTril * _pubthis);
virtual ~p_ExprDenseTril() { /* std::cout << "~p_ExprDenseTril" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDenseTril::t _new_ExprDenseTril(int _6442,int _6443,monty::rc_ptr< ::mosek::fusion::Expression > _6444,int _6445);
void _initialize(int _6442,int _6443,monty::rc_ptr< ::mosek::fusion::Expression > _6444,int _6445);
static ExprDenseTril::t _new_ExprDenseTril(int _6446,int _6447,monty::rc_ptr< ::mosek::fusion::Expression > _6448);
void _initialize(int _6446,int _6447,monty::rc_ptr< ::mosek::fusion::Expression > _6448);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6450,monty::rc_ptr< ::mosek::fusion::WorkStack > _6451,monty::rc_ptr< ::mosek::fusion::WorkStack > _6452) ;
virtual /* override */ std::string toString() ;
}; // struct ExprDenseTril;

struct p_ExprDense : public ::mosek::fusion::p_BaseExpression
{
ExprDense * _pubthis;
static mosek::fusion::p_ExprDense* _get_impl(mosek::fusion::ExprDense * _inst){ return static_cast< mosek::fusion::p_ExprDense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprDense * _get_impl(mosek::fusion::ExprDense::t _inst) { return _get_impl(_inst.get()); }
p_ExprDense(ExprDense * _pubthis);
virtual ~p_ExprDense() { /* std::cout << "~p_ExprDense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprDense::t _new_ExprDense(monty::rc_ptr< ::mosek::fusion::Expression > _6536);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _6536);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6537,monty::rc_ptr< ::mosek::fusion::WorkStack > _6538,monty::rc_ptr< ::mosek::fusion::WorkStack > _6539) ;
virtual /* override */ std::string toString() ;
}; // struct ExprDense;

struct p_ExprSymmetrize : public ::mosek::fusion::p_BaseExpression
{
ExprSymmetrize * _pubthis;
static mosek::fusion::p_ExprSymmetrize* _get_impl(mosek::fusion::ExprSymmetrize * _inst){ return static_cast< mosek::fusion::p_ExprSymmetrize* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprSymmetrize * _get_impl(mosek::fusion::ExprSymmetrize::t _inst) { return _get_impl(_inst.get()); }
p_ExprSymmetrize(ExprSymmetrize * _pubthis);
virtual ~p_ExprSymmetrize() { /* std::cout << "~p_ExprSymmetrize" << std::endl;*/ };
int dim1{};int dim0{};monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprSymmetrize::t _new_ExprSymmetrize(int _6580,int _6581,monty::rc_ptr< ::mosek::fusion::Expression > _6582,int _6583);
void _initialize(int _6580,int _6581,monty::rc_ptr< ::mosek::fusion::Expression > _6582,int _6583);
static ExprSymmetrize::t _new_ExprSymmetrize(int _6584,int _6585,monty::rc_ptr< ::mosek::fusion::Expression > _6586);
void _initialize(int _6584,int _6585,monty::rc_ptr< ::mosek::fusion::Expression > _6586);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6588,monty::rc_ptr< ::mosek::fusion::WorkStack > _6589,monty::rc_ptr< ::mosek::fusion::WorkStack > _6590) ;
virtual /* override */ std::string toString() ;
}; // struct ExprSymmetrize;

struct p_ExprCondense : public ::mosek::fusion::p_BaseExpression
{
ExprCondense * _pubthis;
static mosek::fusion::p_ExprCondense* _get_impl(mosek::fusion::ExprCondense * _inst){ return static_cast< mosek::fusion::p_ExprCondense* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprCondense * _get_impl(mosek::fusion::ExprCondense::t _inst) { return _get_impl(_inst.get()); }
p_ExprCondense(ExprCondense * _pubthis);
virtual ~p_ExprCondense() { /* std::cout << "~p_ExprCondense" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > expr{};virtual void destroy();
static ExprCondense::t _new_ExprCondense(monty::rc_ptr< ::mosek::fusion::Expression > _6714);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _6714);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6715,monty::rc_ptr< ::mosek::fusion::WorkStack > _6716,monty::rc_ptr< ::mosek::fusion::WorkStack > _6717) ;
virtual /* override */ std::string toString() ;
}; // struct ExprCondense;

struct p_ExprFromVar : public ::mosek::fusion::p_BaseExpression
{
ExprFromVar * _pubthis;
static mosek::fusion::p_ExprFromVar* _get_impl(mosek::fusion::ExprFromVar * _inst){ return static_cast< mosek::fusion::p_ExprFromVar* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprFromVar * _get_impl(mosek::fusion::ExprFromVar::t _inst) { return _get_impl(_inst.get()); }
p_ExprFromVar(ExprFromVar * _pubthis);
virtual ~p_ExprFromVar() { /* std::cout << "~p_ExprFromVar" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Variable > x{};virtual void destroy();
static ExprFromVar::t _new_ExprFromVar(monty::rc_ptr< ::mosek::fusion::Variable > _6721);
void _initialize(monty::rc_ptr< ::mosek::fusion::Variable > _6721);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6722,monty::rc_ptr< ::mosek::fusion::WorkStack > _6723,monty::rc_ptr< ::mosek::fusion::WorkStack > _6724) ;
virtual /* override */ std::string toString() ;
}; // struct ExprFromVar;

struct p_ExprReshape : public ::mosek::fusion::p_BaseExpression
{
ExprReshape * _pubthis;
static mosek::fusion::p_ExprReshape* _get_impl(mosek::fusion::ExprReshape * _inst){ return static_cast< mosek::fusion::p_ExprReshape* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_ExprReshape * _get_impl(mosek::fusion::ExprReshape::t _inst) { return _get_impl(_inst.get()); }
p_ExprReshape(ExprReshape * _pubthis);
virtual ~p_ExprReshape() { /* std::cout << "~p_ExprReshape" << std::endl;*/ };
monty::rc_ptr< ::mosek::fusion::Expression > e{};virtual void destroy();
static ExprReshape::t _new_ExprReshape(std::shared_ptr< monty::ndarray< int,1 > > _6741,monty::rc_ptr< ::mosek::fusion::Expression > _6742);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _6741,monty::rc_ptr< ::mosek::fusion::Expression > _6742);
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _6744,monty::rc_ptr< ::mosek::fusion::WorkStack > _6745,monty::rc_ptr< ::mosek::fusion::WorkStack > _6746) ;
virtual /* override */ std::string toString() ;
}; // struct ExprReshape;

struct p_Expr : public ::mosek::fusion::p_BaseExpression
{
Expr * _pubthis;
static mosek::fusion::p_Expr* _get_impl(mosek::fusion::Expr * _inst){ return static_cast< mosek::fusion::p_Expr* >(mosek::fusion::p_BaseExpression::_get_impl(_inst)); }
static mosek::fusion::p_Expr * _get_impl(mosek::fusion::Expr::t _inst) { return _get_impl(_inst.get()); }
p_Expr(Expr * _pubthis);
virtual ~p_Expr() { /* std::cout << "~p_Expr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< double,1 > > cof_v{};std::shared_ptr< monty::ndarray< long long,1 > > subj{};std::shared_ptr< monty::ndarray< long long,1 > > ptrb{};std::shared_ptr< monty::ndarray< double,1 > > bfix{};std::shared_ptr< monty::ndarray< int,1 > > shape{};virtual void destroy();
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _6888,std::shared_ptr< monty::ndarray< long long,1 > > _6889,std::shared_ptr< monty::ndarray< double,1 > > _6890,std::shared_ptr< monty::ndarray< double,1 > > _6891,std::shared_ptr< monty::ndarray< int,1 > > _6892,std::shared_ptr< monty::ndarray< long long,1 > > _6893);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _6888,std::shared_ptr< monty::ndarray< long long,1 > > _6889,std::shared_ptr< monty::ndarray< double,1 > > _6890,std::shared_ptr< monty::ndarray< double,1 > > _6891,std::shared_ptr< monty::ndarray< int,1 > > _6892,std::shared_ptr< monty::ndarray< long long,1 > > _6893);
static Expr::t _new_Expr(std::shared_ptr< monty::ndarray< long long,1 > > _6904,std::shared_ptr< monty::ndarray< long long,1 > > _6905,std::shared_ptr< monty::ndarray< double,1 > > _6906,std::shared_ptr< monty::ndarray< double,1 > > _6907,std::shared_ptr< monty::ndarray< int,1 > > _6908,std::shared_ptr< monty::ndarray< long long,1 > > _6909,int _6910);
void _initialize(std::shared_ptr< monty::ndarray< long long,1 > > _6904,std::shared_ptr< monty::ndarray< long long,1 > > _6905,std::shared_ptr< monty::ndarray< double,1 > > _6906,std::shared_ptr< monty::ndarray< double,1 > > _6907,std::shared_ptr< monty::ndarray< int,1 > > _6908,std::shared_ptr< monty::ndarray< long long,1 > > _6909,int _6910);
static Expr::t _new_Expr(monty::rc_ptr< ::mosek::fusion::Expression > _6911);
void _initialize(monty::rc_ptr< ::mosek::fusion::Expression > _6911);
virtual long long prod(std::shared_ptr< monty::ndarray< int,1 > > _6936) ;
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > >,1 > > _6939);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > varstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6942,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6943);
static  monty::rc_ptr< ::mosek::fusion::Expression > condense(monty::rc_ptr< ::mosek::fusion::Expression > _6947);
static  monty::rc_ptr< ::mosek::fusion::Expression > flatten(monty::rc_ptr< ::mosek::fusion::Expression > _6948);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _6950,int _6951,int _6952);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _6953,int _6954);
static  monty::rc_ptr< ::mosek::fusion::Expression > reshape(monty::rc_ptr< ::mosek::fusion::Expression > _6955,std::shared_ptr< monty::ndarray< int,1 > > _6956);
virtual long long size() ;
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(std::shared_ptr< monty::ndarray< int,1 > > _6957);
static  monty::rc_ptr< ::mosek::fusion::Expression > zeros(int _6958);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones();
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _6959,std::shared_ptr< monty::ndarray< int,2 > > _6960);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(std::shared_ptr< monty::ndarray< int,1 > > _6961);
static  monty::rc_ptr< ::mosek::fusion::Expression > ones(int _6962);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _6963);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(monty::rc_ptr< ::mosek::fusion::Matrix > _6964);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(double _6973);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _6974,std::shared_ptr< monty::ndarray< int,2 > > _6975,double _6976);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _6984,std::shared_ptr< monty::ndarray< int,2 > > _6985,std::shared_ptr< monty::ndarray< double,1 > > _6986);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< int,1 > > _6994,double _6995);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(int _6996,double _6997);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,2 > > _6999);
static  monty::rc_ptr< ::mosek::fusion::Expression > constTerm(std::shared_ptr< monty::ndarray< double,1 > > _7002);
virtual long long numNonzeros() ;
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _7003,int _7004);
static  monty::rc_ptr< ::mosek::fusion::Expression > sum(monty::rc_ptr< ::mosek::fusion::Expression > _7005);
static  monty::rc_ptr< ::mosek::fusion::Expression > neg(monty::rc_ptr< ::mosek::fusion::Expression > _7006);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(bool _7007,monty::rc_ptr< ::mosek::fusion::Matrix > _7008,monty::rc_ptr< ::mosek::fusion::Expression > _7009);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _7016,monty::rc_ptr< ::mosek::fusion::Parameter > _7017);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Parameter > _7018,monty::rc_ptr< ::mosek::fusion::Variable > _7019);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _7020,monty::rc_ptr< ::mosek::fusion::Parameter > _7021);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Parameter > _7022,monty::rc_ptr< ::mosek::fusion::Expression > _7023);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _7024,monty::rc_ptr< ::mosek::fusion::Matrix > _7025);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _7026,monty::rc_ptr< ::mosek::fusion::Variable > _7027);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _7028,monty::rc_ptr< ::mosek::fusion::Matrix > _7029);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Matrix > _7030,monty::rc_ptr< ::mosek::fusion::Expression > _7031);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Variable > _7032,std::shared_ptr< monty::ndarray< double,2 > > _7033);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(monty::rc_ptr< ::mosek::fusion::Expression > _7040,std::shared_ptr< monty::ndarray< double,2 > > _7041);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _7048,monty::rc_ptr< ::mosek::fusion::Variable > _7049);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulDiag(std::shared_ptr< monty::ndarray< double,2 > > _7056,monty::rc_ptr< ::mosek::fusion::Expression > _7057);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::Matrix > _7064,monty::rc_ptr< ::mosek::fusion::Expression > _7065);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(std::shared_ptr< monty::ndarray< double,1 > > _7074,monty::rc_ptr< ::mosek::fusion::Expression > _7075);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm_(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7077,monty::rc_ptr< ::mosek::fusion::Expression > _7078);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _7081,double _7082);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(double _7083,monty::rc_ptr< ::mosek::fusion::Expression > _7084);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _7085,std::shared_ptr< monty::ndarray< double,1 > > _7086);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,1 > > _7087,monty::rc_ptr< ::mosek::fusion::Expression > _7088);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _7089,std::shared_ptr< monty::ndarray< double,2 > > _7090);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(std::shared_ptr< monty::ndarray< double,2 > > _7091,monty::rc_ptr< ::mosek::fusion::Expression > _7092);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _7093,monty::rc_ptr< ::mosek::fusion::Matrix > _7094);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _7095,monty::rc_ptr< ::mosek::fusion::Expression > _7096);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _7097,std::shared_ptr< monty::ndarray< double,1 > > _7098,monty::rc_ptr< ::mosek::fusion::Expression > _7099);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _7114,std::shared_ptr< monty::ndarray< double,2 > > _7115,monty::rc_ptr< ::mosek::fusion::Expression > _7116);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _7131,monty::rc_ptr< ::mosek::fusion::Matrix > _7132,monty::rc_ptr< ::mosek::fusion::Expression > _7133);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Variable > _7142,monty::rc_ptr< ::mosek::fusion::Matrix > _7143);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Matrix > _7149,monty::rc_ptr< ::mosek::fusion::Variable > _7150);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(bool _7156,int _7157,int _7158,std::shared_ptr< monty::ndarray< int,1 > > _7159,std::shared_ptr< monty::ndarray< int,1 > > _7160,std::shared_ptr< monty::ndarray< double,1 > > _7161,monty::rc_ptr< ::mosek::fusion::Variable > _7162);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Expression > _7164,monty::rc_ptr< ::mosek::fusion::Parameter > _7165);
static  monty::rc_ptr< ::mosek::fusion::Expression > mul(monty::rc_ptr< ::mosek::fusion::Parameter > _7166,monty::rc_ptr< ::mosek::fusion::Expression > _7167);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _7168,monty::rc_ptr< ::mosek::fusion::Matrix > _7169);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _7177,std::shared_ptr< monty::ndarray< double,2 > > _7178);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _7182,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7183);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _7184,std::shared_ptr< monty::ndarray< double,1 > > _7185);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Matrix > _7190,monty::rc_ptr< ::mosek::fusion::Expression > _7191);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7192,monty::rc_ptr< ::mosek::fusion::Expression > _7193);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,2 > > _7194,monty::rc_ptr< ::mosek::fusion::Expression > _7195);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(std::shared_ptr< monty::ndarray< double,1 > > _7196,monty::rc_ptr< ::mosek::fusion::Expression > _7197);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Expression > _7198,monty::rc_ptr< ::mosek::fusion::Parameter > _7199);
static  monty::rc_ptr< ::mosek::fusion::Expression > dot(monty::rc_ptr< ::mosek::fusion::Parameter > _7200,monty::rc_ptr< ::mosek::fusion::Expression > _7201);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Matrix > _7202,monty::rc_ptr< ::mosek::fusion::Variable > _7203);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _7210,monty::rc_ptr< ::mosek::fusion::Matrix > _7211);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(std::shared_ptr< monty::ndarray< double,1 > > _7218,monty::rc_ptr< ::mosek::fusion::Variable > _7219);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer(monty::rc_ptr< ::mosek::fusion::Variable > _7221,std::shared_ptr< monty::ndarray< double,1 > > _7222);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(int _7224,std::shared_ptr< monty::ndarray< long long,1 > > _7225,std::shared_ptr< monty::ndarray< long long,1 > > _7226,std::shared_ptr< monty::ndarray< double,1 > > _7227,std::shared_ptr< monty::ndarray< double,1 > > _7228,std::shared_ptr< monty::ndarray< long long,1 > > _7229,std::shared_ptr< monty::ndarray< double,1 > > _7230,std::shared_ptr< monty::ndarray< int,1 > > _7231,int _7232,bool _7233);
static  monty::rc_ptr< ::mosek::fusion::Expression > outer_(monty::rc_ptr< ::mosek::fusion::Variable > _7263,int _7264,std::shared_ptr< monty::ndarray< double,1 > > _7265,std::shared_ptr< monty::ndarray< int,1 > > _7266,int _7267,bool _7268);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > >,1 > > _7285);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _7291,double _7292,double _7293);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _7294,double _7295,monty::rc_ptr< ::mosek::fusion::Expression > _7296);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _7297,monty::rc_ptr< ::mosek::fusion::Expression > _7298,double _7299);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _7300,monty::rc_ptr< ::mosek::fusion::Expression > _7301,monty::rc_ptr< ::mosek::fusion::Expression > _7302);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7303,double _7304,double _7305);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7306,double _7307,monty::rc_ptr< ::mosek::fusion::Expression > _7308);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7309,monty::rc_ptr< ::mosek::fusion::Expression > _7310,double _7311);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7312,monty::rc_ptr< ::mosek::fusion::Expression > _7313,monty::rc_ptr< ::mosek::fusion::Expression > _7314);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(double _7315,monty::rc_ptr< ::mosek::fusion::Expression > _7316);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7317,double _7318);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(monty::rc_ptr< ::mosek::fusion::Expression > _7319,monty::rc_ptr< ::mosek::fusion::Expression > _7320);
static  monty::rc_ptr< ::mosek::fusion::Expression > vstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7321);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7323,monty::rc_ptr< ::mosek::fusion::Expression > _7324,monty::rc_ptr< ::mosek::fusion::Expression > _7325);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7326,monty::rc_ptr< ::mosek::fusion::Expression > _7327,double _7328);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7329,double _7330,monty::rc_ptr< ::mosek::fusion::Expression > _7331);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7332,double _7333,double _7334);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _7335,monty::rc_ptr< ::mosek::fusion::Expression > _7336,monty::rc_ptr< ::mosek::fusion::Expression > _7337);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _7338,monty::rc_ptr< ::mosek::fusion::Expression > _7339,double _7340);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _7341,double _7342,monty::rc_ptr< ::mosek::fusion::Expression > _7343);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(double _7344,monty::rc_ptr< ::mosek::fusion::Expression > _7345);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7346,double _7347);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(monty::rc_ptr< ::mosek::fusion::Expression > _7348,monty::rc_ptr< ::mosek::fusion::Expression > _7349);
static  monty::rc_ptr< ::mosek::fusion::Expression > hstack(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7350);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7352,monty::rc_ptr< ::mosek::fusion::Expression > _7353,monty::rc_ptr< ::mosek::fusion::Expression > _7354,monty::rc_ptr< ::mosek::fusion::Expression > _7355);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7356,monty::rc_ptr< ::mosek::fusion::Expression > _7357,monty::rc_ptr< ::mosek::fusion::Expression > _7358,double _7359);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7360,monty::rc_ptr< ::mosek::fusion::Expression > _7361,double _7362,monty::rc_ptr< ::mosek::fusion::Expression > _7363);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7364,monty::rc_ptr< ::mosek::fusion::Expression > _7365,double _7366,double _7367);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7368,double _7369,monty::rc_ptr< ::mosek::fusion::Expression > _7370,monty::rc_ptr< ::mosek::fusion::Expression > _7371);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7372,double _7373,monty::rc_ptr< ::mosek::fusion::Expression > _7374,double _7375);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7376,double _7377,double _7378,monty::rc_ptr< ::mosek::fusion::Expression > _7379);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7380,double _7381,monty::rc_ptr< ::mosek::fusion::Expression > _7382);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7383,monty::rc_ptr< ::mosek::fusion::Expression > _7384,double _7385);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7386,monty::rc_ptr< ::mosek::fusion::Expression > _7387,monty::rc_ptr< ::mosek::fusion::Expression > _7388);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack(int _7389,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7390);
static  monty::rc_ptr< ::mosek::fusion::Expression > stack_(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7391,int _7392);
static  std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > promote(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7393,int _7394);
static  monty::rc_ptr< ::mosek::fusion::Expression > repeat(monty::rc_ptr< ::mosek::fusion::Variable > _7407,int _7408,int _7409);
static  monty::rc_ptr< ::mosek::fusion::Expression > repeat(monty::rc_ptr< ::mosek::fusion::Expression > _7410,int _7411,int _7412);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Expression >,1 > > _7415);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _7417);
static  monty::rc_ptr< ::mosek::fusion::Expression > add_(monty::rc_ptr< ::mosek::fusion::Expression > _7450,double _7451,monty::rc_ptr< ::mosek::fusion::Expression > _7452,double _7453);
static  monty::rc_ptr< ::mosek::fusion::Expression > transpose(monty::rc_ptr< ::mosek::fusion::Expression > _7464);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Matrix > _7465,monty::rc_ptr< ::mosek::fusion::Expression > _7466);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7467,monty::rc_ptr< ::mosek::fusion::Expression > _7468);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,2 > > _7469,monty::rc_ptr< ::mosek::fusion::Expression > _7470);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(std::shared_ptr< monty::ndarray< double,1 > > _7471,monty::rc_ptr< ::mosek::fusion::Expression > _7472);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7473,monty::rc_ptr< ::mosek::fusion::Matrix > _7474);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7475,std::shared_ptr< monty::ndarray< double,2 > > _7476);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7477,std::shared_ptr< monty::ndarray< double,1 > > _7478);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7479,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7480);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Parameter > _7481,monty::rc_ptr< ::mosek::fusion::Expression > _7482);
static  monty::rc_ptr< ::mosek::fusion::Expression > mulElm(monty::rc_ptr< ::mosek::fusion::Expression > _7483,monty::rc_ptr< ::mosek::fusion::Parameter > _7484);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7485,monty::rc_ptr< ::mosek::fusion::Expression > _7486);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _7487,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7488);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Matrix > _7489,monty::rc_ptr< ::mosek::fusion::Expression > _7490);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _7491,monty::rc_ptr< ::mosek::fusion::Matrix > _7492);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(double _7493,monty::rc_ptr< ::mosek::fusion::Expression > _7494);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _7495,double _7496);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,2 > > _7497,monty::rc_ptr< ::mosek::fusion::Expression > _7498);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(std::shared_ptr< monty::ndarray< double,1 > > _7499,monty::rc_ptr< ::mosek::fusion::Expression > _7500);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _7501,std::shared_ptr< monty::ndarray< double,2 > > _7502);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _7503,std::shared_ptr< monty::ndarray< double,1 > > _7504);
static  monty::rc_ptr< ::mosek::fusion::Expression > sub(monty::rc_ptr< ::mosek::fusion::Expression > _7505,monty::rc_ptr< ::mosek::fusion::Expression > _7506);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7507,monty::rc_ptr< ::mosek::fusion::Expression > _7508);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _7509,monty::rc_ptr< ::mosek::fusion::NDSparseArray > _7510);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Matrix > _7511,monty::rc_ptr< ::mosek::fusion::Expression > _7512);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _7513,monty::rc_ptr< ::mosek::fusion::Matrix > _7514);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(double _7515,monty::rc_ptr< ::mosek::fusion::Expression > _7516);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _7517,double _7518);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,2 > > _7519,monty::rc_ptr< ::mosek::fusion::Expression > _7520);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(std::shared_ptr< monty::ndarray< double,1 > > _7521,monty::rc_ptr< ::mosek::fusion::Expression > _7522);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _7523,std::shared_ptr< monty::ndarray< double,2 > > _7524);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _7525,std::shared_ptr< monty::ndarray< double,1 > > _7526);
static  monty::rc_ptr< ::mosek::fusion::Expression > add(monty::rc_ptr< ::mosek::fusion::Expression > _7527,monty::rc_ptr< ::mosek::fusion::Expression > _7528);
virtual /* override */ int getND() ;
virtual /* override */ std::shared_ptr< monty::ndarray< int,1 > > getShape() ;
virtual /* override */ void eval(monty::rc_ptr< ::mosek::fusion::WorkStack > _7529,monty::rc_ptr< ::mosek::fusion::WorkStack > _7530,monty::rc_ptr< ::mosek::fusion::WorkStack > _7531) ;
static  void validateData(std::shared_ptr< monty::ndarray< long long,1 > > _7547,std::shared_ptr< monty::ndarray< long long,1 > > _7548,std::shared_ptr< monty::ndarray< double,1 > > _7549,std::shared_ptr< monty::ndarray< double,1 > > _7550,std::shared_ptr< monty::ndarray< int,1 > > _7551,std::shared_ptr< monty::ndarray< long long,1 > > _7552);
static  monty::rc_ptr< ::mosek::fusion::Model > extractModel(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _7565);
}; // struct Expr;

struct p_WorkStack
{
WorkStack * _pubthis;
static mosek::fusion::p_WorkStack* _get_impl(mosek::fusion::WorkStack * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_WorkStack * _get_impl(mosek::fusion::WorkStack::t _inst) { return _get_impl(_inst.get()); }
p_WorkStack(WorkStack * _pubthis);
virtual ~p_WorkStack() { /* std::cout << "~p_WorkStack" << std::endl;*/ };
int code_base{};int cconst_base{};int codeptr_base{};int cof_base{};int nidxs_base{};int sp_base{};int shape_base{};int ptr_base{};bool hassp{};int ncodeatom{};int nelem{};int nnz{};int nd{};int pf64{};int pi64{};int pi32{};std::shared_ptr< monty::ndarray< double,1 > > f64{};std::shared_ptr< monty::ndarray< long long,1 > > i64{};std::shared_ptr< monty::ndarray< int,1 > > i32{};virtual void destroy();
static WorkStack::t _new_WorkStack();
void _initialize();
virtual std::string formatCurrent() ;
virtual bool peek_hassp() ;
virtual int peek_nnz() ;
virtual int peek_nelem() ;
virtual int peek_dim(int _6809) ;
virtual int peek_nd() ;
virtual void alloc_expr(int _6810,int _6811,int _6812,bool _6813) ;
virtual void alloc_expr(int _6814,int _6815,int _6816,bool _6817,int _6818) ;
virtual void pop_expr() ;
virtual void move_expr(monty::rc_ptr< ::mosek::fusion::WorkStack > _6819) ;
virtual void peek_expr() ;
virtual void ensure_sparsity() ;
virtual void clear() ;
virtual int allocf64(int _6834) ;
virtual int alloci64(int _6836) ;
virtual int alloci32(int _6838) ;
virtual void pushf64(double _6840) ;
virtual void pushi64(long long _6841) ;
virtual void pushi32(int _6842) ;
virtual void ensuref64(int _6843) ;
virtual void ensurei64(int _6846) ;
virtual void ensurei32(int _6849) ;
virtual int popf64(int _6852) ;
virtual int popi64(int _6853) ;
virtual int popi32(int _6854) ;
virtual void popf64(int _6855,std::shared_ptr< monty::ndarray< double,1 > > _6856,int _6857) ;
virtual void popi64(int _6858,std::shared_ptr< monty::ndarray< long long,1 > > _6859,int _6860) ;
virtual void popi32(int _6861,std::shared_ptr< monty::ndarray< int,1 > > _6862,int _6863) ;
virtual double popf64() ;
virtual long long popi64() ;
virtual int popi32() ;
virtual double peekf64() ;
virtual long long peeki64() ;
virtual int peeki32() ;
virtual double peekf64(int _6864) ;
virtual long long peeki64(int _6865) ;
virtual int peeki32(int _6866) ;
}; // struct WorkStack;

struct p_SymmetricExpr
{
SymmetricExpr * _pubthis;
static mosek::fusion::p_SymmetricExpr* _get_impl(mosek::fusion::SymmetricExpr * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricExpr * _get_impl(mosek::fusion::SymmetricExpr::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricExpr(SymmetricExpr * _pubthis);
virtual ~p_SymmetricExpr() { /* std::cout << "~p_SymmetricExpr" << std::endl;*/ };
std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > xs{};monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > b{};std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > Ms{};int n{};virtual void destroy();
static SymmetricExpr::t _new_SymmetricExpr(int _6867,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _6868,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6869,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6870);
void _initialize(int _6867,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::SymmetricMatrix >,1 > > _6868,std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Variable >,1 > > _6869,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6870);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6871,monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _6872);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > mul(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6873,double _6874);
static  monty::rc_ptr< ::mosek::fusion::SymmetricExpr > add(monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6876,monty::rc_ptr< ::mosek::fusion::SymmetricExpr > _6877);
virtual /* override */ std::string toString() ;
}; // struct SymmetricExpr;

struct p_SymmetricMatrix
{
SymmetricMatrix * _pubthis;
static mosek::fusion::p_SymmetricMatrix* _get_impl(mosek::fusion::SymmetricMatrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_SymmetricMatrix * _get_impl(mosek::fusion::SymmetricMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SymmetricMatrix(SymmetricMatrix * _pubthis);
virtual ~p_SymmetricMatrix() { /* std::cout << "~p_SymmetricMatrix" << std::endl;*/ };
int nnz{};double scale{};std::shared_ptr< monty::ndarray< double,1 > > vval{};std::shared_ptr< monty::ndarray< int,1 > > vsubj{};std::shared_ptr< monty::ndarray< int,1 > > vsubi{};std::shared_ptr< monty::ndarray< double,1 > > uval{};std::shared_ptr< monty::ndarray< int,1 > > usubj{};std::shared_ptr< monty::ndarray< int,1 > > usubi{};int d1{};int d0{};virtual void destroy();
static SymmetricMatrix::t _new_SymmetricMatrix(int _7578,int _7579,std::shared_ptr< monty::ndarray< int,1 > > _7580,std::shared_ptr< monty::ndarray< int,1 > > _7581,std::shared_ptr< monty::ndarray< double,1 > > _7582,std::shared_ptr< monty::ndarray< int,1 > > _7583,std::shared_ptr< monty::ndarray< int,1 > > _7584,std::shared_ptr< monty::ndarray< double,1 > > _7585,double _7586);
void _initialize(int _7578,int _7579,std::shared_ptr< monty::ndarray< int,1 > > _7580,std::shared_ptr< monty::ndarray< int,1 > > _7581,std::shared_ptr< monty::ndarray< double,1 > > _7582,std::shared_ptr< monty::ndarray< int,1 > > _7583,std::shared_ptr< monty::ndarray< int,1 > > _7584,std::shared_ptr< monty::ndarray< double,1 > > _7585,double _7586);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(int _7587,std::shared_ptr< monty::ndarray< int,1 > > _7588,std::shared_ptr< monty::ndarray< double,1 > > _7589);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > rankOne(std::shared_ptr< monty::ndarray< double,1 > > _7597);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > antiDiag(std::shared_ptr< monty::ndarray< double,1 > > _7605);
static  monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _7612);
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__add(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7618) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__sub(monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > _7638) ;
virtual monty::rc_ptr< ::mosek::fusion::SymmetricMatrix > __mosek_2fusion_2SymmetricMatrix__mul(double _7639) ;
virtual int getdim() ;
}; // struct SymmetricMatrix;

struct p_NDSparseArray
{
NDSparseArray * _pubthis;
static mosek::fusion::p_NDSparseArray* _get_impl(mosek::fusion::NDSparseArray * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_NDSparseArray * _get_impl(mosek::fusion::NDSparseArray::t _inst) { return _get_impl(_inst.get()); }
p_NDSparseArray(NDSparseArray * _pubthis);
virtual ~p_NDSparseArray() { /* std::cout << "~p_NDSparseArray" << std::endl;*/ };
std::shared_ptr< monty::ndarray< double,1 > > cof{};std::shared_ptr< monty::ndarray< long long,1 > > inst{};std::shared_ptr< monty::ndarray< int,1 > > dims{};long long size{};virtual void destroy();
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _7640,std::shared_ptr< monty::ndarray< int,2 > > _7641,std::shared_ptr< monty::ndarray< double,1 > > _7642);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _7640,std::shared_ptr< monty::ndarray< int,2 > > _7641,std::shared_ptr< monty::ndarray< double,1 > > _7642);
static NDSparseArray::t _new_NDSparseArray(std::shared_ptr< monty::ndarray< int,1 > > _7663,std::shared_ptr< monty::ndarray< long long,1 > > _7664,std::shared_ptr< monty::ndarray< double,1 > > _7665);
void _initialize(std::shared_ptr< monty::ndarray< int,1 > > _7663,std::shared_ptr< monty::ndarray< long long,1 > > _7664,std::shared_ptr< monty::ndarray< double,1 > > _7665);
static NDSparseArray::t _new_NDSparseArray(monty::rc_ptr< ::mosek::fusion::Matrix > _7681);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _7681);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(monty::rc_ptr< ::mosek::fusion::Matrix > _7689);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _7690,std::shared_ptr< monty::ndarray< long long,1 > > _7691,std::shared_ptr< monty::ndarray< double,1 > > _7692);
static  monty::rc_ptr< ::mosek::fusion::NDSparseArray > make(std::shared_ptr< monty::ndarray< int,1 > > _7693,std::shared_ptr< monty::ndarray< int,2 > > _7694,std::shared_ptr< monty::ndarray< double,1 > > _7695);
}; // struct NDSparseArray;

struct p_Matrix
{
Matrix * _pubthis;
static mosek::fusion::p_Matrix* _get_impl(mosek::fusion::Matrix * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Matrix * _get_impl(mosek::fusion::Matrix::t _inst) { return _get_impl(_inst.get()); }
p_Matrix(Matrix * _pubthis);
virtual ~p_Matrix() { /* std::cout << "~p_Matrix" << std::endl;*/ };
int dimj{};int dimi{};virtual void destroy();
static Matrix::t _new_Matrix(int _7765,int _7766);
void _initialize(int _7765,int _7766);
virtual /* override */ std::string toString() ;
virtual void switchDims() ;
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _7768,monty::rc_ptr< ::mosek::fusion::Matrix > _7769);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > > _7771);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _7789,double _7790,int _7791);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(int _7792,double _7793);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _7794,double _7795,int _7796);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(int _7797,double _7798);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _7799,int _7800);
static  monty::rc_ptr< ::mosek::fusion::Matrix > antidiag(std::shared_ptr< monty::ndarray< double,1 > > _7810);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _7811,int _7812);
static  monty::rc_ptr< ::mosek::fusion::Matrix > diag(std::shared_ptr< monty::ndarray< double,1 > > _7820);
static  monty::rc_ptr< ::mosek::fusion::Matrix > ones(int _7821,int _7822);
static  monty::rc_ptr< ::mosek::fusion::Matrix > eye(int _7823);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(monty::rc_ptr< ::mosek::fusion::Matrix > _7825);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _7826,int _7827,double _7828);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(int _7829,int _7830,std::shared_ptr< monty::ndarray< double,1 > > _7831);
static  monty::rc_ptr< ::mosek::fusion::Matrix > dense(std::shared_ptr< monty::ndarray< double,2 > > _7832);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(monty::rc_ptr< ::mosek::fusion::Matrix > _7833);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< std::shared_ptr< monty::ndarray< monty::rc_ptr< ::mosek::fusion::Matrix >,1 > >,1 > > _7837);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< double,2 > > _7868);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _7878,int _7879);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _7880,int _7881,std::shared_ptr< monty::ndarray< int,1 > > _7882,std::shared_ptr< monty::ndarray< int,1 > > _7883,double _7884);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _7886,std::shared_ptr< monty::ndarray< int,1 > > _7887,double _7888);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(std::shared_ptr< monty::ndarray< int,1 > > _7893,std::shared_ptr< monty::ndarray< int,1 > > _7894,std::shared_ptr< monty::ndarray< double,1 > > _7895);
static  monty::rc_ptr< ::mosek::fusion::Matrix > sparse(int _7900,int _7901,std::shared_ptr< monty::ndarray< int,1 > > _7902,std::shared_ptr< monty::ndarray< int,1 > > _7903,std::shared_ptr< monty::ndarray< double,1 > > _7904);
virtual double get(int _7909,int _7910) { throw monty::AbstractClassError("Call to abstract method"); }
virtual bool isSparse() { throw monty::AbstractClassError("Call to abstract method"); }
virtual std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() { throw monty::AbstractClassError("Call to abstract method"); }
virtual void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _7911,std::shared_ptr< monty::ndarray< int,1 > > _7912,std::shared_ptr< monty::ndarray< double,1 > > _7913) { throw monty::AbstractClassError("Call to abstract method"); }
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { throw monty::AbstractClassError("Call to abstract method"); }
virtual long long numNonzeros() { throw monty::AbstractClassError("Call to abstract method"); }
virtual int numColumns() ;
virtual int numRows() ;
}; // struct Matrix;

struct p_DenseMatrix : public ::mosek::fusion::p_Matrix
{
DenseMatrix * _pubthis;
static mosek::fusion::p_DenseMatrix* _get_impl(mosek::fusion::DenseMatrix * _inst){ return static_cast< mosek::fusion::p_DenseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_DenseMatrix * _get_impl(mosek::fusion::DenseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_DenseMatrix(DenseMatrix * _pubthis);
virtual ~p_DenseMatrix() { /* std::cout << "~p_DenseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > data{};virtual void destroy();
static DenseMatrix::t _new_DenseMatrix(int _7696,int _7697,std::shared_ptr< monty::ndarray< double,1 > > _7698);
void _initialize(int _7696,int _7697,std::shared_ptr< monty::ndarray< double,1 > > _7698);
static DenseMatrix::t _new_DenseMatrix(monty::rc_ptr< ::mosek::fusion::Matrix > _7699);
void _initialize(monty::rc_ptr< ::mosek::fusion::Matrix > _7699);
static DenseMatrix::t _new_DenseMatrix(std::shared_ptr< monty::ndarray< double,2 > > _7704);
void _initialize(std::shared_ptr< monty::ndarray< double,2 > > _7704);
static DenseMatrix::t _new_DenseMatrix(int _7707,int _7708,double _7709);
void _initialize(int _7707,int _7708,double _7709);
virtual /* override */ std::string toString() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2DenseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2DenseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _7722,std::shared_ptr< monty::ndarray< int,1 > > _7723,std::shared_ptr< monty::ndarray< double,1 > > _7724) ;
virtual /* override */ double get(int _7728,int _7729) ;
virtual /* override */ long long numNonzeros() ;
}; // struct DenseMatrix;

struct p_SparseMatrix : public ::mosek::fusion::p_Matrix
{
SparseMatrix * _pubthis;
static mosek::fusion::p_SparseMatrix* _get_impl(mosek::fusion::SparseMatrix * _inst){ return static_cast< mosek::fusion::p_SparseMatrix* >(mosek::fusion::p_Matrix::_get_impl(_inst)); }
static mosek::fusion::p_SparseMatrix * _get_impl(mosek::fusion::SparseMatrix::t _inst) { return _get_impl(_inst.get()); }
p_SparseMatrix(SparseMatrix * _pubthis);
virtual ~p_SparseMatrix() { /* std::cout << "~p_SparseMatrix" << std::endl;*/ };
long long nnz{};std::shared_ptr< monty::ndarray< double,1 > > val{};std::shared_ptr< monty::ndarray< int,1 > > subj{};std::shared_ptr< monty::ndarray< int,1 > > subi{};virtual void destroy();
static SparseMatrix::t _new_SparseMatrix(int _7730,int _7731,std::shared_ptr< monty::ndarray< int,1 > > _7732,std::shared_ptr< monty::ndarray< int,1 > > _7733,std::shared_ptr< monty::ndarray< double,1 > > _7734,long long _7735);
void _initialize(int _7730,int _7731,std::shared_ptr< monty::ndarray< int,1 > > _7732,std::shared_ptr< monty::ndarray< int,1 > > _7733,std::shared_ptr< monty::ndarray< double,1 > > _7734,long long _7735);
static SparseMatrix::t _new_SparseMatrix(int _7741,int _7742,std::shared_ptr< monty::ndarray< int,1 > > _7743,std::shared_ptr< monty::ndarray< int,1 > > _7744,std::shared_ptr< monty::ndarray< double,1 > > _7745);
void _initialize(int _7741,int _7742,std::shared_ptr< monty::ndarray< int,1 > > _7743,std::shared_ptr< monty::ndarray< int,1 > > _7744,std::shared_ptr< monty::ndarray< double,1 > > _7745);
virtual std::shared_ptr< monty::ndarray< long long,1 > > formPtrb() ;
virtual /* override */ std::string toString() ;
virtual /* override */ long long numNonzeros() ;
virtual /* override */ monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2SparseMatrix__transpose() ;
virtual monty::rc_ptr< ::mosek::fusion::Matrix > __mosek_2fusion_2Matrix__transpose() { return __mosek_2fusion_2SparseMatrix__transpose(); }
virtual /* override */ bool isSparse() ;
virtual /* override */ std::shared_ptr< monty::ndarray< double,1 > > getDataAsArray() ;
virtual /* override */ void getDataAsTriplets(std::shared_ptr< monty::ndarray< int,1 > > _7757,std::shared_ptr< monty::ndarray< int,1 > > _7758,std::shared_ptr< monty::ndarray< double,1 > > _7759) ;
virtual /* override */ double get(int _7760,int _7761) ;
}; // struct SparseMatrix;

struct p_LinkedBlocks
{
LinkedBlocks * _pubthis;
static mosek::fusion::p_LinkedBlocks* _get_impl(mosek::fusion::LinkedBlocks * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedBlocks * _get_impl(mosek::fusion::LinkedBlocks::t _inst) { return _get_impl(_inst.get()); }
p_LinkedBlocks(LinkedBlocks * _pubthis);
virtual ~p_LinkedBlocks() { /* std::cout << "~p_LinkedBlocks" << std::endl;*/ };
std::shared_ptr< monty::ndarray< int,1 > > bfirst{};std::shared_ptr< monty::ndarray< int,1 > > bsize{};monty::rc_ptr< ::mosek::fusion::LinkedInts > blocks{};monty::rc_ptr< ::mosek::fusion::LinkedInts > ints{};virtual void destroy();
static LinkedBlocks::t _new_LinkedBlocks();
void _initialize();
static LinkedBlocks::t _new_LinkedBlocks(int _7939);
void _initialize(int _7939);
static LinkedBlocks::t _new_LinkedBlocks(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _7940);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedBlocks > _7940);
virtual void free(int _7941) ;
virtual int alloc(int _7943) ;
virtual int maxidx(int _7948) ;
virtual void get(int _7949,std::shared_ptr< monty::ndarray< int,1 > > _7950,int _7951) ;
virtual int numblocks() ;
virtual int blocksize(int _7952) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedBlocks;

struct p_LinkedInts
{
LinkedInts * _pubthis;
static mosek::fusion::p_LinkedInts* _get_impl(mosek::fusion::LinkedInts * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_LinkedInts * _get_impl(mosek::fusion::LinkedInts::t _inst) { return _get_impl(_inst.get()); }
p_LinkedInts(LinkedInts * _pubthis);
virtual ~p_LinkedInts() { /* std::cout << "~p_LinkedInts" << std::endl;*/ };
int nfree{};int last_free{};int first_free{};int first_used{};std::shared_ptr< monty::ndarray< int,1 > > prev{};std::shared_ptr< monty::ndarray< int,1 > > next{};virtual void destroy();
static LinkedInts::t _new_LinkedInts(int _7953);
void _initialize(int _7953);
static LinkedInts::t _new_LinkedInts();
void _initialize();
static LinkedInts::t _new_LinkedInts(monty::rc_ptr< ::mosek::fusion::LinkedInts > _7956);
void _initialize(monty::rc_ptr< ::mosek::fusion::LinkedInts > _7956);
virtual void free(int _7957,int _7958) ;
virtual int alloc() ;
virtual int alloc(int _7964) ;
virtual void alloc(int _7965,std::shared_ptr< monty::ndarray< int,1 > > _7966,int _7967) ;
virtual void get(int _7970,int _7971,std::shared_ptr< monty::ndarray< int,1 > > _7972,int _7973) ;
virtual int maxidx(int _7976,int _7977) ;
virtual int allocblock(int _7981) ;
virtual void recap(int _7987) ;
virtual int capacity() ;
virtual bool validate() ;
}; // struct LinkedInts;

struct p_Parameters
{
Parameters * _pubthis;
static mosek::fusion::p_Parameters* _get_impl(mosek::fusion::Parameters * _inst){ assert(_inst); assert(_inst->_impl); return _inst->_impl; }
static mosek::fusion::p_Parameters * _get_impl(mosek::fusion::Parameters::t _inst) { return _get_impl(_inst.get()); }
p_Parameters(Parameters * _pubthis);
virtual ~p_Parameters() { /* std::cout << "~p_Parameters" << std::endl;*/ };
virtual void destroy();
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _7996,const std::string &  _7997,double _7998);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _8092,const std::string &  _8093,int _8094);
static  void setParameter(monty::rc_ptr< ::mosek::fusion::Model > _8188,const std::string &  _8189,const std::string &  _8190);
static  int string_to_variabletype_value(const std::string &  _8428);
static  int string_to_value_value(const std::string &  _8429);
static  int string_to_streamtype_value(const std::string &  _8430);
static  int string_to_startpointtype_value(const std::string &  _8431);
static  int string_to_stakey_value(const std::string &  _8432);
static  int string_to_sparam_value(const std::string &  _8433);
static  int string_to_solveform_value(const std::string &  _8434);
static  int string_to_soltype_value(const std::string &  _8435);
static  int string_to_solsta_value(const std::string &  _8436);
static  int string_to_solitem_value(const std::string &  _8437);
static  int string_to_simseltype_value(const std::string &  _8438);
static  int string_to_sensitivitytype_value(const std::string &  _8439);
static  int string_to_scalingmethod_value(const std::string &  _8440);
static  int string_to_scalingtype_value(const std::string &  _8441);
static  int string_to_rescodetype_value(const std::string &  _8442);
static  int string_to_rescode_value(const std::string &  _8443);
static  int string_to_xmlwriteroutputtype_value(const std::string &  _8444);
static  int string_to_prosta_value(const std::string &  _8445);
static  int string_to_problemtype_value(const std::string &  _8446);
static  int string_to_problemitem_value(const std::string &  _8447);
static  int string_to_parametertype_value(const std::string &  _8448);
static  int string_to_presolvemode_value(const std::string &  _8449);
static  int string_to_orderingtype_value(const std::string &  _8450);
static  int string_to_optimizertype_value(const std::string &  _8451);
static  int string_to_onoffkey_value(const std::string &  _8452);
static  int string_to_objsense_value(const std::string &  _8453);
static  int string_to_mpsformat_value(const std::string &  _8454);
static  int string_to_mionodeseltype_value(const std::string &  _8455);
static  int string_to_miomode_value(const std::string &  _8456);
static  int string_to_miocontsoltype_value(const std::string &  _8457);
static  int string_to_branchdir_value(const std::string &  _8458);
static  int string_to_iparam_value(const std::string &  _8459);
static  int string_to_iomode_value(const std::string &  _8460);
static  int string_to_internal_iinf_value(const std::string &  _8461);
static  int string_to_internal_dinf_value(const std::string &  _8462);
static  int string_to_inftype_value(const std::string &  _8463);
static  int string_to_iinfitem_value(const std::string &  _8464);
static  int string_to_internal_liinf_value(const std::string &  _8465);
static  int string_to_liinfitem_value(const std::string &  _8466);
static  int string_to_dparam_value(const std::string &  _8467);
static  int string_to_feature_value(const std::string &  _8468);
static  int string_to_dinfitem_value(const std::string &  _8469);
static  int string_to_dataformat_value(const std::string &  _8470);
static  int string_to_symmattype_value(const std::string &  _8471);
static  int string_to_scopr_value(const std::string &  _8472);
static  int string_to_nametype_value(const std::string &  _8473);
static  int string_to_conetype_value(const std::string &  _8474);
static  int string_to_compresstype_value(const std::string &  _8475);
static  int string_to_checkconvexitytype_value(const std::string &  _8476);
static  int string_to_callbackcode_value(const std::string &  _8477);
static  int string_to_purify_value(const std::string &  _8478);
static  int string_to_intpnthotstart_value(const std::string &  _8479);
static  int string_to_simhotstart_value(const std::string &  _8480);
static  int string_to_simdupvec_value(const std::string &  _8481);
static  int string_to_simreform_value(const std::string &  _8482);
static  int string_to_uplo_value(const std::string &  _8483);
static  int string_to_transpose_value(const std::string &  _8484);
static  int string_to_simdegen_value(const std::string &  _8485);
static  int string_to_mark_value(const std::string &  _8486);
static  int string_to_boundkey_value(const std::string &  _8487);
static  int string_to_basindtype_value(const std::string &  _8488);
static  int string_to_language_value(const std::string &  _8489);
}; // struct Parameters;

}
}
namespace mosek
{
namespace fusion
{
namespace Utils
{
// mosek.fusion.Utils.IntMap from file 'src/fusion/cxx/IntMap_p.h'
struct p_IntMap 
{
  IntMap * _pubself;

  static p_IntMap * _get_impl(IntMap * _inst) { return _inst->_impl.get(); }

  p_IntMap(IntMap * _pubself) : _pubself(_pubself) {}

  static IntMap::t _new_IntMap() { return new IntMap(); }

  ::std::unordered_map<long long,int> m;

  bool hasItem (long long key) { return m.find(key) != m.end(); }
  int  getItem (long long key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (long long key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<long long,1>> keys()
  { 
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<long long,1>>(new monty::ndarray<long long,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;    
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  IntMap::t clone();
  IntMap::t __mosek_2fusion_2Utils_2IntMap__clone();
};



struct p_StringIntMap
{
  StringIntMap * _pubself;

  static p_StringIntMap * _get_impl(StringIntMap * _inst) { return _inst->_impl.get(); }

  p_StringIntMap(StringIntMap * _pubself) : _pubself(_pubself) {}

  static StringIntMap::t _new_StringIntMap() { return new StringIntMap(); }

  ::std::unordered_map<std::string,int> m;

  bool hasItem (const std::string & key) { return m.find(key) != m.end(); }
  int  getItem (const std::string & key) { return m.find(key)->second; } // will probably throw something or crash of no such key
  void setItem (const std::string & key, int val) { m[key] = val; }

  std::shared_ptr<monty::ndarray<std::string,1>> keys()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<std::string,1>>(new monty::ndarray<std::string,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->first;

    return res;
  }

  std::shared_ptr<monty::ndarray<int,1>> values()
  {
    size_t size = m.size();
    auto res = std::shared_ptr<monty::ndarray<int,1>>(new monty::ndarray<int,1>(monty::shape((int)size)));

    ptrdiff_t i = 0;
    for (auto it = m.begin(); it != m.end(); ++it)
      (*res)[i++] = it->second;

    return res;
  }

  StringIntMap::t clone();
  StringIntMap::t __mosek_2fusion_2Utils_2StringIntMap__clone();
};
// End of file 'src/fusion/cxx/IntMap_p.h'
// mosek.fusion.Utils.StringBuffer from file 'src/fusion/cxx/StringBuffer_p.h'
// namespace mosek::fusion::Utils
struct p_StringBuffer
{
  StringBuffer * _pubthis; 
  std::stringstream ss;

  p_StringBuffer(StringBuffer * _pubthis) : _pubthis(_pubthis) {}

  static p_StringBuffer * _get_impl(StringBuffer::t ptr) { return ptr->_impl.get(); }
  static p_StringBuffer * _get_impl(StringBuffer * ptr) { return ptr->_impl.get(); }

  static StringBuffer::t _new_StringBuffer() { return new StringBuffer(); }

  StringBuffer::t clear ();
  
  StringBuffer::t a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t a (const monty::ndarray<int,1> & val);
  StringBuffer::t a (const monty::ndarray<long long,1> & val);
  StringBuffer::t a (const monty::ndarray<double,1> & val);
  

  StringBuffer::t a (const int & val);
  StringBuffer::t a (const long long & val);
  StringBuffer::t a (const double & val);
  StringBuffer::t a (const bool & val);
  StringBuffer::t a (const std::string & val);

  StringBuffer::t lf ();
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__clear ();

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<std::string,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<int,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<long long,1> & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const monty::ndarray<double,1> & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const int & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const long long & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const double & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const bool & val);
  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__a (const std::string & val);

  StringBuffer::t __mosek_2fusion_2Utils_2StringBuffer__lf ();

  std::string toString () const;
};
// End of file 'src/fusion/cxx/StringBuffer_p.h'
}
}
}
#endif
